"""
Question
--------
Which gene-duplicated enzymes exist in Deltaproteobacteria?
Does their existence increase redundancy? If yes, how much?

Method
------
- get Deltaproteobacteria
- get and print gene-duplicated enzyme pairs
- calculate redundancy
- REPEAT for each gene-duplicated enzyme
-     print number of enzymes the gene-duplicated enzyme provides redundancy for (robustness and flexibility)

Result
------

::
    core metabolism majority: 80%

    Deltaproteobacteria:
    
    core metabolism enzymes: 21519
    
    gene-duplicated enzyme pairs: 5561
    (ade:Adeh_0005, ade:Adeh_2750)
    (ade:Adeh_0012, ade:Adeh_2390)
    (ade:Adeh_0012, ade:Adeh_2727)
    (ade:Adeh_0036, ade:Adeh_0038)
    (ade:Adeh_0069, ade:Adeh_4344)
    (ade:Adeh_0171, ade:Adeh_0588)
    (ade:Adeh_0221, ade:Adeh_1954)
    (ade:Adeh_0221, ade:Adeh_1955)
    (ade:Adeh_0221, ade:Adeh_4288)
    (ade:Adeh_0255, ade:Adeh_1600)
    (ade:Adeh_0255, ade:Adeh_2078)
    (ade:Adeh_0255, ade:Adeh_3927)
    (ade:Adeh_0295, ade:Adeh_2597)
    (ade:Adeh_0533, ade:Adeh_1731)
    (ade:Adeh_0533, ade:Adeh_2315)
    (ade:Adeh_0592, ade:Adeh_1048)
    (ade:Adeh_0768, ade:Adeh_3694)
    (ade:Adeh_0821, ade:Adeh_1830)
    (ade:Adeh_0925, ade:Adeh_1165)
    (ade:Adeh_0925, ade:Adeh_2345)
    (ade:Adeh_0925, ade:Adeh_2359)
    (ade:Adeh_0925, ade:Adeh_2886)
    (ade:Adeh_1015, ade:Adeh_1978)
    (ade:Adeh_1052, ade:Adeh_2654)
    (ade:Adeh_1052, ade:Adeh_3428)
    (ade:Adeh_1057, ade:Adeh_4305)
    (ade:Adeh_1078, ade:Adeh_2533)
    (ade:Adeh_1165, ade:Adeh_2345)
    (ade:Adeh_1165, ade:Adeh_2359)
    (ade:Adeh_1165, ade:Adeh_2619)
    (ade:Adeh_1165, ade:Adeh_2886)
    (ade:Adeh_1280, ade:Adeh_2316)
    (ade:Adeh_1280, ade:Adeh_2668)
    (ade:Adeh_1312, ade:Adeh_3637)
    (ade:Adeh_1334, ade:Adeh_2434)
    (ade:Adeh_1600, ade:Adeh_2078)
    (ade:Adeh_1600, ade:Adeh_3927)
    (ade:Adeh_1613, ade:Adeh_2484)
    (ade:Adeh_1618, ade:Adeh_2691)
    (ade:Adeh_1638, ade:Adeh_3931)
    (ade:Adeh_1729, ade:Adeh_3514)
    (ade:Adeh_1954, ade:Adeh_1955)
    (ade:Adeh_1954, ade:Adeh_4288)
    (ade:Adeh_1955, ade:Adeh_4288)
    (ade:Adeh_1963, ade:Adeh_2867)
    (ade:Adeh_1981, ade:Adeh_2071)
    (ade:Adeh_1981, ade:Adeh_3037)
    (ade:Adeh_1994, ade:Adeh_2493)
    (ade:Adeh_2047, ade:Adeh_2619)
    (ade:Adeh_2047, ade:Adeh_3396)
    (ade:Adeh_2057, ade:Adeh_4242)
    (ade:Adeh_2078, ade:Adeh_3927)
    (ade:Adeh_2316, ade:Adeh_2668)
    (ade:Adeh_2345, ade:Adeh_2359)
    (ade:Adeh_2345, ade:Adeh_2886)
    (ade:Adeh_2349, ade:Adeh_3135)
    (ade:Adeh_2359, ade:Adeh_2886)
    (ade:Adeh_2390, ade:Adeh_2727)
    (ade:Adeh_2449, ade:Adeh_3774)
    (ade:Adeh_2533, ade:Adeh_2728)
    (ade:Adeh_2619, ade:Adeh_3396)
    (ade:Adeh_2748, ade:Adeh_2760)
    (ade:Adeh_2748, ade:Adeh_3141)
    (ade:Adeh_2760, ade:Adeh_3141)
    (ade:Adeh_2780, ade:Adeh_2789)
    (ade:Adeh_3748, ade:Adeh_4057)
    (ade:Adeh_3766, ade:Adeh_3767)
    (ade:Adeh_3766, ade:Adeh_3769)
    (ade:Adeh_3769, ade:Adeh_3772)
    (ade:Adeh_3784, ade:Adeh_4220)
    (ade:Adeh_3959, ade:Adeh_4206)
    (afw:Anae109_0005, afw:Anae109_2739)
    (afw:Anae109_0013, afw:Anae109_1477)
    (afw:Anae109_0013, afw:Anae109_2719)
    (afw:Anae109_0039, afw:Anae109_0041)
    (afw:Anae109_0070, afw:Anae109_4491)
    (afw:Anae109_0075, afw:Anae109_1348)
    (afw:Anae109_0087, afw:Anae109_2040)
    (afw:Anae109_0125, afw:Anae109_4122)
    (afw:Anae109_0180, afw:Anae109_0633)
    (afw:Anae109_0276, afw:Anae109_0508)
    (afw:Anae109_0276, afw:Anae109_2213)
    (afw:Anae109_0315, afw:Anae109_2025)
    (afw:Anae109_0315, afw:Anae109_3317)
    (afw:Anae109_0319, afw:Anae109_1264)
    (afw:Anae109_0323, afw:Anae109_2310)
    (afw:Anae109_0371, afw:Anae109_3865)
    (afw:Anae109_0462, afw:Anae109_4354)
    (afw:Anae109_0473, afw:Anae109_2361)
    (afw:Anae109_0473, afw:Anae109_3313)
    (afw:Anae109_0473, afw:Anae109_3360)
    (afw:Anae109_0508, afw:Anae109_2213)
    (afw:Anae109_0637, afw:Anae109_1098)
    (afw:Anae109_0814, afw:Anae109_3137)
    (afw:Anae109_0814, afw:Anae109_3823)
    (afw:Anae109_0859, afw:Anae109_1990)
    (afw:Anae109_0968, afw:Anae109_1212)
    (afw:Anae109_0968, afw:Anae109_1510)
    (afw:Anae109_0968, afw:Anae109_1529)
    (afw:Anae109_1089, afw:Anae109_1877)
    (afw:Anae109_1102, afw:Anae109_2639)
    (afw:Anae109_1117, afw:Anae109_1329)
    (afw:Anae109_1136, afw:Anae109_3317)
    (afw:Anae109_1212, afw:Anae109_1510)
    (afw:Anae109_1212, afw:Anae109_1529)
    (afw:Anae109_1212, afw:Anae109_2586)
    (afw:Anae109_1212, afw:Anae109_3170)
    (afw:Anae109_1374, afw:Anae109_1845)
    (afw:Anae109_1384, afw:Anae109_2198)
    (afw:Anae109_1418, afw:Anae109_3887)
    (afw:Anae109_1445, afw:Anae109_2433)
    (afw:Anae109_1477, afw:Anae109_2719)
    (afw:Anae109_1510, afw:Anae109_1529)
    (afw:Anae109_1524, afw:Anae109_3133)
    (afw:Anae109_1753, afw:Anae109_1874)
    (afw:Anae109_1767, afw:Anae109_2586)
    (afw:Anae109_1767, afw:Anae109_3170)
    (afw:Anae109_1767, afw:Anae109_3461)
    (afw:Anae109_1890, afw:Anae109_2921)
    (afw:Anae109_1900, afw:Anae109_1901)
    (afw:Anae109_1900, afw:Anae109_4196)
    (afw:Anae109_1900, afw:Anae109_4443)
    (afw:Anae109_1901, afw:Anae109_4196)
    (afw:Anae109_1901, afw:Anae109_4443)
    (afw:Anae109_2025, afw:Anae109_3317)
    (afw:Anae109_2026, afw:Anae109_2734)
    (afw:Anae109_2033, afw:Anae109_2552)
    (afw:Anae109_2033, afw:Anae109_2737)
    (afw:Anae109_2033, afw:Anae109_3255)
    (afw:Anae109_2033, afw:Anae109_3601)
    (afw:Anae109_2078, afw:Anae109_3605)
    (afw:Anae109_2183, afw:Anae109_3723)
    (afw:Anae109_2184, afw:Anae109_3724)
    (afw:Anae109_2193, afw:Anae109_2685)
    (afw:Anae109_2361, afw:Anae109_3313)
    (afw:Anae109_2361, afw:Anae109_3360)
    (afw:Anae109_2449, afw:Anae109_3095)
    (afw:Anae109_2451, afw:Anae109_3762)
    (afw:Anae109_2487, afw:Anae109_2647)
    (afw:Anae109_2487, afw:Anae109_3608)
    (afw:Anae109_2487, afw:Anae109_3609)
    (afw:Anae109_2552, afw:Anae109_2737)
    (afw:Anae109_2552, afw:Anae109_3255)
    (afw:Anae109_2552, afw:Anae109_3601)
    (afw:Anae109_2555, afw:Anae109_3065)
    (afw:Anae109_2555, afw:Anae109_3732)
    (afw:Anae109_2555, afw:Anae109_4129)
    (afw:Anae109_2586, afw:Anae109_3170)
    (afw:Anae109_2586, afw:Anae109_3461)
    (afw:Anae109_2647, afw:Anae109_3608)
    (afw:Anae109_2647, afw:Anae109_3609)
    (afw:Anae109_2737, afw:Anae109_3255)
    (afw:Anae109_2737, afw:Anae109_3601)
    (afw:Anae109_2737, afw:Anae109_4404)
    (afw:Anae109_3065, afw:Anae109_3732)
    (afw:Anae109_3065, afw:Anae109_4129)
    (afw:Anae109_3137, afw:Anae109_3823)
    (afw:Anae109_3159, afw:Anae109_3687)
    (afw:Anae109_3170, afw:Anae109_3461)
    (afw:Anae109_3213, afw:Anae109_4447)
    (afw:Anae109_3255, afw:Anae109_3601)
    (afw:Anae109_3255, afw:Anae109_4404)
    (afw:Anae109_3313, afw:Anae109_3360)
    (afw:Anae109_3601, afw:Anae109_4404)
    (afw:Anae109_3608, afw:Anae109_3609)
    (afw:Anae109_3721, afw:Anae109_4391)
    (afw:Anae109_3732, afw:Anae109_4129)
    (afw:Anae109_3879, afw:Anae109_3880)
    (afw:Anae109_3882, afw:Anae109_3885)
    (afw:Anae109_3904, afw:Anae109_4370)
    (afw:Anae109_4196, afw:Anae109_4443)
    (age:AA314_00262, age:AA314_06198)
    (age:AA314_00693, age:AA314_00918)
    (age:AA314_00693, age:AA314_07568)
    (age:AA314_00717, age:AA314_01479)
    (age:AA314_00717, age:AA314_02661)
    (age:AA314_00717, age:AA314_07475)
    (age:AA314_00717, age:AA314_07751)
    (age:AA314_00717, age:AA314_09037)
    (age:AA314_00859, age:AA314_04144)
    (age:AA314_00859, age:AA314_04323)
    (age:AA314_00859, age:AA314_04985)
    (age:AA314_00859, age:AA314_06374)
    (age:AA314_00861, age:AA314_04142)
    (age:AA314_00861, age:AA314_05245)
    (age:AA314_00861, age:AA314_07154)
    (age:AA314_00918, age:AA314_07568)
    (age:AA314_00945, age:AA314_01338)
    (age:AA314_00945, age:AA314_02687)
    (age:AA314_00945, age:AA314_04144)
    (age:AA314_00945, age:AA314_04323)
    (age:AA314_00945, age:AA314_04555)
    (age:AA314_00945, age:AA314_06106)
    (age:AA314_00945, age:AA314_06374)
    (age:AA314_00945, age:AA314_06470)
    (age:AA314_01105, age:AA314_01193)
    (age:AA314_01165, age:AA314_02872)
    (age:AA314_01165, age:AA314_04189)
    (age:AA314_01165, age:AA314_04447)
    (age:AA314_01165, age:AA314_05182)
    (age:AA314_01181, age:AA314_02279)
    (age:AA314_01271, age:AA314_07252)
    (age:AA314_01338, age:AA314_02687)
    (age:AA314_01338, age:AA314_04144)
    (age:AA314_01338, age:AA314_04323)
    (age:AA314_01338, age:AA314_04555)
    (age:AA314_01338, age:AA314_06106)
    (age:AA314_01338, age:AA314_06470)
    (age:AA314_01471, age:AA314_05564)
    (age:AA314_01471, age:AA314_05889)
    (age:AA314_01479, age:AA314_02661)
    (age:AA314_01479, age:AA314_07475)
    (age:AA314_01479, age:AA314_07751)
    (age:AA314_01479, age:AA314_09037)
    (age:AA314_01699, age:AA314_07241)
    (age:AA314_01881, age:AA314_06748)
    (age:AA314_01881, age:AA314_06815)
    (age:AA314_01912, age:AA314_02664)
    (age:AA314_01912, age:AA314_03054)
    (age:AA314_01912, age:AA314_08421)
    (age:AA314_01954, age:AA314_04924)
    (age:AA314_01954, age:AA314_06016)
    (age:AA314_01954, age:AA314_08615)
    (age:AA314_02310, age:AA314_02714)
    (age:AA314_02336, age:AA314_04456)
    (age:AA314_02543, age:AA314_07077)
    (age:AA314_02619, age:AA314_05583)
    (age:AA314_02661, age:AA314_07475)
    (age:AA314_02661, age:AA314_07751)
    (age:AA314_02661, age:AA314_09037)
    (age:AA314_02664, age:AA314_08421)
    (age:AA314_02687, age:AA314_04144)
    (age:AA314_02687, age:AA314_04323)
    (age:AA314_02687, age:AA314_06106)
    (age:AA314_02687, age:AA314_06374)
    (age:AA314_02687, age:AA314_06470)
    (age:AA314_02714, age:AA314_08455)
    (age:AA314_02716, age:AA314_06754)
    (age:AA314_02777, age:AA314_09026)
    (age:AA314_02872, age:AA314_04189)
    (age:AA314_02872, age:AA314_04447)
    (age:AA314_02872, age:AA314_05182)
    (age:AA314_02889, age:AA314_09937)
    (age:AA314_02893, age:AA314_02979)
    (age:AA314_02893, age:AA314_04761)
    (age:AA314_02893, age:AA314_05795)
    (age:AA314_02979, age:AA314_04761)
    (age:AA314_02979, age:AA314_05795)
    (age:AA314_03054, age:AA314_05014)
    (age:AA314_03054, age:AA314_06718)
    (age:AA314_03054, age:AA314_09050)
    (age:AA314_03054, age:AA314_09664)
    (age:AA314_03086, age:AA314_07107)
    (age:AA314_03097, age:AA314_07592)
    (age:AA314_03097, age:AA314_09587)
    (age:AA314_03158, age:AA314_03826)
    (age:AA314_03158, age:AA314_06684)
    (age:AA314_03216, age:AA314_06851)
    (age:AA314_03227, age:AA314_03289)
    (age:AA314_03227, age:AA314_04783)
    (age:AA314_03252, age:AA314_05227)
    (age:AA314_03514, age:AA314_05890)
    (age:AA314_03550, age:AA314_09055)
    (age:AA314_03763, age:AA314_07032)
    (age:AA314_03773, age:AA314_09947)
    (age:AA314_03826, age:AA314_06684)
    (age:AA314_04024, age:AA314_04935)
    (age:AA314_04141, age:AA314_07285)
    (age:AA314_04142, age:AA314_05245)
    (age:AA314_04142, age:AA314_07154)
    (age:AA314_04142, age:AA314_08648)
    (age:AA314_04144, age:AA314_04323)
    (age:AA314_04144, age:AA314_04555)
    (age:AA314_04144, age:AA314_04985)
    (age:AA314_04144, age:AA314_06106)
    (age:AA314_04144, age:AA314_06374)
    (age:AA314_04144, age:AA314_06470)
    (age:AA314_04146, age:AA314_04554)
    (age:AA314_04146, age:AA314_07327)
    (age:AA314_04146, age:AA314_08462)
    (age:AA314_04189, age:AA314_04447)
    (age:AA314_04189, age:AA314_05182)
    (age:AA314_04205, age:AA314_04258)
    (age:AA314_04323, age:AA314_04555)
    (age:AA314_04323, age:AA314_04985)
    (age:AA314_04323, age:AA314_06106)
    (age:AA314_04323, age:AA314_06374)
    (age:AA314_04323, age:AA314_06470)
    (age:AA314_04350, age:AA314_04970)
    (age:AA314_04350, age:AA314_05002)
    (age:AA314_04350, age:AA314_05003)
    (age:AA314_04350, age:AA314_05840)
    (age:AA314_04447, age:AA314_05182)
    (age:AA314_04554, age:AA314_07327)
    (age:AA314_04554, age:AA314_08462)
    (age:AA314_04555, age:AA314_06106)
    (age:AA314_04555, age:AA314_06470)
    (age:AA314_04761, age:AA314_05795)
    (age:AA314_04817, age:AA314_08305)
    (age:AA314_04822, age:AA314_09003)
    (age:AA314_04924, age:AA314_06016)
    (age:AA314_04924, age:AA314_08005)
    (age:AA314_04924, age:AA314_08206)
    (age:AA314_04924, age:AA314_08615)
    (age:AA314_04970, age:AA314_05003)
    (age:AA314_04985, age:AA314_06374)
    (age:AA314_05002, age:AA314_05003)
    (age:AA314_05002, age:AA314_05840)
    (age:AA314_05003, age:AA314_05840)
    (age:AA314_05007, age:AA314_05880)
    (age:AA314_05011, age:AA314_08837)
    (age:AA314_05014, age:AA314_06718)
    (age:AA314_05014, age:AA314_09050)
    (age:AA314_05014, age:AA314_09664)
    (age:AA314_05015, age:AA314_07252)
    (age:AA314_05117, age:AA314_09208)
    (age:AA314_05145, age:AA314_08225)
    (age:AA314_05446, age:AA314_07741)
    (age:AA314_05477, age:AA314_05512)
    (age:AA314_05564, age:AA314_05889)
    (age:AA314_05876, age:AA314_09030)
    (age:AA314_05977, age:AA314_06223)
    (age:AA314_06016, age:AA314_08005)
    (age:AA314_06016, age:AA314_08206)
    (age:AA314_06016, age:AA314_08615)
    (age:AA314_06106, age:AA314_06470)
    (age:AA314_06206, age:AA314_06989)
    (age:AA314_06374, age:AA314_06470)
    (age:AA314_06718, age:AA314_09050)
    (age:AA314_06718, age:AA314_09664)
    (age:AA314_06720, age:AA314_07499)
    (age:AA314_06748, age:AA314_06815)
    (age:AA314_07149, age:AA314_09276)
    (age:AA314_07327, age:AA314_08462)
    (age:AA314_07475, age:AA314_07751)
    (age:AA314_07475, age:AA314_09037)
    (age:AA314_07592, age:AA314_09587)
    (age:AA314_07751, age:AA314_09037)
    (age:AA314_08005, age:AA314_08206)
    (age:AA314_08007, age:AA314_08012)
    (age:AA314_08032, age:AA314_09460)
    (age:AA314_08206, age:AA314_08615)
    (age:AA314_08751, age:AA314_09705)
    (age:AA314_09027, age:AA314_09029)
    (age:AA314_09050, age:AA314_09664)
    (ank:AnaeK_0005, ank:AnaeK_2842)
    (ank:AnaeK_0012, ank:AnaeK_1474)
    (ank:AnaeK_0012, ank:AnaeK_2819)
    (ank:AnaeK_0040, ank:AnaeK_0042)
    (ank:AnaeK_0075, ank:AnaeK_4480)
    (ank:AnaeK_0081, ank:AnaeK_1337)
    (ank:AnaeK_0092, ank:AnaeK_2062)
    (ank:AnaeK_0180, ank:AnaeK_0623)
    (ank:AnaeK_0232, ank:AnaeK_1924)
    (ank:AnaeK_0232, ank:AnaeK_1925)
    (ank:AnaeK_0232, ank:AnaeK_4425)
    (ank:AnaeK_0265, ank:AnaeK_1799)
    (ank:AnaeK_0265, ank:AnaeK_2263)
    (ank:AnaeK_0265, ank:AnaeK_4035)
    (ank:AnaeK_0306, ank:AnaeK_1251)
    (ank:AnaeK_0565, ank:AnaeK_1558)
    (ank:AnaeK_0565, ank:AnaeK_2116)
    (ank:AnaeK_0627, ank:AnaeK_1104)
    (ank:AnaeK_0816, ank:AnaeK_3752)
    (ank:AnaeK_0869, ank:AnaeK_2030)
    (ank:AnaeK_0984, ank:AnaeK_1224)
    (ank:AnaeK_0984, ank:AnaeK_1505)
    (ank:AnaeK_0984, ank:AnaeK_1524)
    (ank:AnaeK_1073, ank:AnaeK_1900)
    (ank:AnaeK_1108, ank:AnaeK_2744)
    (ank:AnaeK_1108, ank:AnaeK_3509)
    (ank:AnaeK_1116, ank:AnaeK_4441)
    (ank:AnaeK_1137, ank:AnaeK_1316)
    (ank:AnaeK_1224, ank:AnaeK_1505)
    (ank:AnaeK_1224, ank:AnaeK_1524)
    (ank:AnaeK_1224, ank:AnaeK_2705)
    (ank:AnaeK_1362, ank:AnaeK_1884)
    (ank:AnaeK_1374, ank:AnaeK_2247)
    (ank:AnaeK_1410, ank:AnaeK_3830)
    (ank:AnaeK_1429, ank:AnaeK_2525)
    (ank:AnaeK_1474, ank:AnaeK_2819)
    (ank:AnaeK_1505, ank:AnaeK_1524)
    (ank:AnaeK_1520, ank:AnaeK_3243)
    (ank:AnaeK_1557, ank:AnaeK_2581)
    (ank:AnaeK_1557, ank:AnaeK_2759)
    (ank:AnaeK_1799, ank:AnaeK_2263)
    (ank:AnaeK_1799, ank:AnaeK_4035)
    (ank:AnaeK_1806, ank:AnaeK_1897)
    (ank:AnaeK_1821, ank:AnaeK_3452)
    (ank:AnaeK_1821, ank:AnaeK_4375)
    (ank:AnaeK_1897, ank:AnaeK_3135)
    (ank:AnaeK_1915, ank:AnaeK_2953)
    (ank:AnaeK_1924, ank:AnaeK_1925)
    (ank:AnaeK_1924, ank:AnaeK_4425)
    (ank:AnaeK_1925, ank:AnaeK_4425)
    (ank:AnaeK_2118, ank:AnaeK_3603)
    (ank:AnaeK_2124, ank:AnaeK_3579)
    (ank:AnaeK_2222, ank:AnaeK_4040)
    (ank:AnaeK_2242, ank:AnaeK_2784)
    (ank:AnaeK_2263, ank:AnaeK_4035)
    (ank:AnaeK_2548, ank:AnaeK_3695)
    (ank:AnaeK_2581, ank:AnaeK_2759)
    (ank:AnaeK_2649, ank:AnaeK_2840)
    (ank:AnaeK_2649, ank:AnaeK_2852)
    (ank:AnaeK_2649, ank:AnaeK_3245)
    (ank:AnaeK_2705, ank:AnaeK_3479)
    (ank:AnaeK_2840, ank:AnaeK_2852)
    (ank:AnaeK_2840, ank:AnaeK_3245)
    (ank:AnaeK_2852, ank:AnaeK_3245)
    (ank:AnaeK_3452, ank:AnaeK_4375)
    (ank:AnaeK_3805, ank:AnaeK_4173)
    (ank:AnaeK_3822, ank:AnaeK_3823)
    (ank:AnaeK_3822, ank:AnaeK_3825)
    (ank:AnaeK_3825, ank:AnaeK_3828)
    (ank:AnaeK_3839, ank:AnaeK_4353)
    (ank:AnaeK_4069, ank:AnaeK_4338)
    (ccro:CMC5_000130, ccro:CMC5_012020)
    (ccro:CMC5_000130, ccro:CMC5_044530)
    (ccro:CMC5_000390, ccro:CMC5_045840)
    (ccro:CMC5_000580, ccro:CMC5_059120)
    (ccro:CMC5_000670, ccro:CMC5_041690)
    (ccro:CMC5_000670, ccro:CMC5_043620)
    (ccro:CMC5_001320, ccro:CMC5_017730)
    (ccro:CMC5_001320, ccro:CMC5_069660)
    (ccro:CMC5_002670, ccro:CMC5_007870)
    (ccro:CMC5_002670, ccro:CMC5_034090)
    (ccro:CMC5_003310, ccro:CMC5_045520)
    (ccro:CMC5_003550, ccro:CMC5_029220)
    (ccro:CMC5_004340, ccro:CMC5_043060)
    (ccro:CMC5_006070, ccro:CMC5_064710)
    (ccro:CMC5_006290, ccro:CMC5_064420)
    (ccro:CMC5_007320, ccro:CMC5_030280)
    (ccro:CMC5_007720, ccro:CMC5_009420)
    (ccro:CMC5_007720, ccro:CMC5_078580)
    (ccro:CMC5_007870, ccro:CMC5_034090)
    (ccro:CMC5_008250, ccro:CMC5_011120)
    (ccro:CMC5_008250, ccro:CMC5_031580)
    (ccro:CMC5_008250, ccro:CMC5_041140)
    (ccro:CMC5_008250, ccro:CMC5_060030)
    (ccro:CMC5_008250, ccro:CMC5_060910)
    (ccro:CMC5_009420, ccro:CMC5_078580)
    (ccro:CMC5_010330, ccro:CMC5_060070)
    (ccro:CMC5_011120, ccro:CMC5_041140)
    (ccro:CMC5_011120, ccro:CMC5_060030)
    (ccro:CMC5_011120, ccro:CMC5_060910)
    (ccro:CMC5_011270, ccro:CMC5_011280)
    (ccro:CMC5_011270, ccro:CMC5_038680)
    (ccro:CMC5_011280, ccro:CMC5_038680)
    (ccro:CMC5_011930, ccro:CMC5_084110)
    (ccro:CMC5_012200, ccro:CMC5_020730)
    (ccro:CMC5_012370, ccro:CMC5_021730)
    (ccro:CMC5_012370, ccro:CMC5_021740)
    (ccro:CMC5_012370, ccro:CMC5_047480)
    (ccro:CMC5_012370, ccro:CMC5_047550)
    (ccro:CMC5_012370, ccro:CMC5_057100)
    (ccro:CMC5_012370, ccro:CMC5_075250)
    (ccro:CMC5_012370, ccro:CMC5_082820)
    (ccro:CMC5_012520, ccro:CMC5_019230)
    (ccro:CMC5_012520, ccro:CMC5_049960)
    (ccro:CMC5_013340, ccro:CMC5_043090)
    (ccro:CMC5_014820, ccro:CMC5_019550)
    (ccro:CMC5_014820, ccro:CMC5_069050)
    (ccro:CMC5_014950, ccro:CMC5_024850)
    (ccro:CMC5_016590, ccro:CMC5_046360)
    (ccro:CMC5_016590, ccro:CMC5_064330)
    (ccro:CMC5_016930, ccro:CMC5_017220)
    (ccro:CMC5_016930, ccro:CMC5_041050)
    (ccro:CMC5_017220, ccro:CMC5_041050)
    (ccro:CMC5_017680, ccro:CMC5_024890)
    (ccro:CMC5_017680, ccro:CMC5_061620)
    (ccro:CMC5_017710, ccro:CMC5_017730)
    (ccro:CMC5_017730, ccro:CMC5_069660)
    (ccro:CMC5_018350, ccro:CMC5_065650)
    (ccro:CMC5_019230, ccro:CMC5_049960)
    (ccro:CMC5_019550, ccro:CMC5_069050)
    (ccro:CMC5_021680, ccro:CMC5_048220)
    (ccro:CMC5_021730, ccro:CMC5_047480)
    (ccro:CMC5_021730, ccro:CMC5_057100)
    (ccro:CMC5_021730, ccro:CMC5_075250)
    (ccro:CMC5_021730, ccro:CMC5_082820)
    (ccro:CMC5_021740, ccro:CMC5_047550)
    (ccro:CMC5_021880, ccro:CMC5_032100)
    (ccro:CMC5_021880, ccro:CMC5_032690)
    (ccro:CMC5_021880, ccro:CMC5_032920)
    (ccro:CMC5_021880, ccro:CMC5_032960)
    (ccro:CMC5_022050, ccro:CMC5_061320)
    (ccro:CMC5_024200, ccro:CMC5_060070)
    (ccro:CMC5_024590, ccro:CMC5_024620)
    (ccro:CMC5_024890, ccro:CMC5_061620)
    (ccro:CMC5_025200, ccro:CMC5_061110)
    (ccro:CMC5_030970, ccro:CMC5_049140)
    (ccro:CMC5_031580, ccro:CMC5_041140)
    (ccro:CMC5_031580, ccro:CMC5_060030)
    (ccro:CMC5_031580, ccro:CMC5_060910)
    (ccro:CMC5_032100, ccro:CMC5_032690)
    (ccro:CMC5_032100, ccro:CMC5_032920)
    (ccro:CMC5_032100, ccro:CMC5_032960)
    (ccro:CMC5_032690, ccro:CMC5_032920)
    (ccro:CMC5_032690, ccro:CMC5_032960)
    (ccro:CMC5_032920, ccro:CMC5_032960)
    (ccro:CMC5_038260, ccro:CMC5_059220)
    (ccro:CMC5_041140, ccro:CMC5_060030)
    (ccro:CMC5_041140, ccro:CMC5_060910)
    (ccro:CMC5_041160, ccro:CMC5_053620)
    (ccro:CMC5_041160, ccro:CMC5_065510)
    (ccro:CMC5_041180, ccro:CMC5_061720)
    (ccro:CMC5_041180, ccro:CMC5_074240)
    (ccro:CMC5_041690, ccro:CMC5_043620)
    (ccro:CMC5_042410, ccro:CMC5_049960)
    (ccro:CMC5_043210, ccro:CMC5_071350)
    (ccro:CMC5_046360, ccro:CMC5_064330)
    (ccro:CMC5_046730, ccro:CMC5_076410)
    (ccro:CMC5_047480, ccro:CMC5_057100)
    (ccro:CMC5_047480, ccro:CMC5_075250)
    (ccro:CMC5_047480, ccro:CMC5_082820)
    (ccro:CMC5_047550, ccro:CMC5_057100)
    (ccro:CMC5_047550, ccro:CMC5_075250)
    (ccro:CMC5_047550, ccro:CMC5_082820)
    (ccro:CMC5_050070, ccro:CMC5_053730)
    (ccro:CMC5_051960, ccro:CMC5_052220)
    (ccro:CMC5_051960, ccro:CMC5_053140)
    (ccro:CMC5_051960, ccro:CMC5_068840)
    (ccro:CMC5_052220, ccro:CMC5_053140)
    (ccro:CMC5_052220, ccro:CMC5_068840)
    (ccro:CMC5_053140, ccro:CMC5_068840)
    (ccro:CMC5_057100, ccro:CMC5_075250)
    (ccro:CMC5_057100, ccro:CMC5_082820)
    (ccro:CMC5_060030, ccro:CMC5_060910)
    (ccro:CMC5_061720, ccro:CMC5_074240)
    (ccro:CMC5_064710, ccro:CMC5_064720)
    (ccro:CMC5_065360, ccro:CMC5_065390)
    (ccro:CMC5_070310, ccro:CMC5_078390)
    (ccro:CMC5_072280, ccro:CMC5_084320)
    (ccro:CMC5_075250, ccro:CMC5_082820)
    (ccx:COCOR_00090, ccx:COCOR_00142)
    (ccx:COCOR_00090, ccx:COCOR_01252)
    (ccx:COCOR_00090, ccx:COCOR_02980)
    (ccx:COCOR_00090, ccx:COCOR_07018)
    (ccx:COCOR_00142, ccx:COCOR_01252)
    (ccx:COCOR_00142, ccx:COCOR_02980)
    (ccx:COCOR_00142, ccx:COCOR_07018)
    (ccx:COCOR_00249, ccx:COCOR_02414)
    (ccx:COCOR_00269, ccx:COCOR_01340)
    (ccx:COCOR_00470, ccx:COCOR_03253)
    (ccx:COCOR_00572, ccx:COCOR_07437)
    (ccx:COCOR_00825, ccx:COCOR_06120)
    (ccx:COCOR_00865, ccx:COCOR_02069)
    (ccx:COCOR_00865, ccx:COCOR_02626)
    (ccx:COCOR_00865, ccx:COCOR_03532)
    (ccx:COCOR_00865, ccx:COCOR_04577)
    (ccx:COCOR_00865, ccx:COCOR_05866)
    (ccx:COCOR_00865, ccx:COCOR_07492)
    (ccx:COCOR_00905, ccx:COCOR_01538)
    (ccx:COCOR_00905, ccx:COCOR_02172)
    (ccx:COCOR_00905, ccx:COCOR_05520)
    (ccx:COCOR_00905, ccx:COCOR_06380)
    (ccx:COCOR_00928, ccx:COCOR_01588)
    (ccx:COCOR_00928, ccx:COCOR_02773)
    (ccx:COCOR_00984, ccx:COCOR_07093)
    (ccx:COCOR_00988, ccx:COCOR_01693)
    (ccx:COCOR_01033, ccx:COCOR_07628)
    (ccx:COCOR_01049, ccx:COCOR_01272)
    (ccx:COCOR_01180, ccx:COCOR_05367)
    (ccx:COCOR_01252, ccx:COCOR_02980)
    (ccx:COCOR_01252, ccx:COCOR_07018)
    (ccx:COCOR_01301, ccx:COCOR_07115)
    (ccx:COCOR_01538, ccx:COCOR_02172)
    (ccx:COCOR_01538, ccx:COCOR_04525)
    (ccx:COCOR_01538, ccx:COCOR_05103)
    (ccx:COCOR_01588, ccx:COCOR_02773)
    (ccx:COCOR_01667, ccx:COCOR_01974)
    (ccx:COCOR_01667, ccx:COCOR_03913)
    (ccx:COCOR_01916, ccx:COCOR_02243)
    (ccx:COCOR_01916, ccx:COCOR_07023)
    (ccx:COCOR_01974, ccx:COCOR_03913)
    (ccx:COCOR_01982, ccx:COCOR_04599)
    (ccx:COCOR_02062, ccx:COCOR_06741)
    (ccx:COCOR_02062, ccx:COCOR_07941)
    (ccx:COCOR_02063, ccx:COCOR_06741)
    (ccx:COCOR_02069, ccx:COCOR_02626)
    (ccx:COCOR_02069, ccx:COCOR_04577)
    (ccx:COCOR_02069, ccx:COCOR_07492)
    (ccx:COCOR_02172, ccx:COCOR_04525)
    (ccx:COCOR_02172, ccx:COCOR_05103)
    (ccx:COCOR_02172, ccx:COCOR_05520)
    (ccx:COCOR_02213, ccx:COCOR_03252)
    (ccx:COCOR_02243, ccx:COCOR_07023)
    (ccx:COCOR_02279, ccx:COCOR_03787)
    (ccx:COCOR_02328, ccx:COCOR_04690)
    (ccx:COCOR_02422, ccx:COCOR_05137)
    (ccx:COCOR_02459, ccx:COCOR_05075)
    (ccx:COCOR_02496, ccx:COCOR_02628)
    (ccx:COCOR_02496, ccx:COCOR_05867)
    (ccx:COCOR_02555, ccx:COCOR_04658)
    (ccx:COCOR_02623, ccx:COCOR_05546)
    (ccx:COCOR_02624, ccx:COCOR_07826)
    (ccx:COCOR_02626, ccx:COCOR_03532)
    (ccx:COCOR_02626, ccx:COCOR_04577)
    (ccx:COCOR_02626, ccx:COCOR_05866)
    (ccx:COCOR_02626, ccx:COCOR_07492)
    (ccx:COCOR_02626, ccx:COCOR_07830)
    (ccx:COCOR_02626, ccx:COCOR_07894)
    (ccx:COCOR_02628, ccx:COCOR_05867)
    (ccx:COCOR_02650, ccx:COCOR_03319)
    (ccx:COCOR_02650, ccx:COCOR_06667)
    (ccx:COCOR_02650, ccx:COCOR_07636)
    (ccx:COCOR_02664, ccx:COCOR_02713)
    (ccx:COCOR_02898, ccx:COCOR_03074)
    (ccx:COCOR_02898, ccx:COCOR_03963)
    (ccx:COCOR_02980, ccx:COCOR_07018)
    (ccx:COCOR_03005, ccx:COCOR_06306)
    (ccx:COCOR_03074, ccx:COCOR_03963)
    (ccx:COCOR_03074, ccx:COCOR_06071)
    (ccx:COCOR_03165, ccx:COCOR_06506)
    (ccx:COCOR_03165, ccx:COCOR_06732)
    (ccx:COCOR_03319, ccx:COCOR_06667)
    (ccx:COCOR_03319, ccx:COCOR_07636)
    (ccx:COCOR_03448, ccx:COCOR_05708)
    (ccx:COCOR_03448, ccx:COCOR_06476)
    (ccx:COCOR_03497, ccx:COCOR_05120)
    (ccx:COCOR_03532, ccx:COCOR_05866)
    (ccx:COCOR_03532, ccx:COCOR_07492)
    (ccx:COCOR_03708, ccx:COCOR_03904)
    (ccx:COCOR_03717, ccx:COCOR_07767)
    (ccx:COCOR_03732, ccx:COCOR_08029)
    (ccx:COCOR_03852, ccx:COCOR_05182)
    (ccx:COCOR_03852, ccx:COCOR_06092)
    (ccx:COCOR_03852, ccx:COCOR_06234)
    (ccx:COCOR_03852, ccx:COCOR_06497)
    (ccx:COCOR_03939, ccx:COCOR_04535)
    (ccx:COCOR_03939, ccx:COCOR_04536)
    (ccx:COCOR_03939, ccx:COCOR_04815)
    (ccx:COCOR_03963, ccx:COCOR_06071)
    (ccx:COCOR_04442, ccx:COCOR_05716)
    (ccx:COCOR_04525, ccx:COCOR_05103)
    (ccx:COCOR_04528, ccx:COCOR_06913)
    (ccx:COCOR_04535, ccx:COCOR_04536)
    (ccx:COCOR_04535, ccx:COCOR_04815)
    (ccx:COCOR_04536, ccx:COCOR_04815)
    (ccx:COCOR_04577, ccx:COCOR_05866)
    (ccx:COCOR_04577, ccx:COCOR_07492)
    (ccx:COCOR_04577, ccx:COCOR_07894)
    (ccx:COCOR_04847, ccx:COCOR_06741)
    (ccx:COCOR_05182, ccx:COCOR_06234)
    (ccx:COCOR_05182, ccx:COCOR_06497)
    (ccx:COCOR_05520, ccx:COCOR_06380)
    (ccx:COCOR_05708, ccx:COCOR_06476)
    (ccx:COCOR_05866, ccx:COCOR_07492)
    (ccx:COCOR_05866, ccx:COCOR_07894)
    (ccx:COCOR_05901, ccx:COCOR_07598)
    (ccx:COCOR_06092, ccx:COCOR_06234)
    (ccx:COCOR_06092, ccx:COCOR_06497)
    (ccx:COCOR_06234, ccx:COCOR_06497)
    (ccx:COCOR_06506, ccx:COCOR_06732)
    (ccx:COCOR_06667, ccx:COCOR_07636)
    (ccx:COCOR_06741, ccx:COCOR_07941)
    (ccx:COCOR_07492, ccx:COCOR_07894)
    (cfus:CYFUS_000149, cfus:CYFUS_001955)
    (cfus:CYFUS_000149, cfus:CYFUS_002692)
    (cfus:CYFUS_000149, cfus:CYFUS_008837)
    (cfus:CYFUS_000149, cfus:CYFUS_009732)
    (cfus:CYFUS_000192, cfus:CYFUS_001400)
    (cfus:CYFUS_000192, cfus:CYFUS_005572)
    (cfus:CYFUS_000192, cfus:CYFUS_007242)
    (cfus:CYFUS_000192, cfus:CYFUS_007657)
    (cfus:CYFUS_000307, cfus:CYFUS_001817)
    (cfus:CYFUS_000307, cfus:CYFUS_002267)
    (cfus:CYFUS_000307, cfus:CYFUS_002936)
    (cfus:CYFUS_000307, cfus:CYFUS_003470)
    (cfus:CYFUS_000313, cfus:CYFUS_009033)
    (cfus:CYFUS_000404, cfus:CYFUS_006579)
    (cfus:CYFUS_000404, cfus:CYFUS_007387)
    (cfus:CYFUS_000458, cfus:CYFUS_006893)
    (cfus:CYFUS_000596, cfus:CYFUS_002943)
    (cfus:CYFUS_000596, cfus:CYFUS_004460)
    (cfus:CYFUS_000596, cfus:CYFUS_005589)
    (cfus:CYFUS_000638, cfus:CYFUS_003276)
    (cfus:CYFUS_000638, cfus:CYFUS_003510)
    (cfus:CYFUS_000638, cfus:CYFUS_004387)
    (cfus:CYFUS_000671, cfus:CYFUS_001448)
    (cfus:CYFUS_000730, cfus:CYFUS_004539)
    (cfus:CYFUS_000730, cfus:CYFUS_005273)
    (cfus:CYFUS_000821, cfus:CYFUS_005582)
    (cfus:CYFUS_001050, cfus:CYFUS_002029)
    (cfus:CYFUS_001074, cfus:CYFUS_004176)
    (cfus:CYFUS_001210, cfus:CYFUS_002221)
    (cfus:CYFUS_001210, cfus:CYFUS_002381)
    (cfus:CYFUS_001210, cfus:CYFUS_002855)
    (cfus:CYFUS_001210, cfus:CYFUS_004967)
    (cfus:CYFUS_001210, cfus:CYFUS_007908)
    (cfus:CYFUS_001258, cfus:CYFUS_004693)
    (cfus:CYFUS_001258, cfus:CYFUS_008485)
    (cfus:CYFUS_001270, cfus:CYFUS_002275)
    (cfus:CYFUS_001270, cfus:CYFUS_004217)
    (cfus:CYFUS_001270, cfus:CYFUS_005417)
    (cfus:CYFUS_001311, cfus:CYFUS_004500)
    (cfus:CYFUS_001311, cfus:CYFUS_005495)
    (cfus:CYFUS_001311, cfus:CYFUS_006014)
    (cfus:CYFUS_001388, cfus:CYFUS_002610)
    (cfus:CYFUS_001388, cfus:CYFUS_009173)
    (cfus:CYFUS_001400, cfus:CYFUS_005572)
    (cfus:CYFUS_001400, cfus:CYFUS_007242)
    (cfus:CYFUS_001400, cfus:CYFUS_007657)
    (cfus:CYFUS_001459, cfus:CYFUS_002029)
    (cfus:CYFUS_001521, cfus:CYFUS_003871)
    (cfus:CYFUS_001521, cfus:CYFUS_007984)
    (cfus:CYFUS_001521, cfus:CYFUS_008295)
    (cfus:CYFUS_001768, cfus:CYFUS_008499)
    (cfus:CYFUS_001817, cfus:CYFUS_002267)
    (cfus:CYFUS_001817, cfus:CYFUS_002936)
    (cfus:CYFUS_001817, cfus:CYFUS_003470)
    (cfus:CYFUS_001817, cfus:CYFUS_004606)
    (cfus:CYFUS_001817, cfus:CYFUS_004932)
    (cfus:CYFUS_001817, cfus:CYFUS_005693)
    (cfus:CYFUS_001817, cfus:CYFUS_009647)
    (cfus:CYFUS_001840, cfus:CYFUS_003023)
    (cfus:CYFUS_001955, cfus:CYFUS_002692)
    (cfus:CYFUS_001955, cfus:CYFUS_008837)
    (cfus:CYFUS_001955, cfus:CYFUS_009732)
    (cfus:CYFUS_001961, cfus:CYFUS_004618)
    (cfus:CYFUS_002032, cfus:CYFUS_006565)
    (cfus:CYFUS_002120, cfus:CYFUS_002856)
    (cfus:CYFUS_002221, cfus:CYFUS_002381)
    (cfus:CYFUS_002221, cfus:CYFUS_004967)
    (cfus:CYFUS_002221, cfus:CYFUS_007908)
    (cfus:CYFUS_002221, cfus:CYFUS_008840)
    (cfus:CYFUS_002221, cfus:CYFUS_009460)
    (cfus:CYFUS_002267, cfus:CYFUS_002936)
    (cfus:CYFUS_002267, cfus:CYFUS_003470)
    (cfus:CYFUS_002267, cfus:CYFUS_004606)
    (cfus:CYFUS_002267, cfus:CYFUS_009647)
    (cfus:CYFUS_002275, cfus:CYFUS_004217)
    (cfus:CYFUS_002275, cfus:CYFUS_005417)
    (cfus:CYFUS_002369, cfus:CYFUS_002879)
    (cfus:CYFUS_002381, cfus:CYFUS_002855)
    (cfus:CYFUS_002381, cfus:CYFUS_004967)
    (cfus:CYFUS_002381, cfus:CYFUS_007908)
    (cfus:CYFUS_002381, cfus:CYFUS_008840)
    (cfus:CYFUS_002381, cfus:CYFUS_009460)
    (cfus:CYFUS_002434, cfus:CYFUS_003324)
    (cfus:CYFUS_002450, cfus:CYFUS_004248)
    (cfus:CYFUS_002450, cfus:CYFUS_007353)
    (cfus:CYFUS_002606, cfus:CYFUS_006545)
    (cfus:CYFUS_002610, cfus:CYFUS_009173)
    (cfus:CYFUS_002692, cfus:CYFUS_008837)
    (cfus:CYFUS_002692, cfus:CYFUS_009732)
    (cfus:CYFUS_002820, cfus:CYFUS_003468)
    (cfus:CYFUS_002842, cfus:CYFUS_003160)
    (cfus:CYFUS_002855, cfus:CYFUS_004967)
    (cfus:CYFUS_002856, cfus:CYFUS_007043)
    (cfus:CYFUS_002936, cfus:CYFUS_003470)
    (cfus:CYFUS_002936, cfus:CYFUS_004932)
    (cfus:CYFUS_002943, cfus:CYFUS_004460)
    (cfus:CYFUS_002943, cfus:CYFUS_005589)
    (cfus:CYFUS_002949, cfus:CYFUS_009170)
    (cfus:CYFUS_003161, cfus:CYFUS_004307)
    (cfus:CYFUS_003161, cfus:CYFUS_006411)
    (cfus:CYFUS_003161, cfus:CYFUS_006640)
    (cfus:CYFUS_003161, cfus:CYFUS_007182)
    (cfus:CYFUS_003276, cfus:CYFUS_003510)
    (cfus:CYFUS_003276, cfus:CYFUS_004387)
    (cfus:CYFUS_003469, cfus:CYFUS_006401)
    (cfus:CYFUS_003470, cfus:CYFUS_004606)
    (cfus:CYFUS_003470, cfus:CYFUS_004932)
    (cfus:CYFUS_003470, cfus:CYFUS_005693)
    (cfus:CYFUS_003470, cfus:CYFUS_009647)
    (cfus:CYFUS_003472, cfus:CYFUS_005114)
    (cfus:CYFUS_003510, cfus:CYFUS_004387)
    (cfus:CYFUS_003523, cfus:CYFUS_006116)
    (cfus:CYFUS_003761, cfus:CYFUS_009744)
    (cfus:CYFUS_003871, cfus:CYFUS_007827)
    (cfus:CYFUS_003871, cfus:CYFUS_007984)
    (cfus:CYFUS_003871, cfus:CYFUS_008295)
    (cfus:CYFUS_003871, cfus:CYFUS_009210)
    (cfus:CYFUS_003986, cfus:CYFUS_006415)
    (cfus:CYFUS_003986, cfus:CYFUS_007177)
    (cfus:CYFUS_003986, cfus:CYFUS_007179)
    (cfus:CYFUS_004217, cfus:CYFUS_005417)
    (cfus:CYFUS_004265, cfus:CYFUS_008059)
    (cfus:CYFUS_004276, cfus:CYFUS_008791)
    (cfus:CYFUS_004307, cfus:CYFUS_006411)
    (cfus:CYFUS_004307, cfus:CYFUS_006640)
    (cfus:CYFUS_004307, cfus:CYFUS_007182)
    (cfus:CYFUS_004460, cfus:CYFUS_005589)
    (cfus:CYFUS_004499, cfus:CYFUS_004500)
    (cfus:CYFUS_004499, cfus:CYFUS_006014)
    (cfus:CYFUS_004500, cfus:CYFUS_005495)
    (cfus:CYFUS_004500, cfus:CYFUS_006014)
    (cfus:CYFUS_004504, cfus:CYFUS_005533)
    (cfus:CYFUS_004522, cfus:CYFUS_005776)
    (cfus:CYFUS_004522, cfus:CYFUS_006707)
    (cfus:CYFUS_004522, cfus:CYFUS_007663)
    (cfus:CYFUS_004536, cfus:CYFUS_008610)
    (cfus:CYFUS_004539, cfus:CYFUS_005273)
    (cfus:CYFUS_004606, cfus:CYFUS_004932)
    (cfus:CYFUS_004606, cfus:CYFUS_005693)
    (cfus:CYFUS_004606, cfus:CYFUS_009647)
    (cfus:CYFUS_004674, cfus:CYFUS_007998)
    (cfus:CYFUS_004693, cfus:CYFUS_008485)
    (cfus:CYFUS_004967, cfus:CYFUS_007908)
    (cfus:CYFUS_004967, cfus:CYFUS_008840)
    (cfus:CYFUS_004967, cfus:CYFUS_009460)
    (cfus:CYFUS_005031, cfus:CYFUS_009048)
    (cfus:CYFUS_005491, cfus:CYFUS_005495)
    (cfus:CYFUS_005495, cfus:CYFUS_006014)
    (cfus:CYFUS_005532, cfus:CYFUS_006568)
    (cfus:CYFUS_005572, cfus:CYFUS_007242)
    (cfus:CYFUS_005572, cfus:CYFUS_007657)
    (cfus:CYFUS_005776, cfus:CYFUS_006707)
    (cfus:CYFUS_005776, cfus:CYFUS_007663)
    (cfus:CYFUS_006411, cfus:CYFUS_006640)
    (cfus:CYFUS_006411, cfus:CYFUS_007182)
    (cfus:CYFUS_006415, cfus:CYFUS_007177)
    (cfus:CYFUS_006415, cfus:CYFUS_007179)
    (cfus:CYFUS_006464, cfus:CYFUS_006709)
    (cfus:CYFUS_006464, cfus:CYFUS_009834)
    (cfus:CYFUS_006469, cfus:CYFUS_006834)
    (cfus:CYFUS_006469, cfus:CYFUS_008079)
    (cfus:CYFUS_006478, cfus:CYFUS_009491)
    (cfus:CYFUS_006579, cfus:CYFUS_007387)
    (cfus:CYFUS_006640, cfus:CYFUS_007182)
    (cfus:CYFUS_006704, cfus:CYFUS_008254)
    (cfus:CYFUS_006707, cfus:CYFUS_007663)
    (cfus:CYFUS_006709, cfus:CYFUS_009834)
    (cfus:CYFUS_006715, cfus:CYFUS_006729)
    (cfus:CYFUS_007112, cfus:CYFUS_008843)
    (cfus:CYFUS_007112, cfus:CYFUS_009233)
    (cfus:CYFUS_007177, cfus:CYFUS_007179)
    (cfus:CYFUS_007242, cfus:CYFUS_007657)
    (cfus:CYFUS_007446, cfus:CYFUS_009429)
    (cfus:CYFUS_007827, cfus:CYFUS_007984)
    (cfus:CYFUS_007834, cfus:CYFUS_007835)
    (cfus:CYFUS_007908, cfus:CYFUS_008840)
    (cfus:CYFUS_007908, cfus:CYFUS_009460)
    (cfus:CYFUS_007984, cfus:CYFUS_008295)
    (cfus:CYFUS_008837, cfus:CYFUS_009732)
    (cfus:CYFUS_008840, cfus:CYFUS_009460)
    (cfus:CYFUS_008843, cfus:CYFUS_009233)
    (daf:Desaf_0028, daf:Desaf_0050)
    (daf:Desaf_0090, daf:Desaf_0304)
    (daf:Desaf_0090, daf:Desaf_2455)
    (daf:Desaf_0090, daf:Desaf_2970)
    (daf:Desaf_0111, daf:Desaf_1564)
    (daf:Desaf_0187, daf:Desaf_0812)
    (daf:Desaf_0187, daf:Desaf_2392)
    (daf:Desaf_0304, daf:Desaf_2455)
    (daf:Desaf_0304, daf:Desaf_2970)
    (daf:Desaf_0322, daf:Desaf_1251)
    (daf:Desaf_0322, daf:Desaf_1391)
    (daf:Desaf_0322, daf:Desaf_2909)
    (daf:Desaf_0342, daf:Desaf_2972)
    (daf:Desaf_0400, daf:Desaf_0457)
    (daf:Desaf_0400, daf:Desaf_3210)
    (daf:Desaf_0400, daf:Desaf_3311)
    (daf:Desaf_0400, daf:Desaf_3668)
    (daf:Desaf_0457, daf:Desaf_3210)
    (daf:Desaf_0457, daf:Desaf_3311)
    (daf:Desaf_0457, daf:Desaf_3668)
    (daf:Desaf_0470, daf:Desaf_3600)
    (daf:Desaf_0481, daf:Desaf_1015)
    (daf:Desaf_0721, daf:Desaf_2280)
    (daf:Desaf_0721, daf:Desaf_2946)
    (daf:Desaf_0721, daf:Desaf_3133)
    (daf:Desaf_0721, daf:Desaf_3337)
    (daf:Desaf_0810, daf:Desaf_2350)
    (daf:Desaf_0812, daf:Desaf_2392)
    (daf:Desaf_0930, daf:Desaf_1776)
    (daf:Desaf_0973, daf:Desaf_1752)
    (daf:Desaf_0993, daf:Desaf_3315)
    (daf:Desaf_1004, daf:Desaf_1508)
    (daf:Desaf_1013, daf:Desaf_2132)
    (daf:Desaf_1013, daf:Desaf_2305)
    (daf:Desaf_1013, daf:Desaf_2415)
    (daf:Desaf_1014, daf:Desaf_1280)
    (daf:Desaf_1207, daf:Desaf_2369)
    (daf:Desaf_1251, daf:Desaf_1333)
    (daf:Desaf_1251, daf:Desaf_1391)
    (daf:Desaf_1251, daf:Desaf_2909)
    (daf:Desaf_1274, daf:Desaf_2261)
    (daf:Desaf_1333, daf:Desaf_2909)
    (daf:Desaf_1391, daf:Desaf_2909)
    (daf:Desaf_1392, daf:Desaf_3712)
    (daf:Desaf_1457, daf:Desaf_2339)
    (daf:Desaf_1457, daf:Desaf_2926)
    (daf:Desaf_1603, daf:Desaf_2183)
    (daf:Desaf_1964, daf:Desaf_2034)
    (daf:Desaf_2132, daf:Desaf_2305)
    (daf:Desaf_2132, daf:Desaf_2415)
    (daf:Desaf_2261, daf:Desaf_2481)
    (daf:Desaf_2280, daf:Desaf_2946)
    (daf:Desaf_2280, daf:Desaf_3337)
    (daf:Desaf_2308, daf:Desaf_2698)
    (daf:Desaf_2339, daf:Desaf_2926)
    (daf:Desaf_2347, daf:Desaf_3665)
    (daf:Desaf_2347, daf:Desaf_3676)
    (daf:Desaf_2349, daf:Desaf_3662)
    (daf:Desaf_2490, daf:Desaf_2502)
    (daf:Desaf_2490, daf:Desaf_3113)
    (daf:Desaf_2502, daf:Desaf_3113)
    (daf:Desaf_2509, daf:Desaf_3260)
    (daf:Desaf_2718, daf:Desaf_3263)
    (daf:Desaf_2806, daf:Desaf_3667)
    (daf:Desaf_2884, daf:Desaf_2887)
    (daf:Desaf_2906, daf:Desaf_2907)
    (daf:Desaf_2946, daf:Desaf_3133)
    (daf:Desaf_2946, daf:Desaf_3337)
    (daf:Desaf_3002, daf:Desaf_3326)
    (daf:Desaf_3133, daf:Desaf_3337)
    (daf:Desaf_3210, daf:Desaf_3311)
    (daf:Desaf_3210, daf:Desaf_3668)
    (daf:Desaf_3311, daf:Desaf_3668)
    (daf:Desaf_3665, daf:Desaf_3676)
    (dak:DaAHT2_0034, dak:DaAHT2_2095)
    (dak:DaAHT2_0075, dak:DaAHT2_0308)
    (dak:DaAHT2_0099, dak:DaAHT2_0356)
    (dak:DaAHT2_0100, dak:DaAHT2_0107)
    (dak:DaAHT2_0100, dak:DaAHT2_1131)
    (dak:DaAHT2_0107, dak:DaAHT2_1131)
    (dak:DaAHT2_0190, dak:DaAHT2_1753)
    (dak:DaAHT2_0190, dak:DaAHT2_2482)
    (dak:DaAHT2_0251, dak:DaAHT2_2607)
    (dak:DaAHT2_0430, dak:DaAHT2_1512)
    (dak:DaAHT2_0472, dak:DaAHT2_1051)
    (dak:DaAHT2_0472, dak:DaAHT2_1178)
    (dak:DaAHT2_0507, dak:DaAHT2_1995)
    (dak:DaAHT2_0543, dak:DaAHT2_0807)
    (dak:DaAHT2_0884, dak:DaAHT2_2657)
    (dak:DaAHT2_0891, dak:DaAHT2_2512)
    (dak:DaAHT2_0908, dak:DaAHT2_1365)
    (dak:DaAHT2_1051, dak:DaAHT2_1178)
    (dak:DaAHT2_1113, dak:DaAHT2_1134)
    (dak:DaAHT2_1113, dak:DaAHT2_1284)
    (dak:DaAHT2_1120, dak:DaAHT2_1286)
    (dak:DaAHT2_1134, dak:DaAHT2_1284)
    (dak:DaAHT2_1248, dak:DaAHT2_1885)
    (dak:DaAHT2_1389, dak:DaAHT2_1390)
    (dak:DaAHT2_1389, dak:DaAHT2_1968)
    (dak:DaAHT2_1390, dak:DaAHT2_1968)
    (dak:DaAHT2_1480, dak:DaAHT2_1482)
    (dak:DaAHT2_1551, dak:DaAHT2_1596)
    (dak:DaAHT2_1636, dak:DaAHT2_2371)
    (dak:DaAHT2_1753, dak:DaAHT2_2482)
    (dak:DaAHT2_1790, dak:DaAHT2_1830)
    (dak:DaAHT2_1791, dak:DaAHT2_1792)
    (dak:DaAHT2_1791, dak:DaAHT2_1831)
    (dak:DaAHT2_1792, dak:DaAHT2_1794)
    (dak:DaAHT2_1792, dak:DaAHT2_1831)
    (dak:DaAHT2_1793, dak:DaAHT2_1833)
    (dak:DaAHT2_2211, dak:DaAHT2_2315)
    (dak:DaAHT2_2537, dak:DaAHT2_2561)
    (dal:Dalk_0003, dal:Dalk_2984)
    (dal:Dalk_0016, dal:Dalk_3482)
    (dal:Dalk_0017, dal:Dalk_3481)
    (dal:Dalk_0024, dal:Dalk_1998)
    (dal:Dalk_0066, dal:Dalk_0853)
    (dal:Dalk_0066, dal:Dalk_0939)
    (dal:Dalk_0066, dal:Dalk_1159)
    (dal:Dalk_0066, dal:Dalk_1587)
    (dal:Dalk_0066, dal:Dalk_3803)
    (dal:Dalk_0066, dal:Dalk_3886)
    (dal:Dalk_0066, dal:Dalk_4640)
    (dal:Dalk_0177, dal:Dalk_0935)
    (dal:Dalk_0244, dal:Dalk_0617)
    (dal:Dalk_0412, dal:Dalk_1414)
    (dal:Dalk_0412, dal:Dalk_4029)
    (dal:Dalk_0439, dal:Dalk_1103)
    (dal:Dalk_0475, dal:Dalk_1693)
    (dal:Dalk_0475, dal:Dalk_4104)
    (dal:Dalk_0497, dal:Dalk_1193)
    (dal:Dalk_0497, dal:Dalk_1770)
    (dal:Dalk_0559, dal:Dalk_1825)
    (dal:Dalk_0560, dal:Dalk_1397)
    (dal:Dalk_0560, dal:Dalk_4163)
    (dal:Dalk_0560, dal:Dalk_5019)
    (dal:Dalk_0564, dal:Dalk_0565)
    (dal:Dalk_0567, dal:Dalk_3370)
    (dal:Dalk_0568, dal:Dalk_1752)
    (dal:Dalk_0568, dal:Dalk_2721)
    (dal:Dalk_0634, dal:Dalk_1315)
    (dal:Dalk_0634, dal:Dalk_3651)
    (dal:Dalk_0635, dal:Dalk_1314)
    (dal:Dalk_0635, dal:Dalk_2581)
    (dal:Dalk_0769, dal:Dalk_3820)
    (dal:Dalk_0836, dal:Dalk_1064)
    (dal:Dalk_0853, dal:Dalk_0939)
    (dal:Dalk_0853, dal:Dalk_1159)
    (dal:Dalk_0853, dal:Dalk_1587)
    (dal:Dalk_0853, dal:Dalk_2329)
    (dal:Dalk_0853, dal:Dalk_3333)
    (dal:Dalk_0853, dal:Dalk_3803)
    (dal:Dalk_0853, dal:Dalk_3886)
    (dal:Dalk_0853, dal:Dalk_4640)
    (dal:Dalk_0888, dal:Dalk_2928)
    (dal:Dalk_0935, dal:Dalk_3370)
    (dal:Dalk_0939, dal:Dalk_1159)
    (dal:Dalk_0939, dal:Dalk_3803)
    (dal:Dalk_0939, dal:Dalk_3886)
    (dal:Dalk_0939, dal:Dalk_4640)
    (dal:Dalk_0954, dal:Dalk_2393)
    (dal:Dalk_1065, dal:Dalk_2752)
    (dal:Dalk_1066, dal:Dalk_2855)
    (dal:Dalk_1076, dal:Dalk_3893)
    (dal:Dalk_1159, dal:Dalk_3803)
    (dal:Dalk_1159, dal:Dalk_3886)
    (dal:Dalk_1193, dal:Dalk_1770)
    (dal:Dalk_1228, dal:Dalk_1438)
    (dal:Dalk_1240, dal:Dalk_1934)
    (dal:Dalk_1314, dal:Dalk_2581)
    (dal:Dalk_1315, dal:Dalk_3651)
    (dal:Dalk_1397, dal:Dalk_4163)
    (dal:Dalk_1397, dal:Dalk_5019)
    (dal:Dalk_1434, dal:Dalk_3962)
    (dal:Dalk_1587, dal:Dalk_2329)
    (dal:Dalk_1587, dal:Dalk_3333)
    (dal:Dalk_1587, dal:Dalk_3886)
    (dal:Dalk_1587, dal:Dalk_4640)
    (dal:Dalk_1693, dal:Dalk_1699)
    (dal:Dalk_1693, dal:Dalk_4104)
    (dal:Dalk_1699, dal:Dalk_4104)
    (dal:Dalk_1700, dal:Dalk_2445)
    (dal:Dalk_1704, dal:Dalk_1711)
    (dal:Dalk_1711, dal:Dalk_2541)
    (dal:Dalk_1711, dal:Dalk_3872)
    (dal:Dalk_1752, dal:Dalk_2721)
    (dal:Dalk_1754, dal:Dalk_3440)
    (dal:Dalk_1784, dal:Dalk_2756)
    (dal:Dalk_2329, dal:Dalk_3333)
    (dal:Dalk_2329, dal:Dalk_4640)
    (dal:Dalk_2506, dal:Dalk_3253)
    (dal:Dalk_2541, dal:Dalk_3872)
    (dal:Dalk_2573, dal:Dalk_3177)
    (dal:Dalk_2649, dal:Dalk_5220)
    (dal:Dalk_2651, dal:Dalk_3820)
    (dal:Dalk_3130, dal:Dalk_3133)
    (dal:Dalk_3135, dal:Dalk_3136)
    (dal:Dalk_3307, dal:Dalk_3912)
    (dal:Dalk_3307, dal:Dalk_4854)
    (dal:Dalk_3333, dal:Dalk_4640)
    (dal:Dalk_3803, dal:Dalk_3886)
    (dal:Dalk_3886, dal:Dalk_4640)
    (dal:Dalk_3901, dal:Dalk_4201)
    (dal:Dalk_3912, dal:Dalk_4854)
    (dal:Dalk_4163, dal:Dalk_5019)
    (dal:Dalk_4695, dal:Dalk_4696)
    (dao:Desac_0009, dao:Desac_2478)
    (dao:Desac_0097, dao:Desac_0099)
    (dao:Desac_0208, dao:Desac_1395)
    (dao:Desac_0239, dao:Desac_2541)
    (dao:Desac_0239, dao:Desac_2544)
    (dao:Desac_0259, dao:Desac_1090)
    (dao:Desac_0291, dao:Desac_1883)
    (dao:Desac_0292, dao:Desac_2517)
    (dao:Desac_0299, dao:Desac_0436)
    (dao:Desac_0299, dao:Desac_1133)
    (dao:Desac_0299, dao:Desac_1607)
    (dao:Desac_0299, dao:Desac_1774)
    (dao:Desac_0299, dao:Desac_2394)
    (dao:Desac_0380, dao:Desac_2427)
    (dao:Desac_0436, dao:Desac_1133)
    (dao:Desac_0436, dao:Desac_1607)
    (dao:Desac_0436, dao:Desac_1774)
    (dao:Desac_0436, dao:Desac_2394)
    (dao:Desac_0448, dao:Desac_2817)
    (dao:Desac_0519, dao:Desac_2462)
    (dao:Desac_0596, dao:Desac_0601)
    (dao:Desac_0599, dao:Desac_0602)
    (dao:Desac_0671, dao:Desac_1973)
    (dao:Desac_0739, dao:Desac_2680)
    (dao:Desac_0932, dao:Desac_1335)
    (dao:Desac_0932, dao:Desac_1664)
    (dao:Desac_0932, dao:Desac_2664)
    (dao:Desac_0945, dao:Desac_2715)
    (dao:Desac_0972, dao:Desac_2722)
    (dao:Desac_1050, dao:Desac_2147)
    (dao:Desac_1107, dao:Desac_2412)
    (dao:Desac_1133, dao:Desac_1607)
    (dao:Desac_1133, dao:Desac_1774)
    (dao:Desac_1133, dao:Desac_2394)
    (dao:Desac_1164, dao:Desac_1681)
    (dao:Desac_1164, dao:Desac_2831)
    (dao:Desac_1186, dao:Desac_1840)
    (dao:Desac_1186, dao:Desac_2015)
    (dao:Desac_1281, dao:Desac_1859)
    (dao:Desac_1300, dao:Desac_2922)
    (dao:Desac_1335, dao:Desac_1664)
    (dao:Desac_1335, dao:Desac_2664)
    (dao:Desac_1415, dao:Desac_1741)
    (dao:Desac_1415, dao:Desac_2908)
    (dao:Desac_1501, dao:Desac_2593)
    (dao:Desac_1607, dao:Desac_1774)
    (dao:Desac_1607, dao:Desac_2394)
    (dao:Desac_1631, dao:Desac_2837)
    (dao:Desac_1664, dao:Desac_2664)
    (dao:Desac_1681, dao:Desac_2831)
    (dao:Desac_1741, dao:Desac_2908)
    (dao:Desac_1774, dao:Desac_2394)
    (dao:Desac_1831, dao:Desac_2573)
    (dao:Desac_1840, dao:Desac_2015)
    (dao:Desac_2143, dao:Desac_2446)
    (dao:Desac_2262, dao:Desac_2517)
    (dao:Desac_2332, dao:Desac_2526)
    (dao:Desac_2541, dao:Desac_2544)
    (dao:Desac_2676, dao:Desac_2702)
    (das:Daes_0042, das:Daes_1774)
    (das:Daes_0076, das:Daes_1973)
    (das:Daes_0077, das:Daes_0911)
    (das:Daes_0077, das:Daes_1972)
    (das:Daes_0119, das:Daes_0128)
    (das:Daes_0119, das:Daes_1012)
    (das:Daes_0119, das:Daes_1192)
    (das:Daes_0119, das:Daes_1679)
    (das:Daes_0128, das:Daes_1012)
    (das:Daes_0128, das:Daes_1192)
    (das:Daes_0128, das:Daes_1679)
    (das:Daes_0165, das:Daes_2884)
    (das:Daes_0202, das:Daes_0542)
    (das:Daes_0202, das:Daes_0665)
    (das:Daes_0202, das:Daes_2972)
    (das:Daes_0235, das:Daes_1396)
    (das:Daes_0296, das:Daes_0593)
    (das:Daes_0316, das:Daes_2350)
    (das:Daes_0542, das:Daes_0665)
    (das:Daes_0542, das:Daes_2972)
    (das:Daes_0665, das:Daes_2972)
    (das:Daes_0687, das:Daes_2857)
    (das:Daes_0687, das:Daes_3100)
    (das:Daes_0700, das:Daes_0715)
    (das:Daes_0700, das:Daes_0716)
    (das:Daes_0700, das:Daes_3309)
    (das:Daes_0715, das:Daes_0716)
    (das:Daes_0715, das:Daes_3309)
    (das:Daes_0716, das:Daes_3309)
    (das:Daes_0744, das:Daes_1709)
    (das:Daes_0744, das:Daes_2821)
    (das:Daes_0753, das:Daes_0961)
    (das:Daes_0791, das:Daes_1070)
    (das:Daes_0911, das:Daes_1972)
    (das:Daes_0937, das:Daes_1225)
    (das:Daes_0937, das:Daes_1798)
    (das:Daes_0937, das:Daes_2846)
    (das:Daes_0937, das:Daes_3214)
    (das:Daes_1012, das:Daes_1192)
    (das:Daes_1012, das:Daes_1679)
    (das:Daes_1136, das:Daes_3284)
    (das:Daes_1192, das:Daes_1679)
    (das:Daes_1225, das:Daes_1798)
    (das:Daes_1225, das:Daes_2846)
    (das:Daes_1225, das:Daes_3214)
    (das:Daes_1318, das:Daes_3345)
    (das:Daes_1343, das:Daes_1823)
    (das:Daes_1374, das:Daes_1991)
    (das:Daes_1375, das:Daes_1992)
    (das:Daes_1396, das:Daes_1850)
    (das:Daes_1451, das:Daes_2080)
    (das:Daes_1558, das:Daes_2553)
    (das:Daes_1696, das:Daes_1775)
    (das:Daes_1706, das:Daes_2350)
    (das:Daes_1709, das:Daes_2821)
    (das:Daes_1744, das:Daes_1912)
    (das:Daes_1746, das:Daes_2549)
    (das:Daes_1798, das:Daes_2846)
    (das:Daes_1798, das:Daes_3214)
    (das:Daes_1909, das:Daes_2678)
    (das:Daes_1973, das:Daes_2554)
    (das:Daes_1973, das:Daes_3138)
    (das:Daes_2032, das:Daes_2884)
    (das:Daes_2107, das:Daes_3270)
    (das:Daes_2166, das:Daes_2796)
    (das:Daes_2209, das:Daes_2550)
    (das:Daes_2276, das:Daes_2714)
    (das:Daes_2546, das:Daes_3139)
    (das:Daes_2552, das:Daes_2770)
    (das:Daes_2554, das:Daes_3138)
    (das:Daes_2654, das:Daes_2852)
    (das:Daes_2654, das:Daes_2972)
    (das:Daes_2846, das:Daes_3214)
    (das:Daes_2857, das:Daes_3018)
    (dat:HRM2_00520, dat:HRM2_07460)
    (dat:HRM2_00970, dat:HRM2_16810)
    (dat:HRM2_01190, dat:HRM2_21000)
    (dat:HRM2_01900, dat:HRM2_45040)
    (dat:HRM2_02030, dat:HRM2_15420)
    (dat:HRM2_02030, dat:HRM2_15450)
    (dat:HRM2_02690, dat:HRM2_02700)
    (dat:HRM2_02710, dat:HRM2_38500)
    (dat:HRM2_02710, dat:HRM2_41050)
    (dat:HRM2_03210, dat:HRM2_07770)
    (dat:HRM2_03210, dat:HRM2_42320)
    (dat:HRM2_03220, dat:HRM2_07760)
    (dat:HRM2_03220, dat:HRM2_42310)
    (dat:HRM2_04430, dat:HRM2_41030)
    (dat:HRM2_06820, dat:HRM2_45740)
    (dat:HRM2_06910, dat:HRM2_20130)
    (dat:HRM2_06910, dat:HRM2_26740)
    (dat:HRM2_07180, dat:HRM2_16260)
    (dat:HRM2_07180, dat:HRM2_22950)
    (dat:HRM2_07180, dat:HRM2_38170)
    (dat:HRM2_07180, dat:HRM2_46050)
    (dat:HRM2_07280, dat:HRM2_25010)
    (dat:HRM2_07280, dat:HRM2_43380)
    (dat:HRM2_07760, dat:HRM2_22630)
    (dat:HRM2_07760, dat:HRM2_42310)
    (dat:HRM2_07770, dat:HRM2_42320)
    (dat:HRM2_08100, dat:HRM2_17700)
    (dat:HRM2_08490, dat:HRM2_18570)
    (dat:HRM2_08490, dat:HRM2_28280)
    (dat:HRM2_08630, dat:HRM2_12400)
    (dat:HRM2_08630, dat:HRM2_27920)
    (dat:HRM2_08850, dat:HRM2_11950)
    (dat:HRM2_08850, dat:HRM2_13680)
    (dat:HRM2_08850, dat:HRM2_28720)
    (dat:HRM2_08850, dat:HRM2_47210)
    (dat:HRM2_08850, dat:HRM2_47820)
    (dat:HRM2_08850, dat:HRM2_47830)
    (dat:HRM2_10630, dat:HRM2_37410)
    (dat:HRM2_11950, dat:HRM2_13680)
    (dat:HRM2_11950, dat:HRM2_28720)
    (dat:HRM2_11950, dat:HRM2_47210)
    (dat:HRM2_11950, dat:HRM2_47820)
    (dat:HRM2_11950, dat:HRM2_47830)
    (dat:HRM2_12400, dat:HRM2_27920)
    (dat:HRM2_12660, dat:HRM2_12670)
    (dat:HRM2_13230, dat:HRM2_13240)
    (dat:HRM2_13680, dat:HRM2_28700)
    (dat:HRM2_13680, dat:HRM2_28720)
    (dat:HRM2_13680, dat:HRM2_47210)
    (dat:HRM2_13680, dat:HRM2_47820)
    (dat:HRM2_13680, dat:HRM2_47830)
    (dat:HRM2_14270, dat:HRM2_35970)
    (dat:HRM2_15420, dat:HRM2_15450)
    (dat:HRM2_16000, dat:HRM2_17690)
    (dat:HRM2_16260, dat:HRM2_22950)
    (dat:HRM2_16260, dat:HRM2_38170)
    (dat:HRM2_16260, dat:HRM2_46050)
    (dat:HRM2_17850, dat:HRM2_34830)
    (dat:HRM2_18570, dat:HRM2_28280)
    (dat:HRM2_20030, dat:HRM2_21490)
    (dat:HRM2_20030, dat:HRM2_23910)
    (dat:HRM2_20130, dat:HRM2_23300)
    (dat:HRM2_20130, dat:HRM2_26740)
    (dat:HRM2_20900, dat:HRM2_24890)
    (dat:HRM2_20900, dat:HRM2_27190)
    (dat:HRM2_20960, dat:HRM2_20970)
    (dat:HRM2_20990, dat:HRM2_29030)
    (dat:HRM2_21490, dat:HRM2_23910)
    (dat:HRM2_21490, dat:HRM2_41270)
    (dat:HRM2_21650, dat:HRM2_24160)
    (dat:HRM2_21650, dat:HRM2_43540)
    (dat:HRM2_22520, dat:HRM2_43510)
    (dat:HRM2_22630, dat:HRM2_42310)
    (dat:HRM2_22950, dat:HRM2_38170)
    (dat:HRM2_22950, dat:HRM2_42990)
    (dat:HRM2_22950, dat:HRM2_46050)
    (dat:HRM2_23040, dat:HRM2_29750)
    (dat:HRM2_23300, dat:HRM2_26740)
    (dat:HRM2_23600, dat:HRM2_24160)
    (dat:HRM2_23610, dat:HRM2_29000)
    (dat:HRM2_23910, dat:HRM2_41270)
    (dat:HRM2_24160, dat:HRM2_43540)
    (dat:HRM2_24750, dat:HRM2_37910)
    (dat:HRM2_24890, dat:HRM2_27190)
    (dat:HRM2_25010, dat:HRM2_43380)
    (dat:HRM2_25160, dat:HRM2_31180)
    (dat:HRM2_25240, dat:HRM2_25270)
    (dat:HRM2_27560, dat:HRM2_27780)
    (dat:HRM2_28700, dat:HRM2_47820)
    (dat:HRM2_28700, dat:HRM2_47830)
    (dat:HRM2_28720, dat:HRM2_47210)
    (dat:HRM2_28720, dat:HRM2_47820)
    (dat:HRM2_28720, dat:HRM2_47830)
    (dat:HRM2_34850, dat:HRM2_41130)
    (dat:HRM2_35730, dat:HRM2_36840)
    (dat:HRM2_35740, dat:HRM2_36790)
    (dat:HRM2_35870, dat:HRM2_45800)
    (dat:HRM2_38170, dat:HRM2_42990)
    (dat:HRM2_38170, dat:HRM2_46050)
    (dat:HRM2_38500, dat:HRM2_41050)
    (dat:HRM2_42990, dat:HRM2_46050)
    (dat:HRM2_47210, dat:HRM2_47820)
    (dat:HRM2_47210, dat:HRM2_47830)
    (dat:HRM2_47820, dat:HRM2_47830)
    (dav:DESACE_00060, dav:DESACE_03180)
    (dav:DESACE_00450, dav:DESACE_03335)
    (dav:DESACE_00685, dav:DESACE_04505)
    (dav:DESACE_00685, dav:DESACE_06220)
    (dav:DESACE_01185, dav:DESACE_02320)
    (dav:DESACE_01185, dav:DESACE_08825)
    (dav:DESACE_01385, dav:DESACE_05855)
    (dav:DESACE_01385, dav:DESACE_06865)
    (dav:DESACE_02070, dav:DESACE_08465)
    (dav:DESACE_02195, dav:DESACE_08570)
    (dav:DESACE_02195, dav:DESACE_08765)
    (dav:DESACE_02280, dav:DESACE_08090)
    (dav:DESACE_02320, dav:DESACE_08825)
    (dav:DESACE_03005, dav:DESACE_03010)
    (dav:DESACE_03010, dav:DESACE_03245)
    (dav:DESACE_03540, dav:DESACE_05935)
    (dav:DESACE_03685, dav:DESACE_03890)
    (dav:DESACE_03685, dav:DESACE_06745)
    (dav:DESACE_03690, dav:DESACE_03885)
    (dav:DESACE_03690, dav:DESACE_06750)
    (dav:DESACE_03885, dav:DESACE_06750)
    (dav:DESACE_03890, dav:DESACE_06745)
    (dav:DESACE_04505, dav:DESACE_06220)
    (dav:DESACE_05445, dav:DESACE_08495)
    (dav:DESACE_05855, dav:DESACE_06865)
    (dav:DESACE_06395, dav:DESACE_07825)
    (dav:DESACE_06860, dav:DESACE_08345)
    (dav:DESACE_06860, dav:DESACE_09325)
    (dav:DESACE_08345, dav:DESACE_09325)
    (dav:DESACE_08570, dav:DESACE_08765)
    (dba:Dbac_0057, dba:Dbac_0488)
    (dba:Dbac_0057, dba:Dbac_2450)
    (dba:Dbac_0065, dba:Dbac_1120)
    (dba:Dbac_0075, dba:Dbac_1951)
    (dba:Dbac_0075, dba:Dbac_3450)
    (dba:Dbac_0093, dba:Dbac_2892)
    (dba:Dbac_0109, dba:Dbac_1478)
    (dba:Dbac_0109, dba:Dbac_1611)
    (dba:Dbac_0109, dba:Dbac_3166)
    (dba:Dbac_0125, dba:Dbac_2388)
    (dba:Dbac_0125, dba:Dbac_3261)
    (dba:Dbac_0193, dba:Dbac_1756)
    (dba:Dbac_0212, dba:Dbac_0874)
    (dba:Dbac_0212, dba:Dbac_1886)
    (dba:Dbac_0212, dba:Dbac_1988)
    (dba:Dbac_0212, dba:Dbac_2044)
    (dba:Dbac_0212, dba:Dbac_2045)
    (dba:Dbac_0246, dba:Dbac_2176)
    (dba:Dbac_0265, dba:Dbac_3084)
    (dba:Dbac_0408, dba:Dbac_1631)
    (dba:Dbac_0409, dba:Dbac_2685)
    (dba:Dbac_0488, dba:Dbac_2450)
    (dba:Dbac_0489, dba:Dbac_3287)
    (dba:Dbac_0773, dba:Dbac_0929)
    (dba:Dbac_0780, dba:Dbac_2161)
    (dba:Dbac_0797, dba:Dbac_1000)
    (dba:Dbac_0797, dba:Dbac_1826)
    (dba:Dbac_0797, dba:Dbac_2205)
    (dba:Dbac_0797, dba:Dbac_2287)
    (dba:Dbac_0797, dba:Dbac_3347)
    (dba:Dbac_0874, dba:Dbac_1886)
    (dba:Dbac_0874, dba:Dbac_2044)
    (dba:Dbac_0874, dba:Dbac_2045)
    (dba:Dbac_0912, dba:Dbac_1754)
    (dba:Dbac_0912, dba:Dbac_3408)
    (dba:Dbac_0961, dba:Dbac_2817)
    (dba:Dbac_0984, dba:Dbac_0985)
    (dba:Dbac_1000, dba:Dbac_1826)
    (dba:Dbac_1000, dba:Dbac_2287)
    (dba:Dbac_1000, dba:Dbac_3347)
    (dba:Dbac_1036, dba:Dbac_1638)
    (dba:Dbac_1178, dba:Dbac_2955)
    (dba:Dbac_1438, dba:Dbac_2135)
    (dba:Dbac_1478, dba:Dbac_1611)
    (dba:Dbac_1478, dba:Dbac_3166)
    (dba:Dbac_1498, dba:Dbac_2874)
    (dba:Dbac_1611, dba:Dbac_1690)
    (dba:Dbac_1611, dba:Dbac_3166)
    (dba:Dbac_1690, dba:Dbac_2282)
    (dba:Dbac_1740, dba:Dbac_1985)
    (dba:Dbac_1743, dba:Dbac_2425)
    (dba:Dbac_1754, dba:Dbac_3408)
    (dba:Dbac_1826, dba:Dbac_2205)
    (dba:Dbac_1826, dba:Dbac_2287)
    (dba:Dbac_1826, dba:Dbac_3347)
    (dba:Dbac_1870, dba:Dbac_2557)
    (dba:Dbac_1870, dba:Dbac_3389)
    (dba:Dbac_1886, dba:Dbac_1988)
    (dba:Dbac_1886, dba:Dbac_2044)
    (dba:Dbac_1886, dba:Dbac_2045)
    (dba:Dbac_1886, dba:Dbac_2917)
    (dba:Dbac_1951, dba:Dbac_3450)
    (dba:Dbac_1988, dba:Dbac_2044)
    (dba:Dbac_1988, dba:Dbac_2045)
    (dba:Dbac_1988, dba:Dbac_2917)
    (dba:Dbac_2044, dba:Dbac_2045)
    (dba:Dbac_2287, dba:Dbac_3347)
    (dba:Dbac_2388, dba:Dbac_3261)
    (dba:Dbac_2557, dba:Dbac_3389)
    (dba:Dbac_2558, dba:Dbac_3118)
    (dba:Dbac_2718, dba:Dbac_3003)
    (dba:Dbac_2833, dba:Dbac_3212)
    (dba:Dbac_2884, dba:Dbac_3039)
    (dba:Dbac_2987, dba:Dbac_3303)
    (dba:Dbac_3325, dba:Dbac_3326)
    (dbr:Deba_0015, dbr:Deba_0581)
    (dbr:Deba_0015, dbr:Deba_1628)
    (dbr:Deba_0015, dbr:Deba_1780)
    (dbr:Deba_0015, dbr:Deba_2748)
    (dbr:Deba_0117, dbr:Deba_1967)
    (dbr:Deba_0131, dbr:Deba_1107)
    (dbr:Deba_0146, dbr:Deba_0419)
    (dbr:Deba_0146, dbr:Deba_0994)
    (dbr:Deba_0146, dbr:Deba_2140)
    (dbr:Deba_0146, dbr:Deba_2288)
    (dbr:Deba_0146, dbr:Deba_2773)
    (dbr:Deba_0206, dbr:Deba_2032)
    (dbr:Deba_0233, dbr:Deba_2415)
    (dbr:Deba_0292, dbr:Deba_3125)
    (dbr:Deba_0300, dbr:Deba_0633)
    (dbr:Deba_0342, dbr:Deba_1275)
    (dbr:Deba_0413, dbr:Deba_1412)
    (dbr:Deba_0413, dbr:Deba_2001)
    (dbr:Deba_0419, dbr:Deba_0994)
    (dbr:Deba_0419, dbr:Deba_2140)
    (dbr:Deba_0419, dbr:Deba_2288)
    (dbr:Deba_0419, dbr:Deba_2773)
    (dbr:Deba_0425, dbr:Deba_0853)
    (dbr:Deba_0425, dbr:Deba_1017)
    (dbr:Deba_0425, dbr:Deba_3094)
    (dbr:Deba_0534, dbr:Deba_3263)
    (dbr:Deba_0577, dbr:Deba_0606)
    (dbr:Deba_0577, dbr:Deba_1025)
    (dbr:Deba_0581, dbr:Deba_0585)
    (dbr:Deba_0581, dbr:Deba_1628)
    (dbr:Deba_0581, dbr:Deba_1780)
    (dbr:Deba_0581, dbr:Deba_2122)
    (dbr:Deba_0581, dbr:Deba_2503)
    (dbr:Deba_0581, dbr:Deba_2748)
    (dbr:Deba_0581, dbr:Deba_3187)
    (dbr:Deba_0585, dbr:Deba_1780)
    (dbr:Deba_0585, dbr:Deba_2122)
    (dbr:Deba_0585, dbr:Deba_2503)
    (dbr:Deba_0585, dbr:Deba_2748)
    (dbr:Deba_0585, dbr:Deba_3187)
    (dbr:Deba_0753, dbr:Deba_0943)
    (dbr:Deba_0853, dbr:Deba_1017)
    (dbr:Deba_0967, dbr:Deba_1849)
    (dbr:Deba_0994, dbr:Deba_2140)
    (dbr:Deba_0994, dbr:Deba_2773)
    (dbr:Deba_1017, dbr:Deba_3094)
    (dbr:Deba_1178, dbr:Deba_3263)
    (dbr:Deba_1412, dbr:Deba_2001)
    (dbr:Deba_1430, dbr:Deba_2388)
    (dbr:Deba_1479, dbr:Deba_2637)
    (dbr:Deba_1506, dbr:Deba_3012)
    (dbr:Deba_1628, dbr:Deba_1780)
    (dbr:Deba_1628, dbr:Deba_2748)
    (dbr:Deba_1734, dbr:Deba_1979)
    (dbr:Deba_1780, dbr:Deba_2122)
    (dbr:Deba_1780, dbr:Deba_2503)
    (dbr:Deba_1780, dbr:Deba_2748)
    (dbr:Deba_1780, dbr:Deba_3187)
    (dbr:Deba_1882, dbr:Deba_2654)
    (dbr:Deba_2122, dbr:Deba_2503)
    (dbr:Deba_2122, dbr:Deba_2748)
    (dbr:Deba_2122, dbr:Deba_3187)
    (dbr:Deba_2140, dbr:Deba_2288)
    (dbr:Deba_2140, dbr:Deba_2773)
    (dbr:Deba_2198, dbr:Deba_2981)
    (dbr:Deba_2288, dbr:Deba_2773)
    (dbr:Deba_2503, dbr:Deba_2748)
    (dbr:Deba_2503, dbr:Deba_3187)
    (dbr:Deba_2748, dbr:Deba_3187)
    (dbr:Deba_2788, dbr:Deba_2789)
    (dbr:Deba_2791, dbr:Deba_2794)
    (dbr:Deba_3185, dbr:Deba_3214)
    (dde:Dde_0033, dde:Dde_2182)
    (dde:Dde_0033, dde:Dde_3691)
    (dde:Dde_0065, dde:Dde_0255)
    (dde:Dde_0079, dde:Dde_3479)
    (dde:Dde_0193, dde:Dde_1725)
    (dde:Dde_0210, dde:Dde_0465)
    (dde:Dde_0210, dde:Dde_1203)
    (dde:Dde_0210, dde:Dde_2066)
    (dde:Dde_0210, dde:Dde_2151)
    (dde:Dde_0230, dde:Dde_3228)
    (dde:Dde_0366, dde:Dde_3042)
    (dde:Dde_0398, dde:Dde_2168)
    (dde:Dde_0408, dde:Dde_3733)
    (dde:Dde_0427, dde:Dde_2187)
    (dde:Dde_0427, dde:Dde_2888)
    (dde:Dde_0427, dde:Dde_3691)
    (dde:Dde_0465, dde:Dde_1203)
    (dde:Dde_0465, dde:Dde_2066)
    (dde:Dde_0465, dde:Dde_2151)
    (dde:Dde_0540, dde:Dde_0972)
    (dde:Dde_0540, dde:Dde_2084)
    (dde:Dde_0540, dde:Dde_3457)
    (dde:Dde_0604, dde:Dde_2080)
    (dde:Dde_0626, dde:Dde_2648)
    (dde:Dde_0836, dde:Dde_0972)
    (dde:Dde_0836, dde:Dde_2084)
    (dde:Dde_0836, dde:Dde_3457)
    (dde:Dde_0972, dde:Dde_2084)
    (dde:Dde_0972, dde:Dde_3457)
    (dde:Dde_1087, dde:Dde_3239)
    (dde:Dde_1103, dde:Dde_3596)
    (dde:Dde_1203, dde:Dde_2066)
    (dde:Dde_1203, dde:Dde_2151)
    (dde:Dde_1225, dde:Dde_3397)
    (dde:Dde_1254, dde:Dde_3638)
    (dde:Dde_1255, dde:Dde_3639)
    (dde:Dde_1379, dde:Dde_1558)
    (dde:Dde_1424, dde:Dde_3088)
    (dde:Dde_1725, dde:Dde_2317)
    (dde:Dde_1725, dde:Dde_2823)
    (dde:Dde_1725, dde:Dde_3207)
    (dde:Dde_1978, dde:Dde_2664)
    (dde:Dde_2004, dde:Dde_2648)
    (dde:Dde_2049, dde:Dde_3218)
    (dde:Dde_2066, dde:Dde_2151)
    (dde:Dde_2084, dde:Dde_3457)
    (dde:Dde_2142, dde:Dde_2439)
    (dde:Dde_2142, dde:Dde_2839)
    (dde:Dde_2182, dde:Dde_2187)
    (dde:Dde_2182, dde:Dde_3691)
    (dde:Dde_2187, dde:Dde_2888)
    (dde:Dde_2187, dde:Dde_3691)
    (dde:Dde_2317, dde:Dde_2823)
    (dde:Dde_2317, dde:Dde_3207)
    (dde:Dde_2342, dde:Dde_3736)
    (dde:Dde_2431, dde:Dde_2660)
    (dde:Dde_2439, dde:Dde_2839)
    (dde:Dde_2656, dde:Dde_3180)
    (dde:Dde_2823, dde:Dde_3207)
    (dde:Dde_2888, dde:Dde_3691)
    (dde:Dde_2891, dde:Dde_3317)
    (dde:Dde_2891, dde:Dde_3677)
    (dde:Dde_3062, dde:Dde_3126)
    (dde:Dde_3062, dde:Dde_3523)
    (dde:Dde_3062, dde:Dde_3534)
    (dde:Dde_3126, dde:Dde_3523)
    (dde:Dde_3222, dde:Dde_3476)
    (dde:Dde_3317, dde:Dde_3677)
    (dde:Dde_3523, dde:Dde_3534)
    (dde:Dde_3647, dde:Dde_3687)
    (dds:Ddes_0025, dds:Ddes_1950)
    (dds:Ddes_0101, dds:Ddes_0509)
    (dds:Ddes_0114, dds:Ddes_1200)
    (dds:Ddes_0132, dds:Ddes_0156)
    (dds:Ddes_0151, dds:Ddes_1416)
    (dds:Ddes_0151, dds:Ddes_2347)
    (dds:Ddes_0192, dds:Ddes_1769)
    (dds:Ddes_0319, dds:Ddes_0559)
    (dds:Ddes_0319, dds:Ddes_0939)
    (dds:Ddes_0319, dds:Ddes_2338)
    (dds:Ddes_0385, dds:Ddes_1623)
    (dds:Ddes_0385, dds:Ddes_2073)
    (dds:Ddes_0559, dds:Ddes_0939)
    (dds:Ddes_0559, dds:Ddes_2338)
    (dds:Ddes_0583, dds:Ddes_1588)
    (dds:Ddes_0828, dds:Ddes_1771)
    (dds:Ddes_0828, dds:Ddes_1772)
    (dds:Ddes_0939, dds:Ddes_2338)
    (dds:Ddes_1149, dds:Ddes_1593)
    (dds:Ddes_1253, dds:Ddes_1748)
    (dds:Ddes_1300, dds:Ddes_2017)
    (dds:Ddes_1416, dds:Ddes_2347)
    (dds:Ddes_1552, dds:Ddes_1565)
    (dds:Ddes_1552, dds:Ddes_1644)
    (dds:Ddes_1565, dds:Ddes_1568)
    (dds:Ddes_1565, dds:Ddes_1644)
    (dds:Ddes_1568, dds:Ddes_1644)
    (dds:Ddes_1623, dds:Ddes_2073)
    (dds:Ddes_1685, dds:Ddes_1942)
    (dds:Ddes_1771, dds:Ddes_1772)
    (dds:Ddes_2089, dds:Ddes_2245)
    (def:CNY67_00560, def:CNY67_11835)
    (def:CNY67_00625, def:CNY67_07855)
    (def:CNY67_00735, def:CNY67_00890)
    (def:CNY67_00845, def:CNY67_09265)
    (def:CNY67_00845, def:CNY67_15330)
    (def:CNY67_01635, def:CNY67_14455)
    (def:CNY67_01730, def:CNY67_04820)
    (def:CNY67_01730, def:CNY67_12850)
    (def:CNY67_01860, def:CNY67_03590)
    (def:CNY67_02160, def:CNY67_09770)
    (def:CNY67_02680, def:CNY67_09320)
    (def:CNY67_03590, def:CNY67_03595)
    (def:CNY67_03595, def:CNY67_10085)
    (def:CNY67_03610, def:CNY67_14075)
    (def:CNY67_03710, def:CNY67_08360)
    (def:CNY67_04680, def:CNY67_05120)
    (def:CNY67_04680, def:CNY67_05135)
    (def:CNY67_04680, def:CNY67_05215)
    (def:CNY67_04820, def:CNY67_12850)
    (def:CNY67_04975, def:CNY67_07200)
    (def:CNY67_05000, def:CNY67_11360)
    (def:CNY67_05120, def:CNY67_05135)
    (def:CNY67_05135, def:CNY67_05215)
    (def:CNY67_05745, def:CNY67_11490)
    (def:CNY67_05745, def:CNY67_12480)
    (def:CNY67_05745, def:CNY67_15275)
    (def:CNY67_08465, def:CNY67_13650)
    (def:CNY67_08465, def:CNY67_14075)
    (def:CNY67_09265, def:CNY67_15330)
    (def:CNY67_11490, def:CNY67_12480)
    (def:CNY67_11490, def:CNY67_15275)
    (def:CNY67_12480, def:CNY67_15275)
    (dej:AWY79_00420, dej:AWY79_15280)
    (dej:AWY79_00595, dej:AWY79_00980)
    (dej:AWY79_00595, dej:AWY79_01195)
    (dej:AWY79_00595, dej:AWY79_17820)
    (dej:AWY79_00730, dej:AWY79_05375)
    (dej:AWY79_00980, dej:AWY79_01195)
    (dej:AWY79_00980, dej:AWY79_17820)
    (dej:AWY79_01195, dej:AWY79_17820)
    (dej:AWY79_01845, dej:AWY79_11170)
    (dej:AWY79_01925, dej:AWY79_11830)
    (dej:AWY79_02360, dej:AWY79_13920)
    (dej:AWY79_02820, dej:AWY79_10850)
    (dej:AWY79_03150, dej:AWY79_12840)
    (dej:AWY79_03505, dej:AWY79_05515)
    (dej:AWY79_03505, dej:AWY79_09715)
    (dej:AWY79_03505, dej:AWY79_15760)
    (dej:AWY79_03845, dej:AWY79_06655)
    (dej:AWY79_03870, dej:AWY79_13255)
    (dej:AWY79_04190, dej:AWY79_13965)
    (dej:AWY79_04800, dej:AWY79_05625)
    (dej:AWY79_04800, dej:AWY79_12450)
    (dej:AWY79_04910, dej:AWY79_16080)
    (dej:AWY79_05115, dej:AWY79_09165)
    (dej:AWY79_05490, dej:AWY79_08700)
    (dej:AWY79_05490, dej:AWY79_17820)
    (dej:AWY79_05515, dej:AWY79_09715)
    (dej:AWY79_05515, dej:AWY79_15760)
    (dej:AWY79_05625, dej:AWY79_12450)
    (dej:AWY79_06240, dej:AWY79_10975)
    (dej:AWY79_06240, dej:AWY79_13090)
    (dej:AWY79_06655, dej:AWY79_08405)
    (dej:AWY79_07380, dej:AWY79_07505)
    (dej:AWY79_07380, dej:AWY79_12270)
    (dej:AWY79_07380, dej:AWY79_16725)
    (dej:AWY79_07505, dej:AWY79_12270)
    (dej:AWY79_07505, dej:AWY79_16725)
    (dej:AWY79_07980, dej:AWY79_09610)
    (dej:AWY79_07980, dej:AWY79_13845)
    (dej:AWY79_07985, dej:AWY79_11045)
    (dej:AWY79_08145, dej:AWY79_17500)
    (dej:AWY79_08325, dej:AWY79_09690)
    (dej:AWY79_08700, dej:AWY79_17820)
    (dej:AWY79_09610, dej:AWY79_13845)
    (dej:AWY79_09715, dej:AWY79_15760)
    (dej:AWY79_09945, dej:AWY79_11185)
    (dej:AWY79_10175, dej:AWY79_17535)
    (dej:AWY79_10180, dej:AWY79_17540)
    (dej:AWY79_10340, dej:AWY79_11140)
    (dej:AWY79_10345, dej:AWY79_11135)
    (dej:AWY79_10770, dej:AWY79_12645)
    (dej:AWY79_10785, dej:AWY79_15450)
    (dej:AWY79_10975, dej:AWY79_13090)
    (dej:AWY79_11535, dej:AWY79_13735)
    (dej:AWY79_12270, dej:AWY79_16725)
    (dej:AWY79_12390, dej:AWY79_12845)
    (dej:AWY79_12435, dej:AWY79_15280)
    (dej:AWY79_12835, dej:AWY79_17490)
    (dej:AWY79_15440, dej:AWY79_15735)
    (des:DSOUD_0047, des:DSOUD_1782)
    (des:DSOUD_0107, des:DSOUD_0363)
    (des:DSOUD_0161, des:DSOUD_3139)
    (des:DSOUD_0206, des:DSOUD_2034)
    (des:DSOUD_0206, des:DSOUD_2450)
    (des:DSOUD_0247, des:DSOUD_1909)
    (des:DSOUD_0294, des:DSOUD_1940)
    (des:DSOUD_0318, des:DSOUD_0953)
    (des:DSOUD_0318, des:DSOUD_2009)
    (des:DSOUD_0343, des:DSOUD_0656)
    (des:DSOUD_0343, des:DSOUD_0657)
    (des:DSOUD_0378, des:DSOUD_2033)
    (des:DSOUD_0407, des:DSOUD_3352)
    (des:DSOUD_0484, des:DSOUD_1127)
    (des:DSOUD_0484, des:DSOUD_1920)
    (des:DSOUD_0593, des:DSOUD_1069)
    (des:DSOUD_0612, des:DSOUD_3461)
    (des:DSOUD_0618, des:DSOUD_2969)
    (des:DSOUD_0657, des:DSOUD_2394)
    (des:DSOUD_0751, des:DSOUD_2757)
    (des:DSOUD_0765, des:DSOUD_3213)
    (des:DSOUD_0923, des:DSOUD_1879)
    (des:DSOUD_0953, des:DSOUD_2009)
    (des:DSOUD_1127, des:DSOUD_1920)
    (des:DSOUD_1171, des:DSOUD_2819)
    (des:DSOUD_1214, des:DSOUD_2032)
    (des:DSOUD_1217, des:DSOUD_1228)
    (des:DSOUD_1217, des:DSOUD_1236)
    (des:DSOUD_1217, des:DSOUD_2030)
    (des:DSOUD_1220, des:DSOUD_1892)
    (des:DSOUD_1220, des:DSOUD_1894)
    (des:DSOUD_1228, des:DSOUD_1236)
    (des:DSOUD_1228, des:DSOUD_2030)
    (des:DSOUD_1236, des:DSOUD_2030)
    (des:DSOUD_1340, des:DSOUD_2497)
    (des:DSOUD_1345, des:DSOUD_2788)
    (des:DSOUD_1475, des:DSOUD_1660)
    (des:DSOUD_1686, des:DSOUD_2288)
    (des:DSOUD_1728, des:DSOUD_3296)
    (des:DSOUD_1777, des:DSOUD_2977)
    (des:DSOUD_1892, des:DSOUD_1894)
    (des:DSOUD_2034, des:DSOUD_2450)
    (des:DSOUD_2209, des:DSOUD_3271)
    (des:DSOUD_2544, des:DSOUD_3002)
    (des:DSOUD_2695, des:DSOUD_2696)
    (des:DSOUD_2695, des:DSOUD_2921)
    (des:DSOUD_2696, des:DSOUD_2921)
    (des:DSOUD_2815, des:DSOUD_2817)
    (des:DSOUD_2923, des:DSOUD_2928)
    (des:DSOUD_2928, des:DSOUD_2929)
    (des:DSOUD_3191, des:DSOUD_3192)
    (deu:DBW_0034, deu:DBW_0441)
    (deu:DBW_0034, deu:DBW_0936)
    (deu:DBW_0034, deu:DBW_1838)
    (deu:DBW_0039, deu:DBW_0158)
    (deu:DBW_0039, deu:DBW_1763)
    (deu:DBW_0039, deu:DBW_1931)
    (deu:DBW_0039, deu:DBW_1933)
    (deu:DBW_0130, deu:DBW_0252)
    (deu:DBW_0130, deu:DBW_0404)
    (deu:DBW_0130, deu:DBW_3285)
    (deu:DBW_0142, deu:DBW_1740)
    (deu:DBW_0142, deu:DBW_2871)
    (deu:DBW_0156, deu:DBW_2119)
    (deu:DBW_0158, deu:DBW_1763)
    (deu:DBW_0158, deu:DBW_1931)
    (deu:DBW_0158, deu:DBW_1933)
    (deu:DBW_0252, deu:DBW_0404)
    (deu:DBW_0252, deu:DBW_3285)
    (deu:DBW_0376, deu:DBW_3241)
    (deu:DBW_0404, deu:DBW_3285)
    (deu:DBW_0440, deu:DBW_1916)
    (deu:DBW_0441, deu:DBW_0936)
    (deu:DBW_0441, deu:DBW_1838)
    (deu:DBW_0541, deu:DBW_1630)
    (deu:DBW_0616, deu:DBW_1746)
    (deu:DBW_0759, deu:DBW_1650)
    (deu:DBW_0759, deu:DBW_2639)
    (deu:DBW_0805, deu:DBW_2198)
    (deu:DBW_0807, deu:DBW_2197)
    (deu:DBW_0911, deu:DBW_1942)
    (deu:DBW_0936, deu:DBW_1838)
    (deu:DBW_1201, deu:DBW_1203)
    (deu:DBW_1238, deu:DBW_2192)
    (deu:DBW_1501, deu:DBW_2134)
    (deu:DBW_1650, deu:DBW_2639)
    (deu:DBW_1740, deu:DBW_2871)
    (deu:DBW_1757, deu:DBW_1820)
    (deu:DBW_1760, deu:DBW_1771)
    (deu:DBW_1760, deu:DBW_1822)
    (deu:DBW_1763, deu:DBW_1931)
    (deu:DBW_1763, deu:DBW_1933)
    (deu:DBW_1771, deu:DBW_1822)
    (deu:DBW_1818, deu:DBW_2731)
    (deu:DBW_1931, deu:DBW_1933)
    (deu:DBW_2132, deu:DBW_2313)
    (deu:DBW_2383, deu:DBW_2384)
    (deu:DBW_2383, deu:DBW_2798)
    (deu:DBW_2384, deu:DBW_2798)
    (deu:DBW_2425, deu:DBW_3054)
    (deu:DBW_2529, deu:DBW_3057)
    (deu:DBW_2530, deu:DBW_3057)
    (deu:DBW_2541, deu:DBW_3054)
    (deu:DBW_2541, deu:DBW_3055)
    (deu:DBW_2799, deu:DBW_2804)
    (deu:DBW_2804, deu:DBW_2805)
    (deu:DBW_2862, deu:DBW_3101)
    (deu:DBW_3160, deu:DBW_3162)
    (deu:DBW_3264, deu:DBW_3265)
    (deu:DBW_3379, deu:DBW_3516)
    (dfi:AXF13_00145, dfi:AXF13_00990)
    (dfi:AXF13_00145, dfi:AXF13_03820)
    (dfi:AXF13_00200, dfi:AXF13_09410)
    (dfi:AXF13_00460, dfi:AXF13_13155)
    (dfi:AXF13_00525, dfi:AXF13_07230)
    (dfi:AXF13_00990, dfi:AXF13_03820)
    (dfi:AXF13_01640, dfi:AXF13_12855)
    (dfi:AXF13_01860, dfi:AXF13_12410)
    (dfi:AXF13_02225, dfi:AXF13_05725)
    (dfi:AXF13_02225, dfi:AXF13_12555)
    (dfi:AXF13_02225, dfi:AXF13_13325)
    (dfi:AXF13_02495, dfi:AXF13_11695)
    (dfi:AXF13_02595, dfi:AXF13_05160)
    (dfi:AXF13_02595, dfi:AXF13_05175)
    (dfi:AXF13_02595, dfi:AXF13_06500)
    (dfi:AXF13_02705, dfi:AXF13_11195)
    (dfi:AXF13_02840, dfi:AXF13_03855)
    (dfi:AXF13_03870, dfi:AXF13_13900)
    (dfi:AXF13_04200, dfi:AXF13_05010)
    (dfi:AXF13_05040, dfi:AXF13_10670)
    (dfi:AXF13_05160, dfi:AXF13_05175)
    (dfi:AXF13_05175, dfi:AXF13_06500)
    (dfi:AXF13_05725, dfi:AXF13_12555)
    (dfi:AXF13_05725, dfi:AXF13_13325)
    (dfi:AXF13_05800, dfi:AXF13_13965)
    (dfi:AXF13_05975, dfi:AXF13_10380)
    (dfi:AXF13_06295, dfi:AXF13_12725)
    (dfi:AXF13_10905, dfi:AXF13_13970)
    (dfi:AXF13_11540, dfi:AXF13_15030)
    (dfi:AXF13_11540, dfi:AXF13_15545)
    (dfi:AXF13_12555, dfi:AXF13_13325)
    (dfi:AXF13_12630, dfi:AXF13_13335)
    (dfi:AXF13_13565, dfi:AXF13_15125)
    (dfi:AXF13_14405, dfi:AXF13_14950)
    (dfi:AXF13_15030, dfi:AXF13_15545)
    (dgg:DGI_0026, dgg:DGI_0864)
    (dgg:DGI_0069, dgg:DGI_0864)
    (dgg:DGI_0194, dgg:DGI_0677)
    (dgg:DGI_0194, dgg:DGI_2559)
    (dgg:DGI_0194, dgg:DGI_2876)
    (dgg:DGI_0194, dgg:DGI_3140)
    (dgg:DGI_0194, dgg:DGI_3493)
    (dgg:DGI_0259, dgg:DGI_1613)
    (dgg:DGI_0259, dgg:DGI_4019)
    (dgg:DGI_0581, dgg:DGI_1438)
    (dgg:DGI_0581, dgg:DGI_1737)
    (dgg:DGI_0581, dgg:DGI_2476)
    (dgg:DGI_0581, dgg:DGI_3014)
    (dgg:DGI_0644, dgg:DGI_2289)
    (dgg:DGI_0677, dgg:DGI_2559)
    (dgg:DGI_0677, dgg:DGI_2876)
    (dgg:DGI_0677, dgg:DGI_3140)
    (dgg:DGI_0677, dgg:DGI_3493)
    (dgg:DGI_0738, dgg:DGI_2681)
    (dgg:DGI_0864, dgg:DGI_4014)
    (dgg:DGI_0873, dgg:DGI_1581)
    (dgg:DGI_0878, dgg:DGI_1654)
    (dgg:DGI_0974, dgg:DGI_2521)
    (dgg:DGI_0974, dgg:DGI_2781)
    (dgg:DGI_1044, dgg:DGI_1047)
    (dgg:DGI_1150, dgg:DGI_1257)
    (dgg:DGI_1348, dgg:DGI_2795)
    (dgg:DGI_1422, dgg:DGI_3110)
    (dgg:DGI_1438, dgg:DGI_1737)
    (dgg:DGI_1438, dgg:DGI_2476)
    (dgg:DGI_1438, dgg:DGI_3014)
    (dgg:DGI_1613, dgg:DGI_4019)
    (dgg:DGI_1648, dgg:DGI_1902)
    (dgg:DGI_1648, dgg:DGI_2774)
    (dgg:DGI_1737, dgg:DGI_2476)
    (dgg:DGI_1737, dgg:DGI_3014)
    (dgg:DGI_1796, dgg:DGI_1888)
    (dgg:DGI_1805, dgg:DGI_1879)
    (dgg:DGI_1807, dgg:DGI_1877)
    (dgg:DGI_1837, dgg:DGI_3520)
    (dgg:DGI_1851, dgg:DGI_3260)
    (dgg:DGI_1902, dgg:DGI_2774)
    (dgg:DGI_2188, dgg:DGI_2546)
    (dgg:DGI_2242, dgg:DGI_2476)
    (dgg:DGI_2250, dgg:DGI_2938)
    (dgg:DGI_2250, dgg:DGI_3042)
    (dgg:DGI_2250, dgg:DGI_3046)
    (dgg:DGI_2466, dgg:DGI_3030)
    (dgg:DGI_2476, dgg:DGI_3014)
    (dgg:DGI_2503, dgg:DGI_3263)
    (dgg:DGI_2521, dgg:DGI_2781)
    (dgg:DGI_2559, dgg:DGI_2876)
    (dgg:DGI_2559, dgg:DGI_3140)
    (dgg:DGI_2559, dgg:DGI_3493)
    (dgg:DGI_2657, dgg:DGI_2716)
    (dgg:DGI_2681, dgg:DGI_3398)
    (dgg:DGI_2876, dgg:DGI_3140)
    (dgg:DGI_2876, dgg:DGI_3493)
    (dgg:DGI_2938, dgg:DGI_2942)
    (dgg:DGI_2938, dgg:DGI_3042)
    (dgg:DGI_2938, dgg:DGI_3046)
    (dgg:DGI_2942, dgg:DGI_3042)
    (dgg:DGI_2942, dgg:DGI_3046)
    (dgg:DGI_3042, dgg:DGI_3046)
    (dgg:DGI_3140, dgg:DGI_3493)
    (dgg:DGI_3482, dgg:DGI_3507)
    (dhy:DESAM_10054, dhy:DESAM_20574)
    (dhy:DESAM_10054, dhy:DESAM_21809)
    (dhy:DESAM_10059, dhy:DESAM_20948)
    (dhy:DESAM_10157, dhy:DESAM_20373)
    (dhy:DESAM_10157, dhy:DESAM_20586)
    (dhy:DESAM_10178, dhy:DESAM_22526)
    (dhy:DESAM_10265, dhy:DESAM_22216)
    (dhy:DESAM_20002, dhy:DESAM_22296)
    (dhy:DESAM_20071, dhy:DESAM_20072)
    (dhy:DESAM_20071, dhy:DESAM_21286)
    (dhy:DESAM_20072, dhy:DESAM_21286)
    (dhy:DESAM_20147, dhy:DESAM_21598)
    (dhy:DESAM_20155, dhy:DESAM_20564)
    (dhy:DESAM_20155, dhy:DESAM_20633)
    (dhy:DESAM_20155, dhy:DESAM_20863)
    (dhy:DESAM_20155, dhy:DESAM_20933)
    (dhy:DESAM_20155, dhy:DESAM_21612)
    (dhy:DESAM_20155, dhy:DESAM_22144)
    (dhy:DESAM_20160, dhy:DESAM_21173)
    (dhy:DESAM_20241, dhy:DESAM_20902)
    (dhy:DESAM_20242, dhy:DESAM_21156)
    (dhy:DESAM_20242, dhy:DESAM_22147)
    (dhy:DESAM_20244, dhy:DESAM_21153)
    (dhy:DESAM_20245, dhy:DESAM_22644)
    (dhy:DESAM_20254, dhy:DESAM_20480)
    (dhy:DESAM_20254, dhy:DESAM_22252)
    (dhy:DESAM_20295, dhy:DESAM_20696)
    (dhy:DESAM_20295, dhy:DESAM_20962)
    (dhy:DESAM_20338, dhy:DESAM_22470)
    (dhy:DESAM_20409, dhy:DESAM_23096)
    (dhy:DESAM_20444, dhy:DESAM_20447)
    (dhy:DESAM_20444, dhy:DESAM_22632)
    (dhy:DESAM_20447, dhy:DESAM_22632)
    (dhy:DESAM_20480, dhy:DESAM_22252)
    (dhy:DESAM_20492, dhy:DESAM_22667)
    (dhy:DESAM_20564, dhy:DESAM_20633)
    (dhy:DESAM_20564, dhy:DESAM_20863)
    (dhy:DESAM_20564, dhy:DESAM_20933)
    (dhy:DESAM_20564, dhy:DESAM_21612)
    (dhy:DESAM_20633, dhy:DESAM_20863)
    (dhy:DESAM_20633, dhy:DESAM_20933)
    (dhy:DESAM_20633, dhy:DESAM_21612)
    (dhy:DESAM_20683, dhy:DESAM_20949)
    (dhy:DESAM_20683, dhy:DESAM_21666)
    (dhy:DESAM_20683, dhy:DESAM_22139)
    (dhy:DESAM_20683, dhy:DESAM_22222)
    (dhy:DESAM_20683, dhy:DESAM_22335)
    (dhy:DESAM_20696, dhy:DESAM_20962)
    (dhy:DESAM_20710, dhy:DESAM_22412)
    (dhy:DESAM_20726, dhy:DESAM_20916)
    (dhy:DESAM_20726, dhy:DESAM_21837)
    (dhy:DESAM_20726, dhy:DESAM_22057)
    (dhy:DESAM_20726, dhy:DESAM_22216)
    (dhy:DESAM_20796, dhy:DESAM_21103)
    (dhy:DESAM_20814, dhy:DESAM_22360)
    (dhy:DESAM_20814, dhy:DESAM_22954)
    (dhy:DESAM_20816, dhy:DESAM_22128)
    (dhy:DESAM_20816, dhy:DESAM_22453)
    (dhy:DESAM_20863, dhy:DESAM_20933)
    (dhy:DESAM_20863, dhy:DESAM_21612)
    (dhy:DESAM_20884, dhy:DESAM_21172)
    (dhy:DESAM_20884, dhy:DESAM_22958)
    (dhy:DESAM_20916, dhy:DESAM_21837)
    (dhy:DESAM_20916, dhy:DESAM_22057)
    (dhy:DESAM_20916, dhy:DESAM_22216)
    (dhy:DESAM_20933, dhy:DESAM_21612)
    (dhy:DESAM_20949, dhy:DESAM_21666)
    (dhy:DESAM_20949, dhy:DESAM_22139)
    (dhy:DESAM_20949, dhy:DESAM_22222)
    (dhy:DESAM_20949, dhy:DESAM_22335)
    (dhy:DESAM_20985, dhy:DESAM_22951)
    (dhy:DESAM_21156, dhy:DESAM_22147)
    (dhy:DESAM_21172, dhy:DESAM_22958)
    (dhy:DESAM_21414, dhy:DESAM_21558)
    (dhy:DESAM_21448, dhy:DESAM_21850)
    (dhy:DESAM_21448, dhy:DESAM_22210)
    (dhy:DESAM_21666, dhy:DESAM_22139)
    (dhy:DESAM_21666, dhy:DESAM_22222)
    (dhy:DESAM_21666, dhy:DESAM_22335)
    (dhy:DESAM_21680, dhy:DESAM_21926)
    (dhy:DESAM_21837, dhy:DESAM_22216)
    (dhy:DESAM_21922, dhy:DESAM_22258)
    (dhy:DESAM_22043, dhy:DESAM_23096)
    (dhy:DESAM_22057, dhy:DESAM_22216)
    (dhy:DESAM_22128, dhy:DESAM_22453)
    (dhy:DESAM_22139, dhy:DESAM_22222)
    (dhy:DESAM_22139, dhy:DESAM_22335)
    (dhy:DESAM_22222, dhy:DESAM_22335)
    (dhy:DESAM_22317, dhy:DESAM_22957)
    (dhy:DESAM_22360, dhy:DESAM_22954)
    (dhy:DESAM_22427, dhy:DESAM_22538)
    (dhy:DESAM_22537, dhy:DESAM_22801)
    (dhy:DESAM_22936, dhy:DESAM_22955)
    (dma:DMR_00110, dma:DMR_28600)
    (dma:DMR_00430, dma:DMR_04400)
    (dma:DMR_00560, dma:DMR_42760)
    (dma:DMR_01800, dma:DMR_37150)
    (dma:DMR_01890, dma:DMR_02380)
    (dma:DMR_01890, dma:DMR_16700)
    (dma:DMR_02050, dma:DMR_04560)
    (dma:DMR_02050, dma:DMR_22170)
    (dma:DMR_02170, dma:DMR_33250)
    (dma:DMR_02380, dma:DMR_16700)
    (dma:DMR_04400, dma:DMR_45660)
    (dma:DMR_04560, dma:DMR_22170)
    (dma:DMR_05110, dma:DMR_09030)
    (dma:DMR_05110, dma:DMR_11340)
    (dma:DMR_05110, dma:DMR_16990)
    (dma:DMR_05110, dma:DMR_25440)
    (dma:DMR_05110, dma:DMR_27000)
    (dma:DMR_05260, dma:DMR_19490)
    (dma:DMR_05730, dma:DMR_34300)
    (dma:DMR_05740, dma:DMR_34310)
    (dma:DMR_06660, dma:DMR_17770)
    (dma:DMR_06660, dma:DMR_19670)
    (dma:DMR_07470, dma:DMR_20060)
    (dma:DMR_09030, dma:DMR_11340)
    (dma:DMR_09030, dma:DMR_16990)
    (dma:DMR_09030, dma:DMR_25440)
    (dma:DMR_09030, dma:DMR_27000)
    (dma:DMR_10970, dma:DMR_11010)
    (dma:DMR_11340, dma:DMR_16990)
    (dma:DMR_11340, dma:DMR_25440)
    (dma:DMR_11340, dma:DMR_27000)
    (dma:DMR_13630, dma:DMR_17800)
    (dma:DMR_13630, dma:DMR_21660)
    (dma:DMR_14920, dma:DMR_39990)
    (dma:DMR_15980, dma:DMR_17880)
    (dma:DMR_16010, dma:DMR_28220)
    (dma:DMR_16990, dma:DMR_25440)
    (dma:DMR_16990, dma:DMR_27000)
    (dma:DMR_17120, dma:DMR_30710)
    (dma:DMR_17120, dma:DMR_37140)
    (dma:DMR_17130, dma:DMR_37080)
    (dma:DMR_17770, dma:DMR_19670)
    (dma:DMR_17800, dma:DMR_21660)
    (dma:DMR_18200, dma:DMR_37110)
    (dma:DMR_19210, dma:DMR_28790)
    (dma:DMR_19340, dma:DMR_39240)
    (dma:DMR_21220, dma:DMR_21290)
    (dma:DMR_21830, dma:DMR_34180)
    (dma:DMR_22790, dma:DMR_39960)
    (dma:DMR_23160, dma:DMR_30710)
    (dma:DMR_25440, dma:DMR_27000)
    (dma:DMR_28090, dma:DMR_35020)
    (dma:DMR_28090, dma:DMR_42440)
    (dma:DMR_30710, dma:DMR_37140)
    (dma:DMR_34740, dma:DMR_45930)
    (dma:DMR_35020, dma:DMR_37260)
    (dma:DMR_35020, dma:DMR_38720)
    (dma:DMR_35020, dma:DMR_42440)
    (dma:DMR_37260, dma:DMR_38720)
    (dma:DMR_37260, dma:DMR_42440)
    (dma:DMR_38720, dma:DMR_42440)
    (dma:DMR_39860, dma:DMR_44510)
    (dml:Dmul_00120, dml:Dmul_30910)
    (dml:Dmul_00400, dml:Dmul_34340)
    (dml:Dmul_00400, dml:Dmul_34350)
    (dml:Dmul_00440, dml:Dmul_11190)
    (dml:Dmul_00590, dml:Dmul_15560)
    (dml:Dmul_01560, dml:Dmul_16000)
    (dml:Dmul_01560, dml:Dmul_16810)
    (dml:Dmul_01640, dml:Dmul_38840)
    (dml:Dmul_01800, dml:Dmul_38840)
    (dml:Dmul_03450, dml:Dmul_25270)
    (dml:Dmul_03970, dml:Dmul_38190)
    (dml:Dmul_05580, dml:Dmul_15210)
    (dml:Dmul_05590, dml:Dmul_15200)
    (dml:Dmul_06060, dml:Dmul_07750)
    (dml:Dmul_06060, dml:Dmul_15350)
    (dml:Dmul_06060, dml:Dmul_26870)
    (dml:Dmul_07460, dml:Dmul_32700)
    (dml:Dmul_07490, dml:Dmul_09580)
    (dml:Dmul_07490, dml:Dmul_23280)
    (dml:Dmul_07490, dml:Dmul_24260)
    (dml:Dmul_07680, dml:Dmul_09400)
    (dml:Dmul_07750, dml:Dmul_15350)
    (dml:Dmul_07750, dml:Dmul_26870)
    (dml:Dmul_08540, dml:Dmul_19320)
    (dml:Dmul_08540, dml:Dmul_21830)
    (dml:Dmul_08540, dml:Dmul_23620)
    (dml:Dmul_08540, dml:Dmul_24630)
    (dml:Dmul_08540, dml:Dmul_28300)
    (dml:Dmul_08540, dml:Dmul_36880)
    (dml:Dmul_08800, dml:Dmul_27550)
    (dml:Dmul_08960, dml:Dmul_35620)
    (dml:Dmul_09580, dml:Dmul_23280)
    (dml:Dmul_09580, dml:Dmul_24260)
    (dml:Dmul_10150, dml:Dmul_22850)
    (dml:Dmul_11080, dml:Dmul_22990)
    (dml:Dmul_11080, dml:Dmul_23060)
    (dml:Dmul_12180, dml:Dmul_36330)
    (dml:Dmul_14330, dml:Dmul_22400)
    (dml:Dmul_14330, dml:Dmul_25380)
    (dml:Dmul_14360, dml:Dmul_34490)
    (dml:Dmul_14400, dml:Dmul_15600)
    (dml:Dmul_15350, dml:Dmul_26870)
    (dml:Dmul_15430, dml:Dmul_28400)
    (dml:Dmul_16000, dml:Dmul_16810)
    (dml:Dmul_16500, dml:Dmul_21160)
    (dml:Dmul_16810, dml:Dmul_22280)
    (dml:Dmul_18930, dml:Dmul_22850)
    (dml:Dmul_19320, dml:Dmul_21830)
    (dml:Dmul_19320, dml:Dmul_23620)
    (dml:Dmul_19320, dml:Dmul_24630)
    (dml:Dmul_19320, dml:Dmul_28300)
    (dml:Dmul_19320, dml:Dmul_36880)
    (dml:Dmul_19830, dml:Dmul_34880)
    (dml:Dmul_20530, dml:Dmul_22820)
    (dml:Dmul_20590, dml:Dmul_21250)
    (dml:Dmul_20590, dml:Dmul_38810)
    (dml:Dmul_20930, dml:Dmul_34830)
    (dml:Dmul_21170, dml:Dmul_38690)
    (dml:Dmul_21250, dml:Dmul_38810)
    (dml:Dmul_21290, dml:Dmul_32710)
    (dml:Dmul_21510, dml:Dmul_24950)
    (dml:Dmul_21510, dml:Dmul_28060)
    (dml:Dmul_21830, dml:Dmul_23620)
    (dml:Dmul_21830, dml:Dmul_24630)
    (dml:Dmul_21830, dml:Dmul_28300)
    (dml:Dmul_22810, dml:Dmul_24040)
    (dml:Dmul_22990, dml:Dmul_23060)
    (dml:Dmul_23530, dml:Dmul_23540)
    (dml:Dmul_23620, dml:Dmul_24630)
    (dml:Dmul_23620, dml:Dmul_28300)
    (dml:Dmul_23620, dml:Dmul_36880)
    (dml:Dmul_24630, dml:Dmul_28300)
    (dml:Dmul_24630, dml:Dmul_36880)
    (dml:Dmul_24950, dml:Dmul_28060)
    (dml:Dmul_24950, dml:Dmul_31480)
    (dml:Dmul_27020, dml:Dmul_31150)
    (dml:Dmul_27750, dml:Dmul_27780)
    (dml:Dmul_27800, dml:Dmul_27810)
    (dml:Dmul_28240, dml:Dmul_28270)
    (dml:Dmul_28300, dml:Dmul_36880)
    (dml:Dmul_31220, dml:Dmul_35200)
    (dml:Dmul_34340, dml:Dmul_34350)
    (doa:AXF15_00335, doa:AXF15_04820)
    (doa:AXF15_00575, doa:AXF15_02605)
    (doa:AXF15_00575, doa:AXF15_06215)
    (doa:AXF15_00690, doa:AXF15_04310)
    (doa:AXF15_00690, doa:AXF15_09000)
    (doa:AXF15_00690, doa:AXF15_10595)
    (doa:AXF15_01445, doa:AXF15_04685)
    (doa:AXF15_01830, doa:AXF15_07630)
    (doa:AXF15_02145, doa:AXF15_05040)
    (doa:AXF15_02215, doa:AXF15_03465)
    (doa:AXF15_02215, doa:AXF15_08610)
    (doa:AXF15_02480, doa:AXF15_03010)
    (doa:AXF15_02605, doa:AXF15_06215)
    (doa:AXF15_03265, doa:AXF15_09390)
    (doa:AXF15_03265, doa:AXF15_09785)
    (doa:AXF15_03265, doa:AXF15_11375)
    (doa:AXF15_03650, doa:AXF15_04445)
    (doa:AXF15_03730, doa:AXF15_05165)
    (doa:AXF15_04035, doa:AXF15_06350)
    (doa:AXF15_04135, doa:AXF15_11000)
    (doa:AXF15_04135, doa:AXF15_11370)
    (doa:AXF15_04310, doa:AXF15_09000)
    (doa:AXF15_04310, doa:AXF15_10595)
    (doa:AXF15_04690, doa:AXF15_12135)
    (doa:AXF15_04965, doa:AXF15_04970)
    (doa:AXF15_05690, doa:AXF15_11880)
    (doa:AXF15_05735, doa:AXF15_11960)
    (doa:AXF15_05770, doa:AXF15_05775)
    (doa:AXF15_05770, doa:AXF15_07580)
    (doa:AXF15_05775, doa:AXF15_07580)
    (doa:AXF15_06240, doa:AXF15_06360)
    (doa:AXF15_06240, doa:AXF15_08785)
    (doa:AXF15_06360, doa:AXF15_08785)
    (doa:AXF15_06400, doa:AXF15_08605)
    (doa:AXF15_06400, doa:AXF15_11595)
    (doa:AXF15_07625, doa:AXF15_09515)
    (doa:AXF15_08605, doa:AXF15_11595)
    (doa:AXF15_08670, doa:AXF15_11865)
    (doa:AXF15_09000, doa:AXF15_10595)
    (doa:AXF15_09390, doa:AXF15_09785)
    (doa:AXF15_09390, doa:AXF15_11375)
    (doa:AXF15_09785, doa:AXF15_11375)
    (doa:AXF15_10405, doa:AXF15_11375)
    (doa:AXF15_11000, doa:AXF15_11370)
    (dol:Dole_0026, dol:Dole_1063)
    (dol:Dole_0063, dol:Dole_0202)
    (dol:Dole_0063, dol:Dole_0683)
    (dol:Dole_0063, dol:Dole_0684)
    (dol:Dole_0121, dol:Dole_1446)
    (dol:Dole_0122, dol:Dole_2113)
    (dol:Dole_0128, dol:Dole_0983)
    (dol:Dole_0128, dol:Dole_1881)
    (dol:Dole_0164, dol:Dole_0314)
    (dol:Dole_0164, dol:Dole_3006)
    (dol:Dole_0187, dol:Dole_2859)
    (dol:Dole_0202, dol:Dole_0683)
    (dol:Dole_0202, dol:Dole_0684)
    (dol:Dole_0222, dol:Dole_0500)
    (dol:Dole_0261, dol:Dole_1885)
    (dol:Dole_0314, dol:Dole_0337)
    (dol:Dole_0314, dol:Dole_3006)
    (dol:Dole_0337, dol:Dole_1973)
    (dol:Dole_0337, dol:Dole_1975)
    (dol:Dole_0337, dol:Dole_3006)
    (dol:Dole_0367, dol:Dole_1131)
    (dol:Dole_0514, dol:Dole_2492)
    (dol:Dole_0542, dol:Dole_3206)
    (dol:Dole_0559, dol:Dole_0838)
    (dol:Dole_0559, dol:Dole_2323)
    (dol:Dole_0582, dol:Dole_1800)
    (dol:Dole_0670, dol:Dole_2847)
    (dol:Dole_0679, dol:Dole_1545)
    (dol:Dole_0683, dol:Dole_0684)
    (dol:Dole_0756, dol:Dole_2243)
    (dol:Dole_0783, dol:Dole_2351)
    (dol:Dole_0838, dol:Dole_2323)
    (dol:Dole_0966, dol:Dole_2680)
    (dol:Dole_0983, dol:Dole_1881)
    (dol:Dole_0983, dol:Dole_2499)
    (dol:Dole_1002, dol:Dole_1013)
    (dol:Dole_1010, dol:Dole_1848)
    (dol:Dole_1010, dol:Dole_2324)
    (dol:Dole_1012, dol:Dole_1961)
    (dol:Dole_1021, dol:Dole_2616)
    (dol:Dole_1068, dol:Dole_1134)
    (dol:Dole_1107, dol:Dole_1462)
    (dol:Dole_1130, dol:Dole_1662)
    (dol:Dole_1132, dol:Dole_1545)
    (dol:Dole_1166, dol:Dole_1667)
    (dol:Dole_1191, dol:Dole_1729)
    (dol:Dole_1191, dol:Dole_2438)
    (dol:Dole_1326, dol:Dole_2037)
    (dol:Dole_1355, dol:Dole_2393)
    (dol:Dole_1426, dol:Dole_2749)
    (dol:Dole_1564, dol:Dole_2074)
    (dol:Dole_1608, dol:Dole_2084)
    (dol:Dole_1729, dol:Dole_2438)
    (dol:Dole_1848, dol:Dole_2324)
    (dol:Dole_1881, dol:Dole_2499)
    (dol:Dole_1908, dol:Dole_2219)
    (dol:Dole_1973, dol:Dole_1975)
    (dol:Dole_2040, dol:Dole_2041)
    (dol:Dole_2786, dol:Dole_2791)
    (dol:Dole_2791, dol:Dole_2792)
    (dpb:BABL1_gene_13, dpb:BABL1_gene_199)
    (dpb:BABL1_gene_13, dpb:BABL1_gene_858)
    (dpb:BABL1_gene_199, dpb:BABL1_gene_858)
    (dpb:BABL1_gene_330, dpb:BABL1_gene_705)
    (dpb:BABL1_gene_5, dpb:BABL1_gene_6)
    (dpb:BABL1_gene_545, dpb:BABL1_gene_809)
    (dpb:BABL1_gene_545, dpb:BABL1_gene_827)
    (dpb:BABL1_gene_545, dpb:BABL1_gene_980)
    (dpb:BABL1_gene_809, dpb:BABL1_gene_827)
    (dpb:BABL1_gene_809, dpb:BABL1_gene_980)
    (dpb:BABL1_gene_827, dpb:BABL1_gene_980)
    (dpg:DESPIGER_0283, dpg:DESPIGER_1297)
    (dpg:DESPIGER_0283, dpg:DESPIGER_1913)
    (dpg:DESPIGER_0323, dpg:DESPIGER_1250)
    (dpg:DESPIGER_0323, dpg:DESPIGER_1949)
    (dpg:DESPIGER_0326, dpg:DESPIGER_2419)
    (dpg:DESPIGER_0351, dpg:DESPIGER_0488)
    (dpg:DESPIGER_0493, dpg:DESPIGER_1352)
    (dpg:DESPIGER_0549, dpg:DESPIGER_0552)
    (dpg:DESPIGER_0549, dpg:DESPIGER_1482)
    (dpg:DESPIGER_0552, dpg:DESPIGER_0649)
    (dpg:DESPIGER_0552, dpg:DESPIGER_1482)
    (dpg:DESPIGER_0559, dpg:DESPIGER_1110)
    (dpg:DESPIGER_0559, dpg:DESPIGER_1638)
    (dpg:DESPIGER_0559, dpg:DESPIGER_1832)
    (dpg:DESPIGER_0649, dpg:DESPIGER_1482)
    (dpg:DESPIGER_0682, dpg:DESPIGER_2427)
    (dpg:DESPIGER_0694, dpg:DESPIGER_2441)
    (dpg:DESPIGER_0969, dpg:DESPIGER_1531)
    (dpg:DESPIGER_1072, dpg:DESPIGER_2402)
    (dpg:DESPIGER_1079, dpg:DESPIGER_1284)
    (dpg:DESPIGER_1079, dpg:DESPIGER_2129)
    (dpg:DESPIGER_1110, dpg:DESPIGER_1638)
    (dpg:DESPIGER_1110, dpg:DESPIGER_1832)
    (dpg:DESPIGER_1191, dpg:DESPIGER_1719)
    (dpg:DESPIGER_1250, dpg:DESPIGER_1949)
    (dpg:DESPIGER_1284, dpg:DESPIGER_2129)
    (dpg:DESPIGER_1297, dpg:DESPIGER_1913)
    (dpg:DESPIGER_1545, dpg:DESPIGER_1797)
    (dpg:DESPIGER_1552, dpg:DESPIGER_2055)
    (dpg:DESPIGER_1638, dpg:DESPIGER_1832)
    (dpg:DESPIGER_1704, dpg:DESPIGER_1830)
    (dpg:DESPIGER_1814, dpg:DESPIGER_1815)
    (dpg:DESPIGER_1840, dpg:DESPIGER_2071)
    (dpi:BN4_10025, dpi:BN4_10583)
    (dpi:BN4_10026, dpi:BN4_10584)
    (dpi:BN4_10112, dpi:BN4_10485)
    (dpi:BN4_10115, dpi:BN4_11407)
    (dpi:BN4_10127, dpi:BN4_12214)
    (dpi:BN4_10161, dpi:BN4_10320)
    (dpi:BN4_10161, dpi:BN4_11381)
    (dpi:BN4_10196, dpi:BN4_11977)
    (dpi:BN4_10242, dpi:BN4_20389)
    (dpi:BN4_10265, dpi:BN4_10725)
    (dpi:BN4_10278, dpi:BN4_11854)
    (dpi:BN4_10278, dpi:BN4_11857)
    (dpi:BN4_10320, dpi:BN4_11381)
    (dpi:BN4_10344, dpi:BN4_10871)
    (dpi:BN4_10344, dpi:BN4_11060)
    (dpi:BN4_10344, dpi:BN4_12231)
    (dpi:BN4_10368, dpi:BN4_10404)
    (dpi:BN4_10369, dpi:BN4_12300)
    (dpi:BN4_10393, dpi:BN4_11936)
    (dpi:BN4_10393, dpi:BN4_12812)
    (dpi:BN4_10396, dpi:BN4_11008)
    (dpi:BN4_10396, dpi:BN4_11230)
    (dpi:BN4_10420, dpi:BN4_10697)
    (dpi:BN4_10420, dpi:BN4_20024)
    (dpi:BN4_10458, dpi:BN4_11868)
    (dpi:BN4_10478, dpi:BN4_12061)
    (dpi:BN4_10697, dpi:BN4_20024)
    (dpi:BN4_10697, dpi:BN4_20088)
    (dpi:BN4_10871, dpi:BN4_11060)
    (dpi:BN4_10871, dpi:BN4_12231)
    (dpi:BN4_10876, dpi:BN4_10996)
    (dpi:BN4_10961, dpi:BN4_12643)
    (dpi:BN4_11008, dpi:BN4_11230)
    (dpi:BN4_11008, dpi:BN4_11826)
    (dpi:BN4_11060, dpi:BN4_12231)
    (dpi:BN4_11318, dpi:BN4_12469)
    (dpi:BN4_11318, dpi:BN4_20265)
    (dpi:BN4_11354, dpi:BN4_11717)
    (dpi:BN4_11368, dpi:BN4_11611)
    (dpi:BN4_11683, dpi:BN4_20324)
    (dpi:BN4_11854, dpi:BN4_11857)
    (dpi:BN4_11936, dpi:BN4_12812)
    (dpi:BN4_12054, dpi:BN4_12384)
    (dpi:BN4_12054, dpi:BN4_12584)
    (dpi:BN4_12054, dpi:BN4_12643)
    (dpi:BN4_12067, dpi:BN4_12189)
    (dpi:BN4_12067, dpi:BN4_12690)
    (dpi:BN4_12189, dpi:BN4_12690)
    (dpi:BN4_12384, dpi:BN4_12584)
    (dpi:BN4_12384, dpi:BN4_12643)
    (dpi:BN4_12531, dpi:BN4_12775)
    (dpi:BN4_12584, dpi:BN4_12643)
    (dpi:BN4_20024, dpi:BN4_20088)
    (dpi:BN4_20344, dpi:BN4_20419)
    (dpr:Despr_0075, dpr:Despr_0082)
    (dpr:Despr_0279, dpr:Despr_2958)
    (dpr:Despr_0281, dpr:Despr_0744)
    (dpr:Despr_0281, dpr:Despr_1504)
    (dpr:Despr_0314, dpr:Despr_1916)
    (dpr:Despr_0363, dpr:Despr_1373)
    (dpr:Despr_0386, dpr:Despr_1962)
    (dpr:Despr_0441, dpr:Despr_1394)
    (dpr:Despr_0441, dpr:Despr_2534)
    (dpr:Despr_0517, dpr:Despr_3156)
    (dpr:Despr_0555, dpr:Despr_2467)
    (dpr:Despr_0559, dpr:Despr_1674)
    (dpr:Despr_0574, dpr:Despr_0909)
    (dpr:Despr_0744, dpr:Despr_1504)
    (dpr:Despr_0827, dpr:Despr_2589)
    (dpr:Despr_0862, dpr:Despr_1050)
    (dpr:Despr_0910, dpr:Despr_2483)
    (dpr:Despr_0918, dpr:Despr_2776)
    (dpr:Despr_0929, dpr:Despr_3296)
    (dpr:Despr_1050, dpr:Despr_3168)
    (dpr:Despr_1394, dpr:Despr_2534)
    (dpr:Despr_1502, dpr:Despr_2672)
    (dpr:Despr_1528, dpr:Despr_2721)
    (dpr:Despr_1538, dpr:Despr_3102)
    (dpr:Despr_1538, dpr:Despr_3332)
    (dpr:Despr_1637, dpr:Despr_2003)
    (dpr:Despr_1637, dpr:Despr_2089)
    (dpr:Despr_1640, dpr:Despr_2189)
    (dpr:Despr_1640, dpr:Despr_2956)
    (dpr:Despr_1776, dpr:Despr_2311)
    (dpr:Despr_1832, dpr:Despr_2394)
    (dpr:Despr_1832, dpr:Despr_3037)
    (dpr:Despr_1881, dpr:Despr_1928)
    (dpr:Despr_1896, dpr:Despr_2908)
    (dpr:Despr_2003, dpr:Despr_2089)
    (dpr:Despr_2009, dpr:Despr_2670)
    (dpr:Despr_2011, dpr:Despr_2500)
    (dpr:Despr_2011, dpr:Despr_2665)
    (dpr:Despr_2042, dpr:Despr_2813)
    (dpr:Despr_2042, dpr:Despr_2865)
    (dpr:Despr_2042, dpr:Despr_2867)
    (dpr:Despr_2042, dpr:Despr_2873)
    (dpr:Despr_2092, dpr:Despr_2093)
    (dpr:Despr_2189, dpr:Despr_2956)
    (dpr:Despr_2283, dpr:Despr_3183)
    (dpr:Despr_2289, dpr:Despr_2324)
    (dpr:Despr_2346, dpr:Despr_2376)
    (dpr:Despr_2394, dpr:Despr_3037)
    (dpr:Despr_2813, dpr:Despr_2865)
    (dpr:Despr_2813, dpr:Despr_2867)
    (dpr:Despr_2813, dpr:Despr_2873)
    (dpr:Despr_2865, dpr:Despr_2867)
    (dpr:Despr_2865, dpr:Despr_2873)
    (dpr:Despr_2867, dpr:Despr_2873)
    (dpr:Despr_2977, dpr:Despr_3152)
    (dpr:Despr_2980, dpr:Despr_3256)
    (dpr:Despr_2989, dpr:Despr_3183)
    (dpr:Despr_3102, dpr:Despr_3332)
    (dpr:Despr_3168, dpr:Despr_3306)
    (dps:DP0014, dps:DPPB70)
    (dps:DP0022, dps:DPPB68)
    (dps:DP0026, dps:DP1007)
    (dps:DP0026, dps:DPPB64)
    (dps:DP0044, dps:DP2221)
    (dps:DP0045, dps:DP2220)
    (dps:DP0045, dps:DP2716)
    (dps:DP0059, dps:DP1022)
    (dps:DP0067, dps:DP0555)
    (dps:DP0067, dps:DP1333)
    (dps:DP0103, dps:DP0822)
    (dps:DP0106, dps:DP0437)
    (dps:DP0394, dps:DP1088)
    (dps:DP0475, dps:DP2376)
    (dps:DP0540, dps:DP0544)
    (dps:DP0555, dps:DP1333)
    (dps:DP0555, dps:DP2097)
    (dps:DP0555, dps:DPPB37)
    (dps:DP0660, dps:DP2768)
    (dps:DP0784, dps:DP1431)
    (dps:DP0812, dps:DP2548)
    (dps:DP0825, dps:DP2097)
    (dps:DP0825, dps:DPPB37)
    (dps:DP0950, dps:DP0951)
    (dps:DP0950, dps:DP0952)
    (dps:DP0950, dps:DP0955)
    (dps:DP0951, dps:DP0952)
    (dps:DP0951, dps:DP0955)
    (dps:DP0952, dps:DP0955)
    (dps:DP1007, dps:DPPB64)
    (dps:DP1165, dps:DP1905)
    (dps:DP1266, dps:DP1272)
    (dps:DP1331, dps:DP1629)
    (dps:DP1472, dps:DP2110)
    (dps:DP1631, dps:DP2949)
    (dps:DP1796, dps:DP2552)
    (dps:DP1796, dps:DP2600)
    (dps:DP1847, dps:DP2407)
    (dps:DP1847, dps:DP2790)
    (dps:DP1859, dps:DP2403)
    (dps:DP1859, dps:DP2788)
    (dps:DP2097, dps:DPPB37)
    (dps:DP2172, dps:DP2991)
    (dps:DP2220, dps:DP2716)
    (dps:DP2403, dps:DP2788)
    (dps:DP2407, dps:DP2790)
    (dps:DP2474, dps:DP2475)
    (dps:DP2474, dps:DP2990)
    (dps:DP2475, dps:DP2990)
    (dps:DP2552, dps:DP2600)
    (drt:Dret_0011, drt:Dret_2110)
    (drt:Dret_0014, drt:Dret_2234)
    (drt:Dret_0042, drt:Dret_1756)
    (drt:Dret_0079, drt:Dret_2027)
    (drt:Dret_0124, drt:Dret_0798)
    (drt:Dret_0143, drt:Dret_0321)
    (drt:Dret_0199, drt:Dret_0202)
    (drt:Dret_0251, drt:Dret_1118)
    (drt:Dret_0251, drt:Dret_1425)
    (drt:Dret_0307, drt:Dret_2499)
    (drt:Dret_0340, drt:Dret_1397)
    (drt:Dret_0439, drt:Dret_1100)
    (drt:Dret_0460, drt:Dret_1139)
    (drt:Dret_0460, drt:Dret_2408)
    (drt:Dret_0460, drt:Dret_2432)
    (drt:Dret_0505, drt:Dret_1107)
    (drt:Dret_0537, drt:Dret_0830)
    (drt:Dret_0542, drt:Dret_0772)
    (drt:Dret_0542, drt:Dret_1907)
    (drt:Dret_0704, drt:Dret_1010)
    (drt:Dret_0730, drt:Dret_2103)
    (drt:Dret_0772, drt:Dret_1907)
    (drt:Dret_0818, drt:Dret_1756)
    (drt:Dret_0818, drt:Dret_2132)
    (drt:Dret_0818, drt:Dret_2481)
    (drt:Dret_0830, drt:Dret_1385)
    (drt:Dret_1046, drt:Dret_2421)
    (drt:Dret_1118, drt:Dret_1425)
    (drt:Dret_1139, drt:Dret_2408)
    (drt:Dret_1139, drt:Dret_2432)
    (drt:Dret_1384, drt:Dret_1409)
    (drt:Dret_1459, drt:Dret_1706)
    (drt:Dret_1756, drt:Dret_2132)
    (drt:Dret_1756, drt:Dret_2481)
    (drt:Dret_1968, drt:Dret_2034)
    (drt:Dret_2102, drt:Dret_2429)
    (drt:Dret_2132, drt:Dret_2481)
    (drt:Dret_2408, drt:Dret_2432)
    (dsa:Desal_0017, dsa:Desal_1784)
    (dsa:Desal_0041, dsa:Desal_0990)
    (dsa:Desal_0041, dsa:Desal_2027)
    (dsa:Desal_0041, dsa:Desal_2493)
    (dsa:Desal_0092, dsa:Desal_0152)
    (dsa:Desal_0092, dsa:Desal_0743)
    (dsa:Desal_0092, dsa:Desal_2829)
    (dsa:Desal_0136, dsa:Desal_2862)
    (dsa:Desal_0143, dsa:Desal_2527)
    (dsa:Desal_0152, dsa:Desal_0743)
    (dsa:Desal_0152, dsa:Desal_2829)
    (dsa:Desal_0178, dsa:Desal_3407)
    (dsa:Desal_0250, dsa:Desal_0650)
    (dsa:Desal_0250, dsa:Desal_2004)
    (dsa:Desal_0284, dsa:Desal_0289)
    (dsa:Desal_0284, dsa:Desal_1318)
    (dsa:Desal_0289, dsa:Desal_1318)
    (dsa:Desal_0368, dsa:Desal_1338)
    (dsa:Desal_0408, dsa:Desal_1363)
    (dsa:Desal_0408, dsa:Desal_1745)
    (dsa:Desal_0408, dsa:Desal_1818)
    (dsa:Desal_0408, dsa:Desal_3739)
    (dsa:Desal_0523, dsa:Desal_0538)
    (dsa:Desal_0523, dsa:Desal_0658)
    (dsa:Desal_0538, dsa:Desal_0658)
    (dsa:Desal_0541, dsa:Desal_0576)
    (dsa:Desal_0541, dsa:Desal_0660)
    (dsa:Desal_0558, dsa:Desal_0574)
    (dsa:Desal_0558, dsa:Desal_0740)
    (dsa:Desal_0559, dsa:Desal_0575)
    (dsa:Desal_0559, dsa:Desal_3668)
    (dsa:Desal_0574, dsa:Desal_0740)
    (dsa:Desal_0575, dsa:Desal_3668)
    (dsa:Desal_0576, dsa:Desal_0660)
    (dsa:Desal_0616, dsa:Desal_3305)
    (dsa:Desal_0650, dsa:Desal_2004)
    (dsa:Desal_0657, dsa:Desal_1305)
    (dsa:Desal_0661, dsa:Desal_3652)
    (dsa:Desal_0743, dsa:Desal_2464)
    (dsa:Desal_0743, dsa:Desal_2829)
    (dsa:Desal_0753, dsa:Desal_2978)
    (dsa:Desal_0836, dsa:Desal_0837)
    (dsa:Desal_0990, dsa:Desal_2027)
    (dsa:Desal_0990, dsa:Desal_2493)
    (dsa:Desal_1082, dsa:Desal_3603)
    (dsa:Desal_1093, dsa:Desal_1585)
    (dsa:Desal_1102, dsa:Desal_2208)
    (dsa:Desal_1102, dsa:Desal_2266)
    (dsa:Desal_1363, dsa:Desal_1745)
    (dsa:Desal_1363, dsa:Desal_1818)
    (dsa:Desal_1363, dsa:Desal_3739)
    (dsa:Desal_1479, dsa:Desal_2397)
    (dsa:Desal_1582, dsa:Desal_1998)
    (dsa:Desal_1628, dsa:Desal_2872)
    (dsa:Desal_1628, dsa:Desal_3397)
    (dsa:Desal_1645, dsa:Desal_2033)
    (dsa:Desal_1645, dsa:Desal_3834)
    (dsa:Desal_1745, dsa:Desal_1818)
    (dsa:Desal_1745, dsa:Desal_3739)
    (dsa:Desal_1769, dsa:Desal_2398)
    (dsa:Desal_1818, dsa:Desal_3739)
    (dsa:Desal_1910, dsa:Desal_3742)
    (dsa:Desal_2027, dsa:Desal_2493)
    (dsa:Desal_2033, dsa:Desal_2682)
    (dsa:Desal_2033, dsa:Desal_3834)
    (dsa:Desal_2037, dsa:Desal_2198)
    (dsa:Desal_2170, dsa:Desal_3566)
    (dsa:Desal_2198, dsa:Desal_2676)
    (dsa:Desal_2302, dsa:Desal_2437)
    (dsa:Desal_2682, dsa:Desal_3834)
    (dsa:Desal_2806, dsa:Desal_3025)
    (dsa:Desal_2862, dsa:Desal_3356)
    (dsa:Desal_2872, dsa:Desal_3397)
    (dsa:Desal_2997, dsa:Desal_3027)
    (dsa:Desal_3010, dsa:Desal_3055)
    (dsa:Desal_3303, dsa:Desal_3402)
    (dsa:Desal_3407, dsa:Desal_3772)
    (dsf:UWK_00066, dsf:UWK_03051)
    (dsf:UWK_00067, dsf:UWK_03052)
    (dsf:UWK_00087, dsf:UWK_00094)
    (dsf:UWK_00105, dsf:UWK_01819)
    (dsf:UWK_00122, dsf:UWK_00143)
    (dsf:UWK_00122, dsf:UWK_00144)
    (dsf:UWK_00122, dsf:UWK_02571)
    (dsf:UWK_00122, dsf:UWK_02973)
    (dsf:UWK_00132, dsf:UWK_02569)
    (dsf:UWK_00132, dsf:UWK_02977)
    (dsf:UWK_00143, dsf:UWK_00144)
    (dsf:UWK_00143, dsf:UWK_02571)
    (dsf:UWK_00143, dsf:UWK_02973)
    (dsf:UWK_00144, dsf:UWK_02571)
    (dsf:UWK_00144, dsf:UWK_02973)
    (dsf:UWK_00180, dsf:UWK_02799)
    (dsf:UWK_00180, dsf:UWK_03410)
    (dsf:UWK_00304, dsf:UWK_00318)
    (dsf:UWK_00304, dsf:UWK_00709)
    (dsf:UWK_00316, dsf:UWK_03294)
    (dsf:UWK_00318, dsf:UWK_00709)
    (dsf:UWK_00454, dsf:UWK_02742)
    (dsf:UWK_00579, dsf:UWK_01937)
    (dsf:UWK_00627, dsf:UWK_02355)
    (dsf:UWK_00627, dsf:UWK_02650)
    (dsf:UWK_00683, dsf:UWK_00793)
    (dsf:UWK_00704, dsf:UWK_00709)
    (dsf:UWK_00789, dsf:UWK_01687)
    (dsf:UWK_00827, dsf:UWK_02784)
    (dsf:UWK_00846, dsf:UWK_01435)
    (dsf:UWK_00965, dsf:UWK_02667)
    (dsf:UWK_00991, dsf:UWK_02122)
    (dsf:UWK_00991, dsf:UWK_03294)
    (dsf:UWK_01050, dsf:UWK_01840)
    (dsf:UWK_01152, dsf:UWK_03535)
    (dsf:UWK_01260, dsf:UWK_03510)
    (dsf:UWK_01351, dsf:UWK_01777)
    (dsf:UWK_01351, dsf:UWK_01801)
    (dsf:UWK_01372, dsf:UWK_01373)
    (dsf:UWK_01373, dsf:UWK_01758)
    (dsf:UWK_01482, dsf:UWK_01685)
    (dsf:UWK_01506, dsf:UWK_02745)
    (dsf:UWK_01617, dsf:UWK_03336)
    (dsf:UWK_01660, dsf:UWK_02972)
    (dsf:UWK_01662, dsf:UWK_03406)
    (dsf:UWK_01777, dsf:UWK_01801)
    (dsf:UWK_01819, dsf:UWK_02241)
    (dsf:UWK_01838, dsf:UWK_02522)
    (dsf:UWK_01915, dsf:UWK_02087)
    (dsf:UWK_01920, dsf:UWK_02430)
    (dsf:UWK_01920, dsf:UWK_02594)
    (dsf:UWK_02316, dsf:UWK_02927)
    (dsf:UWK_02323, dsf:UWK_02569)
    (dsf:UWK_02355, dsf:UWK_02650)
    (dsf:UWK_02372, dsf:UWK_02435)
    (dsf:UWK_02372, dsf:UWK_03174)
    (dsf:UWK_02430, dsf:UWK_02594)
    (dsf:UWK_02435, dsf:UWK_03174)
    (dsf:UWK_02496, dsf:UWK_03539)
    (dsf:UWK_02513, dsf:UWK_03421)
    (dsf:UWK_02514, dsf:UWK_02797)
    (dsf:UWK_02569, dsf:UWK_02977)
    (dsf:UWK_02571, dsf:UWK_02973)
    (dsf:UWK_02595, dsf:UWK_02885)
    (dsf:UWK_02799, dsf:UWK_03410)
    (dsf:UWK_03000, dsf:UWK_03057)
    (dsf:UWK_03329, dsf:UWK_03366)
    (dti:Desti_0036, dti:Desti_2232)
    (dti:Desti_0036, dti:Desti_5358)
    (dti:Desti_0051, dti:Desti_4903)
    (dti:Desti_0057, dti:Desti_0426)
    (dti:Desti_0059, dti:Desti_2327)
    (dti:Desti_0059, dti:Desti_4020)
    (dti:Desti_0062, dti:Desti_3199)
    (dti:Desti_0148, dti:Desti_1492)
    (dti:Desti_0149, dti:Desti_2111)
    (dti:Desti_0149, dti:Desti_3139)
    (dti:Desti_0205, dti:Desti_1014)
    (dti:Desti_0205, dti:Desti_3300)
    (dti:Desti_0219, dti:Desti_0353)
    (dti:Desti_0219, dti:Desti_0901)
    (dti:Desti_0219, dti:Desti_1366)
    (dti:Desti_0219, dti:Desti_1457)
    (dti:Desti_0219, dti:Desti_1808)
    (dti:Desti_0219, dti:Desti_2003)
    (dti:Desti_0219, dti:Desti_2341)
    (dti:Desti_0219, dti:Desti_2345)
    (dti:Desti_0219, dti:Desti_2348)
    (dti:Desti_0219, dti:Desti_2479)
    (dti:Desti_0219, dti:Desti_2797)
    (dti:Desti_0219, dti:Desti_3164)
    (dti:Desti_0219, dti:Desti_3693)
    (dti:Desti_0219, dti:Desti_4164)
    (dti:Desti_0219, dti:Desti_4337)
    (dti:Desti_0219, dti:Desti_4907)
    (dti:Desti_0225, dti:Desti_2739)
    (dti:Desti_0225, dti:Desti_2740)
    (dti:Desti_0234, dti:Desti_1206)
    (dti:Desti_0234, dti:Desti_2998)
    (dti:Desti_0240, dti:Desti_0755)
    (dti:Desti_0240, dti:Desti_1340)
    (dti:Desti_0353, dti:Desti_0901)
    (dti:Desti_0353, dti:Desti_1366)
    (dti:Desti_0353, dti:Desti_1457)
    (dti:Desti_0353, dti:Desti_1808)
    (dti:Desti_0353, dti:Desti_2003)
    (dti:Desti_0353, dti:Desti_2345)
    (dti:Desti_0353, dti:Desti_2348)
    (dti:Desti_0353, dti:Desti_2479)
    (dti:Desti_0353, dti:Desti_2797)
    (dti:Desti_0353, dti:Desti_2892)
    (dti:Desti_0353, dti:Desti_3164)
    (dti:Desti_0353, dti:Desti_3693)
    (dti:Desti_0353, dti:Desti_4164)
    (dti:Desti_0353, dti:Desti_4337)
    (dti:Desti_0353, dti:Desti_4907)
    (dti:Desti_0395, dti:Desti_0830)
    (dti:Desti_0395, dti:Desti_1171)
    (dti:Desti_0441, dti:Desti_0981)
    (dti:Desti_0441, dti:Desti_2096)
    (dti:Desti_0441, dti:Desti_4769)
    (dti:Desti_0441, dti:Desti_5499)
    (dti:Desti_0473, dti:Desti_2739)
    (dti:Desti_0504, dti:Desti_4345)
    (dti:Desti_0569, dti:Desti_0774)
    (dti:Desti_0569, dti:Desti_1836)
    (dti:Desti_0569, dti:Desti_4547)
    (dti:Desti_0569, dti:Desti_4995)
    (dti:Desti_0754, dti:Desti_4149)
    (dti:Desti_0755, dti:Desti_1340)
    (dti:Desti_0757, dti:Desti_4402)
    (dti:Desti_0757, dti:Desti_5563)
    (dti:Desti_0759, dti:Desti_1036)
    (dti:Desti_0759, dti:Desti_2825)
    (dti:Desti_0759, dti:Desti_3101)
    (dti:Desti_0774, dti:Desti_0925)
    (dti:Desti_0774, dti:Desti_0942)
    (dti:Desti_0774, dti:Desti_4572)
    (dti:Desti_0802, dti:Desti_2957)
    (dti:Desti_0830, dti:Desti_1171)
    (dti:Desti_0874, dti:Desti_1662)
    (dti:Desti_0874, dti:Desti_2134)
    (dti:Desti_0874, dti:Desti_4384)
    (dti:Desti_0874, dti:Desti_5141)
    (dti:Desti_0881, dti:Desti_0896)
    (dti:Desti_0881, dti:Desti_2278)
    (dti:Desti_0881, dti:Desti_2371)
    (dti:Desti_0881, dti:Desti_3356)
    (dti:Desti_0896, dti:Desti_2278)
    (dti:Desti_0896, dti:Desti_2371)
    (dti:Desti_0901, dti:Desti_1366)
    (dti:Desti_0901, dti:Desti_1457)
    (dti:Desti_0901, dti:Desti_1808)
    (dti:Desti_0901, dti:Desti_2003)
    (dti:Desti_0901, dti:Desti_2341)
    (dti:Desti_0901, dti:Desti_2345)
    (dti:Desti_0901, dti:Desti_2348)
    (dti:Desti_0901, dti:Desti_2479)
    (dti:Desti_0901, dti:Desti_2797)
    (dti:Desti_0901, dti:Desti_3164)
    (dti:Desti_0901, dti:Desti_4164)
    (dti:Desti_0901, dti:Desti_4907)
    (dti:Desti_0925, dti:Desti_0942)
    (dti:Desti_0925, dti:Desti_4572)
    (dti:Desti_0927, dti:Desti_1600)
    (dti:Desti_0927, dti:Desti_2811)
    (dti:Desti_0927, dti:Desti_3611)
    (dti:Desti_0942, dti:Desti_4572)
    (dti:Desti_0981, dti:Desti_2096)
    (dti:Desti_0981, dti:Desti_4769)
    (dti:Desti_0981, dti:Desti_5499)
    (dti:Desti_0988, dti:Desti_4113)
    (dti:Desti_1014, dti:Desti_3300)
    (dti:Desti_1036, dti:Desti_2825)
    (dti:Desti_1036, dti:Desti_3101)
    (dti:Desti_1039, dti:Desti_2110)
    (dti:Desti_1152, dti:Desti_3121)
    (dti:Desti_1190, dti:Desti_3729)
    (dti:Desti_1200, dti:Desti_1201)
    (dti:Desti_1200, dti:Desti_1674)
    (dti:Desti_1200, dti:Desti_4911)
    (dti:Desti_1201, dti:Desti_1674)
    (dti:Desti_1201, dti:Desti_4911)
    (dti:Desti_1206, dti:Desti_2998)
    (dti:Desti_1259, dti:Desti_3121)
    (dti:Desti_1266, dti:Desti_4116)
    (dti:Desti_1366, dti:Desti_1457)
    (dti:Desti_1366, dti:Desti_1808)
    (dti:Desti_1366, dti:Desti_2003)
    (dti:Desti_1366, dti:Desti_2479)
    (dti:Desti_1366, dti:Desti_2797)
    (dti:Desti_1366, dti:Desti_2892)
    (dti:Desti_1366, dti:Desti_3164)
    (dti:Desti_1366, dti:Desti_3693)
    (dti:Desti_1366, dti:Desti_4337)
    (dti:Desti_1366, dti:Desti_4907)
    (dti:Desti_1457, dti:Desti_1808)
    (dti:Desti_1457, dti:Desti_2003)
    (dti:Desti_1457, dti:Desti_2341)
    (dti:Desti_1457, dti:Desti_2345)
    (dti:Desti_1457, dti:Desti_2348)
    (dti:Desti_1457, dti:Desti_2479)
    (dti:Desti_1457, dti:Desti_2797)
    (dti:Desti_1457, dti:Desti_3164)
    (dti:Desti_1457, dti:Desti_3693)
    (dti:Desti_1457, dti:Desti_4164)
    (dti:Desti_1457, dti:Desti_4337)
    (dti:Desti_1457, dti:Desti_4907)
    (dti:Desti_1600, dti:Desti_2811)
    (dti:Desti_1600, dti:Desti_3611)
    (dti:Desti_1662, dti:Desti_2134)
    (dti:Desti_1662, dti:Desti_4384)
    (dti:Desti_1662, dti:Desti_5141)
    (dti:Desti_1674, dti:Desti_4911)
    (dti:Desti_1695, dti:Desti_3108)
    (dti:Desti_1700, dti:Desti_4704)
    (dti:Desti_1700, dti:Desti_4705)
    (dti:Desti_1808, dti:Desti_2003)
    (dti:Desti_1808, dti:Desti_2345)
    (dti:Desti_1808, dti:Desti_2348)
    (dti:Desti_1808, dti:Desti_2479)
    (dti:Desti_1808, dti:Desti_2797)
    (dti:Desti_1808, dti:Desti_2892)
    (dti:Desti_1808, dti:Desti_3164)
    (dti:Desti_1808, dti:Desti_3693)
    (dti:Desti_1808, dti:Desti_4164)
    (dti:Desti_1808, dti:Desti_4337)
    (dti:Desti_1808, dti:Desti_4907)
    (dti:Desti_1836, dti:Desti_4547)
    (dti:Desti_1836, dti:Desti_4995)
    (dti:Desti_1892, dti:Desti_5539)
    (dti:Desti_2003, dti:Desti_2341)
    (dti:Desti_2003, dti:Desti_2345)
    (dti:Desti_2003, dti:Desti_2348)
    (dti:Desti_2003, dti:Desti_2479)
    (dti:Desti_2003, dti:Desti_2797)
    (dti:Desti_2003, dti:Desti_2892)
    (dti:Desti_2003, dti:Desti_3164)
    (dti:Desti_2003, dti:Desti_3693)
    (dti:Desti_2003, dti:Desti_4164)
    (dti:Desti_2003, dti:Desti_4337)
    (dti:Desti_2003, dti:Desti_4907)
    (dti:Desti_2096, dti:Desti_4769)
    (dti:Desti_2096, dti:Desti_5499)
    (dti:Desti_2111, dti:Desti_3139)
    (dti:Desti_2134, dti:Desti_4384)
    (dti:Desti_2134, dti:Desti_5141)
    (dti:Desti_2232, dti:Desti_5358)
    (dti:Desti_2278, dti:Desti_2371)
    (dti:Desti_2278, dti:Desti_3356)
    (dti:Desti_2327, dti:Desti_4020)
    (dti:Desti_2341, dti:Desti_2345)
    (dti:Desti_2341, dti:Desti_2348)
    (dti:Desti_2341, dti:Desti_2479)
    (dti:Desti_2341, dti:Desti_2797)
    (dti:Desti_2341, dti:Desti_3164)
    (dti:Desti_2341, dti:Desti_4164)
    (dti:Desti_2341, dti:Desti_4907)
    (dti:Desti_2345, dti:Desti_2348)
    (dti:Desti_2345, dti:Desti_2479)
    (dti:Desti_2345, dti:Desti_2797)
    (dti:Desti_2345, dti:Desti_3164)
    (dti:Desti_2345, dti:Desti_4164)
    (dti:Desti_2345, dti:Desti_4907)
    (dti:Desti_2348, dti:Desti_2479)
    (dti:Desti_2348, dti:Desti_2797)
    (dti:Desti_2348, dti:Desti_3164)
    (dti:Desti_2348, dti:Desti_4164)
    (dti:Desti_2348, dti:Desti_4907)
    (dti:Desti_2371, dti:Desti_3356)
    (dti:Desti_2479, dti:Desti_2797)
    (dti:Desti_2479, dti:Desti_2892)
    (dti:Desti_2479, dti:Desti_3164)
    (dti:Desti_2479, dti:Desti_3693)
    (dti:Desti_2479, dti:Desti_4164)
    (dti:Desti_2479, dti:Desti_4337)
    (dti:Desti_2479, dti:Desti_4907)
    (dti:Desti_2554, dti:Desti_4464)
    (dti:Desti_2576, dti:Desti_5667)
    (dti:Desti_2718, dti:Desti_5320)
    (dti:Desti_2739, dti:Desti_2740)
    (dti:Desti_2768, dti:Desti_2856)
    (dti:Desti_2768, dti:Desti_4587)
    (dti:Desti_2797, dti:Desti_3164)
    (dti:Desti_2797, dti:Desti_3693)
    (dti:Desti_2797, dti:Desti_4164)
    (dti:Desti_2797, dti:Desti_4337)
    (dti:Desti_2797, dti:Desti_4907)
    (dti:Desti_2811, dti:Desti_3611)
    (dti:Desti_2825, dti:Desti_3101)
    (dti:Desti_2856, dti:Desti_4587)
    (dti:Desti_2892, dti:Desti_3693)
    (dti:Desti_2892, dti:Desti_4337)
    (dti:Desti_2892, dti:Desti_4907)
    (dti:Desti_2988, dti:Desti_4182)
    (dti:Desti_2988, dti:Desti_4732)
    (dti:Desti_3051, dti:Desti_3628)
    (dti:Desti_3164, dti:Desti_4164)
    (dti:Desti_3164, dti:Desti_4907)
    (dti:Desti_3578, dti:Desti_3894)
    (dti:Desti_3650, dti:Desti_3747)
    (dti:Desti_3684, dti:Desti_3834)
    (dti:Desti_3684, dti:Desti_4083)
    (dti:Desti_3693, dti:Desti_4337)
    (dti:Desti_3693, dti:Desti_4907)
    (dti:Desti_3834, dti:Desti_4083)
    (dti:Desti_4150, dti:Desti_4253)
    (dti:Desti_4164, dti:Desti_4907)
    (dti:Desti_4182, dti:Desti_4732)
    (dti:Desti_4337, dti:Desti_4907)
    (dti:Desti_4384, dti:Desti_5141)
    (dti:Desti_4402, dti:Desti_5563)
    (dti:Desti_4450, dti:Desti_4868)
    (dti:Desti_4547, dti:Desti_4995)
    (dti:Desti_4769, dti:Desti_5499)
    (dto:TOL2_C00330, dto:TOL2_C15960)
    (dto:TOL2_C00560, dto:TOL2_C39750)
    (dto:TOL2_C02640, dto:TOL2_C13310)
    (dto:TOL2_C03020, dto:TOL2_C03030)
    (dto:TOL2_C03020, dto:TOL2_C41730)
    (dto:TOL2_C03020, dto:TOL2_C43490)
    (dto:TOL2_C03020, dto:TOL2_C43570)
    (dto:TOL2_C03030, dto:TOL2_C41730)
    (dto:TOL2_C03030, dto:TOL2_C43490)
    (dto:TOL2_C03030, dto:TOL2_C43570)
    (dto:TOL2_C03360, dto:TOL2_C41270)
    (dto:TOL2_C03820, dto:TOL2_C04490)
    (dto:TOL2_C03820, dto:TOL2_C38530)
    (dto:TOL2_C04170, dto:TOL2_C15960)
    (dto:TOL2_C05070, dto:TOL2_C28470)
    (dto:TOL2_C05080, dto:TOL2_C28480)
    (dto:TOL2_C05120, dto:TOL2_C29790)
    (dto:TOL2_C05220, dto:TOL2_C26900)
    (dto:TOL2_C05220, dto:TOL2_C27090)
    (dto:TOL2_C05220, dto:TOL2_C27260)
    (dto:TOL2_C05220, dto:TOL2_C27460)
    (dto:TOL2_C05220, dto:TOL2_C27650)
    (dto:TOL2_C05220, dto:TOL2_C31520)
    (dto:TOL2_C05220, dto:TOL2_C37120)
    (dto:TOL2_C05370, dto:TOL2_C22520)
    (dto:TOL2_C07190, dto:TOL2_C16630)
    (dto:TOL2_C08210, dto:TOL2_C12360)
    (dto:TOL2_C08210, dto:TOL2_C23400)
    (dto:TOL2_C08210, dto:TOL2_C35200)
    (dto:TOL2_C08210, dto:TOL2_C35290)
    (dto:TOL2_C08510, dto:TOL2_C33600)
    (dto:TOL2_C10040, dto:TOL2_C42990)
    (dto:TOL2_C10990, dto:TOL2_C13310)
    (dto:TOL2_C11340, dto:TOL2_C22880)
    (dto:TOL2_C11440, dto:TOL2_C39790)
    (dto:TOL2_C12360, dto:TOL2_C23400)
    (dto:TOL2_C12360, dto:TOL2_C35200)
    (dto:TOL2_C12360, dto:TOL2_C35290)
    (dto:TOL2_C13270, dto:TOL2_C13420)
    (dto:TOL2_C15720, dto:TOL2_C42790)
    (dto:TOL2_C16510, dto:TOL2_C21050)
    (dto:TOL2_C16510, dto:TOL2_C22640)
    (dto:TOL2_C16630, dto:TOL2_C16640)
    (dto:TOL2_C17330, dto:TOL2_C38950)
    (dto:TOL2_C17500, dto:TOL2_C18400)
    (dto:TOL2_C18190, dto:TOL2_C18860)
    (dto:TOL2_C21050, dto:TOL2_C22640)
    (dto:TOL2_C21920, dto:TOL2_C24560)
    (dto:TOL2_C22060, dto:TOL2_C39980)
    (dto:TOL2_C23200, dto:TOL2_C35960)
    (dto:TOL2_C23400, dto:TOL2_C35200)
    (dto:TOL2_C23400, dto:TOL2_C35290)
    (dto:TOL2_C24750, dto:TOL2_C24800)
    (dto:TOL2_C26900, dto:TOL2_C27090)
    (dto:TOL2_C26900, dto:TOL2_C27260)
    (dto:TOL2_C26900, dto:TOL2_C27460)
    (dto:TOL2_C26900, dto:TOL2_C27650)
    (dto:TOL2_C26900, dto:TOL2_C37120)
    (dto:TOL2_C26900, dto:TOL2_C38520)
    (dto:TOL2_C27090, dto:TOL2_C27260)
    (dto:TOL2_C27090, dto:TOL2_C27460)
    (dto:TOL2_C27090, dto:TOL2_C27650)
    (dto:TOL2_C27090, dto:TOL2_C37120)
    (dto:TOL2_C27090, dto:TOL2_C38520)
    (dto:TOL2_C27260, dto:TOL2_C27460)
    (dto:TOL2_C27260, dto:TOL2_C27650)
    (dto:TOL2_C27260, dto:TOL2_C37120)
    (dto:TOL2_C27260, dto:TOL2_C38520)
    (dto:TOL2_C27460, dto:TOL2_C27650)
    (dto:TOL2_C27460, dto:TOL2_C37120)
    (dto:TOL2_C27460, dto:TOL2_C38520)
    (dto:TOL2_C27650, dto:TOL2_C37120)
    (dto:TOL2_C27650, dto:TOL2_C38520)
    (dto:TOL2_C28080, dto:TOL2_C28120)
    (dto:TOL2_C31520, dto:TOL2_C37120)
    (dto:TOL2_C35200, dto:TOL2_C35290)
    (dto:TOL2_C36220, dto:TOL2_C43000)
    (dto:TOL2_C38340, dto:TOL2_C38550)
    (dto:TOL2_C41730, dto:TOL2_C43490)
    (dto:TOL2_C41730, dto:TOL2_C43570)
    (dto:TOL2_C43490, dto:TOL2_C43570)
    (dvu:DVU0085, dvu:DVU0470)
    (dvu:DVU0152, dvu:DVU0246)
    (dvu:DVU0152, dvu:DVU1833)
    (dvu:DVU0152, dvu:DVU2739)
    (dvu:DVU0152, dvu:DVU3214)
    (dvu:DVU0152, dvu:DVU3237)
    (dvu:DVU0246, dvu:DVU2739)
    (dvu:DVU0246, dvu:DVU3214)
    (dvu:DVU0246, dvu:DVU3237)
    (dvu:DVU0283, dvu:DVU0377)
    (dvu:DVU0283, dvu:DVU1457)
    (dvu:DVU0283, dvu:DVU1838)
    (dvu:DVU0341, dvu:DVU3114)
    (dvu:DVU0360, dvu:DVU1376)
    (dvu:DVU0360, dvu:DVU3293)
    (dvu:DVU0377, dvu:DVU1838)
    (dvu:DVU0477, dvu:DVU2985)
    (dvu:DVU0489, dvu:DVU1615)
    (dvu:DVU0489, dvu:DVU2735)
    (dvu:DVU0489, dvu:DVU3253)
    (dvu:DVU0565, dvu:DVU2144)
    (dvu:DVU0626, dvu:DVU1377)
    (dvu:DVU0732, dvu:DVU1196)
    (dvu:DVU0732, dvu:DVU1927)
    (dvu:DVU0748, dvu:DVU1453)
    (dvu:DVU0748, dvu:DVU2250)
    (dvu:DVU0748, dvu:DVU2969)
    (dvu:DVU0827, dvu:DVU3027)
    (dvu:DVU0841, dvu:DVU3223)
    (dvu:DVU0951, dvu:DVU2990)
    (dvu:DVU1196, dvu:DVU1927)
    (dvu:DVU1204, dvu:DVU2563)
    (dvu:DVU1206, dvu:DVU3137)
    (dvu:DVU1350, dvu:DVU2530)
    (dvu:DVU1360, dvu:DVU1364)
    (dvu:DVU1360, dvu:DVU2996)
    (dvu:DVU1360, dvu:DVU3356)
    (dvu:DVU1364, dvu:DVU3356)
    (dvu:DVU1376, dvu:DVU3293)
    (dvu:DVU1453, dvu:DVU2250)
    (dvu:DVU1453, dvu:DVU2969)
    (dvu:DVU1453, dvu:DVU3119)
    (dvu:DVU1457, dvu:DVU1838)
    (dvu:DVU1615, dvu:DVU2735)
    (dvu:DVU1615, dvu:DVU3253)
    (dvu:DVU1647, dvu:DVU2566)
    (dvu:DVU1693, dvu:DVU2552)
    (dvu:DVU1833, dvu:DVU2739)
    (dvu:DVU1833, dvu:DVU3214)
    (dvu:DVU1914, dvu:DVU2981)
    (dvu:DVU1940, dvu:DVU2673)
    (dvu:DVU1940, dvu:DVU3132)
    (dvu:DVU2091, dvu:DVU2362)
    (dvu:DVU2250, dvu:DVU2969)
    (dvu:DVU2396, dvu:DVU2405)
    (dvu:DVU2396, dvu:DVU2885)
    (dvu:DVU2396, dvu:DVU2905)
    (dvu:DVU2405, dvu:DVU2885)
    (dvu:DVU2405, dvu:DVU2905)
    (dvu:DVU2559, dvu:DVU3168)
    (dvu:DVU2673, dvu:DVU3132)
    (dvu:DVU2735, dvu:DVU3253)
    (dvu:DVU2739, dvu:DVU3214)
    (dvu:DVU2739, dvu:DVU3237)
    (dvu:DVU2885, dvu:DVU2905)
    (dvu:DVU2969, dvu:DVU3119)
    (dvu:DVU3014, dvu:DVUA0073)
    (dvu:DVU3214, dvu:DVU3237)
    (gao:A2G06_01250, gao:A2G06_08995)
    (gao:A2G06_02140, gao:A2G06_08985)
    (gao:A2G06_03585, gao:A2G06_08130)
    (gao:A2G06_03585, gao:A2G06_13760)
    (gao:A2G06_05615, gao:A2G06_05630)
    (gao:A2G06_05670, gao:A2G06_06115)
    (gao:A2G06_05980, gao:A2G06_09675)
    (gao:A2G06_06120, gao:A2G06_07620)
    (gao:A2G06_06270, gao:A2G06_06650)
    (gao:A2G06_06270, gao:A2G06_14765)
    (gao:A2G06_06620, gao:A2G06_08260)
    (gao:A2G06_06650, gao:A2G06_14765)
    (gao:A2G06_07085, gao:A2G06_08260)
    (gao:A2G06_07325, gao:A2G06_07920)
    (gao:A2G06_08130, gao:A2G06_13760)
    (gao:A2G06_09115, gao:A2G06_13050)
    (gao:A2G06_10540, gao:A2G06_15675)
    (gao:A2G06_10625, gao:A2G06_11490)
    (gao:A2G06_12745, gao:A2G06_14560)
    (gao:A2G06_12745, gao:A2G06_14565)
    (gao:A2G06_13760, gao:A2G06_16175)
    (gao:A2G06_13765, gao:A2G06_16175)
    (gao:A2G06_14560, gao:A2G06_14565)
    (gbm:Gbem_0212, gbm:Gbem_3205)
    (gbm:Gbem_0259, gbm:Gbem_1465)
    (gbm:Gbem_0259, gbm:Gbem_3222)
    (gbm:Gbem_0260, gbm:Gbem_1464)
    (gbm:Gbem_0260, gbm:Gbem_3223)
    (gbm:Gbem_0279, gbm:Gbem_1379)
    (gbm:Gbem_0280, gbm:Gbem_1258)
    (gbm:Gbem_0280, gbm:Gbem_3362)
    (gbm:Gbem_0486, gbm:Gbem_0487)
    (gbm:Gbem_0493, gbm:Gbem_3180)
    (gbm:Gbem_0564, gbm:Gbem_2906)
    (gbm:Gbem_0567, gbm:Gbem_3400)
    (gbm:Gbem_0635, gbm:Gbem_2980)
    (gbm:Gbem_0751, gbm:Gbem_1531)
    (gbm:Gbem_0751, gbm:Gbem_3650)
    (gbm:Gbem_0823, gbm:Gbem_1554)
    (gbm:Gbem_0836, gbm:Gbem_2903)
    (gbm:Gbem_0861, gbm:Gbem_3346)
    (gbm:Gbem_0909, gbm:Gbem_0910)
    (gbm:Gbem_1081, gbm:Gbem_1615)
    (gbm:Gbem_1081, gbm:Gbem_1778)
    (gbm:Gbem_1258, gbm:Gbem_3362)
    (gbm:Gbem_1265, gbm:Gbem_2742)
    (gbm:Gbem_1341, gbm:Gbem_1725)
    (gbm:Gbem_1348, gbm:Gbem_2274)
    (gbm:Gbem_1349, gbm:Gbem_2149)
    (gbm:Gbem_1349, gbm:Gbem_2273)
    (gbm:Gbem_1354, gbm:Gbem_1436)
    (gbm:Gbem_1354, gbm:Gbem_2272)
    (gbm:Gbem_1436, gbm:Gbem_2272)
    (gbm:Gbem_1464, gbm:Gbem_3223)
    (gbm:Gbem_1465, gbm:Gbem_3222)
    (gbm:Gbem_1531, gbm:Gbem_3650)
    (gbm:Gbem_1571, gbm:Gbem_3162)
    (gbm:Gbem_1615, gbm:Gbem_1778)
    (gbm:Gbem_1629, gbm:Gbem_2352)
    (gbm:Gbem_1630, gbm:Gbem_2353)
    (gbm:Gbem_1652, gbm:Gbem_3905)
    (gbm:Gbem_1896, gbm:Gbem_3637)
    (gbm:Gbem_1958, gbm:Gbem_3321)
    (gbm:Gbem_1983, gbm:Gbem_3163)
    (gbm:Gbem_2051, gbm:Gbem_3927)
    (gbm:Gbem_2125, gbm:Gbem_2216)
    (gbm:Gbem_2149, gbm:Gbem_2273)
    (gbm:Gbem_2173, gbm:Gbem_2258)
    (gbm:Gbem_2184, gbm:Gbem_2192)
    (gbm:Gbem_2235, gbm:Gbem_2446)
    (gbm:Gbem_2235, gbm:Gbem_3820)
    (gbm:Gbem_2336, gbm:Gbem_3789)
    (gbm:Gbem_2446, gbm:Gbem_3820)
    (gbm:Gbem_2561, gbm:Gbem_3783)
    (gbm:Gbem_2692, gbm:Gbem_2828)
    (gbm:Gbem_2797, gbm:Gbem_3530)
    (gbm:Gbem_2859, gbm:Gbem_4055)
    (gbm:Gbem_3108, gbm:Gbem_3995)
    (gbm:Gbem_3345, gbm:Gbem_4020)
    (gbm:Gbem_3463, gbm:Gbem_3809)
    (gbm:Gbem_3700, gbm:Gbem_3701)
    (geb:GM18_0169, geb:GM18_3247)
    (geb:GM18_0287, geb:GM18_3274)
    (geb:GM18_0288, geb:GM18_3275)
    (geb:GM18_0316, geb:GM18_1241)
    (geb:GM18_0317, geb:GM18_1116)
    (geb:GM18_0317, geb:GM18_3441)
    (geb:GM18_0559, geb:GM18_2665)
    (geb:GM18_0559, geb:GM18_2739)
    (geb:GM18_0634, geb:GM18_4239)
    (geb:GM18_0699, geb:GM18_3789)
    (geb:GM18_0719, geb:GM18_1389)
    (geb:GM18_0730, geb:GM18_2790)
    (geb:GM18_0750, geb:GM18_3424)
    (geb:GM18_0750, geb:GM18_4171)
    (geb:GM18_0779, geb:GM18_3827)
    (geb:GM18_0809, geb:GM18_0810)
    (geb:GM18_0958, geb:GM18_1602)
    (geb:GM18_1054, geb:GM18_3547)
    (geb:GM18_1091, geb:GM18_2560)
    (geb:GM18_1116, geb:GM18_3441)
    (geb:GM18_1123, geb:GM18_2608)
    (geb:GM18_1206, geb:GM18_1956)
    (geb:GM18_1206, geb:GM18_4466)
    (geb:GM18_1211, geb:GM18_1958)
    (geb:GM18_1366, geb:GM18_3598)
    (geb:GM18_1366, geb:GM18_4108)
    (geb:GM18_1403, geb:GM18_1836)
    (geb:GM18_1436, geb:GM18_3257)
    (geb:GM18_1436, geb:GM18_4171)
    (geb:GM18_1438, geb:GM18_1454)
    (geb:GM18_1438, geb:GM18_1672)
    (geb:GM18_1442, geb:GM18_4151)
    (geb:GM18_1443, geb:GM18_4149)
    (geb:GM18_1454, geb:GM18_1672)
    (geb:GM18_1602, geb:GM18_2013)
    (geb:GM18_1602, geb:GM18_2111)
    (geb:GM18_1720, geb:GM18_4095)
    (geb:GM18_1893, geb:GM18_4219)
    (geb:GM18_1956, geb:GM18_4466)
    (geb:GM18_1971, geb:GM18_2068)
    (geb:GM18_1990, geb:GM18_2304)
    (geb:GM18_1990, geb:GM18_3980)
    (geb:GM18_1990, geb:GM18_4250)
    (geb:GM18_2013, geb:GM18_2111)
    (geb:GM18_2054, geb:GM18_2062)
    (geb:GM18_2054, geb:GM18_4063)
    (geb:GM18_2062, geb:GM18_4063)
    (geb:GM18_2157, geb:GM18_4391)
    (geb:GM18_2226, geb:GM18_3132)
    (geb:GM18_2264, geb:GM18_3400)
    (geb:GM18_2304, geb:GM18_3980)
    (geb:GM18_2304, geb:GM18_4250)
    (geb:GM18_2665, geb:GM18_2739)
    (geb:GM18_2719, geb:GM18_4516)
    (geb:GM18_2759, geb:GM18_4463)
    (geb:GM18_2793, geb:GM18_3792)
    (geb:GM18_3075, geb:GM18_4050)
    (geb:GM18_3075, geb:GM18_4055)
    (geb:GM18_3075, geb:GM18_4066)
    (geb:GM18_3077, geb:GM18_4069)
    (geb:GM18_3079, geb:GM18_4453)
    (geb:GM18_3185, geb:GM18_3885)
    (geb:GM18_3257, geb:GM18_3424)
    (geb:GM18_3257, geb:GM18_4171)
    (geb:GM18_3424, geb:GM18_4171)
    (geb:GM18_3598, geb:GM18_4108)
    (geb:GM18_3889, geb:GM18_3891)
    (geb:GM18_3891, geb:GM18_3892)
    (geb:GM18_3980, geb:GM18_4250)
    (geb:GM18_4050, geb:GM18_4055)
    (geb:GM18_4050, geb:GM18_4066)
    (geb:GM18_4055, geb:GM18_4066)
    (geb:GM18_4149, geb:GM18_4150)
    (gem:GM21_0195, gem:GM21_1058)
    (gem:GM21_0244, gem:GM21_1041)
    (gem:GM21_0244, gem:GM21_2788)
    (gem:GM21_0245, gem:GM21_1040)
    (gem:GM21_0245, gem:GM21_2789)
    (gem:GM21_0264, gem:GM21_2903)
    (gem:GM21_0264, gem:GM21_3398)
    (gem:GM21_0265, gem:GM21_0883)
    (gem:GM21_0265, gem:GM21_3025)
    (gem:GM21_0265, gem:GM21_3397)
    (gem:GM21_0503, gem:GM21_0504)
    (gem:GM21_0506, gem:GM21_0509)
    (gem:GM21_0510, gem:GM21_1080)
    (gem:GM21_0510, gem:GM21_2456)
    (gem:GM21_0577, gem:GM21_1319)
    (gem:GM21_0580, gem:GM21_3463)
    (gem:GM21_0718, gem:GM21_3566)
    (gem:GM21_0766, gem:GM21_2685)
    (gem:GM21_0766, gem:GM21_3757)
    (gem:GM21_0883, gem:GM21_3025)
    (gem:GM21_0883, gem:GM21_3397)
    (gem:GM21_0899, gem:GM21_3403)
    (gem:GM21_0900, gem:GM21_4111)
    (gem:GM21_0925, gem:GM21_2258)
    (gem:GM21_1040, gem:GM21_2789)
    (gem:GM21_1041, gem:GM21_2788)
    (gem:GM21_1080, gem:GM21_2456)
    (gem:GM21_1096, gem:GM21_2237)
    (gem:GM21_1097, gem:GM21_2642)
    (gem:GM21_1154, gem:GM21_4090)
    (gem:GM21_1322, gem:GM21_3424)
    (gem:GM21_1355, gem:GM21_4145)
    (gem:GM21_1385, gem:GM21_1547)
    (gem:GM21_1413, gem:GM21_3596)
    (gem:GM21_1499, gem:GM21_3018)
    (gem:GM21_1667, gem:GM21_3867)
    (gem:GM21_1771, gem:GM21_1992)
    (gem:GM21_1771, gem:GM21_3904)
    (gem:GM21_1884, gem:GM21_3873)
    (gem:GM21_1949, gem:GM21_2937)
    (gem:GM21_1950, gem:GM21_2072)
    (gem:GM21_1950, gem:GM21_2936)
    (gem:GM21_1951, gem:GM21_2818)
    (gem:GM21_1951, gem:GM21_2931)
    (gem:GM21_1966, gem:GM21_2050)
    (gem:GM21_1992, gem:GM21_3904)
    (gem:GM21_2011, gem:GM21_2093)
    (gem:GM21_2035, gem:GM21_2043)
    (gem:GM21_2043, gem:GM21_2454)
    (gem:GM21_2072, gem:GM21_2936)
    (gem:GM21_2166, gem:GM21_4011)
    (gem:GM21_2312, gem:GM21_3742)
    (gem:GM21_2457, gem:GM21_3802)
    (gem:GM21_2469, gem:GM21_3180)
    (gem:GM21_2561, gem:GM21_3990)
    (gem:GM21_2662, gem:GM21_3438)
    (gem:GM21_2685, gem:GM21_3757)
    (gem:GM21_2818, gem:GM21_2931)
    (gem:GM21_2903, gem:GM21_3398)
    (gem:GM21_3025, gem:GM21_3397)
    (gem:GM21_3529, gem:GM21_3893)
    (gem:GM21_3795, gem:GM21_3796)
    (geo:Geob_0099, geo:Geob_1910)
    (geo:Geob_0099, geo:Geob_2614)
    (geo:Geob_0150, geo:Geob_1333)
    (geo:Geob_0150, geo:Geob_1637)
    (geo:Geob_0150, geo:Geob_1647)
    (geo:Geob_0247, geo:Geob_0762)
    (geo:Geob_0248, geo:Geob_0761)
    (geo:Geob_0284, geo:Geob_2923)
    (geo:Geob_0378, geo:Geob_2151)
    (geo:Geob_0392, geo:Geob_2171)
    (geo:Geob_0392, geo:Geob_3082)
    (geo:Geob_0461, geo:Geob_3010)
    (geo:Geob_0514, geo:Geob_3549)
    (geo:Geob_0532, geo:Geob_3462)
    (geo:Geob_0543, geo:Geob_1417)
    (geo:Geob_0666, geo:Geob_1368)
    (geo:Geob_0666, geo:Geob_2629)
    (geo:Geob_0666, geo:Geob_3664)
    (geo:Geob_0667, geo:Geob_1002)
    (geo:Geob_0667, geo:Geob_1367)
    (geo:Geob_0692, geo:Geob_0693)
    (geo:Geob_0775, geo:Geob_0776)
    (geo:Geob_0778, geo:Geob_0781)
    (geo:Geob_0805, geo:Geob_1439)
    (geo:Geob_0952, geo:Geob_1550)
    (geo:Geob_1002, geo:Geob_1367)
    (geo:Geob_1002, geo:Geob_1368)
    (geo:Geob_1002, geo:Geob_3664)
    (geo:Geob_1062, geo:Geob_2796)
    (geo:Geob_1062, geo:Geob_2804)
    (geo:Geob_1088, geo:Geob_1753)
    (geo:Geob_1123, geo:Geob_3264)
    (geo:Geob_1129, geo:Geob_1143)
    (geo:Geob_1167, geo:Geob_2897)
    (geo:Geob_1333, geo:Geob_1637)
    (geo:Geob_1333, geo:Geob_1647)
    (geo:Geob_1368, geo:Geob_2629)
    (geo:Geob_1368, geo:Geob_3664)
    (geo:Geob_1403, geo:Geob_2459)
    (geo:Geob_1403, geo:Geob_2530)
    (geo:Geob_1420, geo:Geob_2508)
    (geo:Geob_1458, geo:Geob_2134)
    (geo:Geob_1504, geo:Geob_2938)
    (geo:Geob_1637, geo:Geob_1647)
    (geo:Geob_1656, geo:Geob_2241)
    (geo:Geob_1870, geo:Geob_2923)
    (geo:Geob_1910, geo:Geob_2614)
    (geo:Geob_1911, geo:Geob_2616)
    (geo:Geob_1980, geo:Geob_2507)
    (geo:Geob_1980, geo:Geob_2526)
    (geo:Geob_1980, geo:Geob_3049)
    (geo:Geob_2094, geo:Geob_2661)
    (geo:Geob_2171, geo:Geob_3082)
    (geo:Geob_2295, geo:Geob_2315)
    (geo:Geob_2459, geo:Geob_2530)
    (geo:Geob_2507, geo:Geob_2526)
    (geo:Geob_2507, geo:Geob_3049)
    (geo:Geob_2526, geo:Geob_3049)
    (geo:Geob_2612, geo:Geob_3708)
    (geo:Geob_2629, geo:Geob_3664)
    (geo:Geob_2796, geo:Geob_2804)
    (geo:Geob_3651, geo:Geob_3652)
    (glo:Glov_0210, glo:Glov_0893)
    (glo:Glov_0210, glo:Glov_3585)
    (glo:Glov_0365, glo:Glov_1947)
    (glo:Glov_0418, glo:Glov_1939)
    (glo:Glov_0418, glo:Glov_2418)
    (glo:Glov_0474, glo:Glov_3457)
    (glo:Glov_0479, glo:Glov_1658)
    (glo:Glov_0479, glo:Glov_3365)
    (glo:Glov_0555, glo:Glov_2962)
    (glo:Glov_0584, glo:Glov_2128)
    (glo:Glov_0674, glo:Glov_0675)
    (glo:Glov_0692, glo:Glov_3718)
    (glo:Glov_0757, glo:Glov_1622)
    (glo:Glov_0763, glo:Glov_1937)
    (glo:Glov_0786, glo:Glov_2503)
    (glo:Glov_0795, glo:Glov_2804)
    (glo:Glov_0796, glo:Glov_2182)
    (glo:Glov_0796, glo:Glov_2235)
    (glo:Glov_0808, glo:Glov_1512)
    (glo:Glov_0823, glo:Glov_2405)
    (glo:Glov_0835, glo:Glov_1607)
    (glo:Glov_0892, glo:Glov_1159)
    (glo:Glov_0893, glo:Glov_3585)
    (glo:Glov_0909, glo:Glov_1157)
    (glo:Glov_0981, glo:Glov_2116)
    (glo:Glov_0981, glo:Glov_2538)
    (glo:Glov_1018, glo:Glov_1019)
    (glo:Glov_1018, glo:Glov_3399)
    (glo:Glov_1024, glo:Glov_3068)
    (glo:Glov_1067, glo:Glov_1531)
    (glo:Glov_1099, glo:Glov_2713)
    (glo:Glov_1211, glo:Glov_1213)
    (glo:Glov_1616, glo:Glov_2562)
    (glo:Glov_1658, glo:Glov_3365)
    (glo:Glov_1768, glo:Glov_2600)
    (glo:Glov_1858, glo:Glov_1910)
    (glo:Glov_1934, glo:Glov_2193)
    (glo:Glov_1936, glo:Glov_2194)
    (glo:Glov_1939, glo:Glov_2418)
    (glo:Glov_2038, glo:Glov_3325)
    (glo:Glov_2085, glo:Glov_3149)
    (glo:Glov_2116, glo:Glov_2538)
    (glo:Glov_2182, glo:Glov_2235)
    (glo:Glov_2247, glo:Glov_3139)
    (glo:Glov_2508, glo:Glov_3322)
    (glo:Glov_2764, glo:Glov_3677)
    (glo:Glov_3217, glo:Glov_3634)
    (gme:Gmet_0065, gme:Gmet_3078)
    (gme:Gmet_0104, gme:Gmet_1487)
    (gme:Gmet_0178, gme:Gmet_0551)
    (gme:Gmet_0178, gme:Gmet_0552)
    (gme:Gmet_0205, gme:Gmet_1769)
    (gme:Gmet_0219, gme:Gmet_2019)
    (gme:Gmet_0264, gme:Gmet_1558)
    (gme:Gmet_0264, gme:Gmet_2988)
    (gme:Gmet_0301, gme:Gmet_0337)
    (gme:Gmet_0301, gme:Gmet_2095)
    (gme:Gmet_0336, gme:Gmet_1038)
    (gme:Gmet_0336, gme:Gmet_1804)
    (gme:Gmet_0337, gme:Gmet_2095)
    (gme:Gmet_0351, gme:Gmet_0956)
    (gme:Gmet_0351, gme:Gmet_2300)
    (gme:Gmet_0388, gme:Gmet_0389)
    (gme:Gmet_0407, gme:Gmet_0408)
    (gme:Gmet_0407, gme:Gmet_0410)
    (gme:Gmet_0410, gme:Gmet_0413)
    (gme:Gmet_0471, gme:Gmet_2910)
    (gme:Gmet_0552, gme:Gmet_1934)
    (gme:Gmet_0552, gme:Gmet_2822)
    (gme:Gmet_0661, gme:Gmet_1774)
    (gme:Gmet_0707, gme:Gmet_3175)
    (gme:Gmet_0729, gme:Gmet_2069)
    (gme:Gmet_0729, gme:Gmet_2261)
    (gme:Gmet_0730, gme:Gmet_2068)
    (gme:Gmet_0730, gme:Gmet_2260)
    (gme:Gmet_0770, gme:Gmet_2101)
    (gme:Gmet_0872, gme:Gmet_0992)
    (gme:Gmet_0884, gme:Gmet_3339)
    (gme:Gmet_0940, gme:Gmet_2767)
    (gme:Gmet_0940, gme:Gmet_3159)
    (gme:Gmet_0950, gme:Gmet_1818)
    (gme:Gmet_0950, gme:Gmet_1825)
    (gme:Gmet_0956, gme:Gmet_2300)
    (gme:Gmet_1016, gme:Gmet_2763)
    (gme:Gmet_1038, gme:Gmet_1804)
    (gme:Gmet_1124, gme:Gmet_2689)
    (gme:Gmet_1211, gme:Gmet_1946)
    (gme:Gmet_1265, gme:Gmet_1879)
    (gme:Gmet_1297, gme:Gmet_1910)
    (gme:Gmet_1357, gme:Gmet_2360)
    (gme:Gmet_1469, gme:Gmet_1613)
    (gme:Gmet_1486, gme:Gmet_2329)
    (gme:Gmet_1558, gme:Gmet_2988)
    (gme:Gmet_1580, gme:Gmet_3356)
    (gme:Gmet_1599, gme:Gmet_3272)
    (gme:Gmet_1601, gme:Gmet_1694)
    (gme:Gmet_1601, gme:Gmet_2059)
    (gme:Gmet_1603, gme:Gmet_1695)
    (gme:Gmet_1604, gme:Gmet_2621)
    (gme:Gmet_1613, gme:Gmet_2229)
    (gme:Gmet_1613, gme:Gmet_2340)
    (gme:Gmet_1694, gme:Gmet_2059)
    (gme:Gmet_1818, gme:Gmet_1825)
    (gme:Gmet_1818, gme:Gmet_2007)
    (gme:Gmet_1825, gme:Gmet_2007)
    (gme:Gmet_1896, gme:Gmet_2764)
    (gme:Gmet_1934, gme:Gmet_2822)
    (gme:Gmet_1954, gme:Gmet_2911)
    (gme:Gmet_2024, gme:Gmet_2172)
    (gme:Gmet_2068, gme:Gmet_2260)
    (gme:Gmet_2069, gme:Gmet_2261)
    (gme:Gmet_2229, gme:Gmet_2340)
    (gme:Gmet_2319, gme:Gmet_3422)
    (gme:Gmet_2329, gme:Gmet_2473)
    (gme:Gmet_2330, gme:Gmet_2473)
    (gme:Gmet_2353, gme:Gmet_2567)
    (gme:Gmet_2482, gme:Gmet_2493)
    (gpi:GPICK_00285, gpi:GPICK_06970)
    (gpi:GPICK_00320, gpi:GPICK_14070)
    (gpi:GPICK_01105, gpi:GPICK_06205)
    (gpi:GPICK_01155, gpi:GPICK_03805)
    (gpi:GPICK_01155, gpi:GPICK_10945)
    (gpi:GPICK_01260, gpi:GPICK_02005)
    (gpi:GPICK_01260, gpi:GPICK_09250)
    (gpi:GPICK_01260, gpi:GPICK_13690)
    (gpi:GPICK_01450, gpi:GPICK_09850)
    (gpi:GPICK_01855, gpi:GPICK_04525)
    (gpi:GPICK_01855, gpi:GPICK_09465)
    (gpi:GPICK_02005, gpi:GPICK_09250)
    (gpi:GPICK_02005, gpi:GPICK_13690)
    (gpi:GPICK_02075, gpi:GPICK_05460)
    (gpi:GPICK_02075, gpi:GPICK_10225)
    (gpi:GPICK_02235, gpi:GPICK_02240)
    (gpi:GPICK_02335, gpi:GPICK_02340)
    (gpi:GPICK_02630, gpi:GPICK_13390)
    (gpi:GPICK_02895, gpi:GPICK_08135)
    (gpi:GPICK_02900, gpi:GPICK_04075)
    (gpi:GPICK_02900, gpi:GPICK_07275)
    (gpi:GPICK_03195, gpi:GPICK_03200)
    (gpi:GPICK_03805, gpi:GPICK_10945)
    (gpi:GPICK_03840, gpi:GPICK_05200)
    (gpi:GPICK_04075, gpi:GPICK_07275)
    (gpi:GPICK_04525, gpi:GPICK_09465)
    (gpi:GPICK_04615, gpi:GPICK_11140)
    (gpi:GPICK_04625, gpi:GPICK_06080)
    (gpi:GPICK_04625, gpi:GPICK_07085)
    (gpi:GPICK_05040, gpi:GPICK_06250)
    (gpi:GPICK_05075, gpi:GPICK_09355)
    (gpi:GPICK_05080, gpi:GPICK_09350)
    (gpi:GPICK_05085, gpi:GPICK_09910)
    (gpi:GPICK_05385, gpi:GPICK_14470)
    (gpi:GPICK_05460, gpi:GPICK_10225)
    (gpi:GPICK_06080, gpi:GPICK_07085)
    (gpi:GPICK_06360, gpi:GPICK_09020)
    (gpi:GPICK_07425, gpi:GPICK_08415)
    (gpi:GPICK_07440, gpi:GPICK_07790)
    (gpi:GPICK_07485, gpi:GPICK_14900)
    (gpi:GPICK_07640, gpi:GPICK_15365)
    (gpi:GPICK_07650, gpi:GPICK_10370)
    (gpi:GPICK_07650, gpi:GPICK_10380)
    (gpi:GPICK_07830, gpi:GPICK_15315)
    (gpi:GPICK_07925, gpi:GPICK_15035)
    (gpi:GPICK_07935, gpi:GPICK_09325)
    (gpi:GPICK_07935, gpi:GPICK_15425)
    (gpi:GPICK_07945, gpi:GPICK_15430)
    (gpi:GPICK_08200, gpi:GPICK_08240)
    (gpi:GPICK_08380, gpi:GPICK_15365)
    (gpi:GPICK_08745, gpi:GPICK_10520)
    (gpi:GPICK_09250, gpi:GPICK_13690)
    (gpi:GPICK_09325, gpi:GPICK_15425)
    (gpi:GPICK_10090, gpi:GPICK_11530)
    (gpi:GPICK_10320, gpi:GPICK_15670)
    (gpi:GPICK_10370, gpi:GPICK_10380)
    (gpi:GPICK_10370, gpi:GPICK_11740)
    (gpi:GPICK_10380, gpi:GPICK_11740)
    (gpi:GPICK_10485, gpi:GPICK_12360)
    (gpi:GPICK_11735, gpi:GPICK_13255)
    (gpi:GPICK_11785, gpi:GPICK_11795)
    (gpi:GPICK_12055, gpi:GPICK_14550)
    (gpi:GPICK_12620, gpi:GPICK_15235)
    (gsb:GSUB_00160, gsb:GSUB_02660)
    (gsb:GSUB_00535, gsb:GSUB_02445)
    (gsb:GSUB_00535, gsb:GSUB_13565)
    (gsb:GSUB_00615, gsb:GSUB_09020)
    (gsb:GSUB_01295, gsb:GSUB_07510)
    (gsb:GSUB_01445, gsb:GSUB_09555)
    (gsb:GSUB_01445, gsb:GSUB_13975)
    (gsb:GSUB_01620, gsb:GSUB_05255)
    (gsb:GSUB_01730, gsb:GSUB_07600)
    (gsb:GSUB_01730, gsb:GSUB_11175)
    (gsb:GSUB_01835, gsb:GSUB_13655)
    (gsb:GSUB_01970, gsb:GSUB_12980)
    (gsb:GSUB_02190, gsb:GSUB_09375)
    (gsb:GSUB_02445, gsb:GSUB_13565)
    (gsb:GSUB_02540, gsb:GSUB_02545)
    (gsb:GSUB_02540, gsb:GSUB_08845)
    (gsb:GSUB_02545, gsb:GSUB_08845)
    (gsb:GSUB_02810, gsb:GSUB_14410)
    (gsb:GSUB_02815, gsb:GSUB_06155)
    (gsb:GSUB_02815, gsb:GSUB_14410)
    (gsb:GSUB_03040, gsb:GSUB_09180)
    (gsb:GSUB_03270, gsb:GSUB_08910)
    (gsb:GSUB_03680, gsb:GSUB_05075)
    (gsb:GSUB_03880, gsb:GSUB_09165)
    (gsb:GSUB_04800, gsb:GSUB_10480)
    (gsb:GSUB_07140, gsb:GSUB_10305)
    (gsb:GSUB_07515, gsb:GSUB_17495)
    (gsb:GSUB_07600, gsb:GSUB_11175)
    (gsb:GSUB_07655, gsb:GSUB_10525)
    (gsb:GSUB_08095, gsb:GSUB_08160)
    (gsb:GSUB_08160, gsb:GSUB_09095)
    (gsb:GSUB_08160, gsb:GSUB_09105)
    (gsb:GSUB_08195, gsb:GSUB_15430)
    (gsb:GSUB_08785, gsb:GSUB_10925)
    (gsb:GSUB_08785, gsb:GSUB_12790)
    (gsb:GSUB_08840, gsb:GSUB_15700)
    (gsb:GSUB_09095, gsb:GSUB_09105)
    (gsb:GSUB_09095, gsb:GSUB_13365)
    (gsb:GSUB_09105, gsb:GSUB_13365)
    (gsb:GSUB_09400, gsb:GSUB_11235)
    (gsb:GSUB_09400, gsb:GSUB_13265)
    (gsb:GSUB_09555, gsb:GSUB_13975)
    (gsb:GSUB_10905, gsb:GSUB_12340)
    (gsb:GSUB_10925, gsb:GSUB_12790)
    (gsb:GSUB_11235, gsb:GSUB_13265)
    (gsb:GSUB_12475, gsb:GSUB_12485)
    (gsb:GSUB_12985, gsb:GSUB_13010)
    (gsb:GSUB_13010, gsb:GSUB_13015)
    (gsu:GSU0067, gsu:GSU2307)
    (gsu:GSU0094, gsu:GSU2230)
    (gsu:GSU0152, gsu:GSU1271)
    (gsu:GSU0290, gsu:GSU1601)
    (gsu:GSU0337, gsu:GSU1582)
    (gsu:GSU0371, gsu:GSU2066)
    (gsu:GSU0460, gsu:GSU1605)
    (gsu:GSU0461, gsu:GSU1603)
    (gsu:GSU0482, gsu:GSU3372)
    (gsu:GSU0535, gsu:GSU3158)
    (gsu:GSU0604, gsu:GSU3005)
    (gsu:GSU0686, gsu:GSU1764)
    (gsu:GSU0686, gsu:GSU2918)
    (gsu:GSU0846, gsu:GSU2445)
    (gsu:GSU0999, gsu:GSU2264)
    (gsu:GSU1023, gsu:GSU3257)
    (gsu:GSU1061, gsu:GSU1242)
    (gsu:GSU1463, gsu:GSU2271)
    (gsu:GSU1623, gsu:GSU3296)
    (gsu:GSU1729, gsu:GSU1737)
    (gsu:GSU1764, gsu:GSU2918)
    (gsu:GSU1798, gsu:GSU1906)
    (gsu:GSU2011, gsu:GSU2570)
    (gsu:GSU2011, gsu:GSU2786)
    (gsu:GSU2045, gsu:GSU2209)
    (gsu:GSU2045, gsu:GSU3136)
    (gsu:GSU2209, gsu:GSU3136)
    (gsu:GSU2241, gsu:GSU2366)
    (gsu:GSU2375, gsu:GSU2379)
    (gsu:GSU2446, gsu:GSU2588)
    (gsu:GSU2570, gsu:GSU2786)
    (gsu:GSU2918, gsu:GSU3423)
    (gsu:GSU2919, gsu:GSU3423)
    (gsu:GSU3095, gsu:GSU3096)
    (gur:Gura_0074, gur:Gura_2025)
    (gur:Gura_0135, gur:Gura_1875)
    (gur:Gura_0155, gur:Gura_3486)
    (gur:Gura_0155, gur:Gura_3998)
    (gur:Gura_0155, gur:Gura_4349)
    (gur:Gura_0156, gur:Gura_3485)
    (gur:Gura_0156, gur:Gura_3999)
    (gur:Gura_0156, gur:Gura_4348)
    (gur:Gura_0185, gur:Gura_2259)
    (gur:Gura_0191, gur:Gura_0937)
    (gur:Gura_0227, gur:Gura_1856)
    (gur:Gura_0462, gur:Gura_3393)
    (gur:Gura_0462, gur:Gura_3541)
    (gur:Gura_0491, gur:Gura_0841)
    (gur:Gura_0491, gur:Gura_0970)
    (gur:Gura_0492, gur:Gura_0841)
    (gur:Gura_0492, gur:Gura_1018)
    (gur:Gura_0492, gur:Gura_2175)
    (gur:Gura_0620, gur:Gura_3720)
    (gur:Gura_0648, gur:Gura_2199)
    (gur:Gura_0822, gur:Gura_3859)
    (gur:Gura_0822, gur:Gura_3907)
    (gur:Gura_0841, gur:Gura_0970)
    (gur:Gura_1018, gur:Gura_2175)
    (gur:Gura_1046, gur:Gura_1047)
    (gur:Gura_1346, gur:Gura_1351)
    (gur:Gura_1387, gur:Gura_2953)
    (gur:Gura_1493, gur:Gura_1833)
    (gur:Gura_1570, gur:Gura_2061)
    (gur:Gura_1570, gur:Gura_2659)
    (gur:Gura_1570, gur:Gura_4250)
    (gur:Gura_1685, gur:Gura_2598)
    (gur:Gura_1685, gur:Gura_3171)
    (gur:Gura_1685, gur:Gura_3273)
    (gur:Gura_1691, gur:Gura_4055)
    (gur:Gura_1692, gur:Gura_4053)
    (gur:Gura_1705, gur:Gura_2661)
    (gur:Gura_1705, gur:Gura_3854)
    (gur:Gura_1705, gur:Gura_4193)
    (gur:Gura_1735, gur:Gura_2532)
    (gur:Gura_1735, gur:Gura_3288)
    (gur:Gura_1799, gur:Gura_3134)
    (gur:Gura_1799, gur:Gura_4313)
    (gur:Gura_1877, gur:Gura_3607)
    (gur:Gura_1879, gur:Gura_3606)
    (gur:Gura_2061, gur:Gura_2659)
    (gur:Gura_2061, gur:Gura_4250)
    (gur:Gura_2124, gur:Gura_2133)
    (gur:Gura_2196, gur:Gura_3240)
    (gur:Gura_2244, gur:Gura_4245)
    (gur:Gura_2317, gur:Gura_3715)
    (gur:Gura_2419, gur:Gura_3571)
    (gur:Gura_2420, gur:Gura_3574)
    (gur:Gura_2501, gur:Gura_3354)
    (gur:Gura_2532, gur:Gura_3288)
    (gur:Gura_2566, gur:Gura_2643)
    (gur:Gura_2598, gur:Gura_3273)
    (gur:Gura_2655, gur:Gura_4409)
    (gur:Gura_2659, gur:Gura_4250)
    (gur:Gura_2661, gur:Gura_3854)
    (gur:Gura_2661, gur:Gura_4193)
    (gur:Gura_3134, gur:Gura_4313)
    (gur:Gura_3154, gur:Gura_4327)
    (gur:Gura_3393, gur:Gura_3541)
    (gur:Gura_3485, gur:Gura_3999)
    (gur:Gura_3485, gur:Gura_4348)
    (gur:Gura_3486, gur:Gura_3998)
    (gur:Gura_3486, gur:Gura_4349)
    (gur:Gura_3622, gur:Gura_4137)
    (gur:Gura_3830, gur:Gura_3934)
    (gur:Gura_3852, gur:Gura_4183)
    (gur:Gura_3854, gur:Gura_4193)
    (gur:Gura_3859, gur:Gura_3907)
    (gur:Gura_3978, gur:Gura_3979)
    (gur:Gura_3998, gur:Gura_4349)
    (gur:Gura_3999, gur:Gura_4348)
    (gur:Gura_4053, gur:Gura_4054)
    (hmr:Hipma_0012, hmr:Hipma_0985)
    (hmr:Hipma_0121, hmr:Hipma_0501)
    (hmr:Hipma_0146, hmr:Hipma_0574)
    (hmr:Hipma_0146, hmr:Hipma_1193)
    (hmr:Hipma_0215, hmr:Hipma_1516)
    (hmr:Hipma_0301, hmr:Hipma_1016)
    (hmr:Hipma_0301, hmr:Hipma_1167)
    (hmr:Hipma_0341, hmr:Hipma_0431)
    (hmr:Hipma_0369, hmr:Hipma_0390)
    (hmr:Hipma_0412, hmr:Hipma_0845)
    (hmr:Hipma_0432, hmr:Hipma_1565)
    (hmr:Hipma_0574, hmr:Hipma_1193)
    (hmr:Hipma_0577, hmr:Hipma_1526)
    (hmr:Hipma_0790, hmr:Hipma_1462)
    (hmr:Hipma_0954, hmr:Hipma_0956)
    (hmr:Hipma_1016, hmr:Hipma_1167)
    (hmr:Hipma_1025, hmr:Hipma_1045)
    (hmr:Hipma_1025, hmr:Hipma_1397)
    (hmr:Hipma_1212, hmr:Hipma_1646)
    (hmr:Hipma_1401, hmr:Hipma_1703)
    (hoh:Hoch_0005, hoh:Hoch_0232)
    (hoh:Hoch_0005, hoh:Hoch_2946)
    (hoh:Hoch_0005, hoh:Hoch_6403)
    (hoh:Hoch_0106, hoh:Hoch_3273)
    (hoh:Hoch_0124, hoh:Hoch_4480)
    (hoh:Hoch_0217, hoh:Hoch_4175)
    (hoh:Hoch_0217, hoh:Hoch_4179)
    (hoh:Hoch_0217, hoh:Hoch_6176)
    (hoh:Hoch_0232, hoh:Hoch_2946)
    (hoh:Hoch_0232, hoh:Hoch_6403)
    (hoh:Hoch_0240, hoh:Hoch_3234)
    (hoh:Hoch_0240, hoh:Hoch_3705)
    (hoh:Hoch_0240, hoh:Hoch_4996)
    (hoh:Hoch_0330, hoh:Hoch_4501)
    (hoh:Hoch_0343, hoh:Hoch_4475)
    (hoh:Hoch_0343, hoh:Hoch_6015)
    (hoh:Hoch_0345, hoh:Hoch_5950)
    (hoh:Hoch_0360, hoh:Hoch_4160)
    (hoh:Hoch_0379, hoh:Hoch_6609)
    (hoh:Hoch_0394, hoh:Hoch_5324)
    (hoh:Hoch_0481, hoh:Hoch_5030)
    (hoh:Hoch_0481, hoh:Hoch_5651)
    (hoh:Hoch_0610, hoh:Hoch_4469)
    (hoh:Hoch_0637, hoh:Hoch_0966)
    (hoh:Hoch_0637, hoh:Hoch_1023)
    (hoh:Hoch_0966, hoh:Hoch_1023)
    (hoh:Hoch_1085, hoh:Hoch_3033)
    (hoh:Hoch_1478, hoh:Hoch_4463)
    (hoh:Hoch_1786, hoh:Hoch_4360)
    (hoh:Hoch_1786, hoh:Hoch_4947)
    (hoh:Hoch_1849, hoh:Hoch_2693)
    (hoh:Hoch_1849, hoh:Hoch_6383)
    (hoh:Hoch_1891, hoh:Hoch_4042)
    (hoh:Hoch_2046, hoh:Hoch_5389)
    (hoh:Hoch_2104, hoh:Hoch_5290)
    (hoh:Hoch_2190, hoh:Hoch_2547)
    (hoh:Hoch_2190, hoh:Hoch_3724)
    (hoh:Hoch_2547, hoh:Hoch_3724)
    (hoh:Hoch_2693, hoh:Hoch_6383)
    (hoh:Hoch_3033, hoh:Hoch_6151)
    (hoh:Hoch_3186, hoh:Hoch_3975)
    (hoh:Hoch_3189, hoh:Hoch_5889)
    (hoh:Hoch_3234, hoh:Hoch_3705)
    (hoh:Hoch_3234, hoh:Hoch_4996)
    (hoh:Hoch_3248, hoh:Hoch_3514)
    (hoh:Hoch_3248, hoh:Hoch_3572)
    (hoh:Hoch_3248, hoh:Hoch_4679)
    (hoh:Hoch_3514, hoh:Hoch_3572)
    (hoh:Hoch_3514, hoh:Hoch_4679)
    (hoh:Hoch_3572, hoh:Hoch_4679)
    (hoh:Hoch_3581, hoh:Hoch_6801)
    (hoh:Hoch_3705, hoh:Hoch_4996)
    (hoh:Hoch_4024, hoh:Hoch_4575)
    (hoh:Hoch_4075, hoh:Hoch_4355)
    (hoh:Hoch_4175, hoh:Hoch_4179)
    (hoh:Hoch_4175, hoh:Hoch_6176)
    (hoh:Hoch_4179, hoh:Hoch_6176)
    (hoh:Hoch_4359, hoh:Hoch_6171)
    (hoh:Hoch_4360, hoh:Hoch_4947)
    (hoh:Hoch_4463, hoh:Hoch_5556)
    (hoh:Hoch_4475, hoh:Hoch_6015)
    (hoh:Hoch_4475, hoh:Hoch_6893)
    (hoh:Hoch_4947, hoh:Hoch_6475)
    (hoh:Hoch_4968, hoh:Hoch_5530)
    (hoh:Hoch_5001, hoh:Hoch_5030)
    (hoh:Hoch_5001, hoh:Hoch_5197)
    (hoh:Hoch_5001, hoh:Hoch_5651)
    (hoh:Hoch_5030, hoh:Hoch_5197)
    (hoh:Hoch_5030, hoh:Hoch_5651)
    (hoh:Hoch_5197, hoh:Hoch_5651)
    (hoh:Hoch_5539, hoh:Hoch_6139)
    (hoh:Hoch_5889, hoh:Hoch_6458)
    (hoh:Hoch_6483, hoh:Hoch_6870)
    (lip:LI0152, lip:LI0648)
    (lip:LI0152, lip:LI1051)
    (lip:LI0379, lip:LI0580)
    (lip:LI0466, lip:LI0580)
    (lip:LI0466, lip:LI1066)
    (lip:LI0466, lip:LIC023)
    (lip:LI0580, lip:LI1066)
    (lip:LI0580, lip:LIC023)
    (lip:LI0648, lip:LI1051)
    (lip:LI0764, lip:LI1119)
    (llu:AKJ09_00297, llu:AKJ09_10095)
    (llu:AKJ09_00381, llu:AKJ09_01495)
    (llu:AKJ09_00381, llu:AKJ09_02991)
    (llu:AKJ09_00381, llu:AKJ09_05314)
    (llu:AKJ09_00381, llu:AKJ09_09399)
    (llu:AKJ09_00430, llu:AKJ09_07617)
    (llu:AKJ09_00430, llu:AKJ09_08666)
    (llu:AKJ09_00430, llu:AKJ09_08721)
    (llu:AKJ09_00430, llu:AKJ09_10708)
    (llu:AKJ09_00583, llu:AKJ09_03976)
    (llu:AKJ09_00609, llu:AKJ09_05284)
    (llu:AKJ09_00609, llu:AKJ09_06932)
    (llu:AKJ09_00756, llu:AKJ09_09548)
    (llu:AKJ09_00929, llu:AKJ09_08845)
    (llu:AKJ09_00929, llu:AKJ09_09652)
    (llu:AKJ09_00976, llu:AKJ09_01814)
    (llu:AKJ09_00976, llu:AKJ09_01852)
    (llu:AKJ09_00976, llu:AKJ09_05466)
    (llu:AKJ09_00976, llu:AKJ09_07370)
    (llu:AKJ09_00976, llu:AKJ09_09565)
    (llu:AKJ09_00988, llu:AKJ09_10878)
    (llu:AKJ09_01024, llu:AKJ09_10129)
    (llu:AKJ09_01101, llu:AKJ09_02491)
    (llu:AKJ09_01219, llu:AKJ09_01359)
    (llu:AKJ09_01219, llu:AKJ09_01443)
    (llu:AKJ09_01219, llu:AKJ09_01932)
    (llu:AKJ09_01219, llu:AKJ09_02362)
    (llu:AKJ09_01219, llu:AKJ09_04925)
    (llu:AKJ09_01219, llu:AKJ09_10314)
    (llu:AKJ09_01219, llu:AKJ09_11473)
    (llu:AKJ09_01359, llu:AKJ09_01932)
    (llu:AKJ09_01359, llu:AKJ09_02362)
    (llu:AKJ09_01359, llu:AKJ09_10314)
    (llu:AKJ09_01359, llu:AKJ09_11473)
    (llu:AKJ09_01443, llu:AKJ09_01932)
    (llu:AKJ09_01443, llu:AKJ09_02362)
    (llu:AKJ09_01443, llu:AKJ09_04925)
    (llu:AKJ09_01443, llu:AKJ09_10314)
    (llu:AKJ09_01443, llu:AKJ09_11473)
    (llu:AKJ09_01492, llu:AKJ09_07273)
    (llu:AKJ09_01492, llu:AKJ09_08550)
    (llu:AKJ09_01495, llu:AKJ09_02991)
    (llu:AKJ09_01495, llu:AKJ09_05314)
    (llu:AKJ09_01495, llu:AKJ09_09399)
    (llu:AKJ09_01814, llu:AKJ09_01852)
    (llu:AKJ09_01814, llu:AKJ09_05466)
    (llu:AKJ09_01814, llu:AKJ09_09565)
    (llu:AKJ09_01841, llu:AKJ09_09395)
    (llu:AKJ09_01841, llu:AKJ09_10314)
    (llu:AKJ09_01852, llu:AKJ09_05466)
    (llu:AKJ09_01852, llu:AKJ09_09565)
    (llu:AKJ09_01880, llu:AKJ09_09477)
    (llu:AKJ09_01932, llu:AKJ09_02362)
    (llu:AKJ09_01932, llu:AKJ09_04925)
    (llu:AKJ09_01932, llu:AKJ09_10314)
    (llu:AKJ09_01932, llu:AKJ09_11473)
    (llu:AKJ09_02037, llu:AKJ09_07537)
    (llu:AKJ09_02362, llu:AKJ09_04925)
    (llu:AKJ09_02362, llu:AKJ09_07818)
    (llu:AKJ09_02362, llu:AKJ09_09395)
    (llu:AKJ09_02362, llu:AKJ09_10314)
    (llu:AKJ09_02362, llu:AKJ09_11473)
    (llu:AKJ09_02446, llu:AKJ09_09492)
    (llu:AKJ09_02465, llu:AKJ09_10313)
    (llu:AKJ09_02467, llu:AKJ09_05171)
    (llu:AKJ09_02467, llu:AKJ09_10310)
    (llu:AKJ09_02570, llu:AKJ09_06892)
    (llu:AKJ09_02591, llu:AKJ09_04506)
    (llu:AKJ09_02591, llu:AKJ09_06301)
    (llu:AKJ09_02591, llu:AKJ09_07318)
    (llu:AKJ09_02664, llu:AKJ09_04170)
    (llu:AKJ09_02664, llu:AKJ09_09576)
    (llu:AKJ09_02687, llu:AKJ09_10940)
    (llu:AKJ09_02763, llu:AKJ09_02816)
    (llu:AKJ09_02792, llu:AKJ09_05385)
    (llu:AKJ09_02792, llu:AKJ09_07279)
    (llu:AKJ09_02824, llu:AKJ09_11361)
    (llu:AKJ09_02949, llu:AKJ09_09992)
    (llu:AKJ09_02979, llu:AKJ09_10337)
    (llu:AKJ09_02991, llu:AKJ09_05314)
    (llu:AKJ09_02991, llu:AKJ09_09399)
    (llu:AKJ09_03084, llu:AKJ09_09654)
    (llu:AKJ09_03136, llu:AKJ09_03141)
    (llu:AKJ09_03445, llu:AKJ09_09838)
    (llu:AKJ09_03567, llu:AKJ09_04767)
    (llu:AKJ09_03571, llu:AKJ09_06135)
    (llu:AKJ09_04170, llu:AKJ09_09576)
    (llu:AKJ09_04246, llu:AKJ09_04918)
    (llu:AKJ09_04269, llu:AKJ09_10333)
    (llu:AKJ09_04272, llu:AKJ09_10397)
    (llu:AKJ09_04281, llu:AKJ09_09908)
    (llu:AKJ09_04504, llu:AKJ09_06902)
    (llu:AKJ09_04506, llu:AKJ09_06301)
    (llu:AKJ09_04506, llu:AKJ09_07318)
    (llu:AKJ09_04690, llu:AKJ09_04691)
    (llu:AKJ09_04777, llu:AKJ09_05088)
    (llu:AKJ09_04777, llu:AKJ09_07825)
    (llu:AKJ09_04857, llu:AKJ09_08807)
    (llu:AKJ09_04925, llu:AKJ09_07818)
    (llu:AKJ09_04925, llu:AKJ09_09395)
    (llu:AKJ09_04925, llu:AKJ09_10314)
    (llu:AKJ09_04925, llu:AKJ09_11473)
    (llu:AKJ09_05088, llu:AKJ09_05091)
    (llu:AKJ09_05088, llu:AKJ09_07825)
    (llu:AKJ09_05171, llu:AKJ09_06116)
    (llu:AKJ09_05171, llu:AKJ09_08280)
    (llu:AKJ09_05171, llu:AKJ09_08589)
    (llu:AKJ09_05171, llu:AKJ09_10310)
    (llu:AKJ09_05284, llu:AKJ09_06932)
    (llu:AKJ09_05314, llu:AKJ09_09399)
    (llu:AKJ09_05385, llu:AKJ09_07279)
    (llu:AKJ09_05466, llu:AKJ09_06149)
    (llu:AKJ09_05466, llu:AKJ09_07370)
    (llu:AKJ09_05466, llu:AKJ09_09565)
    (llu:AKJ09_05499, llu:AKJ09_08079)
    (llu:AKJ09_05604, llu:AKJ09_10077)
    (llu:AKJ09_05604, llu:AKJ09_11361)
    (llu:AKJ09_05672, llu:AKJ09_06311)
    (llu:AKJ09_05672, llu:AKJ09_09034)
    (llu:AKJ09_05860, llu:AKJ09_11455)
    (llu:AKJ09_05861, llu:AKJ09_08207)
    (llu:AKJ09_05870, llu:AKJ09_08543)
    (llu:AKJ09_05870, llu:AKJ09_11129)
    (llu:AKJ09_06116, llu:AKJ09_08280)
    (llu:AKJ09_06116, llu:AKJ09_08589)
    (llu:AKJ09_06116, llu:AKJ09_10310)
    (llu:AKJ09_06149, llu:AKJ09_07370)
    (llu:AKJ09_06301, llu:AKJ09_07318)
    (llu:AKJ09_06311, llu:AKJ09_07946)
    (llu:AKJ09_06311, llu:AKJ09_09034)
    (llu:AKJ09_07273, llu:AKJ09_08550)
    (llu:AKJ09_07617, llu:AKJ09_08666)
    (llu:AKJ09_07617, llu:AKJ09_08721)
    (llu:AKJ09_07617, llu:AKJ09_10708)
    (llu:AKJ09_07685, llu:AKJ09_08366)
    (llu:AKJ09_07813, llu:AKJ09_08204)
    (llu:AKJ09_07814, llu:AKJ09_08130)
    (llu:AKJ09_07818, llu:AKJ09_10314)
    (llu:AKJ09_07818, llu:AKJ09_11473)
    (llu:AKJ09_07946, llu:AKJ09_09034)
    (llu:AKJ09_07972, llu:AKJ09_11102)
    (llu:AKJ09_08130, llu:AKJ09_08203)
    (llu:AKJ09_08280, llu:AKJ09_08589)
    (llu:AKJ09_08280, llu:AKJ09_10310)
    (llu:AKJ09_08401, llu:AKJ09_09066)
    (llu:AKJ09_08401, llu:AKJ09_09070)
    (llu:AKJ09_08434, llu:AKJ09_08436)
    (llu:AKJ09_08434, llu:AKJ09_08893)
    (llu:AKJ09_08434, llu:AKJ09_10316)
    (llu:AKJ09_08434, llu:AKJ09_10666)
    (llu:AKJ09_08436, llu:AKJ09_08893)
    (llu:AKJ09_08436, llu:AKJ09_10316)
    (llu:AKJ09_08436, llu:AKJ09_10666)
    (llu:AKJ09_08534, llu:AKJ09_10905)
    (llu:AKJ09_08543, llu:AKJ09_11129)
    (llu:AKJ09_08589, llu:AKJ09_10310)
    (llu:AKJ09_08666, llu:AKJ09_08721)
    (llu:AKJ09_08666, llu:AKJ09_10708)
    (llu:AKJ09_08711, llu:AKJ09_10720)
    (llu:AKJ09_08721, llu:AKJ09_10708)
    (llu:AKJ09_08845, llu:AKJ09_09652)
    (llu:AKJ09_08892, llu:AKJ09_08893)
    (llu:AKJ09_08892, llu:AKJ09_10316)
    (llu:AKJ09_08892, llu:AKJ09_10666)
    (llu:AKJ09_08893, llu:AKJ09_10316)
    (llu:AKJ09_08893, llu:AKJ09_10666)
    (llu:AKJ09_08899, llu:AKJ09_10905)
    (llu:AKJ09_09066, llu:AKJ09_09070)
    (llu:AKJ09_09395, llu:AKJ09_10314)
    (llu:AKJ09_09446, llu:AKJ09_11379)
    (llu:AKJ09_09653, llu:AKJ09_09654)
    (llu:AKJ09_09735, llu:AKJ09_10188)
    (llu:AKJ09_09735, llu:AKJ09_10739)
    (llu:AKJ09_10188, llu:AKJ09_10739)
    (llu:AKJ09_10314, llu:AKJ09_11473)
    (llu:AKJ09_10316, llu:AKJ09_10666)
    (mbd:MEBOL_000129, mbd:MEBOL_002196)
    (mbd:MEBOL_000129, mbd:MEBOL_003801)
    (mbd:MEBOL_000129, mbd:MEBOL_005988)
    (mbd:MEBOL_000129, mbd:MEBOL_007910)
    (mbd:MEBOL_000187, mbd:MEBOL_003207)
    (mbd:MEBOL_000187, mbd:MEBOL_004288)
    (mbd:MEBOL_000191, mbd:MEBOL_005729)
    (mbd:MEBOL_000258, mbd:MEBOL_005248)
    (mbd:MEBOL_000259, mbd:MEBOL_002466)
    (mbd:MEBOL_000279, mbd:MEBOL_004899)
    (mbd:MEBOL_000359, mbd:MEBOL_005201)
    (mbd:MEBOL_000546, mbd:MEBOL_004742)
    (mbd:MEBOL_000633, mbd:MEBOL_002331)
    (mbd:MEBOL_000633, mbd:MEBOL_002469)
    (mbd:MEBOL_000658, mbd:MEBOL_002086)
    (mbd:MEBOL_000709, mbd:MEBOL_005163)
    (mbd:MEBOL_000749, mbd:MEBOL_004362)
    (mbd:MEBOL_000749, mbd:MEBOL_005080)
    (mbd:MEBOL_000749, mbd:MEBOL_008059)
    (mbd:MEBOL_000779, mbd:MEBOL_005961)
    (mbd:MEBOL_000837, mbd:MEBOL_003186)
    (mbd:MEBOL_000837, mbd:MEBOL_003365)
    (mbd:MEBOL_000837, mbd:MEBOL_005346)
    (mbd:MEBOL_000837, mbd:MEBOL_006810)
    (mbd:MEBOL_000837, mbd:MEBOL_006971)
    (mbd:MEBOL_000907, mbd:MEBOL_005217)
    (mbd:MEBOL_000935, mbd:MEBOL_003654)
    (mbd:MEBOL_000935, mbd:MEBOL_007806)
    (mbd:MEBOL_000951, mbd:MEBOL_002586)
    (mbd:MEBOL_001212, mbd:MEBOL_002076)
    (mbd:MEBOL_001212, mbd:MEBOL_003120)
    (mbd:MEBOL_001212, mbd:MEBOL_003524)
    (mbd:MEBOL_001212, mbd:MEBOL_004866)
    (mbd:MEBOL_001212, mbd:MEBOL_005276)
    (mbd:MEBOL_001262, mbd:MEBOL_001387)
    (mbd:MEBOL_001262, mbd:MEBOL_006356)
    (mbd:MEBOL_001387, mbd:MEBOL_001640)
    (mbd:MEBOL_001387, mbd:MEBOL_004626)
    (mbd:MEBOL_001387, mbd:MEBOL_006356)
    (mbd:MEBOL_001393, mbd:MEBOL_006939)
    (mbd:MEBOL_001459, mbd:MEBOL_006635)
    (mbd:MEBOL_001626, mbd:MEBOL_006697)
    (mbd:MEBOL_001640, mbd:MEBOL_004626)
    (mbd:MEBOL_001640, mbd:MEBOL_006356)
    (mbd:MEBOL_001826, mbd:MEBOL_006201)
    (mbd:MEBOL_001876, mbd:MEBOL_006515)
    (mbd:MEBOL_001876, mbd:MEBOL_007650)
    (mbd:MEBOL_001936, mbd:MEBOL_006847)
    (mbd:MEBOL_002073, mbd:MEBOL_007696)
    (mbd:MEBOL_002076, mbd:MEBOL_003120)
    (mbd:MEBOL_002076, mbd:MEBOL_003524)
    (mbd:MEBOL_002076, mbd:MEBOL_004866)
    (mbd:MEBOL_002076, mbd:MEBOL_005276)
    (mbd:MEBOL_002081, mbd:MEBOL_002622)
    (mbd:MEBOL_002081, mbd:MEBOL_005080)
    (mbd:MEBOL_002081, mbd:MEBOL_008059)
    (mbd:MEBOL_002196, mbd:MEBOL_003801)
    (mbd:MEBOL_002196, mbd:MEBOL_007910)
    (mbd:MEBOL_002331, mbd:MEBOL_002469)
    (mbd:MEBOL_002332, mbd:MEBOL_004464)
    (mbd:MEBOL_002444, mbd:MEBOL_006356)
    (mbd:MEBOL_002467, mbd:MEBOL_007199)
    (mbd:MEBOL_002467, mbd:MEBOL_007247)
    (mbd:MEBOL_002622, mbd:MEBOL_005080)
    (mbd:MEBOL_002622, mbd:MEBOL_008059)
    (mbd:MEBOL_002704, mbd:MEBOL_002972)
    (mbd:MEBOL_002704, mbd:MEBOL_003044)
    (mbd:MEBOL_002704, mbd:MEBOL_004723)
    (mbd:MEBOL_002704, mbd:MEBOL_005964)
    (mbd:MEBOL_002704, mbd:MEBOL_007830)
    (mbd:MEBOL_002843, mbd:MEBOL_005688)
    (mbd:MEBOL_002893, mbd:MEBOL_004287)
    (mbd:MEBOL_002972, mbd:MEBOL_003044)
    (mbd:MEBOL_002972, mbd:MEBOL_004723)
    (mbd:MEBOL_002972, mbd:MEBOL_005964)
    (mbd:MEBOL_002972, mbd:MEBOL_007830)
    (mbd:MEBOL_003044, mbd:MEBOL_003610)
    (mbd:MEBOL_003044, mbd:MEBOL_004723)
    (mbd:MEBOL_003044, mbd:MEBOL_005964)
    (mbd:MEBOL_003044, mbd:MEBOL_007830)
    (mbd:MEBOL_003120, mbd:MEBOL_003524)
    (mbd:MEBOL_003120, mbd:MEBOL_004866)
    (mbd:MEBOL_003120, mbd:MEBOL_005276)
    (mbd:MEBOL_003149, mbd:MEBOL_006208)
    (mbd:MEBOL_003186, mbd:MEBOL_003365)
    (mbd:MEBOL_003186, mbd:MEBOL_005346)
    (mbd:MEBOL_003186, mbd:MEBOL_005347)
    (mbd:MEBOL_003186, mbd:MEBOL_006810)
    (mbd:MEBOL_003186, mbd:MEBOL_006971)
    (mbd:MEBOL_003195, mbd:MEBOL_005966)
    (mbd:MEBOL_003207, mbd:MEBOL_004288)
    (mbd:MEBOL_003365, mbd:MEBOL_005346)
    (mbd:MEBOL_003365, mbd:MEBOL_006810)
    (mbd:MEBOL_003365, mbd:MEBOL_006971)
    (mbd:MEBOL_003524, mbd:MEBOL_004866)
    (mbd:MEBOL_003524, mbd:MEBOL_005276)
    (mbd:MEBOL_003610, mbd:MEBOL_004723)
    (mbd:MEBOL_003610, mbd:MEBOL_005964)
    (mbd:MEBOL_003612, mbd:MEBOL_005962)
    (mbd:MEBOL_003654, mbd:MEBOL_007806)
    (mbd:MEBOL_003759, mbd:MEBOL_003822)
    (mbd:MEBOL_003801, mbd:MEBOL_005988)
    (mbd:MEBOL_003801, mbd:MEBOL_007910)
    (mbd:MEBOL_003817, mbd:MEBOL_004536)
    (mbd:MEBOL_004017, mbd:MEBOL_007718)
    (mbd:MEBOL_004362, mbd:MEBOL_005080)
    (mbd:MEBOL_004362, mbd:MEBOL_008059)
    (mbd:MEBOL_004403, mbd:MEBOL_006600)
    (mbd:MEBOL_004403, mbd:MEBOL_007560)
    (mbd:MEBOL_004563, mbd:MEBOL_004893)
    (mbd:MEBOL_004613, mbd:MEBOL_006920)
    (mbd:MEBOL_004626, mbd:MEBOL_006356)
    (mbd:MEBOL_004723, mbd:MEBOL_005964)
    (mbd:MEBOL_004723, mbd:MEBOL_007830)
    (mbd:MEBOL_004866, mbd:MEBOL_005276)
    (mbd:MEBOL_004988, mbd:MEBOL_006600)
    (mbd:MEBOL_005080, mbd:MEBOL_008059)
    (mbd:MEBOL_005217, mbd:MEBOL_006623)
    (mbd:MEBOL_005346, mbd:MEBOL_006971)
    (mbd:MEBOL_005347, mbd:MEBOL_006810)
    (mbd:MEBOL_005347, mbd:MEBOL_006971)
    (mbd:MEBOL_005452, mbd:MEBOL_006903)
    (mbd:MEBOL_005477, mbd:MEBOL_007719)
    (mbd:MEBOL_005679, mbd:MEBOL_007750)
    (mbd:MEBOL_005896, mbd:MEBOL_006725)
    (mbd:MEBOL_005963, mbd:MEBOL_006606)
    (mbd:MEBOL_005964, mbd:MEBOL_007830)
    (mbd:MEBOL_005988, mbd:MEBOL_007910)
    (mbd:MEBOL_006001, mbd:MEBOL_008079)
    (mbd:MEBOL_006515, mbd:MEBOL_007650)
    (mbd:MEBOL_006600, mbd:MEBOL_007560)
    (mbd:MEBOL_006810, mbd:MEBOL_006971)
    (mbd:MEBOL_006836, mbd:MEBOL_006837)
    (mbd:MEBOL_006836, mbd:MEBOL_007979)
    (mbd:MEBOL_006837, mbd:MEBOL_007627)
    (mbd:MEBOL_006837, mbd:MEBOL_007979)
    (mbd:MEBOL_006840, mbd:MEBOL_007700)
    (mbd:MEBOL_007199, mbd:MEBOL_007247)
    (mbd:MEBOL_007627, mbd:MEBOL_007979)
    (mbd:MEBOL_007699, mbd:MEBOL_007805)
    (mfu:LILAB_00500, mfu:LILAB_03385)
    (mfu:LILAB_00760, mfu:LILAB_17540)
    (mfu:LILAB_00760, mfu:LILAB_28260)
    (mfu:LILAB_00790, mfu:LILAB_15915)
    (mfu:LILAB_00885, mfu:LILAB_03750)
    (mfu:LILAB_00885, mfu:LILAB_29010)
    (mfu:LILAB_01140, mfu:LILAB_11470)
    (mfu:LILAB_01140, mfu:LILAB_20360)
    (mfu:LILAB_01140, mfu:LILAB_22525)
    (mfu:LILAB_01140, mfu:LILAB_25560)
    (mfu:LILAB_01545, mfu:LILAB_10705)
    (mfu:LILAB_01860, mfu:LILAB_03115)
    (mfu:LILAB_01980, mfu:LILAB_06150)
    (mfu:LILAB_01980, mfu:LILAB_08200)
    (mfu:LILAB_01980, mfu:LILAB_14400)
    (mfu:LILAB_01980, mfu:LILAB_14860)
    (mfu:LILAB_02370, mfu:LILAB_21070)
    (mfu:LILAB_03490, mfu:LILAB_14035)
    (mfu:LILAB_03630, mfu:LILAB_08110)
    (mfu:LILAB_03750, mfu:LILAB_29010)
    (mfu:LILAB_04135, mfu:LILAB_11935)
    (mfu:LILAB_04135, mfu:LILAB_31800)
    (mfu:LILAB_04155, mfu:LILAB_35630)
    (mfu:LILAB_04510, mfu:LILAB_07620)
    (mfu:LILAB_06150, mfu:LILAB_08200)
    (mfu:LILAB_06150, mfu:LILAB_14400)
    (mfu:LILAB_06150, mfu:LILAB_14860)
    (mfu:LILAB_06190, mfu:LILAB_24705)
    (mfu:LILAB_06660, mfu:LILAB_25565)
    (mfu:LILAB_06720, mfu:LILAB_07065)
    (mfu:LILAB_06880, mfu:LILAB_15365)
    (mfu:LILAB_06880, mfu:LILAB_30430)
    (mfu:LILAB_06880, mfu:LILAB_31675)
    (mfu:LILAB_07165, mfu:LILAB_21465)
    (mfu:LILAB_07270, mfu:LILAB_29235)
    (mfu:LILAB_07680, mfu:LILAB_31800)
    (mfu:LILAB_07990, mfu:LILAB_24435)
    (mfu:LILAB_07990, mfu:LILAB_27945)
    (mfu:LILAB_08200, mfu:LILAB_14400)
    (mfu:LILAB_08200, mfu:LILAB_14860)
    (mfu:LILAB_09240, mfu:LILAB_29200)
    (mfu:LILAB_10620, mfu:LILAB_33330)
    (mfu:LILAB_11470, mfu:LILAB_20360)
    (mfu:LILAB_11470, mfu:LILAB_22525)
    (mfu:LILAB_11470, mfu:LILAB_25560)
    (mfu:LILAB_11935, mfu:LILAB_31800)
    (mfu:LILAB_12180, mfu:LILAB_15700)
    (mfu:LILAB_14400, mfu:LILAB_14860)
    (mfu:LILAB_14960, mfu:LILAB_25545)
    (mfu:LILAB_15365, mfu:LILAB_30430)
    (mfu:LILAB_15365, mfu:LILAB_31675)
    (mfu:LILAB_16115, mfu:LILAB_20770)
    (mfu:LILAB_16510, mfu:LILAB_28665)
    (mfu:LILAB_16510, mfu:LILAB_35470)
    (mfu:LILAB_16510, mfu:LILAB_36195)
    (mfu:LILAB_16625, mfu:LILAB_19495)
    (mfu:LILAB_17495, mfu:LILAB_21705)
    (mfu:LILAB_17540, mfu:LILAB_28260)
    (mfu:LILAB_19465, mfu:LILAB_25930)
    (mfu:LILAB_20360, mfu:LILAB_22525)
    (mfu:LILAB_20360, mfu:LILAB_25560)
    (mfu:LILAB_20395, mfu:LILAB_31810)
    (mfu:LILAB_22395, mfu:LILAB_33165)
    (mfu:LILAB_22525, mfu:LILAB_25560)
    (mfu:LILAB_22655, mfu:LILAB_32910)
    (mfu:LILAB_24435, mfu:LILAB_27945)
    (mfu:LILAB_24435, mfu:LILAB_35365)
    (mfu:LILAB_24700, mfu:LILAB_34620)
    (mfu:LILAB_24705, mfu:LILAB_28305)
    (mfu:LILAB_25075, mfu:LILAB_32345)
    (mfu:LILAB_25505, mfu:LILAB_25510)
    (mfu:LILAB_25505, mfu:LILAB_28080)
    (mfu:LILAB_25505, mfu:LILAB_31010)
    (mfu:LILAB_25510, mfu:LILAB_28080)
    (mfu:LILAB_25510, mfu:LILAB_31010)
    (mfu:LILAB_27945, mfu:LILAB_35365)
    (mfu:LILAB_28080, mfu:LILAB_31010)
    (mfu:LILAB_28305, mfu:LILAB_29280)
    (mfu:LILAB_28665, mfu:LILAB_35470)
    (mfu:LILAB_28665, mfu:LILAB_36195)
    (mfu:LILAB_29975, mfu:LILAB_31800)
    (mfu:LILAB_30430, mfu:LILAB_31675)
    (mfu:LILAB_31365, mfu:LILAB_31605)
    (mfu:LILAB_35470, mfu:LILAB_36195)
    (mfu:LILAB_35480, mfu:LILAB_35505)
    (mmas:MYMAC_000124, mmas:MYMAC_000552)
    (mmas:MYMAC_000124, mmas:MYMAC_001355)
    (mmas:MYMAC_000124, mmas:MYMAC_006053)
    (mmas:MYMAC_000124, mmas:MYMAC_006137)
    (mmas:MYMAC_000161, mmas:MYMAC_003287)
    (mmas:MYMAC_000161, mmas:MYMAC_003879)
    (mmas:MYMAC_000220, mmas:MYMAC_004668)
    (mmas:MYMAC_000232, mmas:MYMAC_000869)
    (mmas:MYMAC_000305, mmas:MYMAC_004129)
    (mmas:MYMAC_000327, mmas:MYMAC_002715)
    (mmas:MYMAC_000346, mmas:MYMAC_000432)
    (mmas:MYMAC_000385, mmas:MYMAC_004643)
    (mmas:MYMAC_000385, mmas:MYMAC_005959)
    (mmas:MYMAC_000444, mmas:MYMAC_003460)
    (mmas:MYMAC_000545, mmas:MYMAC_003338)
    (mmas:MYMAC_000552, mmas:MYMAC_001355)
    (mmas:MYMAC_000552, mmas:MYMAC_006053)
    (mmas:MYMAC_000552, mmas:MYMAC_006137)
    (mmas:MYMAC_000935, mmas:MYMAC_005425)
    (mmas:MYMAC_000937, mmas:MYMAC_004291)
    (mmas:MYMAC_000937, mmas:MYMAC_004668)
    (mmas:MYMAC_000937, mmas:MYMAC_006600)
    (mmas:MYMAC_001009, mmas:MYMAC_001692)
    (mmas:MYMAC_001009, mmas:MYMAC_004085)
    (mmas:MYMAC_001062, mmas:MYMAC_006204)
    (mmas:MYMAC_001081, mmas:MYMAC_001767)
    (mmas:MYMAC_001135, mmas:MYMAC_001379)
    (mmas:MYMAC_001273, mmas:MYMAC_002638)
    (mmas:MYMAC_001355, mmas:MYMAC_006053)
    (mmas:MYMAC_001355, mmas:MYMAC_006137)
    (mmas:MYMAC_001440, mmas:MYMAC_006837)
    (mmas:MYMAC_001577, mmas:MYMAC_001939)
    (mmas:MYMAC_001644, mmas:MYMAC_002498)
    (mmas:MYMAC_001644, mmas:MYMAC_002908)
    (mmas:MYMAC_001644, mmas:MYMAC_003459)
    (mmas:MYMAC_001644, mmas:MYMAC_006691)
    (mmas:MYMAC_001692, mmas:MYMAC_004085)
    (mmas:MYMAC_001711, mmas:MYMAC_005856)
    (mmas:MYMAC_001717, mmas:MYMAC_002002)
    (mmas:MYMAC_001717, mmas:MYMAC_003937)
    (mmas:MYMAC_001988, mmas:MYMAC_002764)
    (mmas:MYMAC_002002, mmas:MYMAC_003937)
    (mmas:MYMAC_002320, mmas:MYMAC_003532)
    (mmas:MYMAC_002326, mmas:MYMAC_005716)
    (mmas:MYMAC_002498, mmas:MYMAC_002908)
    (mmas:MYMAC_002498, mmas:MYMAC_003459)
    (mmas:MYMAC_002498, mmas:MYMAC_006691)
    (mmas:MYMAC_002505, mmas:MYMAC_004670)
    (mmas:MYMAC_002881, mmas:MYMAC_004931)
    (mmas:MYMAC_002908, mmas:MYMAC_003459)
    (mmas:MYMAC_002908, mmas:MYMAC_006691)
    (mmas:MYMAC_002933, mmas:MYMAC_004879)
    (mmas:MYMAC_003287, mmas:MYMAC_003879)
    (mmas:MYMAC_003287, mmas:MYMAC_005375)
    (mmas:MYMAC_003337, mmas:MYMAC_005218)
    (mmas:MYMAC_003338, mmas:MYMAC_003947)
    (mmas:MYMAC_003407, mmas:MYMAC_004768)
    (mmas:MYMAC_003448, mmas:MYMAC_003449)
    (mmas:MYMAC_003448, mmas:MYMAC_003905)
    (mmas:MYMAC_003448, mmas:MYMAC_004501)
    (mmas:MYMAC_003449, mmas:MYMAC_003905)
    (mmas:MYMAC_003449, mmas:MYMAC_004501)
    (mmas:MYMAC_003456, mmas:MYMAC_006033)
    (mmas:MYMAC_003459, mmas:MYMAC_006691)
    (mmas:MYMAC_003879, mmas:MYMAC_005375)
    (mmas:MYMAC_003905, mmas:MYMAC_004501)
    (mmas:MYMAC_003947, mmas:MYMAC_004138)
    (mmas:MYMAC_004020, mmas:MYMAC_005396)
    (mmas:MYMAC_004020, mmas:MYMAC_005532)
    (mmas:MYMAC_004020, mmas:MYMAC_005739)
    (mmas:MYMAC_004122, mmas:MYMAC_007137)
    (mmas:MYMAC_004291, mmas:MYMAC_004668)
    (mmas:MYMAC_004575, mmas:MYMAC_004629)
    (mmas:MYMAC_004643, mmas:MYMAC_005959)
    (mmas:MYMAC_004668, mmas:MYMAC_006600)
    (mmas:MYMAC_004962, mmas:MYMAC_006854)
    (mmas:MYMAC_005396, mmas:MYMAC_005532)
    (mmas:MYMAC_005396, mmas:MYMAC_005739)
    (mmas:MYMAC_005398, mmas:MYMAC_005403)
    (mmas:MYMAC_005403, mmas:MYMAC_005404)
    (mmas:MYMAC_005532, mmas:MYMAC_005739)
    (mmas:MYMAC_005899, mmas:MYMAC_006554)
    (mmas:MYMAC_006053, mmas:MYMAC_006137)
    (mrm:A7982_00131, mrm:A7982_08578)
    (mrm:A7982_00170, mrm:A7982_01282)
    (mrm:A7982_00170, mrm:A7982_03403)
    (mrm:A7982_00170, mrm:A7982_04986)
    (mrm:A7982_00170, mrm:A7982_07818)
    (mrm:A7982_00170, mrm:A7982_09670)
    (mrm:A7982_00170, mrm:A7982_11353)
    (mrm:A7982_00288, mrm:A7982_05215)
    (mrm:A7982_00296, mrm:A7982_02950)
    (mrm:A7982_00296, mrm:A7982_05341)
    (mrm:A7982_00296, mrm:A7982_10667)
    (mrm:A7982_00309, mrm:A7982_09578)
    (mrm:A7982_00315, mrm:A7982_11144)
    (mrm:A7982_00371, mrm:A7982_04801)
    (mrm:A7982_00419, mrm:A7982_06545)
    (mrm:A7982_00419, mrm:A7982_06712)
    (mrm:A7982_00419, mrm:A7982_06716)
    (mrm:A7982_00419, mrm:A7982_08550)
    (mrm:A7982_00443, mrm:A7982_08822)
    (mrm:A7982_00857, mrm:A7982_01558)
    (mrm:A7982_00857, mrm:A7982_10241)
    (mrm:A7982_01128, mrm:A7982_02037)
    (mrm:A7982_01149, mrm:A7982_09970)
    (mrm:A7982_01228, mrm:A7982_02950)
    (mrm:A7982_01228, mrm:A7982_09573)
    (mrm:A7982_01282, mrm:A7982_03403)
    (mrm:A7982_01282, mrm:A7982_04986)
    (mrm:A7982_01282, mrm:A7982_07818)
    (mrm:A7982_01282, mrm:A7982_09670)
    (mrm:A7982_01282, mrm:A7982_11353)
    (mrm:A7982_01283, mrm:A7982_02966)
    (mrm:A7982_01283, mrm:A7982_04984)
    (mrm:A7982_01283, mrm:A7982_07817)
    (mrm:A7982_01283, mrm:A7982_12232)
    (mrm:A7982_01358, mrm:A7982_09718)
    (mrm:A7982_01390, mrm:A7982_02966)
    (mrm:A7982_01390, mrm:A7982_04984)
    (mrm:A7982_01390, mrm:A7982_05137)
    (mrm:A7982_01390, mrm:A7982_09318)
    (mrm:A7982_01390, mrm:A7982_12232)
    (mrm:A7982_01558, mrm:A7982_10241)
    (mrm:A7982_01769, mrm:A7982_02481)
    (mrm:A7982_01769, mrm:A7982_05402)
    (mrm:A7982_01898, mrm:A7982_07497)
    (mrm:A7982_01898, mrm:A7982_07501)
    (mrm:A7982_02117, mrm:A7982_12858)
    (mrm:A7982_02117, mrm:A7982_13556)
    (mrm:A7982_02397, mrm:A7982_02930)
    (mrm:A7982_02397, mrm:A7982_12819)
    (mrm:A7982_02481, mrm:A7982_05182)
    (mrm:A7982_02481, mrm:A7982_05402)
    (mrm:A7982_02481, mrm:A7982_05891)
    (mrm:A7982_02481, mrm:A7982_09160)
    (mrm:A7982_02519, mrm:A7982_02766)
    (mrm:A7982_02519, mrm:A7982_07443)
    (mrm:A7982_02519, mrm:A7982_08337)
    (mrm:A7982_02519, mrm:A7982_09042)
    (mrm:A7982_02519, mrm:A7982_09539)
    (mrm:A7982_02611, mrm:A7982_07040)
    (mrm:A7982_02751, mrm:A7982_09898)
    (mrm:A7982_02766, mrm:A7982_05339)
    (mrm:A7982_02766, mrm:A7982_07443)
    (mrm:A7982_02766, mrm:A7982_07690)
    (mrm:A7982_02766, mrm:A7982_08337)
    (mrm:A7982_02766, mrm:A7982_09042)
    (mrm:A7982_02766, mrm:A7982_09539)
    (mrm:A7982_02766, mrm:A7982_10601)
    (mrm:A7982_02766, mrm:A7982_12872)
    (mrm:A7982_02846, mrm:A7982_12969)
    (mrm:A7982_02892, mrm:A7982_03222)
    (mrm:A7982_02930, mrm:A7982_12819)
    (mrm:A7982_02946, mrm:A7982_06799)
    (mrm:A7982_02947, mrm:A7982_04886)
    (mrm:A7982_02947, mrm:A7982_06799)
    (mrm:A7982_02950, mrm:A7982_05341)
    (mrm:A7982_02950, mrm:A7982_08818)
    (mrm:A7982_02950, mrm:A7982_09573)
    (mrm:A7982_02950, mrm:A7982_10667)
    (mrm:A7982_02950, mrm:A7982_13482)
    (mrm:A7982_02966, mrm:A7982_04984)
    (mrm:A7982_02966, mrm:A7982_05137)
    (mrm:A7982_02966, mrm:A7982_07817)
    (mrm:A7982_02966, mrm:A7982_08798)
    (mrm:A7982_02966, mrm:A7982_09318)
    (mrm:A7982_02966, mrm:A7982_12232)
    (mrm:A7982_03001, mrm:A7982_04312)
    (mrm:A7982_03001, mrm:A7982_10763)
    (mrm:A7982_03017, mrm:A7982_08253)
    (mrm:A7982_03046, mrm:A7982_03371)
    (mrm:A7982_03046, mrm:A7982_06576)
    (mrm:A7982_03051, mrm:A7982_06344)
    (mrm:A7982_03225, mrm:A7982_05274)
    (mrm:A7982_03238, mrm:A7982_03263)
    (mrm:A7982_03238, mrm:A7982_08416)
    (mrm:A7982_03263, mrm:A7982_08416)
    (mrm:A7982_03263, mrm:A7982_08417)
    (mrm:A7982_03371, mrm:A7982_06576)
    (mrm:A7982_03403, mrm:A7982_04986)
    (mrm:A7982_03403, mrm:A7982_07818)
    (mrm:A7982_03403, mrm:A7982_09670)
    (mrm:A7982_03403, mrm:A7982_11353)
    (mrm:A7982_03732, mrm:A7982_05342)
    (mrm:A7982_04070, mrm:A7982_09588)
    (mrm:A7982_04070, mrm:A7982_09589)
    (mrm:A7982_04111, mrm:A7982_08728)
    (mrm:A7982_04172, mrm:A7982_09467)
    (mrm:A7982_04312, mrm:A7982_10763)
    (mrm:A7982_04316, mrm:A7982_07487)
    (mrm:A7982_04557, mrm:A7982_13708)
    (mrm:A7982_04886, mrm:A7982_06797)
    (mrm:A7982_04886, mrm:A7982_06799)
    (mrm:A7982_04886, mrm:A7982_09830)
    (mrm:A7982_04886, mrm:A7982_12408)
    (mrm:A7982_04896, mrm:A7982_05825)
    (mrm:A7982_04984, mrm:A7982_07817)
    (mrm:A7982_04984, mrm:A7982_12232)
    (mrm:A7982_04986, mrm:A7982_07818)
    (mrm:A7982_04986, mrm:A7982_09670)
    (mrm:A7982_04986, mrm:A7982_11353)
    (mrm:A7982_05137, mrm:A7982_08798)
    (mrm:A7982_05137, mrm:A7982_09318)
    (mrm:A7982_05137, mrm:A7982_12232)
    (mrm:A7982_05339, mrm:A7982_07443)
    (mrm:A7982_05339, mrm:A7982_07690)
    (mrm:A7982_05339, mrm:A7982_09042)
    (mrm:A7982_05339, mrm:A7982_10601)
    (mrm:A7982_05339, mrm:A7982_12872)
    (mrm:A7982_05341, mrm:A7982_10667)
    (mrm:A7982_05342, mrm:A7982_09691)
    (mrm:A7982_05342, mrm:A7982_12663)
    (mrm:A7982_05402, mrm:A7982_05891)
    (mrm:A7982_05402, mrm:A7982_09160)
    (mrm:A7982_05441, mrm:A7982_13093)
    (mrm:A7982_05940, mrm:A7982_11740)
    (mrm:A7982_06222, mrm:A7982_06887)
    (mrm:A7982_06544, mrm:A7982_07760)
    (mrm:A7982_06545, mrm:A7982_06712)
    (mrm:A7982_06545, mrm:A7982_06716)
    (mrm:A7982_06545, mrm:A7982_08550)
    (mrm:A7982_06712, mrm:A7982_06716)
    (mrm:A7982_06712, mrm:A7982_08550)
    (mrm:A7982_06716, mrm:A7982_08550)
    (mrm:A7982_06797, mrm:A7982_06799)
    (mrm:A7982_06797, mrm:A7982_09830)
    (mrm:A7982_06799, mrm:A7982_09830)
    (mrm:A7982_06955, mrm:A7982_09221)
    (mrm:A7982_07040, mrm:A7982_10056)
    (mrm:A7982_07107, mrm:A7982_08046)
    (mrm:A7982_07107, mrm:A7982_13543)
    (mrm:A7982_07443, mrm:A7982_08337)
    (mrm:A7982_07443, mrm:A7982_09042)
    (mrm:A7982_07443, mrm:A7982_09539)
    (mrm:A7982_07443, mrm:A7982_10601)
    (mrm:A7982_07497, mrm:A7982_07501)
    (mrm:A7982_07540, mrm:A7982_11385)
    (mrm:A7982_07690, mrm:A7982_09042)
    (mrm:A7982_07690, mrm:A7982_10601)
    (mrm:A7982_07690, mrm:A7982_12872)
    (mrm:A7982_07818, mrm:A7982_09670)
    (mrm:A7982_07818, mrm:A7982_11353)
    (mrm:A7982_07821, mrm:A7982_10858)
    (mrm:A7982_08288, mrm:A7982_08677)
    (mrm:A7982_08337, mrm:A7982_09539)
    (mrm:A7982_08390, mrm:A7982_12928)
    (mrm:A7982_08418, mrm:A7982_09715)
    (mrm:A7982_08670, mrm:A7982_11365)
    (mrm:A7982_08798, mrm:A7982_12232)
    (mrm:A7982_08818, mrm:A7982_09573)
    (mrm:A7982_08954, mrm:A7982_09248)
    (mrm:A7982_08974, mrm:A7982_12709)
    (mrm:A7982_08974, mrm:A7982_12710)
    (mrm:A7982_09042, mrm:A7982_10601)
    (mrm:A7982_09042, mrm:A7982_12872)
    (mrm:A7982_09318, mrm:A7982_12232)
    (mrm:A7982_09430, mrm:A7982_12387)
    (mrm:A7982_09573, mrm:A7982_10667)
    (mrm:A7982_09670, mrm:A7982_11353)
    (mrm:A7982_09691, mrm:A7982_12663)
    (mrm:A7982_09715, mrm:A7982_10954)
    (mrm:A7982_10601, mrm:A7982_12872)
    (mrm:A7982_10892, mrm:A7982_11740)
    (mrm:A7982_11237, mrm:A7982_12661)
    (mrm:A7982_12709, mrm:A7982_12710)
    (mrm:A7982_12858, mrm:A7982_13556)
    (msd:MYSTI_00087, msd:MYSTI_03443)
    (msd:MYSTI_00087, msd:MYSTI_05492)
    (msd:MYSTI_00124, msd:MYSTI_03947)
    (msd:MYSTI_00124, msd:MYSTI_04606)
    (msd:MYSTI_00211, msd:MYSTI_03298)
    (msd:MYSTI_00211, msd:MYSTI_05228)
    (msd:MYSTI_00211, msd:MYSTI_07831)
    (msd:MYSTI_00219, msd:MYSTI_01589)
    (msd:MYSTI_00274, msd:MYSTI_03731)
    (msd:MYSTI_00373, msd:MYSTI_04946)
    (msd:MYSTI_00373, msd:MYSTI_05203)
    (msd:MYSTI_00373, msd:MYSTI_06805)
    (msd:MYSTI_00520, msd:MYSTI_04546)
    (msd:MYSTI_00528, msd:MYSTI_01382)
    (msd:MYSTI_00528, msd:MYSTI_06940)
    (msd:MYSTI_00925, msd:MYSTI_06221)
    (msd:MYSTI_00933, msd:MYSTI_01365)
    (msd:MYSTI_00933, msd:MYSTI_03298)
    (msd:MYSTI_00933, msd:MYSTI_05228)
    (msd:MYSTI_00933, msd:MYSTI_07506)
    (msd:MYSTI_00933, msd:MYSTI_07831)
    (msd:MYSTI_00991, msd:MYSTI_01655)
    (msd:MYSTI_00991, msd:MYSTI_01751)
    (msd:MYSTI_00991, msd:MYSTI_02961)
    (msd:MYSTI_00991, msd:MYSTI_04815)
    (msd:MYSTI_00991, msd:MYSTI_06468)
    (msd:MYSTI_01019, msd:MYSTI_01045)
    (msd:MYSTI_01019, msd:MYSTI_01696)
    (msd:MYSTI_01019, msd:MYSTI_03778)
    (msd:MYSTI_01045, msd:MYSTI_01696)
    (msd:MYSTI_01045, msd:MYSTI_03778)
    (msd:MYSTI_01086, msd:MYSTI_07118)
    (msd:MYSTI_01146, msd:MYSTI_01404)
    (msd:MYSTI_01293, msd:MYSTI_03078)
    (msd:MYSTI_01365, msd:MYSTI_07506)
    (msd:MYSTI_01365, msd:MYSTI_07831)
    (msd:MYSTI_01369, msd:MYSTI_06833)
    (msd:MYSTI_01370, msd:MYSTI_06833)
    (msd:MYSTI_01370, msd:MYSTI_08015)
    (msd:MYSTI_01382, msd:MYSTI_06940)
    (msd:MYSTI_01404, msd:MYSTI_07249)
    (msd:MYSTI_01458, msd:MYSTI_07724)
    (msd:MYSTI_01655, msd:MYSTI_01751)
    (msd:MYSTI_01655, msd:MYSTI_02961)
    (msd:MYSTI_01655, msd:MYSTI_03419)
    (msd:MYSTI_01655, msd:MYSTI_04013)
    (msd:MYSTI_01655, msd:MYSTI_04456)
    (msd:MYSTI_01655, msd:MYSTI_04815)
    (msd:MYSTI_01696, msd:MYSTI_03778)
    (msd:MYSTI_01723, msd:MYSTI_02238)
    (msd:MYSTI_01751, msd:MYSTI_02961)
    (msd:MYSTI_01751, msd:MYSTI_03419)
    (msd:MYSTI_01751, msd:MYSTI_04456)
    (msd:MYSTI_01751, msd:MYSTI_04815)
    (msd:MYSTI_01751, msd:MYSTI_06468)
    (msd:MYSTI_01815, msd:MYSTI_03722)
    (msd:MYSTI_01815, msd:MYSTI_03888)
    (msd:MYSTI_01936, msd:MYSTI_04068)
    (msd:MYSTI_02222, msd:MYSTI_03222)
    (msd:MYSTI_02238, msd:MYSTI_03897)
    (msd:MYSTI_02246, msd:MYSTI_07288)
    (msd:MYSTI_02512, msd:MYSTI_03297)
    (msd:MYSTI_02512, msd:MYSTI_05226)
    (msd:MYSTI_02512, msd:MYSTI_05450)
    (msd:MYSTI_02683, msd:MYSTI_04482)
    (msd:MYSTI_02722, msd:MYSTI_04360)
    (msd:MYSTI_02727, msd:MYSTI_06547)
    (msd:MYSTI_02928, msd:MYSTI_05230)
    (msd:MYSTI_02961, msd:MYSTI_04815)
    (msd:MYSTI_02961, msd:MYSTI_06468)
    (msd:MYSTI_03297, msd:MYSTI_05226)
    (msd:MYSTI_03297, msd:MYSTI_05450)
    (msd:MYSTI_03298, msd:MYSTI_04872)
    (msd:MYSTI_03298, msd:MYSTI_05228)
    (msd:MYSTI_03298, msd:MYSTI_06617)
    (msd:MYSTI_03298, msd:MYSTI_07506)
    (msd:MYSTI_03298, msd:MYSTI_07831)
    (msd:MYSTI_03397, msd:MYSTI_05549)
    (msd:MYSTI_03416, msd:MYSTI_08093)
    (msd:MYSTI_03419, msd:MYSTI_04013)
    (msd:MYSTI_03419, msd:MYSTI_04456)
    (msd:MYSTI_03443, msd:MYSTI_05492)
    (msd:MYSTI_03722, msd:MYSTI_03888)
    (msd:MYSTI_03738, msd:MYSTI_08065)
    (msd:MYSTI_03827, msd:MYSTI_06191)
    (msd:MYSTI_03827, msd:MYSTI_06327)
    (msd:MYSTI_03827, msd:MYSTI_06570)
    (msd:MYSTI_03928, msd:MYSTI_04466)
    (msd:MYSTI_03928, msd:MYSTI_05067)
    (msd:MYSTI_03947, msd:MYSTI_04606)
    (msd:MYSTI_03947, msd:MYSTI_06170)
    (msd:MYSTI_04013, msd:MYSTI_04456)
    (msd:MYSTI_04345, msd:MYSTI_06198)
    (msd:MYSTI_04459, msd:MYSTI_06919)
    (msd:MYSTI_04466, msd:MYSTI_04467)
    (msd:MYSTI_04466, msd:MYSTI_05067)
    (msd:MYSTI_04467, msd:MYSTI_05067)
    (msd:MYSTI_04507, msd:MYSTI_05360)
    (msd:MYSTI_04547, msd:MYSTI_05921)
    (msd:MYSTI_04606, msd:MYSTI_06170)
    (msd:MYSTI_04683, msd:MYSTI_06393)
    (msd:MYSTI_04778, msd:MYSTI_05229)
    (msd:MYSTI_04872, msd:MYSTI_05228)
    (msd:MYSTI_04872, msd:MYSTI_07506)
    (msd:MYSTI_04872, msd:MYSTI_07831)
    (msd:MYSTI_04946, msd:MYSTI_05203)
    (msd:MYSTI_04946, msd:MYSTI_06805)
    (msd:MYSTI_05093, msd:MYSTI_06833)
    (msd:MYSTI_05139, msd:MYSTI_05188)
    (msd:MYSTI_05203, msd:MYSTI_06805)
    (msd:MYSTI_05226, msd:MYSTI_05450)
    (msd:MYSTI_05228, msd:MYSTI_06617)
    (msd:MYSTI_05228, msd:MYSTI_07506)
    (msd:MYSTI_05228, msd:MYSTI_07831)
    (msd:MYSTI_05561, msd:MYSTI_07749)
    (msd:MYSTI_05851, msd:MYSTI_05889)
    (msd:MYSTI_05851, msd:MYSTI_06140)
    (msd:MYSTI_05851, msd:MYSTI_07032)
    (msd:MYSTI_05889, msd:MYSTI_06140)
    (msd:MYSTI_05889, msd:MYSTI_07032)
    (msd:MYSTI_06076, msd:MYSTI_06394)
    (msd:MYSTI_06140, msd:MYSTI_07032)
    (msd:MYSTI_06191, msd:MYSTI_06327)
    (msd:MYSTI_06191, msd:MYSTI_06570)
    (msd:MYSTI_06327, msd:MYSTI_06570)
    (msd:MYSTI_06617, msd:MYSTI_07506)
    (msd:MYSTI_06617, msd:MYSTI_07831)
    (msd:MYSTI_06833, msd:MYSTI_08015)
    (msd:MYSTI_07106, msd:MYSTI_07451)
    (msd:MYSTI_07506, msd:MYSTI_07831)
    (mxa:MXAN_0110, mxa:MXAN_0537)
    (mxa:MXAN_0110, mxa:MXAN_1362)
    (mxa:MXAN_0110, mxa:MXAN_6319)
    (mxa:MXAN_0110, mxa:MXAN_6431)
    (mxa:MXAN_0147, mxa:MXAN_3330)
    (mxa:MXAN_0147, mxa:MXAN_3969)
    (mxa:MXAN_0147, mxa:MXAN_5578)
    (mxa:MXAN_0211, mxa:MXAN_4770)
    (mxa:MXAN_0211, mxa:MXAN_6399)
    (mxa:MXAN_0215, mxa:MXAN_0853)
    (mxa:MXAN_0278, mxa:MXAN_4219)
    (mxa:MXAN_0318, mxa:MXAN_0395)
    (mxa:MXAN_0358, mxa:MXAN_4051)
    (mxa:MXAN_0358, mxa:MXAN_4460)
    (mxa:MXAN_0358, mxa:MXAN_4745)
    (mxa:MXAN_0358, mxa:MXAN_6220)
    (mxa:MXAN_0407, mxa:MXAN_3519)
    (mxa:MXAN_0501, mxa:MXAN_1103)
    (mxa:MXAN_0501, mxa:MXAN_1386)
    (mxa:MXAN_0531, mxa:MXAN_3386)
    (mxa:MXAN_0537, mxa:MXAN_1362)
    (mxa:MXAN_0537, mxa:MXAN_6319)
    (mxa:MXAN_0912, mxa:MXAN_5630)
    (mxa:MXAN_0915, mxa:MXAN_4770)
    (mxa:MXAN_0915, mxa:MXAN_6399)
    (mxa:MXAN_0915, mxa:MXAN_6909)
    (mxa:MXAN_0949, mxa:MXAN_1528)
    (mxa:MXAN_0949, mxa:MXAN_2570)
    (mxa:MXAN_0949, mxa:MXAN_5856)
    (mxa:MXAN_0992, mxa:MXAN_1571)
    (mxa:MXAN_0992, mxa:MXAN_4171)
    (mxa:MXAN_1039, mxa:MXAN_6497)
    (mxa:MXAN_1103, mxa:MXAN_1386)
    (mxa:MXAN_1271, mxa:MXAN_2675)
    (mxa:MXAN_1283, mxa:MXAN_3537)
    (mxa:MXAN_1362, mxa:MXAN_6319)
    (mxa:MXAN_1438, mxa:MXAN_7138)
    (mxa:MXAN_1528, mxa:MXAN_2536)
    (mxa:MXAN_1528, mxa:MXAN_2959)
    (mxa:MXAN_1528, mxa:MXAN_3518)
    (mxa:MXAN_1571, mxa:MXAN_4171)
    (mxa:MXAN_1595, mxa:MXAN_1947)
    (mxa:MXAN_1595, mxa:MXAN_4027)
    (mxa:MXAN_1933, mxa:MXAN_2800)
    (mxa:MXAN_1947, mxa:MXAN_4027)
    (mxa:MXAN_2352, mxa:MXAN_3591)
    (mxa:MXAN_2358, mxa:MXAN_5929)
    (mxa:MXAN_2536, mxa:MXAN_2959)
    (mxa:MXAN_2536, mxa:MXAN_3518)
    (mxa:MXAN_2543, mxa:MXAN_4772)
    (mxa:MXAN_2570, mxa:MXAN_5856)
    (mxa:MXAN_2925, mxa:MXAN_5057)
    (mxa:MXAN_2959, mxa:MXAN_3518)
    (mxa:MXAN_2983, mxa:MXAN_5001)
    (mxa:MXAN_3330, mxa:MXAN_3969)
    (mxa:MXAN_3330, mxa:MXAN_5578)
    (mxa:MXAN_3385, mxa:MXAN_5358)
    (mxa:MXAN_3466, mxa:MXAN_4877)
    (mxa:MXAN_3506, mxa:MXAN_3507)
    (mxa:MXAN_3506, mxa:MXAN_3987)
    (mxa:MXAN_3506, mxa:MXAN_4613)
    (mxa:MXAN_3507, mxa:MXAN_3987)
    (mxa:MXAN_3507, mxa:MXAN_4613)
    (mxa:MXAN_3514, mxa:MXAN_6299)
    (mxa:MXAN_3969, mxa:MXAN_5578)
    (mxa:MXAN_3987, mxa:MXAN_4613)
    (mxa:MXAN_4038, mxa:MXAN_4228)
    (mxa:MXAN_4051, mxa:MXAN_4460)
    (mxa:MXAN_4051, mxa:MXAN_4745)
    (mxa:MXAN_4097, mxa:MXAN_5601)
    (mxa:MXAN_4097, mxa:MXAN_5741)
    (mxa:MXAN_4097, mxa:MXAN_5951)
    (mxa:MXAN_4212, mxa:MXAN_7413)
    (mxa:MXAN_4370, mxa:MXAN_4770)
    (mxa:MXAN_4370, mxa:MXAN_6399)
    (mxa:MXAN_4460, mxa:MXAN_4745)
    (mxa:MXAN_4460, mxa:MXAN_6220)
    (mxa:MXAN_4684, mxa:MXAN_4731)
    (mxa:MXAN_4725, mxa:MXAN_6393)
    (mxa:MXAN_4745, mxa:MXAN_6220)
    (mxa:MXAN_4768, mxa:MXAN_6395)
    (mxa:MXAN_4768, mxa:MXAN_6400)
    (mxa:MXAN_4770, mxa:MXAN_6398)
    (mxa:MXAN_4770, mxa:MXAN_6399)
    (mxa:MXAN_4770, mxa:MXAN_6909)
    (mxa:MXAN_5075, mxa:MXAN_7156)
    (mxa:MXAN_5601, mxa:MXAN_5741)
    (mxa:MXAN_5601, mxa:MXAN_5951)
    (mxa:MXAN_5608, mxa:MXAN_5609)
    (mxa:MXAN_5741, mxa:MXAN_5951)
    (mxa:MXAN_5928, mxa:MXAN_6731)
    (mxa:MXAN_6112, mxa:MXAN_6859)
    (mxa:MXAN_6395, mxa:MXAN_6400)
    (mxa:MXAN_6398, mxa:MXAN_6399)
    (mxa:MXAN_6398, mxa:MXAN_6909)
    (mxa:MXAN_6399, mxa:MXAN_6909)
    (mym:A176_000033, mym:A176_002773)
    (mym:A176_000388, mym:A176_005929)
    (mym:A176_000459, mym:A176_000578)
    (mym:A176_000459, mym:A176_005642)
    (mym:A176_000459, mym:A176_006490)
    (mym:A176_000459, mym:A176_006908)
    (mym:A176_000489, mym:A176_000494)
    (mym:A176_000489, mym:A176_001932)
    (mym:A176_000489, mym:A176_002124)
    (mym:A176_000489, mym:A176_004236)
    (mym:A176_000490, mym:A176_002122)
    (mym:A176_000490, mym:A176_002532)
    (mym:A176_000490, mym:A176_006064)
    (mym:A176_000490, mym:A176_006784)
    (mym:A176_000490, mym:A176_007648)
    (mym:A176_000491, mym:A176_002122)
    (mym:A176_000494, mym:A176_001932)
    (mym:A176_000494, mym:A176_002124)
    (mym:A176_000494, mym:A176_004236)
    (mym:A176_000496, mym:A176_002167)
    (mym:A176_000578, mym:A176_005642)
    (mym:A176_000578, mym:A176_006490)
    (mym:A176_000578, mym:A176_006908)
    (mym:A176_000601, mym:A176_003399)
    (mym:A176_000635, mym:A176_002984)
    (mym:A176_000682, mym:A176_001499)
    (mym:A176_000682, mym:A176_002147)
    (mym:A176_000682, mym:A176_002437)
    (mym:A176_000682, mym:A176_006642)
    (mym:A176_000945, mym:A176_002800)
    (mym:A176_000967, mym:A176_004685)
    (mym:A176_001048, mym:A176_004468)
    (mym:A176_001048, mym:A176_006029)
    (mym:A176_001167, mym:A176_001320)
    (mym:A176_001167, mym:A176_002800)
    (mym:A176_001288, mym:A176_006068)
    (mym:A176_001320, mym:A176_002800)
    (mym:A176_001362, mym:A176_002955)
    (mym:A176_001362, mym:A176_003617)
    (mym:A176_001362, mym:A176_006864)
    (mym:A176_001499, mym:A176_002147)
    (mym:A176_001499, mym:A176_002437)
    (mym:A176_001499, mym:A176_006642)
    (mym:A176_001554, mym:A176_003561)
    (mym:A176_001811, mym:A176_007377)
    (mym:A176_001826, mym:A176_004084)
    (mym:A176_001887, mym:A176_004027)
    (mym:A176_001887, mym:A176_004884)
    (mym:A176_001932, mym:A176_002124)
    (mym:A176_001932, mym:A176_004236)
    (mym:A176_002007, mym:A176_003458)
    (mym:A176_002120, mym:A176_004497)
    (mym:A176_002122, mym:A176_002532)
    (mym:A176_002122, mym:A176_006064)
    (mym:A176_002122, mym:A176_006784)
    (mym:A176_002122, mym:A176_007648)
    (mym:A176_002124, mym:A176_004236)
    (mym:A176_002147, mym:A176_002437)
    (mym:A176_002147, mym:A176_006642)
    (mym:A176_002161, mym:A176_002210)
    (mym:A176_002255, mym:A176_003863)
    (mym:A176_002284, mym:A176_002926)
    (mym:A176_002284, mym:A176_003407)
    (mym:A176_002284, mym:A176_003408)
    (mym:A176_002437, mym:A176_006642)
    (mym:A176_002672, mym:A176_002870)
    (mym:A176_002681, mym:A176_006715)
    (mym:A176_002689, mym:A176_007109)
    (mym:A176_002734, mym:A176_005409)
    (mym:A176_002734, mym:A176_005981)
    (mym:A176_002879, mym:A176_005044)
    (mym:A176_002879, mym:A176_005386)
    (mym:A176_002926, mym:A176_003407)
    (mym:A176_002926, mym:A176_003408)
    (mym:A176_002955, mym:A176_003617)
    (mym:A176_002955, mym:A176_006864)
    (mym:A176_003317, mym:A176_004693)
    (mym:A176_003393, mym:A176_004054)
    (mym:A176_003393, mym:A176_004505)
    (mym:A176_003393, mym:A176_005227)
    (mym:A176_003393, mym:A176_005454)
    (mym:A176_003393, mym:A176_007563)
    (mym:A176_003407, mym:A176_003408)
    (mym:A176_003560, mym:A176_006496)
    (mym:A176_003617, mym:A176_006864)
    (mym:A176_003849, mym:A176_004057)
    (mym:A176_003863, mym:A176_007168)
    (mym:A176_004027, mym:A176_004884)
    (mym:A176_004054, mym:A176_004505)
    (mym:A176_004054, mym:A176_005227)
    (mym:A176_004054, mym:A176_005454)
    (mym:A176_004054, mym:A176_007563)
    (mym:A176_004217, mym:A176_005054)
    (mym:A176_004355, mym:A176_005718)
    (mym:A176_004468, mym:A176_006029)
    (mym:A176_004505, mym:A176_005227)
    (mym:A176_004505, mym:A176_005454)
    (mym:A176_004505, mym:A176_007563)
    (mym:A176_005044, mym:A176_005386)
    (mym:A176_005227, mym:A176_005454)
    (mym:A176_005227, mym:A176_007563)
    (mym:A176_005409, mym:A176_005981)
    (mym:A176_005454, mym:A176_006029)
    (mym:A176_005454, mym:A176_007563)
    (mym:A176_005543, mym:A176_007396)
    (mym:A176_005616, mym:A176_005864)
    (mym:A176_005642, mym:A176_006490)
    (mym:A176_005642, mym:A176_006908)
    (mym:A176_006029, mym:A176_007563)
    (mym:A176_006064, mym:A176_007648)
    (mym:A176_006490, mym:A176_006908)
    (pace:A6070_00050, pace:A6070_14775)
    (pace:A6070_00320, pace:A6070_08045)
    (pace:A6070_00575, pace:A6070_13365)
    (pace:A6070_00575, pace:A6070_13370)
    (pace:A6070_00600, pace:A6070_01515)
    (pace:A6070_01225, pace:A6070_05920)
    (pace:A6070_01315, pace:A6070_03160)
    (pace:A6070_01580, pace:A6070_06665)
    (pace:A6070_01735, pace:A6070_04115)
    (pace:A6070_01780, pace:A6070_06385)
    (pace:A6070_01880, pace:A6070_05385)
    (pace:A6070_02565, pace:A6070_07975)
    (pace:A6070_02940, pace:A6070_03835)
    (pace:A6070_02940, pace:A6070_05790)
    (pace:A6070_03240, pace:A6070_07185)
    (pace:A6070_03835, pace:A6070_05790)
    (pace:A6070_04095, pace:A6070_04955)
    (pace:A6070_04145, pace:A6070_10120)
    (pace:A6070_04260, pace:A6070_04265)
    (pace:A6070_04300, pace:A6070_06445)
    (pace:A6070_04300, pace:A6070_06450)
    (pace:A6070_04750, pace:A6070_05320)
    (pace:A6070_04750, pace:A6070_07325)
    (pace:A6070_04975, pace:A6070_10090)
    (pace:A6070_05010, pace:A6070_06835)
    (pace:A6070_05320, pace:A6070_07325)
    (pace:A6070_05405, pace:A6070_11125)
    (pace:A6070_05405, pace:A6070_13415)
    (pace:A6070_06035, pace:A6070_14665)
    (pace:A6070_06075, pace:A6070_06120)
    (pace:A6070_06445, pace:A6070_06450)
    (pace:A6070_06815, pace:A6070_13365)
    (pace:A6070_07200, pace:A6070_13790)
    (pace:A6070_07305, pace:A6070_10675)
    (pace:A6070_07305, pace:A6070_10805)
    (pace:A6070_07305, pace:A6070_13980)
    (pace:A6070_07305, pace:A6070_13985)
    (pace:A6070_07305, pace:A6070_14605)
    (pace:A6070_07525, pace:A6070_13030)
    (pace:A6070_08275, pace:A6070_10395)
    (pace:A6070_08290, pace:A6070_14230)
    (pace:A6070_09000, pace:A6070_14615)
    (pace:A6070_10675, pace:A6070_10805)
    (pace:A6070_10675, pace:A6070_13980)
    (pace:A6070_10675, pace:A6070_13985)
    (pace:A6070_10675, pace:A6070_14605)
    (pace:A6070_10805, pace:A6070_13980)
    (pace:A6070_10805, pace:A6070_13985)
    (pace:A6070_10805, pace:A6070_14605)
    (pace:A6070_11125, pace:A6070_13415)
    (pace:A6070_12850, pace:A6070_13195)
    (pace:A6070_12850, pace:A6070_13200)
    (pace:A6070_13195, pace:A6070_13200)
    (pace:A6070_13980, pace:A6070_13985)
    (pace:A6070_13980, pace:A6070_14605)
    (pace:A6070_13985, pace:A6070_14605)
    (pca:Pcar_0050, pca:Pcar_1841)
    (pca:Pcar_0050, pca:Pcar_1860)
    (pca:Pcar_0092, pca:Pcar_1727)
    (pca:Pcar_0114, pca:Pcar_2943)
    (pca:Pcar_0189, pca:Pcar_1121)
    (pca:Pcar_0189, pca:Pcar_1910)
    (pca:Pcar_0251, pca:Pcar_0255)
    (pca:Pcar_0251, pca:Pcar_1594)
    (pca:Pcar_0251, pca:Pcar_2506)
    (pca:Pcar_0251, pca:Pcar_2847)
    (pca:Pcar_0255, pca:Pcar_1594)
    (pca:Pcar_0255, pca:Pcar_2506)
    (pca:Pcar_0255, pca:Pcar_2847)
    (pca:Pcar_0266, pca:Pcar_1460)
    (pca:Pcar_0337, pca:Pcar_2236)
    (pca:Pcar_0342, pca:Pcar_0607)
    (pca:Pcar_0347, pca:Pcar_1486)
    (pca:Pcar_0374, pca:Pcar_1692)
    (pca:Pcar_0482, pca:Pcar_3106)
    (pca:Pcar_0824, pca:Pcar_1514)
    (pca:Pcar_1007, pca:Pcar_1907)
    (pca:Pcar_1033, pca:Pcar_2230)
    (pca:Pcar_1040, pca:Pcar_1248)
    (pca:Pcar_1121, pca:Pcar_1910)
    (pca:Pcar_1129, pca:Pcar_2596)
    (pca:Pcar_1244, pca:Pcar_2240)
    (pca:Pcar_1255, pca:Pcar_1495)
    (pca:Pcar_1320, pca:Pcar_1569)
    (pca:Pcar_1320, pca:Pcar_2115)
    (pca:Pcar_1326, pca:Pcar_1805)
    (pca:Pcar_1326, pca:Pcar_2933)
    (pca:Pcar_1331, pca:Pcar_2254)
    (pca:Pcar_1331, pca:Pcar_2624)
    (pca:Pcar_1413, pca:Pcar_2315)
    (pca:Pcar_1413, pca:Pcar_2455)
    (pca:Pcar_1436, pca:Pcar_2987)
    (pca:Pcar_1438, pca:Pcar_2667)
    (pca:Pcar_1440, pca:Pcar_2664)
    (pca:Pcar_1466, pca:Pcar_1806)
    (pca:Pcar_1467, pca:Pcar_1804)
    (pca:Pcar_1467, pca:Pcar_1807)
    (pca:Pcar_1467, pca:Pcar_2593)
    (pca:Pcar_1534, pca:Pcar_1718)
    (pca:Pcar_1534, pca:Pcar_2430)
    (pca:Pcar_1534, pca:Pcar_3005)
    (pca:Pcar_1569, pca:Pcar_2115)
    (pca:Pcar_1594, pca:Pcar_2506)
    (pca:Pcar_1594, pca:Pcar_2847)
    (pca:Pcar_1607, pca:Pcar_1632)
    (pca:Pcar_1607, pca:Pcar_1722)
    (pca:Pcar_1615, pca:Pcar_2415)
    (pca:Pcar_1632, pca:Pcar_1722)
    (pca:Pcar_1667, pca:Pcar_2719)
    (pca:Pcar_1718, pca:Pcar_2430)
    (pca:Pcar_1718, pca:Pcar_3005)
    (pca:Pcar_1776, pca:Pcar_2174)
    (pca:Pcar_1804, pca:Pcar_1807)
    (pca:Pcar_1805, pca:Pcar_2933)
    (pca:Pcar_1807, pca:Pcar_2593)
    (pca:Pcar_1841, pca:Pcar_1860)
    (pca:Pcar_1916, pca:Pcar_2778)
    (pca:Pcar_2150, pca:Pcar_2192)
    (pca:Pcar_2206, pca:Pcar_2207)
    (pca:Pcar_2254, pca:Pcar_2624)
    (pca:Pcar_2315, pca:Pcar_2455)
    (pca:Pcar_2430, pca:Pcar_3005)
    (pca:Pcar_2435, pca:Pcar_3011)
    (pca:Pcar_2506, pca:Pcar_2847)
    (pca:Pcar_2684, pca:Pcar_2685)
    (pca:Pcar_2719, pca:Pcar_3125)
    (pca:Pcar_2720, pca:Pcar_3125)
    (pef:A7E78_00020, pef:A7E78_10820)
    (pef:A7E78_00045, pef:A7E78_11135)
    (pef:A7E78_00095, pef:A7E78_01225)
    (pef:A7E78_00335, pef:A7E78_03040)
    (pef:A7E78_00335, pef:A7E78_11740)
    (pef:A7E78_00350, pef:A7E78_01430)
    (pef:A7E78_00350, pef:A7E78_03875)
    (pef:A7E78_00355, pef:A7E78_01440)
    (pef:A7E78_00360, pef:A7E78_01445)
    (pef:A7E78_01045, pef:A7E78_03875)
    (pef:A7E78_01330, pef:A7E78_05895)
    (pef:A7E78_01430, pef:A7E78_03875)
    (pef:A7E78_01785, pef:A7E78_13175)
    (pef:A7E78_01825, pef:A7E78_09055)
    (pef:A7E78_02235, pef:A7E78_03620)
    (pef:A7E78_02275, pef:A7E78_05185)
    (pef:A7E78_02355, pef:A7E78_08565)
    (pef:A7E78_02400, pef:A7E78_06630)
    (pef:A7E78_02400, pef:A7E78_13520)
    (pef:A7E78_02580, pef:A7E78_07855)
    (pef:A7E78_02580, pef:A7E78_11340)
    (pef:A7E78_02580, pef:A7E78_12505)
    (pef:A7E78_02600, pef:A7E78_11715)
    (pef:A7E78_02750, pef:A7E78_11150)
    (pef:A7E78_02810, pef:A7E78_02815)
    (pef:A7E78_02810, pef:A7E78_14195)
    (pef:A7E78_02815, pef:A7E78_14195)
    (pef:A7E78_02985, pef:A7E78_13795)
    (pef:A7E78_03040, pef:A7E78_11740)
    (pef:A7E78_03600, pef:A7E78_04420)
    (pef:A7E78_03600, pef:A7E78_08985)
    (pef:A7E78_03600, pef:A7E78_13750)
    (pef:A7E78_04140, pef:A7E78_04585)
    (pef:A7E78_04140, pef:A7E78_04590)
    (pef:A7E78_04140, pef:A7E78_10690)
    (pef:A7E78_04420, pef:A7E78_08985)
    (pef:A7E78_04420, pef:A7E78_13750)
    (pef:A7E78_04585, pef:A7E78_04590)
    (pef:A7E78_04585, pef:A7E78_10690)
    (pef:A7E78_04590, pef:A7E78_10690)
    (pef:A7E78_04875, pef:A7E78_05905)
    (pef:A7E78_04890, pef:A7E78_06000)
    (pef:A7E78_05540, pef:A7E78_10875)
    (pef:A7E78_05805, pef:A7E78_12430)
    (pef:A7E78_06095, pef:A7E78_06150)
    (pef:A7E78_06150, pef:A7E78_11875)
    (pef:A7E78_06630, pef:A7E78_13520)
    (pef:A7E78_07325, pef:A7E78_07335)
    (pef:A7E78_07855, pef:A7E78_11340)
    (pef:A7E78_07855, pef:A7E78_12505)
    (pef:A7E78_08220, pef:A7E78_08225)
    (pef:A7E78_08985, pef:A7E78_13750)
    (pef:A7E78_10095, pef:A7E78_12525)
    (pef:A7E78_10390, pef:A7E78_11145)
    (pef:A7E78_10450, pef:A7E78_12325)
    (pef:A7E78_10830, pef:A7E78_10835)
    (pef:A7E78_11340, pef:A7E78_12505)
    (ppd:Ppro_0016, ppd:Ppro_1516)
    (ppd:Ppro_0050, ppd:Ppro_2466)
    (ppd:Ppro_0050, ppd:Ppro_2871)
    (ppd:Ppro_0301, ppd:Ppro_1664)
    (ppd:Ppro_0342, ppd:Ppro_3020)
    (ppd:Ppro_0343, ppd:Ppro_1714)
    (ppd:Ppro_0387, ppd:Ppro_1617)
    (ppd:Ppro_0415, ppd:Ppro_2240)
    (ppd:Ppro_0454, ppd:Ppro_1453)
    (ppd:Ppro_0454, ppd:Ppro_1454)
    (ppd:Ppro_0579, ppd:Ppro_1687)
    (ppd:Ppro_0905, ppd:Ppro_1518)
    (ppd:Ppro_0905, ppd:Ppro_1744)
    (ppd:Ppro_0907, ppd:Ppro_1746)
    (ppd:Ppro_1029, ppd:Ppro_2239)
    (ppd:Ppro_1034, ppd:Ppro_2596)
    (ppd:Ppro_1034, ppd:Ppro_2809)
    (ppd:Ppro_1046, ppd:Ppro_2189)
    (ppd:Ppro_1177, ppd:Ppro_2666)
    (ppd:Ppro_1191, ppd:Ppro_2403)
    (ppd:Ppro_1291, ppd:Ppro_1293)
    (ppd:Ppro_1453, ppd:Ppro_1454)
    (ppd:Ppro_1518, ppd:Ppro_1744)
    (ppd:Ppro_1520, ppd:Ppro_3041)
    (ppd:Ppro_1580, ppd:Ppro_1731)
    (ppd:Ppro_1580, ppd:Ppro_3596)
    (ppd:Ppro_1669, ppd:Ppro_1754)
    (ppd:Ppro_1725, ppd:Ppro_3484)
    (ppd:Ppro_1731, ppd:Ppro_3596)
    (ppd:Ppro_1832, ppd:Ppro_3359)
    (ppd:Ppro_2098, ppd:Ppro_2973)
    (ppd:Ppro_2098, ppd:Ppro_3406)
    (ppd:Ppro_2118, ppd:Ppro_3347)
    (ppd:Ppro_2240, ppd:Ppro_3415)
    (ppd:Ppro_2329, ppd:Ppro_3014)
    (ppd:Ppro_2466, ppd:Ppro_2871)
    (ppd:Ppro_2529, ppd:Ppro_3172)
    (ppd:Ppro_2540, ppd:Ppro_3253)
    (ppd:Ppro_2556, ppd:Ppro_2557)
    (ppd:Ppro_2596, ppd:Ppro_2809)
    (ppd:Ppro_3055, ppd:Ppro_3056)
    (ppd:Ppro_3288, ppd:Ppro_3293)
    (ppd:Ppro_3293, ppd:Ppro_3294)
    (pprf:DPRO_0148, pprf:DPRO_0842)
    (pprf:DPRO_0151, pprf:DPRO_2879)
    (pprf:DPRO_0163, pprf:DPRO_1945)
    (pprf:DPRO_0184, pprf:DPRO_0920)
    (pprf:DPRO_0184, pprf:DPRO_1845)
    (pprf:DPRO_0282, pprf:DPRO_3892)
    (pprf:DPRO_0296, pprf:DPRO_1057)
    (pprf:DPRO_0434, pprf:DPRO_1584)
    (pprf:DPRO_0650, pprf:DPRO_3319)
    (pprf:DPRO_0665, pprf:DPRO_0870)
    (pprf:DPRO_0799, pprf:DPRO_2976)
    (pprf:DPRO_0802, pprf:DPRO_2470)
    (pprf:DPRO_0802, pprf:DPRO_2602)
    (pprf:DPRO_0843, pprf:DPRO_1580)
    (pprf:DPRO_0869, pprf:DPRO_1966)
    (pprf:DPRO_0895, pprf:DPRO_1221)
    (pprf:DPRO_0895, pprf:DPRO_1856)
    (pprf:DPRO_0895, pprf:DPRO_2030)
    (pprf:DPRO_0895, pprf:DPRO_2643)
    (pprf:DPRO_0920, pprf:DPRO_1845)
    (pprf:DPRO_1084, pprf:DPRO_1450)
    (pprf:DPRO_1221, pprf:DPRO_1856)
    (pprf:DPRO_1221, pprf:DPRO_2030)
    (pprf:DPRO_1221, pprf:DPRO_2643)
    (pprf:DPRO_1333, pprf:DPRO_1945)
    (pprf:DPRO_1336, pprf:DPRO_1657)
    (pprf:DPRO_1432, pprf:DPRO_1502)
    (pprf:DPRO_1432, pprf:DPRO_1802)
    (pprf:DPRO_1432, pprf:DPRO_2174)
    (pprf:DPRO_1432, pprf:DPRO_2638)
    (pprf:DPRO_1432, pprf:DPRO_3025)
    (pprf:DPRO_1502, pprf:DPRO_1802)
    (pprf:DPRO_1502, pprf:DPRO_2174)
    (pprf:DPRO_1557, pprf:DPRO_2629)
    (pprf:DPRO_1577, pprf:DPRO_2329)
    (pprf:DPRO_1581, pprf:DPRO_4008)
    (pprf:DPRO_1583, pprf:DPRO_2705)
    (pprf:DPRO_1586, pprf:DPRO_2330)
    (pprf:DPRO_1802, pprf:DPRO_2174)
    (pprf:DPRO_1856, pprf:DPRO_2030)
    (pprf:DPRO_1856, pprf:DPRO_2643)
    (pprf:DPRO_2030, pprf:DPRO_2643)
    (pprf:DPRO_2239, pprf:DPRO_3321)
    (pprf:DPRO_2275, pprf:DPRO_3102)
    (pprf:DPRO_2444, pprf:DPRO_2976)
    (pprf:DPRO_2470, pprf:DPRO_2602)
    (pprf:DPRO_2555, pprf:DPRO_3829)
    (pprf:DPRO_2638, pprf:DPRO_3025)
    (pprf:DPRO_2839, pprf:DPRO_2881)
    (pprf:DPRO_3102, pprf:DPRO_3768)
    (pprf:DPRO_3319, pprf:DPRO_3425)
    (samy:DB32_000011, samy:DB32_008540)
    (samy:DB32_000011, samy:DB32_008959)
    (samy:DB32_000113, samy:DB32_006304)
    (samy:DB32_000113, samy:DB32_008649)
    (samy:DB32_000113, samy:DB32_008650)
    (samy:DB32_000220, samy:DB32_001412)
    (samy:DB32_000220, samy:DB32_001928)
    (samy:DB32_000220, samy:DB32_002239)
    (samy:DB32_000220, samy:DB32_003887)
    (samy:DB32_000279, samy:DB32_000657)
    (samy:DB32_000279, samy:DB32_001409)
    (samy:DB32_000279, samy:DB32_003889)
    (samy:DB32_000279, samy:DB32_004662)
    (samy:DB32_000329, samy:DB32_007373)
    (samy:DB32_000330, samy:DB32_005704)
    (samy:DB32_000455, samy:DB32_006503)
    (samy:DB32_000467, samy:DB32_004284)
    (samy:DB32_000470, samy:DB32_001908)
    (samy:DB32_000588, samy:DB32_004856)
    (samy:DB32_000588, samy:DB32_005289)
    (samy:DB32_000657, samy:DB32_001409)
    (samy:DB32_000657, samy:DB32_003889)
    (samy:DB32_000657, samy:DB32_004662)
    (samy:DB32_000680, samy:DB32_007648)
    (samy:DB32_000949, samy:DB32_001412)
    (samy:DB32_000949, samy:DB32_001928)
    (samy:DB32_000949, samy:DB32_002239)
    (samy:DB32_000949, samy:DB32_003887)
    (samy:DB32_000965, samy:DB32_004421)
    (samy:DB32_000992, samy:DB32_004319)
    (samy:DB32_001023, samy:DB32_005406)
    (samy:DB32_001141, samy:DB32_007188)
    (samy:DB32_001141, samy:DB32_007931)
    (samy:DB32_001141, samy:DB32_008367)
    (samy:DB32_001261, samy:DB32_008592)
    (samy:DB32_001353, samy:DB32_003546)
    (samy:DB32_001353, samy:DB32_006421)
    (samy:DB32_001409, samy:DB32_003889)
    (samy:DB32_001409, samy:DB32_004662)
    (samy:DB32_001412, samy:DB32_001928)
    (samy:DB32_001412, samy:DB32_002239)
    (samy:DB32_001412, samy:DB32_003887)
    (samy:DB32_001415, samy:DB32_002924)
    (samy:DB32_001613, samy:DB32_001636)
    (samy:DB32_001613, samy:DB32_004998)
    (samy:DB32_001613, samy:DB32_005885)
    (samy:DB32_001636, samy:DB32_004998)
    (samy:DB32_001636, samy:DB32_005885)
    (samy:DB32_001667, samy:DB32_002947)
    (samy:DB32_001708, samy:DB32_003678)
    (samy:DB32_001708, samy:DB32_005205)
    (samy:DB32_001770, samy:DB32_006309)
    (samy:DB32_001845, samy:DB32_004155)
    (samy:DB32_001928, samy:DB32_002239)
    (samy:DB32_001928, samy:DB32_003887)
    (samy:DB32_002077, samy:DB32_005118)
    (samy:DB32_002077, samy:DB32_007837)
    (samy:DB32_002225, samy:DB32_003101)
    (samy:DB32_002225, samy:DB32_003115)
    (samy:DB32_002225, samy:DB32_005212)
    (samy:DB32_002239, samy:DB32_003887)
    (samy:DB32_002265, samy:DB32_006894)
    (samy:DB32_002265, samy:DB32_008737)
    (samy:DB32_002497, samy:DB32_003877)
    (samy:DB32_002655, samy:DB32_004597)
    (samy:DB32_002852, samy:DB32_003477)
    (samy:DB32_002852, samy:DB32_003480)
    (samy:DB32_002852, samy:DB32_005734)
    (samy:DB32_002852, samy:DB32_007120)
    (samy:DB32_002852, samy:DB32_007268)
    (samy:DB32_002852, samy:DB32_007469)
    (samy:DB32_002852, samy:DB32_008364)
    (samy:DB32_002954, samy:DB32_008496)
    (samy:DB32_003077, samy:DB32_003961)
    (samy:DB32_003077, samy:DB32_003964)
    (samy:DB32_003077, samy:DB32_005101)
    (samy:DB32_003077, samy:DB32_006298)
    (samy:DB32_003101, samy:DB32_003115)
    (samy:DB32_003101, samy:DB32_005212)
    (samy:DB32_003115, samy:DB32_005212)
    (samy:DB32_003116, samy:DB32_007931)
    (samy:DB32_003116, samy:DB32_008367)
    (samy:DB32_003149, samy:DB32_005686)
    (samy:DB32_003166, samy:DB32_005700)
    (samy:DB32_003170, samy:DB32_004608)
    (samy:DB32_003477, samy:DB32_003480)
    (samy:DB32_003477, samy:DB32_005734)
    (samy:DB32_003477, samy:DB32_007120)
    (samy:DB32_003477, samy:DB32_007469)
    (samy:DB32_003477, samy:DB32_008364)
    (samy:DB32_003480, samy:DB32_005734)
    (samy:DB32_003480, samy:DB32_007120)
    (samy:DB32_003480, samy:DB32_007469)
    (samy:DB32_003480, samy:DB32_008364)
    (samy:DB32_003518, samy:DB32_007196)
    (samy:DB32_003546, samy:DB32_006421)
    (samy:DB32_003553, samy:DB32_003711)
    (samy:DB32_003553, samy:DB32_003728)
    (samy:DB32_003583, samy:DB32_004060)
    (samy:DB32_003678, samy:DB32_005205)
    (samy:DB32_003711, samy:DB32_003728)
    (samy:DB32_003841, samy:DB32_003842)
    (samy:DB32_003889, samy:DB32_004662)
    (samy:DB32_003941, samy:DB32_006326)
    (samy:DB32_003961, samy:DB32_003964)
    (samy:DB32_003961, samy:DB32_005101)
    (samy:DB32_003961, samy:DB32_006298)
    (samy:DB32_003964, samy:DB32_005101)
    (samy:DB32_003964, samy:DB32_006298)
    (samy:DB32_003973, samy:DB32_008649)
    (samy:DB32_004039, samy:DB32_004546)
    (samy:DB32_004093, samy:DB32_004711)
    (samy:DB32_004135, samy:DB32_004322)
    (samy:DB32_004135, samy:DB32_006581)
    (samy:DB32_004322, samy:DB32_006581)
    (samy:DB32_004394, samy:DB32_006869)
    (samy:DB32_004445, samy:DB32_004448)
    (samy:DB32_004856, samy:DB32_005289)
    (samy:DB32_004998, samy:DB32_005885)
    (samy:DB32_005052, samy:DB32_005931)
    (samy:DB32_005101, samy:DB32_006298)
    (samy:DB32_005105, samy:DB32_007124)
    (samy:DB32_005118, samy:DB32_007837)
    (samy:DB32_005118, samy:DB32_008655)
    (samy:DB32_005206, samy:DB32_005209)
    (samy:DB32_005206, samy:DB32_006761)
    (samy:DB32_005209, samy:DB32_006761)
    (samy:DB32_005734, samy:DB32_007120)
    (samy:DB32_005734, samy:DB32_007469)
    (samy:DB32_005734, samy:DB32_008364)
    (samy:DB32_005996, samy:DB32_008570)
    (samy:DB32_006304, samy:DB32_008650)
    (samy:DB32_006309, samy:DB32_006310)
    (samy:DB32_006894, samy:DB32_008737)
    (samy:DB32_007120, samy:DB32_007469)
    (samy:DB32_007120, samy:DB32_008364)
    (samy:DB32_007188, samy:DB32_007931)
    (samy:DB32_007188, samy:DB32_008367)
    (samy:DB32_007469, samy:DB32_008364)
    (samy:DB32_007585, samy:DB32_008421)
    (samy:DB32_007837, samy:DB32_008655)
    (samy:DB32_007931, samy:DB32_008367)
    (samy:DB32_008540, samy:DB32_008959)
    (samy:DB32_008649, samy:DB32_008650)
    (sat:SYN_00001, sat:SYN_02502)
    (sat:SYN_00075, sat:SYN_00446)
    (sat:SYN_00075, sat:SYN_01253)
    (sat:SYN_00075, sat:SYN_03026)
    (sat:SYN_00090, sat:SYN_02194)
    (sat:SYN_00163, sat:SYN_02985)
    (sat:SYN_00211, sat:SYN_02884)
    (sat:SYN_00231, sat:SYN_00298)
    (sat:SYN_00231, sat:SYN_02761)
    (sat:SYN_00231, sat:SYN_02880)
    (sat:SYN_00266, sat:SYN_00267)
    (sat:SYN_00266, sat:SYN_00272)
    (sat:SYN_00266, sat:SYN_02148)
    (sat:SYN_00267, sat:SYN_00272)
    (sat:SYN_00267, sat:SYN_02148)
    (sat:SYN_00272, sat:SYN_02148)
    (sat:SYN_00298, sat:SYN_01331)
    (sat:SYN_00298, sat:SYN_02600)
    (sat:SYN_00298, sat:SYN_02761)
    (sat:SYN_00298, sat:SYN_02880)
    (sat:SYN_00302, sat:SYN_00442)
    (sat:SYN_00381, sat:SYN_01960)
    (sat:SYN_00412, sat:SYN_01483)
    (sat:SYN_00424, sat:SYN_00729)
    (sat:SYN_00446, sat:SYN_01253)
    (sat:SYN_00583, sat:SYN_02563)
    (sat:SYN_00621, sat:SYN_00891)
    (sat:SYN_00621, sat:SYN_02641)
    (sat:SYN_00761, sat:SYN_01451)
    (sat:SYN_00891, sat:SYN_02641)
    (sat:SYN_00904, sat:SYN_01901)
    (sat:SYN_00907, sat:SYN_01624)
    (sat:SYN_00908, sat:SYN_02937)
    (sat:SYN_01112, sat:SYN_01130)
    (sat:SYN_01112, sat:SYN_02661)
    (sat:SYN_01112, sat:SYN_02866)
    (sat:SYN_01125, sat:SYN_01130)
    (sat:SYN_01125, sat:SYN_02661)
    (sat:SYN_01130, sat:SYN_02661)
    (sat:SYN_01130, sat:SYN_02866)
    (sat:SYN_01149, sat:SYN_01150)
    (sat:SYN_01164, sat:SYN_01517)
    (sat:SYN_01184, sat:SYN_01365)
    (sat:SYN_01184, sat:SYN_01577)
    (sat:SYN_01209, sat:SYN_01226)
    (sat:SYN_01223, sat:SYN_02635)
    (sat:SYN_01223, sat:SYN_02640)
    (sat:SYN_01223, sat:SYN_02643)
    (sat:SYN_01223, sat:SYN_03128)
    (sat:SYN_01231, sat:SYN_02496)
    (sat:SYN_01251, sat:SYN_02126)
    (sat:SYN_01258, sat:SYN_02758)
    (sat:SYN_01331, sat:SYN_02600)
    (sat:SYN_01331, sat:SYN_02761)
    (sat:SYN_01365, sat:SYN_01577)
    (sat:SYN_01451, sat:SYN_01684)
    (sat:SYN_01454, sat:SYN_02374)
    (sat:SYN_01454, sat:SYN_02886)
    (sat:SYN_01532, sat:SYN_02156)
    (sat:SYN_01625, sat:SYN_02589)
    (sat:SYN_01680, sat:SYN_01696)
    (sat:SYN_01680, sat:SYN_02127)
    (sat:SYN_01696, sat:SYN_02127)
    (sat:SYN_01710, sat:SYN_01712)
    (sat:SYN_01711, sat:SYN_01713)
    (sat:SYN_01711, sat:SYN_01965)
    (sat:SYN_01713, sat:SYN_01965)
    (sat:SYN_01740, sat:SYN_01747)
    (sat:SYN_01742, sat:SYN_01747)
    (sat:SYN_01942, sat:SYN_01988)
    (sat:SYN_01943, sat:SYN_02592)
    (sat:SYN_01944, sat:SYN_02591)
    (sat:SYN_01945, sat:SYN_02590)
    (sat:SYN_02188, sat:SYN_02538)
    (sat:SYN_02365, sat:SYN_02566)
    (sat:SYN_02374, sat:SYN_02886)
    (sat:SYN_02501, sat:SYN_03227)
    (sat:SYN_02535, sat:SYN_02602)
    (sat:SYN_02578, sat:SYN_02778)
    (sat:SYN_02635, sat:SYN_02640)
    (sat:SYN_02635, sat:SYN_02643)
    (sat:SYN_02635, sat:SYN_03128)
    (sat:SYN_02640, sat:SYN_02643)
    (sat:SYN_02640, sat:SYN_03128)
    (sat:SYN_02643, sat:SYN_03128)
    (sat:SYN_02661, sat:SYN_02866)
    (sat:SYN_02666, sat:SYN_02678)
    (scl:sce0088, scl:sce1032)
    (scl:sce0127, scl:sce7883)
    (scl:sce0176, scl:sce0253)
    (scl:sce0379, scl:sce3875)
    (scl:sce0564, scl:sce6856)
    (scl:sce0616, scl:sce5320)
    (scl:sce0693, scl:sce9167)
    (scl:sce0752, scl:sce5078)
    (scl:sce0903, scl:sce5271)
    (scl:sce0903, scl:sce8012)
    (scl:sce0903, scl:sce8696)
    (scl:sce1044, scl:sce4502)
    (scl:sce1063, scl:sce3161)
    (scl:sce1175, scl:sce8683)
    (scl:sce1213, scl:sce3817)
    (scl:sce1214, scl:sce3730)
    (scl:sce1214, scl:sce8127)
    (scl:sce1214, scl:sce8755)
    (scl:sce1639, scl:sce2226)
    (scl:sce1646, scl:sce3354)
    (scl:sce1646, scl:sce3815)
    (scl:sce1646, scl:sce5302)
    (scl:sce1736, scl:sce1738)
    (scl:sce1736, scl:sce8281)
    (scl:sce1738, scl:sce8281)
    (scl:sce2402, scl:sce9309)
    (scl:sce2526, scl:sce3351)
    (scl:sce2526, scl:sce3813)
    (scl:sce2526, scl:sce5922)
    (scl:sce2535, scl:sce6246)
    (scl:sce2535, scl:sce9261)
    (scl:sce2553, scl:sce6193)
    (scl:sce2600, scl:sce3817)
    (scl:sce2600, scl:sce5053)
    (scl:sce2813, scl:sce5886)
    (scl:sce3018, scl:sce3432)
    (scl:sce3018, scl:sce4359)
    (scl:sce3035, scl:sce6876)
    (scl:sce3187, scl:sce3826)
    (scl:sce3187, scl:sce4939)
    (scl:sce3187, scl:sce8804)
    (scl:sce3273, scl:sce3354)
    (scl:sce3273, scl:sce3815)
    (scl:sce3273, scl:sce5302)
    (scl:sce3351, scl:sce3813)
    (scl:sce3351, scl:sce5922)
    (scl:sce3354, scl:sce3815)
    (scl:sce3354, scl:sce5302)
    (scl:sce3432, scl:sce4359)
    (scl:sce3447, scl:sce3760)
    (scl:sce3526, scl:sce4640)
    (scl:sce3703, scl:sce7329)
    (scl:sce3730, scl:sce8127)
    (scl:sce3730, scl:sce8755)
    (scl:sce3733, scl:sce3734)
    (scl:sce3733, scl:sce4883)
    (scl:sce3733, scl:sce8174)
    (scl:sce3735, scl:sce8151)
    (scl:sce3813, scl:sce5922)
    (scl:sce3815, scl:sce5302)
    (scl:sce3817, scl:sce5053)
    (scl:sce3826, scl:sce4939)
    (scl:sce3826, scl:sce8804)
    (scl:sce3953, scl:sce7210)
    (scl:sce3987, scl:sce8467)
    (scl:sce4177, scl:sce4570)
    (scl:sce4177, scl:sce7847)
    (scl:sce4215, scl:sce8855)
    (scl:sce4215, scl:sce8915)
    (scl:sce4236, scl:sce5134)
    (scl:sce4236, scl:sce7417)
    (scl:sce4259, scl:sce4283)
    (scl:sce4320, scl:sce7407)
    (scl:sce4540, scl:sce5197)
    (scl:sce4570, scl:sce7847)
    (scl:sce4641, scl:sce4786)
    (scl:sce4641, scl:sce5753)
    (scl:sce4641, scl:sce5757)
    (scl:sce4641, scl:sce7375)
    (scl:sce4786, scl:sce5753)
    (scl:sce4786, scl:sce5757)
    (scl:sce4786, scl:sce7375)
    (scl:sce4939, scl:sce8804)
    (scl:sce5134, scl:sce7417)
    (scl:sce5271, scl:sce8012)
    (scl:sce5271, scl:sce8696)
    (scl:sce5556, scl:sce7038)
    (scl:sce5753, scl:sce5757)
    (scl:sce5753, scl:sce7375)
    (scl:sce5757, scl:sce7375)
    (scl:sce5871, scl:sce7733)
    (scl:sce6246, scl:sce9261)
    (scl:sce6540, scl:sce6934)
    (scl:sce7844, scl:sce8601)
    (scl:sce7844, scl:sce8917)
    (scl:sce7883, scl:sce8081)
    (scl:sce7883, scl:sce8230)
    (scl:sce7927, scl:sce8012)
    (scl:sce8012, scl:sce8696)
    (scl:sce8081, scl:sce8230)
    (scl:sce8127, scl:sce8755)
    (scl:sce8601, scl:sce8917)
    (scl:sce8671, scl:sce8676)
    (scl:sce8855, scl:sce8915)
    (scl:sce9115, scl:sce9130)
    (sfu:Sfum_0007, sfu:Sfum_0268)
    (sfu:Sfum_0007, sfu:Sfum_2580)
    (sfu:Sfum_0008, sfu:Sfum_3911)
    (sfu:Sfum_0062, sfu:Sfum_2090)
    (sfu:Sfum_0108, sfu:Sfum_0745)
    (sfu:Sfum_0108, sfu:Sfum_3454)
    (sfu:Sfum_0112, sfu:Sfum_1374)
    (sfu:Sfum_0113, sfu:Sfum_0933)
    (sfu:Sfum_0122, sfu:Sfum_0192)
    (sfu:Sfum_0122, sfu:Sfum_2084)
    (sfu:Sfum_0156, sfu:Sfum_2789)
    (sfu:Sfum_0179, sfu:Sfum_2264)
    (sfu:Sfum_0192, sfu:Sfum_2084)
    (sfu:Sfum_0296, sfu:Sfum_2981)
    (sfu:Sfum_0296, sfu:Sfum_2982)
    (sfu:Sfum_0296, sfu:Sfum_3023)
    (sfu:Sfum_0296, sfu:Sfum_3024)
    (sfu:Sfum_0379, sfu:Sfum_0382)
    (sfu:Sfum_0379, sfu:Sfum_1676)
    (sfu:Sfum_0379, sfu:Sfum_1683)
    (sfu:Sfum_0382, sfu:Sfum_1676)
    (sfu:Sfum_0382, sfu:Sfum_1683)
    (sfu:Sfum_0392, sfu:Sfum_0534)
    (sfu:Sfum_0478, sfu:Sfum_1634)
    (sfu:Sfum_0478, sfu:Sfum_2681)
    (sfu:Sfum_0483, sfu:Sfum_1215)
    (sfu:Sfum_0483, sfu:Sfum_3692)
    (sfu:Sfum_0605, sfu:Sfum_4095)
    (sfu:Sfum_0615, sfu:Sfum_1700)
    (sfu:Sfum_0615, sfu:Sfum_3076)
    (sfu:Sfum_0630, sfu:Sfum_0634)
    (sfu:Sfum_0630, sfu:Sfum_0649)
    (sfu:Sfum_0630, sfu:Sfum_2666)
    (sfu:Sfum_0634, sfu:Sfum_0649)
    (sfu:Sfum_0634, sfu:Sfum_2666)
    (sfu:Sfum_0649, sfu:Sfum_2666)
    (sfu:Sfum_0698, sfu:Sfum_1709)
    (sfu:Sfum_0745, sfu:Sfum_3454)
    (sfu:Sfum_0769, sfu:Sfum_1774)
    (sfu:Sfum_0841, sfu:Sfum_1844)
    (sfu:Sfum_0871, sfu:Sfum_1596)
    (sfu:Sfum_0934, sfu:Sfum_1376)
    (sfu:Sfum_0937, sfu:Sfum_1596)
    (sfu:Sfum_0983, sfu:Sfum_2111)
    (sfu:Sfum_1039, sfu:Sfum_2669)
    (sfu:Sfum_1171, sfu:Sfum_1665)
    (sfu:Sfum_1208, sfu:Sfum_3652)
    (sfu:Sfum_1215, sfu:Sfum_3692)
    (sfu:Sfum_1302, sfu:Sfum_1418)
    (sfu:Sfum_1375, sfu:Sfum_3714)
    (sfu:Sfum_1468, sfu:Sfum_2061)
    (sfu:Sfum_1468, sfu:Sfum_2062)
    (sfu:Sfum_1470, sfu:Sfum_2957)
    (sfu:Sfum_1475, sfu:Sfum_2959)
    (sfu:Sfum_1533, sfu:Sfum_2105)
    (sfu:Sfum_1538, sfu:Sfum_2262)
    (sfu:Sfum_1608, sfu:Sfum_3719)
    (sfu:Sfum_1676, sfu:Sfum_1683)
    (sfu:Sfum_1700, sfu:Sfum_3076)
    (sfu:Sfum_1771, sfu:Sfum_2404)
    (sfu:Sfum_1824, sfu:Sfum_3508)
    (sfu:Sfum_1913, sfu:Sfum_1953)
    (sfu:Sfum_2015, sfu:Sfum_2116)
    (sfu:Sfum_2061, sfu:Sfum_2062)
    (sfu:Sfum_2123, sfu:Sfum_3619)
    (sfu:Sfum_2263, sfu:Sfum_3965)
    (sfu:Sfum_2610, sfu:Sfum_3720)
    (sfu:Sfum_2645, sfu:Sfum_3549)
    (sfu:Sfum_2980, sfu:Sfum_2983)
    (sfu:Sfum_2980, sfu:Sfum_3022)
    (sfu:Sfum_2980, sfu:Sfum_3025)
    (sfu:Sfum_2981, sfu:Sfum_2982)
    (sfu:Sfum_2981, sfu:Sfum_3023)
    (sfu:Sfum_2981, sfu:Sfum_3024)
    (sfu:Sfum_2982, sfu:Sfum_3023)
    (sfu:Sfum_2982, sfu:Sfum_3024)
    (sfu:Sfum_2983, sfu:Sfum_3022)
    (sfu:Sfum_2983, sfu:Sfum_3025)
    (sfu:Sfum_2984, sfu:Sfum_3026)
    (sfu:Sfum_2985, sfu:Sfum_3027)
    (sfu:Sfum_2986, sfu:Sfum_3028)
    (sfu:Sfum_2989, sfu:Sfum_3031)
    (sfu:Sfum_2989, sfu:Sfum_3896)
    (sfu:Sfum_2990, sfu:Sfum_3032)
    (sfu:Sfum_2992, sfu:Sfum_3034)
    (sfu:Sfum_3010, sfu:Sfum_3052)
    (sfu:Sfum_3022, sfu:Sfum_3025)
    (sfu:Sfum_3023, sfu:Sfum_3024)
    (sfu:Sfum_3031, sfu:Sfum_3896)
    (sfu:Sfum_3302, sfu:Sfum_3365)
    (sfu:Sfum_3365, sfu:Sfum_3742)
    (sur:STAUR_0056, sur:STAUR_5425)
    (sur:STAUR_0276, sur:STAUR_5620)
    (sur:STAUR_0279, sur:STAUR_5622)
    (sur:STAUR_0299, sur:STAUR_4663)
    (sur:STAUR_0404, sur:STAUR_7259)
    (sur:STAUR_0531, sur:STAUR_4815)
    (sur:STAUR_0531, sur:STAUR_5595)
    (sur:STAUR_0531, sur:STAUR_5774)
    (sur:STAUR_0636, sur:STAUR_2240)
    (sur:STAUR_0672, sur:STAUR_3316)
    (sur:STAUR_0782, sur:STAUR_6764)
    (sur:STAUR_0784, sur:STAUR_6096)
    (sur:STAUR_0784, sur:STAUR_6098)
    (sur:STAUR_0785, sur:STAUR_5122)
    (sur:STAUR_0785, sur:STAUR_6805)
    (sur:STAUR_1091, sur:STAUR_6761)
    (sur:STAUR_1573, sur:STAUR_5621)
    (sur:STAUR_1653, sur:STAUR_8110)
    (sur:STAUR_1671, sur:STAUR_2146)
    (sur:STAUR_1904, sur:STAUR_3412)
    (sur:STAUR_2087, sur:STAUR_2729)
    (sur:STAUR_2087, sur:STAUR_5620)
    (sur:STAUR_2087, sur:STAUR_7849)
    (sur:STAUR_2116, sur:STAUR_7168)
    (sur:STAUR_2146, sur:STAUR_5309)
    (sur:STAUR_2244, sur:STAUR_3769)
    (sur:STAUR_2244, sur:STAUR_4439)
    (sur:STAUR_2244, sur:STAUR_6979)
    (sur:STAUR_2302, sur:STAUR_3279)
    (sur:STAUR_2302, sur:STAUR_3296)
    (sur:STAUR_2302, sur:STAUR_4038)
    (sur:STAUR_2302, sur:STAUR_5152)
    (sur:STAUR_2302, sur:STAUR_7055)
    (sur:STAUR_2346, sur:STAUR_4852)
    (sur:STAUR_2346, sur:STAUR_5285)
    (sur:STAUR_2346, sur:STAUR_7012)
    (sur:STAUR_2543, sur:STAUR_2647)
    (sur:STAUR_2699, sur:STAUR_5252)
    (sur:STAUR_2714, sur:STAUR_4493)
    (sur:STAUR_2729, sur:STAUR_5620)
    (sur:STAUR_2729, sur:STAUR_7849)
    (sur:STAUR_3111, sur:STAUR_6597)
    (sur:STAUR_3279, sur:STAUR_3296)
    (sur:STAUR_3279, sur:STAUR_5152)
    (sur:STAUR_3279, sur:STAUR_7055)
    (sur:STAUR_3296, sur:STAUR_7055)
    (sur:STAUR_3348, sur:STAUR_7939)
    (sur:STAUR_3549, sur:STAUR_4027)
    (sur:STAUR_3549, sur:STAUR_4028)
    (sur:STAUR_3605, sur:STAUR_4874)
    (sur:STAUR_3608, sur:STAUR_4873)
    (sur:STAUR_3769, sur:STAUR_4439)
    (sur:STAUR_3769, sur:STAUR_6979)
    (sur:STAUR_3779, sur:STAUR_4567)
    (sur:STAUR_3779, sur:STAUR_6406)
    (sur:STAUR_3779, sur:STAUR_6616)
    (sur:STAUR_3846, sur:STAUR_6310)
    (sur:STAUR_3888, sur:STAUR_6468)
    (sur:STAUR_3898, sur:STAUR_4273)
    (sur:STAUR_3898, sur:STAUR_5482)
    (sur:STAUR_3946, sur:STAUR_6060)
    (sur:STAUR_3991, sur:STAUR_5666)
    (sur:STAUR_4027, sur:STAUR_4028)
    (sur:STAUR_4035, sur:STAUR_6858)
    (sur:STAUR_4038, sur:STAUR_5152)
    (sur:STAUR_4039, sur:STAUR_6701)
    (sur:STAUR_4050, sur:STAUR_4874)
    (sur:STAUR_4128, sur:STAUR_6684)
    (sur:STAUR_4273, sur:STAUR_5482)
    (sur:STAUR_4439, sur:STAUR_6979)
    (sur:STAUR_4567, sur:STAUR_6259)
    (sur:STAUR_4567, sur:STAUR_6406)
    (sur:STAUR_4567, sur:STAUR_6616)
    (sur:STAUR_4684, sur:STAUR_4869)
    (sur:STAUR_4743, sur:STAUR_5620)
    (sur:STAUR_4815, sur:STAUR_5595)
    (sur:STAUR_4815, sur:STAUR_5774)
    (sur:STAUR_4815, sur:STAUR_8129)
    (sur:STAUR_4852, sur:STAUR_5285)
    (sur:STAUR_4852, sur:STAUR_7012)
    (sur:STAUR_4853, sur:STAUR_5872)
    (sur:STAUR_5122, sur:STAUR_6805)
    (sur:STAUR_5127, sur:STAUR_5813)
    (sur:STAUR_5155, sur:STAUR_7912)
    (sur:STAUR_5175, sur:STAUR_5839)
    (sur:STAUR_5197, sur:STAUR_5845)
    (sur:STAUR_5285, sur:STAUR_7012)
    (sur:STAUR_5339, sur:STAUR_5618)
    (sur:STAUR_5347, sur:STAUR_6803)
    (sur:STAUR_5486, sur:STAUR_5581)
    (sur:STAUR_5595, sur:STAUR_5774)
    (sur:STAUR_5620, sur:STAUR_7849)
    (sur:STAUR_5774, sur:STAUR_8129)
    (sur:STAUR_5870, sur:STAUR_7164)
    (sur:STAUR_5875, sur:STAUR_7165)
    (sur:STAUR_6096, sur:STAUR_6098)
    (sur:STAUR_6259, sur:STAUR_6406)
    (sur:STAUR_6266, sur:STAUR_6267)
    (sur:STAUR_6310, sur:STAUR_6830)
    (sur:STAUR_6406, sur:STAUR_6616)
    (sur:STAUR_8101, sur:STAUR_8226)
    (vin:AKJ08_0033, vin:AKJ08_0035)
    (vin:AKJ08_0051, vin:AKJ08_2528)
    (vin:AKJ08_0067, vin:AKJ08_0779)
    (vin:AKJ08_0163, vin:AKJ08_1411)
    (vin:AKJ08_0182, vin:AKJ08_2231)
    (vin:AKJ08_0229, vin:AKJ08_0242)
    (vin:AKJ08_0304, vin:AKJ08_2325)
    (vin:AKJ08_0448, vin:AKJ08_0452)
    (vin:AKJ08_0448, vin:AKJ08_0517)
    (vin:AKJ08_0452, vin:AKJ08_0517)
    (vin:AKJ08_0452, vin:AKJ08_1829)
    (vin:AKJ08_0452, vin:AKJ08_1884)
    (vin:AKJ08_0498, vin:AKJ08_1633)
    (vin:AKJ08_0507, vin:AKJ08_1488)
    (vin:AKJ08_0517, vin:AKJ08_1829)
    (vin:AKJ08_0517, vin:AKJ08_1884)
    (vin:AKJ08_0647, vin:AKJ08_2124)
    (vin:AKJ08_0731, vin:AKJ08_1262)
    (vin:AKJ08_0879, vin:AKJ08_1847)
    (vin:AKJ08_0977, vin:AKJ08_1190)
    (vin:AKJ08_0977, vin:AKJ08_2065)
    (vin:AKJ08_0977, vin:AKJ08_3214)
    (vin:AKJ08_1030, vin:AKJ08_2290)
    (vin:AKJ08_1046, vin:AKJ08_2528)
    (vin:AKJ08_1190, vin:AKJ08_2065)
    (vin:AKJ08_1190, vin:AKJ08_3214)
    (vin:AKJ08_1405, vin:AKJ08_1882)
    (vin:AKJ08_1409, vin:AKJ08_1848)
    (vin:AKJ08_1410, vin:AKJ08_3662)
    (vin:AKJ08_1417, vin:AKJ08_2627)
    (vin:AKJ08_1488, vin:AKJ08_2247)
    (vin:AKJ08_1509, vin:AKJ08_3161)
    (vin:AKJ08_1631, vin:AKJ08_2336)
    (vin:AKJ08_1631, vin:AKJ08_2585)
    (vin:AKJ08_1908, vin:AKJ08_3614)
    (vin:AKJ08_2065, vin:AKJ08_3214)
    (vin:AKJ08_2249, vin:AKJ08_2252)
    (vin:AKJ08_2249, vin:AKJ08_2254)
    (vin:AKJ08_2254, vin:AKJ08_2255)
    (vin:AKJ08_2274, vin:AKJ08_3459)
    (vin:AKJ08_2747, vin:AKJ08_2890)
    (vin:AKJ08_2748, vin:AKJ08_3025)
    (vin:AKJ08_2749, vin:AKJ08_3025)
    
    gene-duplicated enzymes: 5868 (27%)
    ade:Adeh_0005 (1108 target-flexibility) (319 robustness)
    ade:Adeh_0012 (222 target-flexibility) (83 robustness)
    ade:Adeh_0036 (0 target-flexibility) (0 robustness)
    ade:Adeh_0038 (0 target-flexibility) (0 robustness)
    ade:Adeh_0069 (0 target-flexibility) (0 robustness)
    ade:Adeh_0171 (0 target-flexibility) (0 robustness)
    ade:Adeh_0221 (0 target-flexibility) (0 robustness)
    ade:Adeh_0255 (343 target-flexibility) (180 robustness)
    ade:Adeh_0295 (357 target-flexibility) (102 robustness)
    ade:Adeh_0533 (1385 target-flexibility) (204 robustness)
    ade:Adeh_0588 (0 target-flexibility) (0 robustness)
    ade:Adeh_0592 (358 target-flexibility) (124 robustness)
    ade:Adeh_0768 (691 target-flexibility) (528 robustness)
    ade:Adeh_0821 (700 target-flexibility) (89 robustness)
    ade:Adeh_0925 (0 target-flexibility) (0 robustness)
    ade:Adeh_1015 (902 target-flexibility) (228 robustness)
    ade:Adeh_1048 (358 target-flexibility) (124 robustness)
    ade:Adeh_1052 (855 target-flexibility) (138 robustness)
    ade:Adeh_1057 (0 target-flexibility) (0 robustness)
    ade:Adeh_1078 (71 target-flexibility) (71 robustness)
    ade:Adeh_1165 (0 target-flexibility) (0 robustness)
    ade:Adeh_1280 (528 target-flexibility) (157 robustness)
    ade:Adeh_1312 (691 target-flexibility) (528 robustness)
    ade:Adeh_1334 (0 target-flexibility) (0 robustness)
    ade:Adeh_1600 (343 target-flexibility) (180 robustness)
    ade:Adeh_1613 (734 target-flexibility) (110 robustness)
    ade:Adeh_1618 (897 target-flexibility) (71 robustness)
    ade:Adeh_1638 (245 target-flexibility) (66 robustness)
    ade:Adeh_1729 (405 target-flexibility) (169 robustness)
    ade:Adeh_1731 (1385 target-flexibility) (204 robustness)
    ade:Adeh_1830 (700 target-flexibility) (89 robustness)
    ade:Adeh_1954 (0 target-flexibility) (0 robustness)
    ade:Adeh_1955 (0 target-flexibility) (0 robustness)
    ade:Adeh_1963 (0 target-flexibility) (0 robustness)
    ade:Adeh_1978 (902 target-flexibility) (228 robustness)
    ade:Adeh_1981 (841 target-flexibility) (126 robustness)
    ade:Adeh_1994 (75 target-flexibility) (75 robustness)
    ade:Adeh_2047 (790 target-flexibility) (134 robustness)
    ade:Adeh_2057 (0 target-flexibility) (0 robustness)
    ade:Adeh_2071 (841 target-flexibility) (126 robustness)
    ade:Adeh_2078 (343 target-flexibility) (180 robustness)
    ade:Adeh_2315 (1385 target-flexibility) (204 robustness)
    ade:Adeh_2316 (528 target-flexibility) (157 robustness)
    ade:Adeh_2345 (0 target-flexibility) (0 robustness)
    ade:Adeh_2349 (423 target-flexibility) (81 robustness)
    ade:Adeh_2359 (0 target-flexibility) (0 robustness)
    ade:Adeh_2390 (212 target-flexibility) (73 robustness)
    ade:Adeh_2434 (0 target-flexibility) (0 robustness)
    ade:Adeh_2449 (231 target-flexibility) (158 robustness)
    ade:Adeh_2484 (734 target-flexibility) (110 robustness)
    ade:Adeh_2493 (75 target-flexibility) (75 robustness)
    ade:Adeh_2533 (752 target-flexibility) (76 robustness)
    ade:Adeh_2597 (357 target-flexibility) (102 robustness)
    ade:Adeh_2619 (790 target-flexibility) (134 robustness)
    ade:Adeh_2654 (855 target-flexibility) (138 robustness)
    ade:Adeh_2668 (528 target-flexibility) (157 robustness)
    ade:Adeh_2691 (138 target-flexibility) (66 robustness)
    ade:Adeh_2727 (0 target-flexibility) (0 robustness)
    ade:Adeh_2728 (206 target-flexibility) (68 robustness)
    ade:Adeh_2748 (659 target-flexibility) (240 robustness)
    ade:Adeh_2750 (1108 target-flexibility) (319 robustness)
    ade:Adeh_2760 (659 target-flexibility) (240 robustness)
    ade:Adeh_2780 (821 target-flexibility) (137 robustness)
    ade:Adeh_2789 (821 target-flexibility) (137 robustness)
    ade:Adeh_2867 (0 target-flexibility) (0 robustness)
    ade:Adeh_2886 (0 target-flexibility) (0 robustness)
    ade:Adeh_3037 (841 target-flexibility) (126 robustness)
    ade:Adeh_3135 (423 target-flexibility) (81 robustness)
    ade:Adeh_3141 (659 target-flexibility) (240 robustness)
    ade:Adeh_3396 (790 target-flexibility) (134 robustness)
    ade:Adeh_3428 (855 target-flexibility) (138 robustness)
    ade:Adeh_3514 (405 target-flexibility) (169 robustness)
    ade:Adeh_3637 (691 target-flexibility) (528 robustness)
    ade:Adeh_3694 (691 target-flexibility) (528 robustness)
    ade:Adeh_3748 (686 target-flexibility) (192 robustness)
    ade:Adeh_3766 (239 target-flexibility) (67 robustness)
    ade:Adeh_3767 (67 target-flexibility) (67 robustness)
    ade:Adeh_3769 (140 target-flexibility) (71 robustness)
    ade:Adeh_3772 (70 target-flexibility) (70 robustness)
    ade:Adeh_3774 (231 target-flexibility) (158 robustness)
    ade:Adeh_3784 (228 target-flexibility) (83 robustness)
    ade:Adeh_3927 (343 target-flexibility) (180 robustness)
    ade:Adeh_3931 (245 target-flexibility) (66 robustness)
    ade:Adeh_3959 (796 target-flexibility) (85 robustness)
    ade:Adeh_4057 (686 target-flexibility) (192 robustness)
    ade:Adeh_4206 (732 target-flexibility) (78 robustness)
    ade:Adeh_4220 (228 target-flexibility) (83 robustness)
    ade:Adeh_4242 (0 target-flexibility) (0 robustness)
    ade:Adeh_4288 (0 target-flexibility) (0 robustness)
    ade:Adeh_4305 (0 target-flexibility) (0 robustness)
    ade:Adeh_4344 (80 target-flexibility) (80 robustness)
    afw:Anae109_0005 (1108 target-flexibility) (319 robustness)
    afw:Anae109_0013 (222 target-flexibility) (83 robustness)
    afw:Anae109_0039 (0 target-flexibility) (0 robustness)
    afw:Anae109_0070 (0 target-flexibility) (0 robustness)
    afw:Anae109_0075 (0 target-flexibility) (0 robustness)
    afw:Anae109_0087 (350 target-flexibility) (84 robustness)
    afw:Anae109_0125 (657 target-flexibility) (95 robustness)
    afw:Anae109_0180 (0 target-flexibility) (0 robustness)
    afw:Anae109_0276 (343 target-flexibility) (180 robustness)
    afw:Anae109_0315 (1041 target-flexibility) (243 robustness)
    afw:Anae109_0319 (357 target-flexibility) (102 robustness)
    afw:Anae109_0323 (0 target-flexibility) (0 robustness)
    afw:Anae109_0371 (686 target-flexibility) (192 robustness)
    afw:Anae109_0462 (796 target-flexibility) (85 robustness)
    afw:Anae109_0473 (138 target-flexibility) (138 robustness)
    afw:Anae109_0508 (343 target-flexibility) (180 robustness)
    afw:Anae109_0637 (358 target-flexibility) (124 robustness)
    afw:Anae109_0814 (691 target-flexibility) (528 robustness)
    afw:Anae109_0859 (700 target-flexibility) (89 robustness)
    afw:Anae109_0968 (0 target-flexibility) (0 robustness)
    afw:Anae109_1089 (902 target-flexibility) (228 robustness)
    afw:Anae109_1102 (855 target-flexibility) (138 robustness)
    afw:Anae109_1117 (71 target-flexibility) (71 robustness)
    afw:Anae109_1136 (1169 target-flexibility) (76 robustness)
    afw:Anae109_1212 (0 target-flexibility) (0 robustness)
    afw:Anae109_1374 (75 target-flexibility) (75 robustness)
    afw:Anae109_1384 (734 target-flexibility) (110 robustness)
    afw:Anae109_1418 (231 target-flexibility) (158 robustness)
    afw:Anae109_1445 (0 target-flexibility) (0 robustness)
    afw:Anae109_1477 (212 target-flexibility) (73 robustness)
    afw:Anae109_1510 (0 target-flexibility) (0 robustness)
    afw:Anae109_1524 (423 target-flexibility) (81 robustness)
    afw:Anae109_1753 (841 target-flexibility) (126 robustness)
    afw:Anae109_1767 (790 target-flexibility) (134 robustness)
    afw:Anae109_1890 (0 target-flexibility) (0 robustness)
    afw:Anae109_1900 (0 target-flexibility) (0 robustness)
    afw:Anae109_1901 (0 target-flexibility) (0 robustness)
    afw:Anae109_2025 (1041 target-flexibility) (243 robustness)
    afw:Anae109_2026 (486 target-flexibility) (89 robustness)
    afw:Anae109_2033 (659 target-flexibility) (240 robustness)
    afw:Anae109_2078 (0 target-flexibility) (0 robustness)
    afw:Anae109_2183 (0 target-flexibility) (0 robustness)
    afw:Anae109_2184 (0 target-flexibility) (0 robustness)
    afw:Anae109_2193 (897 target-flexibility) (71 robustness)
    afw:Anae109_2361 (138 target-flexibility) (138 robustness)
    afw:Anae109_2449 (175 target-flexibility) (78 robustness)
    afw:Anae109_2451 (691 target-flexibility) (528 robustness)
    afw:Anae109_2487 (528 target-flexibility) (157 robustness)
    afw:Anae109_2552 (659 target-flexibility) (240 robustness)
    afw:Anae109_2555 (0 target-flexibility) (0 robustness)
    afw:Anae109_2586 (790 target-flexibility) (134 robustness)
    afw:Anae109_2647 (528 target-flexibility) (157 robustness)
    afw:Anae109_2737 (659 target-flexibility) (240 robustness)
    afw:Anae109_3065 (0 target-flexibility) (0 robustness)
    afw:Anae109_3137 (691 target-flexibility) (528 robustness)
    afw:Anae109_3159 (854 target-flexibility) (204 robustness)
    afw:Anae109_3170 (790 target-flexibility) (134 robustness)
    afw:Anae109_3213 (0 target-flexibility) (0 robustness)
    afw:Anae109_3255 (659 target-flexibility) (240 robustness)
    afw:Anae109_3313 (138 target-flexibility) (138 robustness)
    afw:Anae109_3601 (659 target-flexibility) (240 robustness)
    afw:Anae109_3608 (528 target-flexibility) (157 robustness)
    afw:Anae109_3721 (0 target-flexibility) (0 robustness)
    afw:Anae109_3732 (0 target-flexibility) (0 robustness)
    afw:Anae109_3879 (239 target-flexibility) (67 robustness)
    afw:Anae109_3882 (140 target-flexibility) (71 robustness)
    afw:Anae109_3904 (228 target-flexibility) (83 robustness)
    afw:Anae109_4196 (0 target-flexibility) (0 robustness)
    age:AA314_00262 (0 target-flexibility) (0 robustness)
    age:AA314_00693 (528 target-flexibility) (157 robustness)
    age:AA314_00717 (0 target-flexibility) (0 robustness)
    age:AA314_00859 (659 target-flexibility) (240 robustness)
    age:AA314_00861 (1108 target-flexibility) (319 robustness)
    age:AA314_00918 (528 target-flexibility) (157 robustness)
    age:AA314_00945 (659 target-flexibility) (240 robustness)
    age:AA314_01105 (0 target-flexibility) (0 robustness)
    age:AA314_01165 (222 target-flexibility) (83 robustness)
    age:AA314_01181 (73 target-flexibility) (73 robustness)
    age:AA314_01193 (80 target-flexibility) (80 robustness)
    age:AA314_01271 (924 target-flexibility) (101 robustness)
    age:AA314_01338 (659 target-flexibility) (240 robustness)
    age:AA314_01471 (1385 target-flexibility) (204 robustness)
    age:AA314_01479 (0 target-flexibility) (0 robustness)
    age:AA314_01699 (140 target-flexibility) (74 robustness)
    age:AA314_01881 (902 target-flexibility) (228 robustness)
    age:AA314_01912 (790 target-flexibility) (134 robustness)
    age:AA314_01954 (231 target-flexibility) (158 robustness)
    age:AA314_02279 (73 target-flexibility) (73 robustness)
    age:AA314_02310 (732 target-flexibility) (78 robustness)
    age:AA314_02336 (1183 target-flexibility) (114 robustness)
    age:AA314_02543 (357 target-flexibility) (102 robustness)
    age:AA314_02619 (377 target-flexibility) (117 robustness)
    age:AA314_02661 (0 target-flexibility) (0 robustness)
    age:AA314_02664 (790 target-flexibility) (134 robustness)
    age:AA314_02687 (659 target-flexibility) (240 robustness)
    age:AA314_02714 (796 target-flexibility) (85 robustness)
    age:AA314_02716 (734 target-flexibility) (110 robustness)
    age:AA314_02777 (350 target-flexibility) (189 robustness)
    age:AA314_02872 (0 target-flexibility) (0 robustness)
    age:AA314_02889 (336 target-flexibility) (81 robustness)
    age:AA314_02893 (343 target-flexibility) (180 robustness)
    age:AA314_02979 (343 target-flexibility) (180 robustness)
    age:AA314_03054 (0 target-flexibility) (0 robustness)
    age:AA314_03086 (75 target-flexibility) (75 robustness)
    age:AA314_03097 (0 target-flexibility) (0 robustness)
    age:AA314_03158 (358 target-flexibility) (124 robustness)
    age:AA314_03216 (691 target-flexibility) (528 robustness)
    age:AA314_03227 (0 target-flexibility) (0 robustness)
    age:AA314_03252 (138 target-flexibility) (138 robustness)
    age:AA314_03289 (0 target-flexibility) (0 robustness)
    age:AA314_03514 (0 target-flexibility) (0 robustness)
    age:AA314_03550 (1183 target-flexibility) (114 robustness)
    age:AA314_03763 (0 target-flexibility) (0 robustness)
    age:AA314_03773 (657 target-flexibility) (95 robustness)
    age:AA314_03826 (358 target-flexibility) (124 robustness)
    age:AA314_04024 (752 target-flexibility) (105 robustness)
    age:AA314_04141 (530 target-flexibility) (162 robustness)
    age:AA314_04142 (1108 target-flexibility) (319 robustness)
    age:AA314_04144 (659 target-flexibility) (240 robustness)
    age:AA314_04146 (703 target-flexibility) (319 robustness)
    age:AA314_04189 (0 target-flexibility) (0 robustness)
    age:AA314_04205 (71 target-flexibility) (71 robustness)
    age:AA314_04258 (752 target-flexibility) (76 robustness)
    age:AA314_04323 (659 target-flexibility) (240 robustness)
    age:AA314_04350 (0 target-flexibility) (0 robustness)
    age:AA314_04447 (212 target-flexibility) (73 robustness)
    age:AA314_04456 (1183 target-flexibility) (114 robustness)
    age:AA314_04554 (703 target-flexibility) (319 robustness)
    age:AA314_04555 (659 target-flexibility) (240 robustness)
    age:AA314_04761 (343 target-flexibility) (180 robustness)
    age:AA314_04783 (0 target-flexibility) (0 robustness)
    age:AA314_04817 (228 target-flexibility) (83 robustness)
    age:AA314_04822 (0 target-flexibility) (0 robustness)
    age:AA314_04924 (231 target-flexibility) (158 robustness)
    age:AA314_04935 (752 target-flexibility) (105 robustness)
    age:AA314_04970 (0 target-flexibility) (0 robustness)
    age:AA314_04985 (659 target-flexibility) (240 robustness)
    age:AA314_05002 (0 target-flexibility) (0 robustness)
    age:AA314_05003 (0 target-flexibility) (0 robustness)
    age:AA314_05007 (897 target-flexibility) (71 robustness)
    age:AA314_05011 (1784 target-flexibility) (162 robustness)
    age:AA314_05014 (0 target-flexibility) (0 robustness)
    age:AA314_05015 (924 target-flexibility) (101 robustness)
    age:AA314_05117 (74 target-flexibility) (74 robustness)
    age:AA314_05145 (0 target-flexibility) (0 robustness)
    age:AA314_05182 (212 target-flexibility) (73 robustness)
    age:AA314_05227 (138 target-flexibility) (138 robustness)
    age:AA314_05245 (1108 target-flexibility) (319 robustness)
    age:AA314_05446 (706 target-flexibility) (173 robustness)
    age:AA314_05477 (423 target-flexibility) (81 robustness)
    age:AA314_05512 (423 target-flexibility) (81 robustness)
    age:AA314_05564 (1385 target-flexibility) (204 robustness)
    age:AA314_05583 (377 target-flexibility) (117 robustness)
    age:AA314_05795 (343 target-flexibility) (180 robustness)
    age:AA314_05840 (0 target-flexibility) (0 robustness)
    age:AA314_05876 (0 target-flexibility) (0 robustness)
    age:AA314_05880 (138 target-flexibility) (66 robustness)
    age:AA314_05889 (1385 target-flexibility) (204 robustness)
    age:AA314_05890 (0 target-flexibility) (0 robustness)
    age:AA314_05977 (0 target-flexibility) (0 robustness)
    age:AA314_06016 (231 target-flexibility) (158 robustness)
    age:AA314_06106 (659 target-flexibility) (240 robustness)
    age:AA314_06198 (0 target-flexibility) (0 robustness)
    age:AA314_06206 (323 target-flexibility) (101 robustness)
    age:AA314_06223 (0 target-flexibility) (0 robustness)
    age:AA314_06374 (659 target-flexibility) (240 robustness)
    age:AA314_06470 (659 target-flexibility) (240 robustness)
    age:AA314_06684 (358 target-flexibility) (124 robustness)
    age:AA314_06718 (0 target-flexibility) (0 robustness)
    age:AA314_06720 (0 target-flexibility) (0 robustness)
    age:AA314_06748 (902 target-flexibility) (228 robustness)
    age:AA314_06754 (734 target-flexibility) (110 robustness)
    age:AA314_06815 (902 target-flexibility) (228 robustness)
    age:AA314_06851 (691 target-flexibility) (528 robustness)
    age:AA314_06989 (323 target-flexibility) (101 robustness)
    age:AA314_07032 (0 target-flexibility) (0 robustness)
    age:AA314_07077 (357 target-flexibility) (102 robustness)
    age:AA314_07107 (75 target-flexibility) (75 robustness)
    age:AA314_07149 (1022 target-flexibility) (80 robustness)
    age:AA314_07154 (1108 target-flexibility) (319 robustness)
    age:AA314_07241 (140 target-flexibility) (74 robustness)
    age:AA314_07252 (924 target-flexibility) (101 robustness)
    age:AA314_07285 (530 target-flexibility) (162 robustness)
    age:AA314_07327 (703 target-flexibility) (319 robustness)
    age:AA314_07475 (0 target-flexibility) (0 robustness)
    age:AA314_07499 (0 target-flexibility) (0 robustness)
    age:AA314_07568 (528 target-flexibility) (157 robustness)
    age:AA314_07592 (0 target-flexibility) (0 robustness)
    age:AA314_07741 (706 target-flexibility) (173 robustness)
    age:AA314_07751 (0 target-flexibility) (0 robustness)
    age:AA314_08005 (231 target-flexibility) (158 robustness)
    age:AA314_08007 (70 target-flexibility) (70 robustness)
    age:AA314_08012 (67 target-flexibility) (67 robustness)
    age:AA314_08032 (357 target-flexibility) (115 robustness)
    age:AA314_08206 (231 target-flexibility) (158 robustness)
    age:AA314_08225 (0 target-flexibility) (0 robustness)
    age:AA314_08305 (228 target-flexibility) (83 robustness)
    age:AA314_08421 (790 target-flexibility) (134 robustness)
    age:AA314_08455 (796 target-flexibility) (85 robustness)
    age:AA314_08462 (703 target-flexibility) (319 robustness)
    age:AA314_08615 (231 target-flexibility) (158 robustness)
    age:AA314_08648 (1108 target-flexibility) (319 robustness)
    age:AA314_08751 (226 target-flexibility) (85 robustness)
    age:AA314_08837 (1784 target-flexibility) (162 robustness)
    age:AA314_09003 (0 target-flexibility) (0 robustness)
    age:AA314_09026 (350 target-flexibility) (189 robustness)
    age:AA314_09027 (0 target-flexibility) (0 robustness)
    age:AA314_09029 (0 target-flexibility) (0 robustness)
    age:AA314_09030 (0 target-flexibility) (0 robustness)
    age:AA314_09037 (0 target-flexibility) (0 robustness)
    age:AA314_09050 (0 target-flexibility) (0 robustness)
    age:AA314_09055 (1183 target-flexibility) (114 robustness)
    age:AA314_09208 (74 target-flexibility) (74 robustness)
    age:AA314_09276 (1022 target-flexibility) (80 robustness)
    age:AA314_09460 (357 target-flexibility) (115 robustness)
    age:AA314_09587 (0 target-flexibility) (0 robustness)
    age:AA314_09664 (0 target-flexibility) (0 robustness)
    age:AA314_09705 (226 target-flexibility) (85 robustness)
    age:AA314_09937 (336 target-flexibility) (81 robustness)
    age:AA314_09947 (657 target-flexibility) (95 robustness)
    ank:AnaeK_0005 (1108 target-flexibility) (319 robustness)
    ank:AnaeK_0012 (222 target-flexibility) (83 robustness)
    ank:AnaeK_0040 (0 target-flexibility) (0 robustness)
    ank:AnaeK_0075 (0 target-flexibility) (0 robustness)
    ank:AnaeK_0081 (0 target-flexibility) (0 robustness)
    ank:AnaeK_0092 (350 target-flexibility) (84 robustness)
    ank:AnaeK_0180 (0 target-flexibility) (0 robustness)
    ank:AnaeK_0232 (0 target-flexibility) (0 robustness)
    ank:AnaeK_0265 (343 target-flexibility) (180 robustness)
    ank:AnaeK_0306 (357 target-flexibility) (102 robustness)
    ank:AnaeK_0565 (1385 target-flexibility) (204 robustness)
    ank:AnaeK_0627 (358 target-flexibility) (124 robustness)
    ank:AnaeK_0816 (691 target-flexibility) (528 robustness)
    ank:AnaeK_0869 (700 target-flexibility) (89 robustness)
    ank:AnaeK_0984 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1073 (902 target-flexibility) (228 robustness)
    ank:AnaeK_1108 (855 target-flexibility) (138 robustness)
    ank:AnaeK_1116 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1137 (71 target-flexibility) (71 robustness)
    ank:AnaeK_1224 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1362 (75 target-flexibility) (75 robustness)
    ank:AnaeK_1374 (734 target-flexibility) (110 robustness)
    ank:AnaeK_1410 (231 target-flexibility) (158 robustness)
    ank:AnaeK_1429 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1474 (212 target-flexibility) (73 robustness)
    ank:AnaeK_1505 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1520 (423 target-flexibility) (81 robustness)
    ank:AnaeK_1557 (528 target-flexibility) (157 robustness)
    ank:AnaeK_1799 (343 target-flexibility) (180 robustness)
    ank:AnaeK_1806 (841 target-flexibility) (126 robustness)
    ank:AnaeK_1821 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1897 (841 target-flexibility) (126 robustness)
    ank:AnaeK_1915 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1924 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1925 (0 target-flexibility) (0 robustness)
    ank:AnaeK_2118 (405 target-flexibility) (169 robustness)
    ank:AnaeK_2124 (0 target-flexibility) (0 robustness)
    ank:AnaeK_2222 (245 target-flexibility) (66 robustness)
    ank:AnaeK_2242 (897 target-flexibility) (71 robustness)
    ank:AnaeK_2263 (343 target-flexibility) (180 robustness)
    ank:AnaeK_2548 (691 target-flexibility) (528 robustness)
    ank:AnaeK_2581 (528 target-flexibility) (157 robustness)
    ank:AnaeK_2649 (659 target-flexibility) (240 robustness)
    ank:AnaeK_2705 (790 target-flexibility) (134 robustness)
    ank:AnaeK_2840 (659 target-flexibility) (240 robustness)
    ank:AnaeK_2852 (659 target-flexibility) (240 robustness)
    ank:AnaeK_3452 (0 target-flexibility) (0 robustness)
    ank:AnaeK_3805 (686 target-flexibility) (192 robustness)
    ank:AnaeK_3822 (239 target-flexibility) (67 robustness)
    ank:AnaeK_3825 (140 target-flexibility) (71 robustness)
    ank:AnaeK_3839 (228 target-flexibility) (83 robustness)
    ank:AnaeK_4069 (796 target-flexibility) (85 robustness)
    ccro:CMC5_000130 (212 target-flexibility) (73 robustness)
    ccro:CMC5_000390 (780 target-flexibility) (243 robustness)
    ccro:CMC5_000580 (1385 target-flexibility) (204 robustness)
    ccro:CMC5_000670 (343 target-flexibility) (180 robustness)
    ccro:CMC5_001320 (0 target-flexibility) (0 robustness)
    ccro:CMC5_002670 (0 target-flexibility) (0 robustness)
    ccro:CMC5_003310 (697 target-flexibility) (78 robustness)
    ccro:CMC5_003550 (691 target-flexibility) (528 robustness)
    ccro:CMC5_004340 (752 target-flexibility) (73 robustness)
    ccro:CMC5_006070 (924 target-flexibility) (101 robustness)
    ccro:CMC5_006290 (902 target-flexibility) (228 robustness)
    ccro:CMC5_007320 (350 target-flexibility) (189 robustness)
    ccro:CMC5_007720 (790 target-flexibility) (134 robustness)
    ccro:CMC5_007870 (0 target-flexibility) (0 robustness)
    ccro:CMC5_008250 (1108 target-flexibility) (319 robustness)
    ccro:CMC5_009420 (790 target-flexibility) (134 robustness)
    ccro:CMC5_010330 (1022 target-flexibility) (80 robustness)
    ccro:CMC5_011120 (1108 target-flexibility) (319 robustness)
    ccro:CMC5_011270 (0 target-flexibility) (0 robustness)
    ccro:CMC5_011280 (0 target-flexibility) (0 robustness)
    ccro:CMC5_011930 (80 target-flexibility) (80 robustness)
    ccro:CMC5_012020 (0 target-flexibility) (0 robustness)
    ccro:CMC5_012200 (423 target-flexibility) (81 robustness)
    ccro:CMC5_012370 (706 target-flexibility) (173 robustness)
    ccro:CMC5_012520 (0 target-flexibility) (0 robustness)
    ccro:CMC5_013340 (0 target-flexibility) (0 robustness)
    ccro:CMC5_014820 (231 target-flexibility) (158 robustness)
    ccro:CMC5_014950 (734 target-flexibility) (110 robustness)
    ccro:CMC5_016590 (358 target-flexibility) (124 robustness)
    ccro:CMC5_016930 (821 target-flexibility) (137 robustness)
    ccro:CMC5_017220 (821 target-flexibility) (137 robustness)
    ccro:CMC5_017680 (752 target-flexibility) (105 robustness)
    ccro:CMC5_017710 (0 target-flexibility) (0 robustness)
    ccro:CMC5_017730 (0 target-flexibility) (0 robustness)
    ccro:CMC5_018350 (71 target-flexibility) (71 robustness)
    ccro:CMC5_019230 (0 target-flexibility) (0 robustness)
    ccro:CMC5_019550 (231 target-flexibility) (158 robustness)
    ccro:CMC5_020730 (423 target-flexibility) (81 robustness)
    ccro:CMC5_021680 (0 target-flexibility) (0 robustness)
    ccro:CMC5_021730 (706 target-flexibility) (173 robustness)
    ccro:CMC5_021740 (706 target-flexibility) (173 robustness)
    ccro:CMC5_021880 (528 target-flexibility) (157 robustness)
    ccro:CMC5_022050 (358 target-flexibility) (104 robustness)
    ccro:CMC5_024200 (1022 target-flexibility) (80 robustness)
    ccro:CMC5_024590 (377 target-flexibility) (117 robustness)
    ccro:CMC5_024620 (377 target-flexibility) (117 robustness)
    ccro:CMC5_024850 (734 target-flexibility) (110 robustness)
    ccro:CMC5_024890 (752 target-flexibility) (105 robustness)
    ccro:CMC5_025200 (140 target-flexibility) (74 robustness)
    ccro:CMC5_029220 (691 target-flexibility) (528 robustness)
    ccro:CMC5_030280 (350 target-flexibility) (189 robustness)
    ccro:CMC5_030970 (146 target-flexibility) (75 robustness)
    ccro:CMC5_031580 (1108 target-flexibility) (319 robustness)
    ccro:CMC5_032100 (528 target-flexibility) (157 robustness)
    ccro:CMC5_032690 (528 target-flexibility) (157 robustness)
    ccro:CMC5_032920 (528 target-flexibility) (157 robustness)
    ccro:CMC5_032960 (528 target-flexibility) (157 robustness)
    ccro:CMC5_034090 (0 target-flexibility) (0 robustness)
    ccro:CMC5_038260 (0 target-flexibility) (0 robustness)
    ccro:CMC5_038680 (0 target-flexibility) (0 robustness)
    ccro:CMC5_041050 (821 target-flexibility) (137 robustness)
    ccro:CMC5_041140 (1108 target-flexibility) (319 robustness)
    ccro:CMC5_041160 (659 target-flexibility) (240 robustness)
    ccro:CMC5_041180 (703 target-flexibility) (319 robustness)
    ccro:CMC5_041690 (343 target-flexibility) (180 robustness)
    ccro:CMC5_042410 (0 target-flexibility) (0 robustness)
    ccro:CMC5_043060 (752 target-flexibility) (73 robustness)
    ccro:CMC5_043090 (0 target-flexibility) (0 robustness)
    ccro:CMC5_043210 (1183 target-flexibility) (114 robustness)
    ccro:CMC5_043620 (343 target-flexibility) (180 robustness)
    ccro:CMC5_044530 (222 target-flexibility) (83 robustness)
    ccro:CMC5_045520 (697 target-flexibility) (78 robustness)
    ccro:CMC5_045840 (780 target-flexibility) (243 robustness)
    ccro:CMC5_046360 (358 target-flexibility) (124 robustness)
    ccro:CMC5_046730 (497 target-flexibility) (186 robustness)
    ccro:CMC5_047480 (706 target-flexibility) (173 robustness)
    ccro:CMC5_047550 (706 target-flexibility) (173 robustness)
    ccro:CMC5_048220 (0 target-flexibility) (0 robustness)
    ccro:CMC5_049140 (146 target-flexibility) (75 robustness)
    ccro:CMC5_049960 (0 target-flexibility) (0 robustness)
    ccro:CMC5_050070 (1041 target-flexibility) (243 robustness)
    ccro:CMC5_051960 (0 target-flexibility) (0 robustness)
    ccro:CMC5_052220 (0 target-flexibility) (0 robustness)
    ccro:CMC5_053140 (0 target-flexibility) (0 robustness)
    ccro:CMC5_053620 (659 target-flexibility) (240 robustness)
    ccro:CMC5_053730 (1041 target-flexibility) (243 robustness)
    ccro:CMC5_057100 (706 target-flexibility) (173 robustness)
    ccro:CMC5_059120 (1385 target-flexibility) (204 robustness)
    ccro:CMC5_059220 (0 target-flexibility) (0 robustness)
    ccro:CMC5_060030 (1108 target-flexibility) (319 robustness)
    ccro:CMC5_060070 (1022 target-flexibility) (80 robustness)
    ccro:CMC5_060910 (1108 target-flexibility) (319 robustness)
    ccro:CMC5_061110 (140 target-flexibility) (74 robustness)
    ccro:CMC5_061320 (358 target-flexibility) (104 robustness)
    ccro:CMC5_061620 (752 target-flexibility) (105 robustness)
    ccro:CMC5_061720 (703 target-flexibility) (319 robustness)
    ccro:CMC5_064330 (358 target-flexibility) (124 robustness)
    ccro:CMC5_064420 (902 target-flexibility) (228 robustness)
    ccro:CMC5_064710 (924 target-flexibility) (101 robustness)
    ccro:CMC5_064720 (924 target-flexibility) (101 robustness)
    ccro:CMC5_065360 (70 target-flexibility) (70 robustness)
    ccro:CMC5_065390 (140 target-flexibility) (71 robustness)
    ccro:CMC5_065510 (659 target-flexibility) (240 robustness)
    ccro:CMC5_065650 (71 target-flexibility) (71 robustness)
    ccro:CMC5_068840 (0 target-flexibility) (0 robustness)
    ccro:CMC5_069050 (231 target-flexibility) (158 robustness)
    ccro:CMC5_069660 (0 target-flexibility) (0 robustness)
    ccro:CMC5_070310 (657 target-flexibility) (95 robustness)
    ccro:CMC5_071350 (1183 target-flexibility) (114 robustness)
    ccro:CMC5_072280 (855 target-flexibility) (138 robustness)
    ccro:CMC5_074240 (703 target-flexibility) (319 robustness)
    ccro:CMC5_075250 (706 target-flexibility) (173 robustness)
    ccro:CMC5_076410 (497 target-flexibility) (186 robustness)
    ccro:CMC5_078390 (657 target-flexibility) (95 robustness)
    ccro:CMC5_078580 (790 target-flexibility) (134 robustness)
    ccro:CMC5_082820 (706 target-flexibility) (173 robustness)
    ccro:CMC5_084110 (0 target-flexibility) (0 robustness)
    ccro:CMC5_084320 (855 target-flexibility) (138 robustness)
    ccx:COCOR_00090 (0 target-flexibility) (0 robustness)
    ccx:COCOR_00142 (0 target-flexibility) (0 robustness)
    ccx:COCOR_00249 (657 target-flexibility) (95 robustness)
    ccx:COCOR_00269 (336 target-flexibility) (81 robustness)
    ccx:COCOR_00470 (1385 target-flexibility) (204 robustness)
    ccx:COCOR_00572 (0 target-flexibility) (0 robustness)
    ccx:COCOR_00825 (357 target-flexibility) (115 robustness)
    ccx:COCOR_00865 (659 target-flexibility) (240 robustness)
    ccx:COCOR_00905 (790 target-flexibility) (134 robustness)
    ccx:COCOR_00928 (528 target-flexibility) (157 robustness)
    ccx:COCOR_00984 (154 target-flexibility) (80 robustness)
    ccx:COCOR_00988 (0 target-flexibility) (0 robustness)
    ccx:COCOR_01033 (73 target-flexibility) (73 robustness)
    ccx:COCOR_01049 (732 target-flexibility) (78 robustness)
    ccx:COCOR_01180 (357 target-flexibility) (102 robustness)
    ccx:COCOR_01252 (0 target-flexibility) (0 robustness)
    ccx:COCOR_01272 (796 target-flexibility) (85 robustness)
    ccx:COCOR_01301 (350 target-flexibility) (189 robustness)
    ccx:COCOR_01340 (336 target-flexibility) (81 robustness)
    ccx:COCOR_01538 (0 target-flexibility) (0 robustness)
    ccx:COCOR_01588 (528 target-flexibility) (157 robustness)
    ccx:COCOR_01667 (0 target-flexibility) (0 robustness)
    ccx:COCOR_01693 (0 target-flexibility) (0 robustness)
    ccx:COCOR_01916 (1183 target-flexibility) (114 robustness)
    ccx:COCOR_01974 (0 target-flexibility) (0 robustness)
    ccx:COCOR_01982 (138 target-flexibility) (138 robustness)
    ccx:COCOR_02062 (1041 target-flexibility) (243 robustness)
    ccx:COCOR_02063 (1041 target-flexibility) (243 robustness)
    ccx:COCOR_02069 (659 target-flexibility) (240 robustness)
    ccx:COCOR_02172 (0 target-flexibility) (0 robustness)
    ccx:COCOR_02213 (0 target-flexibility) (0 robustness)
    ccx:COCOR_02243 (1183 target-flexibility) (114 robustness)
    ccx:COCOR_02279 (902 target-flexibility) (228 robustness)
    ccx:COCOR_02328 (0 target-flexibility) (0 robustness)
    ccx:COCOR_02414 (657 target-flexibility) (95 robustness)
    ccx:COCOR_02422 (734 target-flexibility) (110 robustness)
    ccx:COCOR_02459 (358 target-flexibility) (124 robustness)
    ccx:COCOR_02496 (703 target-flexibility) (319 robustness)
    ccx:COCOR_02555 (752 target-flexibility) (105 robustness)
    ccx:COCOR_02623 (530 target-flexibility) (162 robustness)
    ccx:COCOR_02624 (1108 target-flexibility) (319 robustness)
    ccx:COCOR_02626 (659 target-flexibility) (240 robustness)
    ccx:COCOR_02628 (703 target-flexibility) (319 robustness)
    ccx:COCOR_02650 (0 target-flexibility) (0 robustness)
    ccx:COCOR_02664 (71 target-flexibility) (71 robustness)
    ccx:COCOR_02713 (752 target-flexibility) (76 robustness)
    ccx:COCOR_02773 (528 target-flexibility) (157 robustness)
    ccx:COCOR_02898 (343 target-flexibility) (180 robustness)
    ccx:COCOR_02980 (0 target-flexibility) (0 robustness)
    ccx:COCOR_03005 (701 target-flexibility) (106 robustness)
    ccx:COCOR_03074 (343 target-flexibility) (180 robustness)
    ccx:COCOR_03165 (706 target-flexibility) (173 robustness)
    ccx:COCOR_03252 (0 target-flexibility) (0 robustness)
    ccx:COCOR_03253 (1385 target-flexibility) (204 robustness)
    ccx:COCOR_03319 (212 target-flexibility) (73 robustness)
    ccx:COCOR_03448 (239 target-flexibility) (99 robustness)
    ccx:COCOR_03497 (0 target-flexibility) (0 robustness)
    ccx:COCOR_03532 (659 target-flexibility) (240 robustness)
    ccx:COCOR_03708 (0 target-flexibility) (0 robustness)
    ccx:COCOR_03717 (323 target-flexibility) (101 robustness)
    ccx:COCOR_03732 (0 target-flexibility) (0 robustness)
    ccx:COCOR_03787 (902 target-flexibility) (228 robustness)
    ccx:COCOR_03852 (231 target-flexibility) (158 robustness)
    ccx:COCOR_03904 (0 target-flexibility) (0 robustness)
    ccx:COCOR_03913 (0 target-flexibility) (0 robustness)
    ccx:COCOR_03939 (0 target-flexibility) (0 robustness)
    ccx:COCOR_03963 (343 target-flexibility) (180 robustness)
    ccx:COCOR_04442 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04525 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04528 (1784 target-flexibility) (162 robustness)
    ccx:COCOR_04535 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04536 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04577 (659 target-flexibility) (240 robustness)
    ccx:COCOR_04599 (138 target-flexibility) (138 robustness)
    ccx:COCOR_04658 (752 target-flexibility) (105 robustness)
    ccx:COCOR_04690 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04815 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04847 (1169 target-flexibility) (76 robustness)
    ccx:COCOR_05075 (358 target-flexibility) (124 robustness)
    ccx:COCOR_05103 (0 target-flexibility) (0 robustness)
    ccx:COCOR_05120 (0 target-flexibility) (0 robustness)
    ccx:COCOR_05137 (734 target-flexibility) (110 robustness)
    ccx:COCOR_05182 (231 target-flexibility) (158 robustness)
    ccx:COCOR_05367 (357 target-flexibility) (102 robustness)
    ccx:COCOR_05520 (790 target-flexibility) (134 robustness)
    ccx:COCOR_05546 (530 target-flexibility) (162 robustness)
    ccx:COCOR_05708 (239 target-flexibility) (99 robustness)
    ccx:COCOR_05716 (0 target-flexibility) (0 robustness)
    ccx:COCOR_05866 (659 target-flexibility) (240 robustness)
    ccx:COCOR_05867 (703 target-flexibility) (319 robustness)
    ccx:COCOR_05901 (924 target-flexibility) (101 robustness)
    ccx:COCOR_06071 (343 target-flexibility) (180 robustness)
    ccx:COCOR_06092 (231 target-flexibility) (158 robustness)
    ccx:COCOR_06120 (357 target-flexibility) (115 robustness)
    ccx:COCOR_06234 (231 target-flexibility) (158 robustness)
    ccx:COCOR_06306 (701 target-flexibility) (106 robustness)
    ccx:COCOR_06380 (790 target-flexibility) (134 robustness)
    ccx:COCOR_06476 (239 target-flexibility) (99 robustness)
    ccx:COCOR_06497 (231 target-flexibility) (158 robustness)
    ccx:COCOR_06506 (706 target-flexibility) (173 robustness)
    ccx:COCOR_06667 (222 target-flexibility) (83 robustness)
    ccx:COCOR_06732 (706 target-flexibility) (173 robustness)
    ccx:COCOR_06741 (1041 target-flexibility) (243 robustness)
    ccx:COCOR_06913 (1784 target-flexibility) (162 robustness)
    ccx:COCOR_07018 (0 target-flexibility) (0 robustness)
    ccx:COCOR_07023 (1183 target-flexibility) (114 robustness)
    ccx:COCOR_07093 (154 target-flexibility) (80 robustness)
    ccx:COCOR_07115 (350 target-flexibility) (189 robustness)
    ccx:COCOR_07437 (0 target-flexibility) (0 robustness)
    ccx:COCOR_07492 (659 target-flexibility) (240 robustness)
    ccx:COCOR_07598 (924 target-flexibility) (101 robustness)
    ccx:COCOR_07628 (73 target-flexibility) (73 robustness)
    ccx:COCOR_07636 (222 target-flexibility) (83 robustness)
    ccx:COCOR_07767 (323 target-flexibility) (101 robustness)
    ccx:COCOR_07826 (1108 target-flexibility) (319 robustness)
    ccx:COCOR_07830 (659 target-flexibility) (240 robustness)
    ccx:COCOR_07894 (659 target-flexibility) (240 robustness)
    ccx:COCOR_07941 (1041 target-flexibility) (243 robustness)
    ccx:COCOR_08029 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_000149 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_000192 (821 target-flexibility) (137 robustness)
    cfus:CYFUS_000307 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_000313 (387 target-flexibility) (72 robustness)
    cfus:CYFUS_000404 (528 target-flexibility) (157 robustness)
    cfus:CYFUS_000458 (657 target-flexibility) (95 robustness)
    cfus:CYFUS_000596 (706 target-flexibility) (173 robustness)
    cfus:CYFUS_000638 (222 target-flexibility) (83 robustness)
    cfus:CYFUS_000671 (73 target-flexibility) (73 robustness)
    cfus:CYFUS_000730 (924 target-flexibility) (101 robustness)
    cfus:CYFUS_000821 (1385 target-flexibility) (204 robustness)
    cfus:CYFUS_001050 (796 target-flexibility) (85 robustness)
    cfus:CYFUS_001074 (146 target-flexibility) (75 robustness)
    cfus:CYFUS_001210 (790 target-flexibility) (134 robustness)
    cfus:CYFUS_001258 (686 target-flexibility) (192 robustness)
    cfus:CYFUS_001270 (343 target-flexibility) (180 robustness)
    cfus:CYFUS_001311 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_001388 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_001400 (821 target-flexibility) (137 robustness)
    cfus:CYFUS_001448 (73 target-flexibility) (73 robustness)
    cfus:CYFUS_001459 (732 target-flexibility) (78 robustness)
    cfus:CYFUS_001521 (231 target-flexibility) (158 robustness)
    cfus:CYFUS_001768 (215 target-flexibility) (142 robustness)
    cfus:CYFUS_001817 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_001840 (357 target-flexibility) (102 robustness)
    cfus:CYFUS_001955 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_001961 (262 target-flexibility) (86 robustness)
    cfus:CYFUS_002029 (796 target-flexibility) (85 robustness)
    cfus:CYFUS_002032 (734 target-flexibility) (110 robustness)
    cfus:CYFUS_002120 (336 target-flexibility) (81 robustness)
    cfus:CYFUS_002221 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_002267 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_002275 (343 target-flexibility) (180 robustness)
    cfus:CYFUS_002369 (526 target-flexibility) (95 robustness)
    cfus:CYFUS_002381 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_002434 (691 target-flexibility) (528 robustness)
    cfus:CYFUS_002450 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_002606 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_002610 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_002692 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_002820 (530 target-flexibility) (162 robustness)
    cfus:CYFUS_002842 (166 target-flexibility) (99 robustness)
    cfus:CYFUS_002855 (790 target-flexibility) (134 robustness)
    cfus:CYFUS_002856 (336 target-flexibility) (81 robustness)
    cfus:CYFUS_002879 (526 target-flexibility) (95 robustness)
    cfus:CYFUS_002936 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_002943 (706 target-flexibility) (173 robustness)
    cfus:CYFUS_002949 (1022 target-flexibility) (80 robustness)
    cfus:CYFUS_003023 (357 target-flexibility) (102 robustness)
    cfus:CYFUS_003160 (166 target-flexibility) (99 robustness)
    cfus:CYFUS_003161 (752 target-flexibility) (105 robustness)
    cfus:CYFUS_003276 (222 target-flexibility) (83 robustness)
    cfus:CYFUS_003324 (691 target-flexibility) (528 robustness)
    cfus:CYFUS_003468 (530 target-flexibility) (162 robustness)
    cfus:CYFUS_003469 (503 target-flexibility) (78 robustness)
    cfus:CYFUS_003470 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_003472 (703 target-flexibility) (319 robustness)
    cfus:CYFUS_003510 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_003523 (71 target-flexibility) (71 robustness)
    cfus:CYFUS_003761 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_003871 (231 target-flexibility) (158 robustness)
    cfus:CYFUS_003986 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_004176 (146 target-flexibility) (75 robustness)
    cfus:CYFUS_004217 (343 target-flexibility) (180 robustness)
    cfus:CYFUS_004248 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_004265 (228 target-flexibility) (83 robustness)
    cfus:CYFUS_004276 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_004307 (752 target-flexibility) (105 robustness)
    cfus:CYFUS_004387 (212 target-flexibility) (73 robustness)
    cfus:CYFUS_004460 (706 target-flexibility) (173 robustness)
    cfus:CYFUS_004499 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_004500 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_004504 (897 target-flexibility) (71 robustness)
    cfus:CYFUS_004522 (902 target-flexibility) (228 robustness)
    cfus:CYFUS_004536 (1784 target-flexibility) (162 robustness)
    cfus:CYFUS_004539 (924 target-flexibility) (101 robustness)
    cfus:CYFUS_004606 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_004618 (262 target-flexibility) (86 robustness)
    cfus:CYFUS_004674 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_004693 (686 target-flexibility) (192 robustness)
    cfus:CYFUS_004932 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_004967 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_005031 (377 target-flexibility) (117 robustness)
    cfus:CYFUS_005114 (703 target-flexibility) (319 robustness)
    cfus:CYFUS_005273 (924 target-flexibility) (101 robustness)
    cfus:CYFUS_005417 (343 target-flexibility) (180 robustness)
    cfus:CYFUS_005491 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_005495 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_005532 (301 target-flexibility) (74 robustness)
    cfus:CYFUS_005533 (138 target-flexibility) (66 robustness)
    cfus:CYFUS_005572 (821 target-flexibility) (137 robustness)
    cfus:CYFUS_005582 (1385 target-flexibility) (204 robustness)
    cfus:CYFUS_005589 (706 target-flexibility) (173 robustness)
    cfus:CYFUS_005693 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_005776 (902 target-flexibility) (228 robustness)
    cfus:CYFUS_006014 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_006116 (752 target-flexibility) (76 robustness)
    cfus:CYFUS_006401 (503 target-flexibility) (78 robustness)
    cfus:CYFUS_006411 (752 target-flexibility) (105 robustness)
    cfus:CYFUS_006415 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_006464 (855 target-flexibility) (138 robustness)
    cfus:CYFUS_006469 (358 target-flexibility) (124 robustness)
    cfus:CYFUS_006478 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_006545 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_006565 (734 target-flexibility) (110 robustness)
    cfus:CYFUS_006568 (301 target-flexibility) (74 robustness)
    cfus:CYFUS_006579 (528 target-flexibility) (157 robustness)
    cfus:CYFUS_006640 (752 target-flexibility) (105 robustness)
    cfus:CYFUS_006704 (697 target-flexibility) (78 robustness)
    cfus:CYFUS_006707 (902 target-flexibility) (228 robustness)
    cfus:CYFUS_006709 (855 target-flexibility) (138 robustness)
    cfus:CYFUS_006715 (359 target-flexibility) (65 robustness)
    cfus:CYFUS_006729 (359 target-flexibility) (65 robustness)
    cfus:CYFUS_006834 (358 target-flexibility) (124 robustness)
    cfus:CYFUS_006893 (657 target-flexibility) (95 robustness)
    cfus:CYFUS_007043 (336 target-flexibility) (81 robustness)
    cfus:CYFUS_007112 (1183 target-flexibility) (114 robustness)
    cfus:CYFUS_007177 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_007179 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_007182 (752 target-flexibility) (105 robustness)
    cfus:CYFUS_007242 (821 target-flexibility) (137 robustness)
    cfus:CYFUS_007353 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_007387 (528 target-flexibility) (157 robustness)
    cfus:CYFUS_007446 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_007657 (821 target-flexibility) (137 robustness)
    cfus:CYFUS_007663 (902 target-flexibility) (228 robustness)
    cfus:CYFUS_007827 (231 target-flexibility) (158 robustness)
    cfus:CYFUS_007834 (67 target-flexibility) (67 robustness)
    cfus:CYFUS_007835 (239 target-flexibility) (67 robustness)
    cfus:CYFUS_007908 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_007984 (231 target-flexibility) (158 robustness)
    cfus:CYFUS_007998 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_008059 (228 target-flexibility) (83 robustness)
    cfus:CYFUS_008079 (358 target-flexibility) (124 robustness)
    cfus:CYFUS_008254 (697 target-flexibility) (78 robustness)
    cfus:CYFUS_008295 (231 target-flexibility) (158 robustness)
    cfus:CYFUS_008485 (686 target-flexibility) (192 robustness)
    cfus:CYFUS_008499 (215 target-flexibility) (142 robustness)
    cfus:CYFUS_008610 (1784 target-flexibility) (162 robustness)
    cfus:CYFUS_008791 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_008837 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_008840 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_008843 (1183 target-flexibility) (114 robustness)
    cfus:CYFUS_009033 (387 target-flexibility) (72 robustness)
    cfus:CYFUS_009048 (377 target-flexibility) (117 robustness)
    cfus:CYFUS_009170 (1022 target-flexibility) (80 robustness)
    cfus:CYFUS_009173 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_009210 (231 target-flexibility) (158 robustness)
    cfus:CYFUS_009233 (1183 target-flexibility) (114 robustness)
    cfus:CYFUS_009429 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_009460 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_009491 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_009647 (659 target-flexibility) (240 robustness)
    cfus:CYFUS_009732 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_009744 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_009834 (855 target-flexibility) (138 robustness)
    daf:Desaf_0028 (855 target-flexibility) (138 robustness)
    daf:Desaf_0050 (855 target-flexibility) (138 robustness)
    daf:Desaf_0090 (1041 target-flexibility) (243 robustness)
    daf:Desaf_0111 (732 target-flexibility) (78 robustness)
    daf:Desaf_0187 (600 target-flexibility) (126 robustness)
    daf:Desaf_0304 (1041 target-flexibility) (243 robustness)
    daf:Desaf_0322 (790 target-flexibility) (134 robustness)
    daf:Desaf_0342 (0 target-flexibility) (0 robustness)
    daf:Desaf_0400 (0 target-flexibility) (0 robustness)
    daf:Desaf_0457 (0 target-flexibility) (0 robustness)
    daf:Desaf_0470 (468 target-flexibility) (75 robustness)
    daf:Desaf_0481 (0 target-flexibility) (0 robustness)
    daf:Desaf_0721 (706 target-flexibility) (173 robustness)
    daf:Desaf_0810 (1108 target-flexibility) (319 robustness)
    daf:Desaf_0812 (600 target-flexibility) (126 robustness)
    daf:Desaf_0930 (0 target-flexibility) (0 robustness)
    daf:Desaf_0973 (1385 target-flexibility) (204 robustness)
    daf:Desaf_0993 (0 target-flexibility) (0 robustness)
    daf:Desaf_1004 (0 target-flexibility) (0 robustness)
    daf:Desaf_1013 (0 target-flexibility) (0 robustness)
    daf:Desaf_1014 (0 target-flexibility) (0 robustness)
    daf:Desaf_1015 (0 target-flexibility) (0 robustness)
    daf:Desaf_1207 (357 target-flexibility) (102 robustness)
    daf:Desaf_1251 (790 target-flexibility) (134 robustness)
    daf:Desaf_1274 (528 target-flexibility) (157 robustness)
    daf:Desaf_1280 (0 target-flexibility) (0 robustness)
    daf:Desaf_1333 (0 target-flexibility) (0 robustness)
    daf:Desaf_1391 (790 target-flexibility) (134 robustness)
    daf:Desaf_1392 (821 target-flexibility) (137 robustness)
    daf:Desaf_1457 (212 target-flexibility) (73 robustness)
    daf:Desaf_1508 (0 target-flexibility) (0 robustness)
    daf:Desaf_1564 (796 target-flexibility) (85 robustness)
    daf:Desaf_1603 (0 target-flexibility) (0 robustness)
    daf:Desaf_1752 (1385 target-flexibility) (204 robustness)
    daf:Desaf_1776 (80 target-flexibility) (80 robustness)
    daf:Desaf_1964 (0 target-flexibility) (0 robustness)
    daf:Desaf_2034 (0 target-flexibility) (0 robustness)
    daf:Desaf_2132 (0 target-flexibility) (0 robustness)
    daf:Desaf_2183 (0 target-flexibility) (0 robustness)
    daf:Desaf_2261 (358 target-flexibility) (104 robustness)
    daf:Desaf_2280 (706 target-flexibility) (173 robustness)
    daf:Desaf_2305 (0 target-flexibility) (0 robustness)
    daf:Desaf_2308 (657 target-flexibility) (95 robustness)
    daf:Desaf_2339 (0 target-flexibility) (0 robustness)
    daf:Desaf_2347 (703 target-flexibility) (319 robustness)
    daf:Desaf_2349 (659 target-flexibility) (240 robustness)
    daf:Desaf_2350 (1108 target-flexibility) (319 robustness)
    daf:Desaf_2369 (357 target-flexibility) (102 robustness)
    daf:Desaf_2392 (600 target-flexibility) (126 robustness)
    daf:Desaf_2415 (0 target-flexibility) (0 robustness)
    daf:Desaf_2455 (1041 target-flexibility) (243 robustness)
    daf:Desaf_2481 (358 target-flexibility) (104 robustness)
    daf:Desaf_2490 (138 target-flexibility) (138 robustness)
    daf:Desaf_2502 (138 target-flexibility) (138 robustness)
    daf:Desaf_2509 (289 target-flexibility) (73 robustness)
    daf:Desaf_2698 (657 target-flexibility) (95 robustness)
    daf:Desaf_2718 (841 target-flexibility) (126 robustness)
    daf:Desaf_2806 (343 target-flexibility) (180 robustness)
    daf:Desaf_2884 (0 target-flexibility) (0 robustness)
    daf:Desaf_2887 (0 target-flexibility) (0 robustness)
    daf:Desaf_2906 (75 target-flexibility) (75 robustness)
    daf:Desaf_2907 (75 target-flexibility) (75 robustness)
    daf:Desaf_2909 (0 target-flexibility) (0 robustness)
    daf:Desaf_2926 (222 target-flexibility) (83 robustness)
    daf:Desaf_2946 (706 target-flexibility) (173 robustness)
    daf:Desaf_2970 (1169 target-flexibility) (76 robustness)
    daf:Desaf_2972 (0 target-flexibility) (0 robustness)
    daf:Desaf_3002 (902 target-flexibility) (228 robustness)
    daf:Desaf_3113 (138 target-flexibility) (138 robustness)
    daf:Desaf_3133 (706 target-flexibility) (173 robustness)
    daf:Desaf_3210 (0 target-flexibility) (0 robustness)
    daf:Desaf_3260 (434 target-flexibility) (67 robustness)
    daf:Desaf_3263 (841 target-flexibility) (126 robustness)
    daf:Desaf_3311 (0 target-flexibility) (0 robustness)
    daf:Desaf_3315 (0 target-flexibility) (0 robustness)
    daf:Desaf_3326 (902 target-flexibility) (228 robustness)
    daf:Desaf_3337 (706 target-flexibility) (173 robustness)
    daf:Desaf_3600 (468 target-flexibility) (75 robustness)
    daf:Desaf_3662 (659 target-flexibility) (240 robustness)
    daf:Desaf_3665 (703 target-flexibility) (319 robustness)
    daf:Desaf_3667 (343 target-flexibility) (180 robustness)
    daf:Desaf_3668 (0 target-flexibility) (0 robustness)
    daf:Desaf_3676 (703 target-flexibility) (319 robustness)
    daf:Desaf_3712 (821 target-flexibility) (137 robustness)
    dak:DaAHT2_0034 (600 target-flexibility) (126 robustness)
    dak:DaAHT2_0075 (138 target-flexibility) (138 robustness)
    dak:DaAHT2_0099 (1385 target-flexibility) (204 robustness)
    dak:DaAHT2_0100 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_0107 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_0190 (821 target-flexibility) (137 robustness)
    dak:DaAHT2_0251 (700 target-flexibility) (80 robustness)
    dak:DaAHT2_0308 (138 target-flexibility) (138 robustness)
    dak:DaAHT2_0356 (1385 target-flexibility) (204 robustness)
    dak:DaAHT2_0430 (607 target-flexibility) (75 robustness)
    dak:DaAHT2_0472 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_0507 (357 target-flexibility) (102 robustness)
    dak:DaAHT2_0543 (841 target-flexibility) (126 robustness)
    dak:DaAHT2_0807 (841 target-flexibility) (126 robustness)
    dak:DaAHT2_0884 (279 target-flexibility) (126 robustness)
    dak:DaAHT2_0891 (706 target-flexibility) (173 robustness)
    dak:DaAHT2_0908 (686 target-flexibility) (192 robustness)
    dak:DaAHT2_1051 (212 target-flexibility) (73 robustness)
    dak:DaAHT2_1113 (703 target-flexibility) (319 robustness)
    dak:DaAHT2_1120 (659 target-flexibility) (240 robustness)
    dak:DaAHT2_1131 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1134 (703 target-flexibility) (319 robustness)
    dak:DaAHT2_1178 (222 target-flexibility) (83 robustness)
    dak:DaAHT2_1248 (691 target-flexibility) (528 robustness)
    dak:DaAHT2_1284 (703 target-flexibility) (319 robustness)
    dak:DaAHT2_1286 (659 target-flexibility) (240 robustness)
    dak:DaAHT2_1365 (686 target-flexibility) (192 robustness)
    dak:DaAHT2_1389 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1390 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1480 (70 target-flexibility) (70 robustness)
    dak:DaAHT2_1482 (140 target-flexibility) (71 robustness)
    dak:DaAHT2_1512 (607 target-flexibility) (75 robustness)
    dak:DaAHT2_1551 (91 target-flexibility) (91 robustness)
    dak:DaAHT2_1596 (91 target-flexibility) (91 robustness)
    dak:DaAHT2_1636 (732 target-flexibility) (78 robustness)
    dak:DaAHT2_1753 (821 target-flexibility) (137 robustness)
    dak:DaAHT2_1790 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1791 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1792 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1793 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1794 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1830 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1831 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1833 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1885 (691 target-flexibility) (528 robustness)
    dak:DaAHT2_1968 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1995 (357 target-flexibility) (102 robustness)
    dak:DaAHT2_2095 (600 target-flexibility) (126 robustness)
    dak:DaAHT2_2211 (138 target-flexibility) (66 robustness)
    dak:DaAHT2_2315 (897 target-flexibility) (71 robustness)
    dak:DaAHT2_2371 (796 target-flexibility) (85 robustness)
    dak:DaAHT2_2482 (821 target-flexibility) (137 robustness)
    dak:DaAHT2_2512 (706 target-flexibility) (173 robustness)
    dak:DaAHT2_2537 (80 target-flexibility) (80 robustness)
    dak:DaAHT2_2561 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_2607 (700 target-flexibility) (80 robustness)
    dak:DaAHT2_2657 (279 target-flexibility) (126 robustness)
    dal:Dalk_0003 (0 target-flexibility) (0 robustness)
    dal:Dalk_0016 (732 target-flexibility) (78 robustness)
    dal:Dalk_0017 (405 target-flexibility) (169 robustness)
    dal:Dalk_0024 (691 target-flexibility) (528 robustness)
    dal:Dalk_0066 (0 target-flexibility) (0 robustness)
    dal:Dalk_0177 (0 target-flexibility) (0 robustness)
    dal:Dalk_0244 (330 target-flexibility) (76 robustness)
    dal:Dalk_0412 (239 target-flexibility) (99 robustness)
    dal:Dalk_0439 (91 target-flexibility) (91 robustness)
    dal:Dalk_0475 (0 target-flexibility) (0 robustness)
    dal:Dalk_0497 (212 target-flexibility) (73 robustness)
    dal:Dalk_0559 (269 target-flexibility) (64 robustness)
    dal:Dalk_0560 (902 target-flexibility) (228 robustness)
    dal:Dalk_0564 (841 target-flexibility) (126 robustness)
    dal:Dalk_0565 (841 target-flexibility) (126 robustness)
    dal:Dalk_0567 (1385 target-flexibility) (204 robustness)
    dal:Dalk_0568 (1108 target-flexibility) (319 robustness)
    dal:Dalk_0617 (330 target-flexibility) (76 robustness)
    dal:Dalk_0634 (0 target-flexibility) (0 robustness)
    dal:Dalk_0635 (0 target-flexibility) (0 robustness)
    dal:Dalk_0769 (358 target-flexibility) (104 robustness)
    dal:Dalk_0836 (1169 target-flexibility) (76 robustness)
    dal:Dalk_0853 (0 target-flexibility) (0 robustness)
    dal:Dalk_0888 (0 target-flexibility) (0 robustness)
    dal:Dalk_0935 (0 target-flexibility) (0 robustness)
    dal:Dalk_0939 (0 target-flexibility) (0 robustness)
    dal:Dalk_0954 (0 target-flexibility) (0 robustness)
    dal:Dalk_1064 (1041 target-flexibility) (243 robustness)
    dal:Dalk_1065 (1041 target-flexibility) (243 robustness)
    dal:Dalk_1066 (80 target-flexibility) (80 robustness)
    dal:Dalk_1076 (343 target-flexibility) (180 robustness)
    dal:Dalk_1103 (91 target-flexibility) (91 robustness)
    dal:Dalk_1159 (0 target-flexibility) (0 robustness)
    dal:Dalk_1193 (0 target-flexibility) (0 robustness)
    dal:Dalk_1228 (215 target-flexibility) (142 robustness)
    dal:Dalk_1240 (434 target-flexibility) (67 robustness)
    dal:Dalk_1314 (0 target-flexibility) (0 robustness)
    dal:Dalk_1315 (0 target-flexibility) (0 robustness)
    dal:Dalk_1397 (902 target-flexibility) (228 robustness)
    dal:Dalk_1414 (239 target-flexibility) (99 robustness)
    dal:Dalk_1434 (686 target-flexibility) (192 robustness)
    dal:Dalk_1438 (215 target-flexibility) (142 robustness)
    dal:Dalk_1587 (0 target-flexibility) (0 robustness)
    dal:Dalk_1693 (0 target-flexibility) (0 robustness)
    dal:Dalk_1699 (0 target-flexibility) (0 robustness)
    dal:Dalk_1700 (0 target-flexibility) (0 robustness)
    dal:Dalk_1704 (0 target-flexibility) (0 robustness)
    dal:Dalk_1711 (0 target-flexibility) (0 robustness)
    dal:Dalk_1752 (1108 target-flexibility) (319 robustness)
    dal:Dalk_1754 (503 target-flexibility) (78 robustness)
    dal:Dalk_1770 (222 target-flexibility) (83 robustness)
    dal:Dalk_1784 (71 target-flexibility) (71 robustness)
    dal:Dalk_1825 (269 target-flexibility) (64 robustness)
    dal:Dalk_1934 (289 target-flexibility) (73 robustness)
    dal:Dalk_1998 (691 target-flexibility) (528 robustness)
    dal:Dalk_2329 (790 target-flexibility) (134 robustness)
    dal:Dalk_2393 (0 target-flexibility) (0 robustness)
    dal:Dalk_2445 (0 target-flexibility) (0 robustness)
    dal:Dalk_2506 (175 target-flexibility) (96 robustness)
    dal:Dalk_2541 (0 target-flexibility) (0 robustness)
    dal:Dalk_2573 (497 target-flexibility) (186 robustness)
    dal:Dalk_2581 (0 target-flexibility) (0 robustness)
    dal:Dalk_2649 (358 target-flexibility) (124 robustness)
    dal:Dalk_2651 (528 target-flexibility) (157 robustness)
    dal:Dalk_2721 (1108 target-flexibility) (319 robustness)
    dal:Dalk_2752 (1041 target-flexibility) (243 robustness)
    dal:Dalk_2756 (752 target-flexibility) (76 robustness)
    dal:Dalk_2855 (80 target-flexibility) (80 robustness)
    dal:Dalk_2928 (0 target-flexibility) (0 robustness)
    dal:Dalk_2984 (0 target-flexibility) (0 robustness)
    dal:Dalk_3130 (70 target-flexibility) (70 robustness)
    dal:Dalk_3133 (140 target-flexibility) (71 robustness)
    dal:Dalk_3135 (67 target-flexibility) (67 robustness)
    dal:Dalk_3136 (239 target-flexibility) (67 robustness)
    dal:Dalk_3177 (497 target-flexibility) (186 robustness)
    dal:Dalk_3253 (175 target-flexibility) (96 robustness)
    dal:Dalk_3307 (659 target-flexibility) (240 robustness)
    dal:Dalk_3333 (0 target-flexibility) (0 robustness)
    dal:Dalk_3370 (1385 target-flexibility) (204 robustness)
    dal:Dalk_3440 (503 target-flexibility) (78 robustness)
    dal:Dalk_3481 (405 target-flexibility) (169 robustness)
    dal:Dalk_3482 (732 target-flexibility) (78 robustness)
    dal:Dalk_3651 (0 target-flexibility) (0 robustness)
    dal:Dalk_3803 (0 target-flexibility) (0 robustness)
    dal:Dalk_3820 (358 target-flexibility) (104 robustness)
    dal:Dalk_3872 (0 target-flexibility) (0 robustness)
    dal:Dalk_3886 (0 target-flexibility) (0 robustness)
    dal:Dalk_3893 (343 target-flexibility) (180 robustness)
    dal:Dalk_3901 (0 target-flexibility) (0 robustness)
    dal:Dalk_3912 (659 target-flexibility) (240 robustness)
    dal:Dalk_3962 (686 target-flexibility) (192 robustness)
    dal:Dalk_4029 (239 target-flexibility) (99 robustness)
    dal:Dalk_4104 (0 target-flexibility) (0 robustness)
    dal:Dalk_4163 (902 target-flexibility) (228 robustness)
    dal:Dalk_4201 (0 target-flexibility) (0 robustness)
    dal:Dalk_4640 (0 target-flexibility) (0 robustness)
    dal:Dalk_4695 (0 target-flexibility) (0 robustness)
    dal:Dalk_4696 (0 target-flexibility) (0 robustness)
    dal:Dalk_4854 (659 target-flexibility) (240 robustness)
    dal:Dalk_5019 (902 target-flexibility) (228 robustness)
    dal:Dalk_5220 (358 target-flexibility) (124 robustness)
    dao:Desac_0009 (897 target-flexibility) (71 robustness)
    dao:Desac_0097 (0 target-flexibility) (0 robustness)
    dao:Desac_0099 (0 target-flexibility) (0 robustness)
    dao:Desac_0208 (175 target-flexibility) (96 robustness)
    dao:Desac_0239 (0 target-flexibility) (0 robustness)
    dao:Desac_0259 (358 target-flexibility) (104 robustness)
    dao:Desac_0291 (0 target-flexibility) (0 robustness)
    dao:Desac_0292 (0 target-flexibility) (0 robustness)
    dao:Desac_0299 (706 target-flexibility) (173 robustness)
    dao:Desac_0380 (1385 target-flexibility) (204 robustness)
    dao:Desac_0436 (706 target-flexibility) (173 robustness)
    dao:Desac_0448 (0 target-flexibility) (0 robustness)
    dao:Desac_0519 (732 target-flexibility) (78 robustness)
    dao:Desac_0596 (70 target-flexibility) (70 robustness)
    dao:Desac_0599 (140 target-flexibility) (71 robustness)
    dao:Desac_0601 (67 target-flexibility) (67 robustness)
    dao:Desac_0602 (239 target-flexibility) (67 robustness)
    dao:Desac_0671 (600 target-flexibility) (126 robustness)
    dao:Desac_0739 (686 target-flexibility) (192 robustness)
    dao:Desac_0932 (821 target-flexibility) (137 robustness)
    dao:Desac_0945 (139 target-flexibility) (66 robustness)
    dao:Desac_0972 (206 target-flexibility) (68 robustness)
    dao:Desac_1050 (405 target-flexibility) (169 robustness)
    dao:Desac_1090 (358 target-flexibility) (104 robustness)
    dao:Desac_1107 (0 target-flexibility) (0 robustness)
    dao:Desac_1133 (706 target-flexibility) (173 robustness)
    dao:Desac_1164 (350 target-flexibility) (189 robustness)
    dao:Desac_1186 (0 target-flexibility) (0 robustness)
    dao:Desac_1281 (657 target-flexibility) (95 robustness)
    dao:Desac_1300 (289 target-flexibility) (73 robustness)
    dao:Desac_1335 (821 target-flexibility) (137 robustness)
    dao:Desac_1395 (175 target-flexibility) (96 robustness)
    dao:Desac_1415 (212 target-flexibility) (73 robustness)
    dao:Desac_1501 (0 target-flexibility) (0 robustness)
    dao:Desac_1607 (706 target-flexibility) (173 robustness)
    dao:Desac_1631 (0 target-flexibility) (0 robustness)
    dao:Desac_1664 (821 target-flexibility) (137 robustness)
    dao:Desac_1681 (350 target-flexibility) (189 robustness)
    dao:Desac_1741 (0 target-flexibility) (0 robustness)
    dao:Desac_1774 (706 target-flexibility) (173 robustness)
    dao:Desac_1831 (215 target-flexibility) (142 robustness)
    dao:Desac_1840 (0 target-flexibility) (0 robustness)
    dao:Desac_1859 (657 target-flexibility) (95 robustness)
    dao:Desac_1883 (0 target-flexibility) (0 robustness)
    dao:Desac_1973 (600 target-flexibility) (126 robustness)
    dao:Desac_2015 (0 target-flexibility) (0 robustness)
    dao:Desac_2143 (691 target-flexibility) (528 robustness)
    dao:Desac_2147 (405 target-flexibility) (169 robustness)
    dao:Desac_2262 (0 target-flexibility) (0 robustness)
    dao:Desac_2332 (841 target-flexibility) (126 robustness)
    dao:Desac_2394 (706 target-flexibility) (173 robustness)
    dao:Desac_2412 (0 target-flexibility) (0 robustness)
    dao:Desac_2427 (1385 target-flexibility) (204 robustness)
    dao:Desac_2446 (691 target-flexibility) (528 robustness)
    dao:Desac_2462 (796 target-flexibility) (85 robustness)
    dao:Desac_2478 (138 target-flexibility) (66 robustness)
    dao:Desac_2517 (0 target-flexibility) (0 robustness)
    dao:Desac_2526 (841 target-flexibility) (126 robustness)
    dao:Desac_2541 (0 target-flexibility) (0 robustness)
    dao:Desac_2544 (0 target-flexibility) (0 robustness)
    dao:Desac_2573 (215 target-flexibility) (142 robustness)
    dao:Desac_2593 (80 target-flexibility) (80 robustness)
    dao:Desac_2664 (821 target-flexibility) (137 robustness)
    dao:Desac_2676 (634 target-flexibility) (72 robustness)
    dao:Desac_2680 (686 target-flexibility) (192 robustness)
    dao:Desac_2702 (634 target-flexibility) (72 robustness)
    dao:Desac_2715 (139 target-flexibility) (66 robustness)
    dao:Desac_2722 (71 target-flexibility) (71 robustness)
    dao:Desac_2817 (0 target-flexibility) (0 robustness)
    dao:Desac_2831 (350 target-flexibility) (189 robustness)
    dao:Desac_2837 (0 target-flexibility) (0 robustness)
    dao:Desac_2908 (222 target-flexibility) (83 robustness)
    dao:Desac_2922 (434 target-flexibility) (67 robustness)
    das:Daes_0042 (902 target-flexibility) (228 robustness)
    das:Daes_0076 (1041 target-flexibility) (243 robustness)
    das:Daes_0077 (1041 target-flexibility) (243 robustness)
    das:Daes_0119 (706 target-flexibility) (173 robustness)
    das:Daes_0128 (706 target-flexibility) (173 robustness)
    das:Daes_0165 (0 target-flexibility) (0 robustness)
    das:Daes_0202 (790 target-flexibility) (134 robustness)
    das:Daes_0235 (752 target-flexibility) (76 robustness)
    das:Daes_0296 (0 target-flexibility) (0 robustness)
    das:Daes_0316 (358 target-flexibility) (104 robustness)
    das:Daes_0542 (790 target-flexibility) (134 robustness)
    das:Daes_0593 (0 target-flexibility) (0 robustness)
    das:Daes_0665 (790 target-flexibility) (134 robustness)
    das:Daes_0687 (1385 target-flexibility) (204 robustness)
    das:Daes_0700 (821 target-flexibility) (137 robustness)
    das:Daes_0715 (821 target-flexibility) (137 robustness)
    das:Daes_0716 (821 target-flexibility) (137 robustness)
    das:Daes_0744 (212 target-flexibility) (73 robustness)
    das:Daes_0753 (80 target-flexibility) (80 robustness)
    das:Daes_0791 (0 target-flexibility) (0 robustness)
    das:Daes_0911 (1169 target-flexibility) (76 robustness)
    das:Daes_0937 (0 target-flexibility) (0 robustness)
    das:Daes_0961 (0 target-flexibility) (0 robustness)
    das:Daes_1012 (706 target-flexibility) (173 robustness)
    das:Daes_1070 (0 target-flexibility) (0 robustness)
    das:Daes_1136 (357 target-flexibility) (115 robustness)
    das:Daes_1192 (706 target-flexibility) (173 robustness)
    das:Daes_1225 (0 target-flexibility) (0 robustness)
    das:Daes_1318 (0 target-flexibility) (0 robustness)
    das:Daes_1343 (138 target-flexibility) (138 robustness)
    das:Daes_1374 (0 target-flexibility) (0 robustness)
    das:Daes_1375 (0 target-flexibility) (0 robustness)
    das:Daes_1396 (71 target-flexibility) (71 robustness)
    das:Daes_1451 (711 target-flexibility) (104 robustness)
    das:Daes_1558 (330 target-flexibility) (76 robustness)
    das:Daes_1679 (706 target-flexibility) (173 robustness)
    das:Daes_1696 (902 target-flexibility) (228 robustness)
    das:Daes_1706 (528 target-flexibility) (157 robustness)
    das:Daes_1709 (222 target-flexibility) (83 robustness)
    das:Daes_1744 (841 target-flexibility) (126 robustness)
    das:Daes_1746 (600 target-flexibility) (126 robustness)
    das:Daes_1774 (902 target-flexibility) (228 robustness)
    das:Daes_1775 (902 target-flexibility) (228 robustness)
    das:Daes_1798 (0 target-flexibility) (0 robustness)
    das:Daes_1823 (138 target-flexibility) (138 robustness)
    das:Daes_1850 (206 target-flexibility) (68 robustness)
    das:Daes_1909 (434 target-flexibility) (67 robustness)
    das:Daes_1912 (841 target-flexibility) (126 robustness)
    das:Daes_1972 (1041 target-flexibility) (243 robustness)
    das:Daes_1973 (1041 target-flexibility) (243 robustness)
    das:Daes_1991 (0 target-flexibility) (0 robustness)
    das:Daes_1992 (0 target-flexibility) (0 robustness)
    das:Daes_2032 (0 target-flexibility) (0 robustness)
    das:Daes_2080 (711 target-flexibility) (104 robustness)
    das:Daes_2107 (0 target-flexibility) (0 robustness)
    das:Daes_2166 (659 target-flexibility) (240 robustness)
    das:Daes_2209 (390 target-flexibility) (74 robustness)
    das:Daes_2276 (231 target-flexibility) (158 robustness)
    das:Daes_2350 (358 target-flexibility) (104 robustness)
    das:Daes_2546 (414 target-flexibility) (96 robustness)
    das:Daes_2549 (600 target-flexibility) (126 robustness)
    das:Daes_2550 (390 target-flexibility) (74 robustness)
    das:Daes_2552 (1784 target-flexibility) (162 robustness)
    das:Daes_2553 (330 target-flexibility) (76 robustness)
    das:Daes_2554 (1041 target-flexibility) (243 robustness)
    das:Daes_2654 (0 target-flexibility) (0 robustness)
    das:Daes_2678 (289 target-flexibility) (73 robustness)
    das:Daes_2714 (231 target-flexibility) (158 robustness)
    das:Daes_2770 (1784 target-flexibility) (162 robustness)
    das:Daes_2796 (659 target-flexibility) (240 robustness)
    das:Daes_2821 (0 target-flexibility) (0 robustness)
    das:Daes_2846 (0 target-flexibility) (0 robustness)
    das:Daes_2852 (0 target-flexibility) (0 robustness)
    das:Daes_2857 (0 target-flexibility) (0 robustness)
    das:Daes_2884 (0 target-flexibility) (0 robustness)
    das:Daes_2972 (0 target-flexibility) (0 robustness)
    das:Daes_3018 (0 target-flexibility) (0 robustness)
    das:Daes_3100 (1385 target-flexibility) (204 robustness)
    das:Daes_3138 (1041 target-flexibility) (243 robustness)
    das:Daes_3139 (414 target-flexibility) (96 robustness)
    das:Daes_3214 (0 target-flexibility) (0 robustness)
    das:Daes_3270 (0 target-flexibility) (0 robustness)
    das:Daes_3284 (357 target-flexibility) (115 robustness)
    das:Daes_3309 (821 target-flexibility) (137 robustness)
    das:Daes_3345 (0 target-flexibility) (0 robustness)
    dat:HRM2_00520 (350 target-flexibility) (84 robustness)
    dat:HRM2_00970 (657 target-flexibility) (95 robustness)
    dat:HRM2_01190 (269 target-flexibility) (64 robustness)
    dat:HRM2_01900 (103 target-flexibility) (103 robustness)
    dat:HRM2_02030 (0 target-flexibility) (0 robustness)
    dat:HRM2_02690 (0 target-flexibility) (0 robustness)
    dat:HRM2_02700 (0 target-flexibility) (0 robustness)
    dat:HRM2_02710 (924 target-flexibility) (101 robustness)
    dat:HRM2_03210 (497 target-flexibility) (186 robustness)
    dat:HRM2_03220 (497 target-flexibility) (186 robustness)
    dat:HRM2_04430 (434 target-flexibility) (67 robustness)
    dat:HRM2_06820 (357 target-flexibility) (115 robustness)
    dat:HRM2_06910 (528 target-flexibility) (157 robustness)
    dat:HRM2_07180 (706 target-flexibility) (173 robustness)
    dat:HRM2_07280 (323 target-flexibility) (101 robustness)
    dat:HRM2_07460 (350 target-flexibility) (84 robustness)
    dat:HRM2_07760 (497 target-flexibility) (186 robustness)
    dat:HRM2_07770 (497 target-flexibility) (186 robustness)
    dat:HRM2_08100 (215 target-flexibility) (142 robustness)
    dat:HRM2_08490 (0 target-flexibility) (0 robustness)
    dat:HRM2_08630 (600 target-flexibility) (126 robustness)
    dat:HRM2_08850 (790 target-flexibility) (134 robustness)
    dat:HRM2_10630 (239 target-flexibility) (99 robustness)
    dat:HRM2_11950 (790 target-flexibility) (134 robustness)
    dat:HRM2_12400 (600 target-flexibility) (126 robustness)
    dat:HRM2_12660 (239 target-flexibility) (67 robustness)
    dat:HRM2_12670 (67 target-flexibility) (67 robustness)
    dat:HRM2_13230 (231 target-flexibility) (158 robustness)
    dat:HRM2_13240 (231 target-flexibility) (158 robustness)
    dat:HRM2_13680 (0 target-flexibility) (0 robustness)
    dat:HRM2_14270 (700 target-flexibility) (89 robustness)
    dat:HRM2_15420 (0 target-flexibility) (0 robustness)
    dat:HRM2_15450 (0 target-flexibility) (0 robustness)
    dat:HRM2_16000 (634 target-flexibility) (72 robustness)
    dat:HRM2_16260 (706 target-flexibility) (173 robustness)
    dat:HRM2_16810 (657 target-flexibility) (95 robustness)
    dat:HRM2_17690 (634 target-flexibility) (72 robustness)
    dat:HRM2_17700 (215 target-flexibility) (142 robustness)
    dat:HRM2_17850 (64 target-flexibility) (64 robustness)
    dat:HRM2_18570 (0 target-flexibility) (0 robustness)
    dat:HRM2_20030 (0 target-flexibility) (0 robustness)
    dat:HRM2_20130 (358 target-flexibility) (104 robustness)
    dat:HRM2_20900 (212 target-flexibility) (73 robustness)
    dat:HRM2_20960 (841 target-flexibility) (126 robustness)
    dat:HRM2_20970 (841 target-flexibility) (126 robustness)
    dat:HRM2_20990 (902 target-flexibility) (228 robustness)
    dat:HRM2_21000 (269 target-flexibility) (64 robustness)
    dat:HRM2_21490 (0 target-flexibility) (0 robustness)
    dat:HRM2_21650 (0 target-flexibility) (0 robustness)
    dat:HRM2_22520 (150 target-flexibility) (76 robustness)
    dat:HRM2_22630 (497 target-flexibility) (186 robustness)
    dat:HRM2_22950 (706 target-flexibility) (173 robustness)
    dat:HRM2_23040 (0 target-flexibility) (0 robustness)
    dat:HRM2_23300 (358 target-flexibility) (104 robustness)
    dat:HRM2_23600 (0 target-flexibility) (0 robustness)
    dat:HRM2_23610 (0 target-flexibility) (0 robustness)
    dat:HRM2_23910 (0 target-flexibility) (0 robustness)
    dat:HRM2_24160 (0 target-flexibility) (0 robustness)
    dat:HRM2_24750 (0 target-flexibility) (0 robustness)
    dat:HRM2_24890 (222 target-flexibility) (83 robustness)
    dat:HRM2_25010 (323 target-flexibility) (101 robustness)
    dat:HRM2_25160 (0 target-flexibility) (0 robustness)
    dat:HRM2_25240 (0 target-flexibility) (0 robustness)
    dat:HRM2_25270 (0 target-flexibility) (0 robustness)
    dat:HRM2_26740 (358 target-flexibility) (104 robustness)
    dat:HRM2_27190 (0 target-flexibility) (0 robustness)
    dat:HRM2_27560 (138 target-flexibility) (66 robustness)
    dat:HRM2_27780 (897 target-flexibility) (71 robustness)
    dat:HRM2_27920 (600 target-flexibility) (126 robustness)
    dat:HRM2_28280 (0 target-flexibility) (0 robustness)
    dat:HRM2_28700 (0 target-flexibility) (0 robustness)
    dat:HRM2_28720 (790 target-flexibility) (134 robustness)
    dat:HRM2_29000 (0 target-flexibility) (0 robustness)
    dat:HRM2_29030 (902 target-flexibility) (228 robustness)
    dat:HRM2_29750 (0 target-flexibility) (0 robustness)
    dat:HRM2_31180 (0 target-flexibility) (0 robustness)
    dat:HRM2_34830 (64 target-flexibility) (64 robustness)
    dat:HRM2_34850 (358 target-flexibility) (124 robustness)
    dat:HRM2_35730 (0 target-flexibility) (0 robustness)
    dat:HRM2_35740 (0 target-flexibility) (0 robustness)
    dat:HRM2_35870 (752 target-flexibility) (105 robustness)
    dat:HRM2_35970 (700 target-flexibility) (89 robustness)
    dat:HRM2_36790 (0 target-flexibility) (0 robustness)
    dat:HRM2_36840 (0 target-flexibility) (0 robustness)
    dat:HRM2_37410 (239 target-flexibility) (99 robustness)
    dat:HRM2_37910 (0 target-flexibility) (0 robustness)
    dat:HRM2_38170 (706 target-flexibility) (173 robustness)
    dat:HRM2_38500 (924 target-flexibility) (101 robustness)
    dat:HRM2_41030 (289 target-flexibility) (73 robustness)
    dat:HRM2_41050 (924 target-flexibility) (101 robustness)
    dat:HRM2_41130 (358 target-flexibility) (124 robustness)
    dat:HRM2_41270 (0 target-flexibility) (0 robustness)
    dat:HRM2_42310 (497 target-flexibility) (186 robustness)
    dat:HRM2_42320 (497 target-flexibility) (186 robustness)
    dat:HRM2_42990 (706 target-flexibility) (173 robustness)
    dat:HRM2_43380 (323 target-flexibility) (101 robustness)
    dat:HRM2_43510 (150 target-flexibility) (76 robustness)
    dat:HRM2_43540 (0 target-flexibility) (0 robustness)
    dat:HRM2_45040 (103 target-flexibility) (103 robustness)
    dat:HRM2_45740 (357 target-flexibility) (115 robustness)
    dat:HRM2_45800 (752 target-flexibility) (105 robustness)
    dat:HRM2_46050 (706 target-flexibility) (173 robustness)
    dat:HRM2_47210 (790 target-flexibility) (134 robustness)
    dat:HRM2_47820 (0 target-flexibility) (0 robustness)
    dat:HRM2_47830 (0 target-flexibility) (0 robustness)
    dav:DESACE_00060 (1041 target-flexibility) (243 robustness)
    dav:DESACE_00450 (262 target-flexibility) (86 robustness)
    dav:DESACE_00685 (0 target-flexibility) (0 robustness)
    dav:DESACE_01185 (212 target-flexibility) (73 robustness)
    dav:DESACE_01385 (841 target-flexibility) (126 robustness)
    dav:DESACE_02070 (0 target-flexibility) (0 robustness)
    dav:DESACE_02195 (0 target-flexibility) (0 robustness)
    dav:DESACE_02280 (686 target-flexibility) (192 robustness)
    dav:DESACE_02320 (222 target-flexibility) (83 robustness)
    dav:DESACE_03005 (67 target-flexibility) (67 robustness)
    dav:DESACE_03010 (239 target-flexibility) (67 robustness)
    dav:DESACE_03180 (1169 target-flexibility) (76 robustness)
    dav:DESACE_03245 (70 target-flexibility) (70 robustness)
    dav:DESACE_03335 (262 target-flexibility) (86 robustness)
    dav:DESACE_03540 (0 target-flexibility) (0 robustness)
    dav:DESACE_03685 (0 target-flexibility) (0 robustness)
    dav:DESACE_03690 (0 target-flexibility) (0 robustness)
    dav:DESACE_03885 (0 target-flexibility) (0 robustness)
    dav:DESACE_03890 (0 target-flexibility) (0 robustness)
    dav:DESACE_04505 (0 target-flexibility) (0 robustness)
    dav:DESACE_05445 (790 target-flexibility) (134 robustness)
    dav:DESACE_05855 (841 target-flexibility) (126 robustness)
    dav:DESACE_05935 (80 target-flexibility) (80 robustness)
    dav:DESACE_06220 (0 target-flexibility) (0 robustness)
    dav:DESACE_06395 (691 target-flexibility) (528 robustness)
    dav:DESACE_06745 (0 target-flexibility) (0 robustness)
    dav:DESACE_06750 (0 target-flexibility) (0 robustness)
    dav:DESACE_06860 (924 target-flexibility) (101 robustness)
    dav:DESACE_06865 (841 target-flexibility) (126 robustness)
    dav:DESACE_07825 (691 target-flexibility) (528 robustness)
    dav:DESACE_08090 (686 target-flexibility) (192 robustness)
    dav:DESACE_08345 (924 target-flexibility) (101 robustness)
    dav:DESACE_08465 (0 target-flexibility) (0 robustness)
    dav:DESACE_08495 (790 target-flexibility) (134 robustness)
    dav:DESACE_08570 (0 target-flexibility) (0 robustness)
    dav:DESACE_08765 (0 target-flexibility) (0 robustness)
    dav:DESACE_08825 (0 target-flexibility) (0 robustness)
    dav:DESACE_09325 (924 target-flexibility) (101 robustness)
    dba:Dbac_0057 (0 target-flexibility) (0 robustness)
    dba:Dbac_0065 (703 target-flexibility) (319 robustness)
    dba:Dbac_0075 (357 target-flexibility) (102 robustness)
    dba:Dbac_0093 (600 target-flexibility) (126 robustness)
    dba:Dbac_0109 (790 target-flexibility) (134 robustness)
    dba:Dbac_0125 (821 target-flexibility) (137 robustness)
    dba:Dbac_0193 (855 target-flexibility) (138 robustness)
    dba:Dbac_0212 (706 target-flexibility) (173 robustness)
    dba:Dbac_0246 (138 target-flexibility) (66 robustness)
    dba:Dbac_0265 (0 target-flexibility) (0 robustness)
    dba:Dbac_0408 (902 target-flexibility) (228 robustness)
    dba:Dbac_0409 (902 target-flexibility) (228 robustness)
    dba:Dbac_0488 (222 target-flexibility) (83 robustness)
    dba:Dbac_0489 (0 target-flexibility) (0 robustness)
    dba:Dbac_0773 (0 target-flexibility) (0 robustness)
    dba:Dbac_0780 (0 target-flexibility) (0 robustness)
    dba:Dbac_0797 (0 target-flexibility) (0 robustness)
    dba:Dbac_0874 (706 target-flexibility) (173 robustness)
    dba:Dbac_0912 (138 target-flexibility) (138 robustness)
    dba:Dbac_0961 (686 target-flexibility) (192 robustness)
    dba:Dbac_0984 (0 target-flexibility) (0 robustness)
    dba:Dbac_1000 (0 target-flexibility) (0 robustness)
    dba:Dbac_1036 (358 target-flexibility) (104 robustness)
    dba:Dbac_1178 (0 target-flexibility) (0 robustness)
    dba:Dbac_1438 (497 target-flexibility) (186 robustness)
    dba:Dbac_1478 (790 target-flexibility) (134 robustness)
    dba:Dbac_1498 (0 target-flexibility) (0 robustness)
    dba:Dbac_1611 (0 target-flexibility) (0 robustness)
    dba:Dbac_1690 (0 target-flexibility) (0 robustness)
    dba:Dbac_1740 (434 target-flexibility) (67 robustness)
    dba:Dbac_1743 (841 target-flexibility) (126 robustness)
    dba:Dbac_1754 (138 target-flexibility) (138 robustness)
    dba:Dbac_1826 (0 target-flexibility) (0 robustness)
    dba:Dbac_1870 (0 target-flexibility) (0 robustness)
    dba:Dbac_1886 (706 target-flexibility) (173 robustness)
    dba:Dbac_1951 (357 target-flexibility) (102 robustness)
    dba:Dbac_1988 (706 target-flexibility) (173 robustness)
    dba:Dbac_2044 (706 target-flexibility) (173 robustness)
    dba:Dbac_2287 (0 target-flexibility) (0 robustness)
    dba:Dbac_2388 (821 target-flexibility) (137 robustness)
    dba:Dbac_2557 (0 target-flexibility) (0 robustness)
    dba:Dbac_2558 (0 target-flexibility) (0 robustness)
    dba:Dbac_2718 (0 target-flexibility) (0 robustness)
    dba:Dbac_2833 (796 target-flexibility) (85 robustness)
    dba:Dbac_2884 (0 target-flexibility) (0 robustness)
    dba:Dbac_2987 (1385 target-flexibility) (204 robustness)
    dba:Dbac_3325 (0 target-flexibility) (0 robustness)
    dbr:Deba_0015 (0 target-flexibility) (0 robustness)
    dbr:Deba_0117 (330 target-flexibility) (76 robustness)
    dbr:Deba_0131 (343 target-flexibility) (180 robustness)
    dbr:Deba_0146 (0 target-flexibility) (0 robustness)
    dbr:Deba_0206 (91 target-flexibility) (91 robustness)
    dbr:Deba_0233 (691 target-flexibility) (528 robustness)
    dbr:Deba_0292 (796 target-flexibility) (85 robustness)
    dbr:Deba_0300 (686 target-flexibility) (192 robustness)
    dbr:Deba_0342 (434 target-flexibility) (67 robustness)
    dbr:Deba_0413 (222 target-flexibility) (83 robustness)
    dbr:Deba_0419 (0 target-flexibility) (0 robustness)
    dbr:Deba_0425 (0 target-flexibility) (0 robustness)
    dbr:Deba_0534 (358 target-flexibility) (104 robustness)
    dbr:Deba_0577 (80 target-flexibility) (80 robustness)
    dbr:Deba_0581 (0 target-flexibility) (0 robustness)
    dbr:Deba_0585 (790 target-flexibility) (134 robustness)
    dbr:Deba_0606 (0 target-flexibility) (0 robustness)
    dbr:Deba_0633 (686 target-flexibility) (192 robustness)
    dbr:Deba_0753 (841 target-flexibility) (126 robustness)
    dbr:Deba_0853 (0 target-flexibility) (0 robustness)
    dbr:Deba_0943 (841 target-flexibility) (126 robustness)
    dbr:Deba_0967 (361 target-flexibility) (101 robustness)
    dbr:Deba_0994 (0 target-flexibility) (0 robustness)
    dbr:Deba_1017 (0 target-flexibility) (0 robustness)
    dbr:Deba_1025 (80 target-flexibility) (80 robustness)
    dbr:Deba_1107 (343 target-flexibility) (180 robustness)
    dbr:Deba_1178 (528 target-flexibility) (157 robustness)
    dbr:Deba_1275 (289 target-flexibility) (73 robustness)
    dbr:Deba_1412 (0 target-flexibility) (0 robustness)
    dbr:Deba_1430 (659 target-flexibility) (240 robustness)
    dbr:Deba_1479 (0 target-flexibility) (0 robustness)
    dbr:Deba_1506 (497 target-flexibility) (186 robustness)
    dbr:Deba_1628 (0 target-flexibility) (0 robustness)
    dbr:Deba_1734 (1385 target-flexibility) (204 robustness)
    dbr:Deba_1780 (0 target-flexibility) (0 robustness)
    dbr:Deba_1849 (361 target-flexibility) (101 robustness)
    dbr:Deba_1882 (138 target-flexibility) (66 robustness)
    dbr:Deba_1967 (330 target-flexibility) (76 robustness)
    dbr:Deba_1979 (1385 target-flexibility) (204 robustness)
    dbr:Deba_2001 (212 target-flexibility) (73 robustness)
    dbr:Deba_2032 (91 target-flexibility) (91 robustness)
    dbr:Deba_2122 (790 target-flexibility) (134 robustness)
    dbr:Deba_2140 (0 target-flexibility) (0 robustness)
    dbr:Deba_2198 (323 target-flexibility) (101 robustness)
    dbr:Deba_2288 (0 target-flexibility) (0 robustness)
    dbr:Deba_2388 (659 target-flexibility) (240 robustness)
    dbr:Deba_2415 (691 target-flexibility) (528 robustness)
    dbr:Deba_2503 (790 target-flexibility) (134 robustness)
    dbr:Deba_2637 (0 target-flexibility) (0 robustness)
    dbr:Deba_2654 (897 target-flexibility) (71 robustness)
    dbr:Deba_2748 (0 target-flexibility) (0 robustness)
    dbr:Deba_2773 (0 target-flexibility) (0 robustness)
    dbr:Deba_2788 (239 target-flexibility) (67 robustness)
    dbr:Deba_2789 (67 target-flexibility) (67 robustness)
    dbr:Deba_2791 (140 target-flexibility) (71 robustness)
    dbr:Deba_2794 (70 target-flexibility) (70 robustness)
    dbr:Deba_2981 (323 target-flexibility) (101 robustness)
    dbr:Deba_3012 (497 target-flexibility) (186 robustness)
    dbr:Deba_3094 (0 target-flexibility) (0 robustness)
    dbr:Deba_3125 (732 target-flexibility) (78 robustness)
    dbr:Deba_3185 (215 target-flexibility) (142 robustness)
    dbr:Deba_3187 (790 target-flexibility) (134 robustness)
    dbr:Deba_3214 (215 target-flexibility) (142 robustness)
    dbr:Deba_3263 (358 target-flexibility) (104 robustness)
    dde:Dde_0033 (0 target-flexibility) (0 robustness)
    dde:Dde_0065 (855 target-flexibility) (138 robustness)
    dde:Dde_0079 (686 target-flexibility) (192 robustness)
    dde:Dde_0193 (0 target-flexibility) (0 robustness)
    dde:Dde_0210 (138 target-flexibility) (138 robustness)
    dde:Dde_0230 (0 target-flexibility) (0 robustness)
    dde:Dde_0255 (855 target-flexibility) (138 robustness)
    dde:Dde_0366 (231 target-flexibility) (158 robustness)
    dde:Dde_0398 (902 target-flexibility) (228 robustness)
    dde:Dde_0408 (497 target-flexibility) (186 robustness)
    dde:Dde_0427 (0 target-flexibility) (0 robustness)
    dde:Dde_0465 (138 target-flexibility) (138 robustness)
    dde:Dde_0540 (0 target-flexibility) (0 robustness)
    dde:Dde_0604 (706 target-flexibility) (173 robustness)
    dde:Dde_0626 (405 target-flexibility) (70 robustness)
    dde:Dde_0836 (0 target-flexibility) (0 robustness)
    dde:Dde_0972 (0 target-flexibility) (0 robustness)
    dde:Dde_1087 (0 target-flexibility) (0 robustness)
    dde:Dde_1103 (1385 target-flexibility) (204 robustness)
    dde:Dde_1203 (138 target-flexibility) (138 robustness)
    dde:Dde_1225 (350 target-flexibility) (189 robustness)
    dde:Dde_1254 (301 target-flexibility) (154 robustness)
    dde:Dde_1255 (301 target-flexibility) (154 robustness)
    dde:Dde_1379 (0 target-flexibility) (0 robustness)
    dde:Dde_1424 (0 target-flexibility) (0 robustness)
    dde:Dde_1558 (0 target-flexibility) (0 robustness)
    dde:Dde_1725 (0 target-flexibility) (0 robustness)
    dde:Dde_1978 (239 target-flexibility) (99 robustness)
    dde:Dde_2004 (357 target-flexibility) (102 robustness)
    dde:Dde_2049 (841 target-flexibility) (126 robustness)
    dde:Dde_2066 (138 target-flexibility) (138 robustness)
    dde:Dde_2080 (706 target-flexibility) (173 robustness)
    dde:Dde_2084 (0 target-flexibility) (0 robustness)
    dde:Dde_2142 (222 target-flexibility) (83 robustness)
    dde:Dde_2151 (138 target-flexibility) (138 robustness)
    dde:Dde_2168 (902 target-flexibility) (228 robustness)
    dde:Dde_2182 (0 target-flexibility) (0 robustness)
    dde:Dde_2187 (0 target-flexibility) (0 robustness)
    dde:Dde_2317 (790 target-flexibility) (134 robustness)
    dde:Dde_2342 (600 target-flexibility) (126 robustness)
    dde:Dde_2431 (703 target-flexibility) (319 robustness)
    dde:Dde_2439 (0 target-flexibility) (0 robustness)
    dde:Dde_2648 (357 target-flexibility) (102 robustness)
    dde:Dde_2656 (0 target-flexibility) (0 robustness)
    dde:Dde_2660 (703 target-flexibility) (319 robustness)
    dde:Dde_2664 (239 target-flexibility) (99 robustness)
    dde:Dde_2823 (790 target-flexibility) (134 robustness)
    dde:Dde_2839 (212 target-flexibility) (73 robustness)
    dde:Dde_2888 (0 target-flexibility) (0 robustness)
    dde:Dde_2891 (821 target-flexibility) (137 robustness)
    dde:Dde_3042 (231 target-flexibility) (158 robustness)
    dde:Dde_3062 (0 target-flexibility) (0 robustness)
    dde:Dde_3088 (0 target-flexibility) (0 robustness)
    dde:Dde_3126 (0 target-flexibility) (0 robustness)
    dde:Dde_3180 (80 target-flexibility) (80 robustness)
    dde:Dde_3207 (790 target-flexibility) (134 robustness)
    dde:Dde_3218 (841 target-flexibility) (126 robustness)
    dde:Dde_3222 (434 target-flexibility) (67 robustness)
    dde:Dde_3228 (0 target-flexibility) (0 robustness)
    dde:Dde_3239 (0 target-flexibility) (0 robustness)
    dde:Dde_3317 (821 target-flexibility) (137 robustness)
    dde:Dde_3397 (350 target-flexibility) (189 robustness)
    dde:Dde_3457 (0 target-flexibility) (0 robustness)
    dde:Dde_3476 (289 target-flexibility) (73 robustness)
    dde:Dde_3479 (686 target-flexibility) (192 robustness)
    dde:Dde_3523 (0 target-flexibility) (0 robustness)
    dde:Dde_3534 (0 target-flexibility) (0 robustness)
    dde:Dde_3596 (1385 target-flexibility) (204 robustness)
    dde:Dde_3638 (301 target-flexibility) (154 robustness)
    dde:Dde_3639 (301 target-flexibility) (154 robustness)
    dde:Dde_3647 (70 target-flexibility) (70 robustness)
    dde:Dde_3677 (821 target-flexibility) (137 robustness)
    dde:Dde_3687 (70 target-flexibility) (70 robustness)
    dde:Dde_3691 (0 target-flexibility) (0 robustness)
    dde:Dde_3733 (497 target-flexibility) (186 robustness)
    dde:Dde_3736 (600 target-flexibility) (126 robustness)
    dds:Ddes_0025 (0 target-flexibility) (0 robustness)
    dds:Ddes_0101 (289 target-flexibility) (73 robustness)
    dds:Ddes_0114 (138 target-flexibility) (138 robustness)
    dds:Ddes_0132 (600 target-flexibility) (126 robustness)
    dds:Ddes_0151 (323 target-flexibility) (101 robustness)
    dds:Ddes_0192 (357 target-flexibility) (102 robustness)
    dds:Ddes_0319 (0 target-flexibility) (0 robustness)
    dds:Ddes_0385 (222 target-flexibility) (83 robustness)
    dds:Ddes_0559 (0 target-flexibility) (0 robustness)
    dds:Ddes_0583 (686 target-flexibility) (192 robustness)
    dds:Ddes_0828 (0 target-flexibility) (0 robustness)
    dds:Ddes_0939 (0 target-flexibility) (0 robustness)
    dds:Ddes_1149 (357 target-flexibility) (115 robustness)
    dds:Ddes_1253 (0 target-flexibility) (0 robustness)
    dds:Ddes_1300 (0 target-flexibility) (0 robustness)
    dds:Ddes_1416 (323 target-flexibility) (101 robustness)
    dds:Ddes_1552 (706 target-flexibility) (173 robustness)
    dds:Ddes_1565 (706 target-flexibility) (173 robustness)
    dds:Ddes_1568 (706 target-flexibility) (173 robustness)
    dds:Ddes_1623 (0 target-flexibility) (0 robustness)
    dds:Ddes_1685 (697 target-flexibility) (78 robustness)
    dds:Ddes_1771 (0 target-flexibility) (0 robustness)
    dds:Ddes_2089 (1385 target-flexibility) (204 robustness)
    def:CNY67_00560 (289 target-flexibility) (73 robustness)
    def:CNY67_00625 (138 target-flexibility) (138 robustness)
    def:CNY67_00735 (600 target-flexibility) (126 robustness)
    def:CNY67_00845 (323 target-flexibility) (101 robustness)
    def:CNY67_00890 (600 target-flexibility) (126 robustness)
    def:CNY67_01635 (1385 target-flexibility) (204 robustness)
    def:CNY67_01730 (212 target-flexibility) (73 robustness)
    def:CNY67_01860 (0 target-flexibility) (0 robustness)
    def:CNY67_02160 (0 target-flexibility) (0 robustness)
    def:CNY67_02680 (902 target-flexibility) (228 robustness)
    def:CNY67_03590 (0 target-flexibility) (0 robustness)
    def:CNY67_03595 (0 target-flexibility) (0 robustness)
    def:CNY67_03610 (357 target-flexibility) (102 robustness)
    def:CNY67_03710 (790 target-flexibility) (134 robustness)
    def:CNY67_04680 (706 target-flexibility) (173 robustness)
    def:CNY67_04820 (0 target-flexibility) (0 robustness)
    def:CNY67_04975 (357 target-flexibility) (115 robustness)
    def:CNY67_05000 (686 target-flexibility) (192 robustness)
    def:CNY67_05120 (706 target-flexibility) (173 robustness)
    def:CNY67_05135 (706 target-flexibility) (173 robustness)
    def:CNY67_05215 (706 target-flexibility) (173 robustness)
    def:CNY67_05745 (0 target-flexibility) (0 robustness)
    def:CNY67_07200 (357 target-flexibility) (115 robustness)
    def:CNY67_07855 (138 target-flexibility) (138 robustness)
    def:CNY67_08360 (0 target-flexibility) (0 robustness)
    def:CNY67_08465 (405 target-flexibility) (70 robustness)
    def:CNY67_09265 (323 target-flexibility) (101 robustness)
    def:CNY67_09320 (902 target-flexibility) (228 robustness)
    def:CNY67_09770 (0 target-flexibility) (0 robustness)
    def:CNY67_10085 (0 target-flexibility) (0 robustness)
    def:CNY67_11360 (686 target-flexibility) (192 robustness)
    def:CNY67_11490 (0 target-flexibility) (0 robustness)
    def:CNY67_11835 (434 target-flexibility) (67 robustness)
    def:CNY67_12480 (0 target-flexibility) (0 robustness)
    def:CNY67_12850 (222 target-flexibility) (83 robustness)
    def:CNY67_13650 (405 target-flexibility) (70 robustness)
    def:CNY67_14075 (357 target-flexibility) (102 robustness)
    def:CNY67_14455 (1385 target-flexibility) (204 robustness)
    def:CNY67_15275 (0 target-flexibility) (0 robustness)
    def:CNY67_15330 (323 target-flexibility) (101 robustness)
    dej:AWY79_00420 (358 target-flexibility) (104 robustness)
    dej:AWY79_00595 (790 target-flexibility) (134 robustness)
    dej:AWY79_00730 (1385 target-flexibility) (204 robustness)
    dej:AWY79_00980 (790 target-flexibility) (134 robustness)
    dej:AWY79_01195 (790 target-flexibility) (134 robustness)
    dej:AWY79_01845 (0 target-flexibility) (0 robustness)
    dej:AWY79_01925 (0 target-flexibility) (0 robustness)
    dej:AWY79_02360 (357 target-flexibility) (115 robustness)
    dej:AWY79_02820 (0 target-flexibility) (0 robustness)
    dej:AWY79_03150 (902 target-flexibility) (228 robustness)
    dej:AWY79_03505 (0 target-flexibility) (0 robustness)
    dej:AWY79_03845 (0 target-flexibility) (0 robustness)
    dej:AWY79_03870 (752 target-flexibility) (76 robustness)
    dej:AWY79_04190 (0 target-flexibility) (0 robustness)
    dej:AWY79_04800 (212 target-flexibility) (73 robustness)
    dej:AWY79_04910 (780 target-flexibility) (243 robustness)
    dej:AWY79_05115 (0 target-flexibility) (0 robustness)
    dej:AWY79_05375 (1385 target-flexibility) (204 robustness)
    dej:AWY79_05490 (0 target-flexibility) (0 robustness)
    dej:AWY79_05515 (0 target-flexibility) (0 robustness)
    dej:AWY79_05625 (0 target-flexibility) (0 robustness)
    dej:AWY79_06240 (138 target-flexibility) (138 robustness)
    dej:AWY79_06655 (0 target-flexibility) (0 robustness)
    dej:AWY79_07380 (706 target-flexibility) (173 robustness)
    dej:AWY79_07505 (706 target-flexibility) (173 robustness)
    dej:AWY79_07980 (0 target-flexibility) (0 robustness)
    dej:AWY79_07985 (64 target-flexibility) (64 robustness)
    dej:AWY79_08145 (147 target-flexibility) (76 robustness)
    dej:AWY79_08325 (0 target-flexibility) (0 robustness)
    dej:AWY79_08405 (0 target-flexibility) (0 robustness)
    dej:AWY79_08700 (0 target-flexibility) (0 robustness)
    dej:AWY79_09165 (0 target-flexibility) (0 robustness)
    dej:AWY79_09610 (0 target-flexibility) (0 robustness)
    dej:AWY79_09690 (0 target-flexibility) (0 robustness)
    dej:AWY79_09715 (0 target-flexibility) (0 robustness)
    dej:AWY79_09945 (0 target-flexibility) (0 robustness)
    dej:AWY79_10175 (301 target-flexibility) (154 robustness)
    dej:AWY79_10180 (301 target-flexibility) (154 robustness)
    dej:AWY79_10340 (0 target-flexibility) (0 robustness)
    dej:AWY79_10345 (0 target-flexibility) (0 robustness)
    dej:AWY79_10770 (841 target-flexibility) (126 robustness)
    dej:AWY79_10785 (434 target-flexibility) (67 robustness)
    dej:AWY79_10850 (0 target-flexibility) (0 robustness)
    dej:AWY79_10975 (138 target-flexibility) (138 robustness)
    dej:AWY79_11045 (64 target-flexibility) (64 robustness)
    dej:AWY79_11135 (0 target-flexibility) (0 robustness)
    dej:AWY79_11140 (0 target-flexibility) (0 robustness)
    dej:AWY79_11170 (0 target-flexibility) (0 robustness)
    dej:AWY79_11185 (0 target-flexibility) (0 robustness)
    dej:AWY79_11535 (711 target-flexibility) (104 robustness)
    dej:AWY79_11830 (0 target-flexibility) (0 robustness)
    dej:AWY79_12270 (706 target-flexibility) (173 robustness)
    dej:AWY79_12390 (902 target-flexibility) (228 robustness)
    dej:AWY79_12435 (528 target-flexibility) (157 robustness)
    dej:AWY79_12450 (222 target-flexibility) (83 robustness)
    dej:AWY79_12645 (841 target-flexibility) (126 robustness)
    dej:AWY79_12835 (359 target-flexibility) (65 robustness)
    dej:AWY79_12840 (902 target-flexibility) (228 robustness)
    dej:AWY79_12845 (902 target-flexibility) (228 robustness)
    dej:AWY79_13090 (138 target-flexibility) (138 robustness)
    dej:AWY79_13255 (206 target-flexibility) (68 robustness)
    dej:AWY79_13735 (711 target-flexibility) (104 robustness)
    dej:AWY79_13845 (0 target-flexibility) (0 robustness)
    dej:AWY79_13920 (357 target-flexibility) (115 robustness)
    dej:AWY79_13965 (0 target-flexibility) (0 robustness)
    dej:AWY79_15280 (358 target-flexibility) (104 robustness)
    dej:AWY79_15440 (686 target-flexibility) (192 robustness)
    dej:AWY79_15450 (289 target-flexibility) (73 robustness)
    dej:AWY79_15735 (686 target-flexibility) (192 robustness)
    dej:AWY79_15760 (0 target-flexibility) (0 robustness)
    dej:AWY79_16080 (780 target-flexibility) (243 robustness)
    dej:AWY79_16725 (706 target-flexibility) (173 robustness)
    dej:AWY79_17490 (359 target-flexibility) (65 robustness)
    dej:AWY79_17500 (147 target-flexibility) (76 robustness)
    dej:AWY79_17535 (301 target-flexibility) (154 robustness)
    dej:AWY79_17540 (301 target-flexibility) (154 robustness)
    dej:AWY79_17820 (0 target-flexibility) (0 robustness)
    des:DSOUD_0047 (796 target-flexibility) (85 robustness)
    des:DSOUD_0107 (0 target-flexibility) (0 robustness)
    des:DSOUD_0161 (138 target-flexibility) (138 robustness)
    des:DSOUD_0206 (1108 target-flexibility) (319 robustness)
    des:DSOUD_0247 (80 target-flexibility) (80 robustness)
    des:DSOUD_0294 (691 target-flexibility) (528 robustness)
    des:DSOUD_0318 (0 target-flexibility) (0 robustness)
    des:DSOUD_0343 (1041 target-flexibility) (243 robustness)
    des:DSOUD_0363 (0 target-flexibility) (0 robustness)
    des:DSOUD_0378 (503 target-flexibility) (78 robustness)
    des:DSOUD_0407 (0 target-flexibility) (0 robustness)
    des:DSOUD_0484 (222 target-flexibility) (83 robustness)
    des:DSOUD_0593 (0 target-flexibility) (0 robustness)
    des:DSOUD_0612 (0 target-flexibility) (0 robustness)
    des:DSOUD_0618 (91 target-flexibility) (91 robustness)
    des:DSOUD_0656 (1041 target-flexibility) (243 robustness)
    des:DSOUD_0657 (1041 target-flexibility) (243 robustness)
    des:DSOUD_0751 (262 target-flexibility) (86 robustness)
    des:DSOUD_0765 (528 target-flexibility) (157 robustness)
    des:DSOUD_0923 (138 target-flexibility) (66 robustness)
    des:DSOUD_0953 (0 target-flexibility) (0 robustness)
    des:DSOUD_1069 (0 target-flexibility) (0 robustness)
    des:DSOUD_1127 (212 target-flexibility) (73 robustness)
    des:DSOUD_1171 (634 target-flexibility) (72 robustness)
    des:DSOUD_1214 (659 target-flexibility) (240 robustness)
    des:DSOUD_1217 (703 target-flexibility) (319 robustness)
    des:DSOUD_1220 (0 target-flexibility) (0 robustness)
    des:DSOUD_1228 (703 target-flexibility) (319 robustness)
    des:DSOUD_1236 (703 target-flexibility) (319 robustness)
    des:DSOUD_1340 (902 target-flexibility) (228 robustness)
    des:DSOUD_1345 (841 target-flexibility) (126 robustness)
    des:DSOUD_1475 (752 target-flexibility) (76 robustness)
    des:DSOUD_1660 (71 target-flexibility) (71 robustness)
    des:DSOUD_1686 (0 target-flexibility) (0 robustness)
    des:DSOUD_1728 (706 target-flexibility) (173 robustness)
    des:DSOUD_1777 (600 target-flexibility) (126 robustness)
    des:DSOUD_1782 (732 target-flexibility) (78 robustness)
    des:DSOUD_1879 (897 target-flexibility) (71 robustness)
    des:DSOUD_1892 (0 target-flexibility) (0 robustness)
    des:DSOUD_1894 (0 target-flexibility) (0 robustness)
    des:DSOUD_1909 (0 target-flexibility) (0 robustness)
    des:DSOUD_1920 (0 target-flexibility) (0 robustness)
    des:DSOUD_1940 (691 target-flexibility) (528 robustness)
    des:DSOUD_2009 (0 target-flexibility) (0 robustness)
    des:DSOUD_2030 (703 target-flexibility) (319 robustness)
    des:DSOUD_2032 (659 target-flexibility) (240 robustness)
    des:DSOUD_2033 (503 target-flexibility) (78 robustness)
    des:DSOUD_2034 (1108 target-flexibility) (319 robustness)
    des:DSOUD_2209 (358 target-flexibility) (124 robustness)
    des:DSOUD_2288 (0 target-flexibility) (0 robustness)
    des:DSOUD_2394 (1169 target-flexibility) (76 robustness)
    des:DSOUD_2450 (1108 target-flexibility) (319 robustness)
    des:DSOUD_2497 (902 target-flexibility) (228 robustness)
    des:DSOUD_2544 (0 target-flexibility) (0 robustness)
    des:DSOUD_2695 (231 target-flexibility) (158 robustness)
    des:DSOUD_2696 (231 target-flexibility) (158 robustness)
    des:DSOUD_2757 (262 target-flexibility) (86 robustness)
    des:DSOUD_2788 (841 target-flexibility) (126 robustness)
    des:DSOUD_2815 (686 target-flexibility) (192 robustness)
    des:DSOUD_2817 (686 target-flexibility) (192 robustness)
    des:DSOUD_2819 (634 target-flexibility) (72 robustness)
    des:DSOUD_2921 (231 target-flexibility) (158 robustness)
    des:DSOUD_2923 (70 target-flexibility) (70 robustness)
    des:DSOUD_2928 (67 target-flexibility) (67 robustness)
    des:DSOUD_2929 (239 target-flexibility) (67 robustness)
    des:DSOUD_2969 (91 target-flexibility) (91 robustness)
    des:DSOUD_2977 (600 target-flexibility) (126 robustness)
    des:DSOUD_3002 (0 target-flexibility) (0 robustness)
    des:DSOUD_3139 (138 target-flexibility) (138 robustness)
    des:DSOUD_3191 (0 target-flexibility) (0 robustness)
    des:DSOUD_3192 (0 target-flexibility) (0 robustness)
    des:DSOUD_3213 (528 target-flexibility) (157 robustness)
    des:DSOUD_3271 (358 target-flexibility) (124 robustness)
    des:DSOUD_3296 (706 target-flexibility) (173 robustness)
    des:DSOUD_3352 (0 target-flexibility) (0 robustness)
    des:DSOUD_3461 (0 target-flexibility) (0 robustness)
    deu:DBW_0034 (0 target-flexibility) (0 robustness)
    deu:DBW_0039 (0 target-flexibility) (0 robustness)
    deu:DBW_0130 (528 target-flexibility) (157 robustness)
    deu:DBW_0142 (600 target-flexibility) (126 robustness)
    deu:DBW_0156 (358 target-flexibility) (124 robustness)
    deu:DBW_0158 (0 target-flexibility) (0 robustness)
    deu:DBW_0252 (528 target-flexibility) (157 robustness)
    deu:DBW_0376 (138 target-flexibility) (138 robustness)
    deu:DBW_0404 (528 target-flexibility) (157 robustness)
    deu:DBW_0440 (80 target-flexibility) (80 robustness)
    deu:DBW_0441 (0 target-flexibility) (0 robustness)
    deu:DBW_0541 (691 target-flexibility) (528 robustness)
    deu:DBW_0616 (796 target-flexibility) (85 robustness)
    deu:DBW_0759 (222 target-flexibility) (83 robustness)
    deu:DBW_0805 (269 target-flexibility) (64 robustness)
    deu:DBW_0807 (902 target-flexibility) (228 robustness)
    deu:DBW_0911 (138 target-flexibility) (66 robustness)
    deu:DBW_0936 (0 target-flexibility) (0 robustness)
    deu:DBW_1201 (686 target-flexibility) (192 robustness)
    deu:DBW_1203 (686 target-flexibility) (192 robustness)
    deu:DBW_1238 (841 target-flexibility) (126 robustness)
    deu:DBW_1501 (0 target-flexibility) (0 robustness)
    deu:DBW_1630 (691 target-flexibility) (528 robustness)
    deu:DBW_1650 (0 target-flexibility) (0 robustness)
    deu:DBW_1740 (600 target-flexibility) (126 robustness)
    deu:DBW_1746 (732 target-flexibility) (78 robustness)
    deu:DBW_1757 (659 target-flexibility) (240 robustness)
    deu:DBW_1760 (703 target-flexibility) (319 robustness)
    deu:DBW_1763 (0 target-flexibility) (0 robustness)
    deu:DBW_1771 (703 target-flexibility) (319 robustness)
    deu:DBW_1818 (1108 target-flexibility) (319 robustness)
    deu:DBW_1820 (659 target-flexibility) (240 robustness)
    deu:DBW_1822 (703 target-flexibility) (319 robustness)
    deu:DBW_1838 (0 target-flexibility) (0 robustness)
    deu:DBW_1916 (0 target-flexibility) (0 robustness)
    deu:DBW_1931 (0 target-flexibility) (0 robustness)
    deu:DBW_1933 (0 target-flexibility) (0 robustness)
    deu:DBW_1942 (897 target-flexibility) (71 robustness)
    deu:DBW_2119 (358 target-flexibility) (124 robustness)
    deu:DBW_2132 (0 target-flexibility) (0 robustness)
    deu:DBW_2134 (0 target-flexibility) (0 robustness)
    deu:DBW_2192 (841 target-flexibility) (126 robustness)
    deu:DBW_2197 (902 target-flexibility) (228 robustness)
    deu:DBW_2198 (269 target-flexibility) (64 robustness)
    deu:DBW_2313 (0 target-flexibility) (0 robustness)
    deu:DBW_2383 (231 target-flexibility) (158 robustness)
    deu:DBW_2384 (231 target-flexibility) (158 robustness)
    deu:DBW_2425 (1169 target-flexibility) (76 robustness)
    deu:DBW_2529 (350 target-flexibility) (84 robustness)
    deu:DBW_2530 (350 target-flexibility) (84 robustness)
    deu:DBW_2541 (1041 target-flexibility) (243 robustness)
    deu:DBW_2639 (212 target-flexibility) (73 robustness)
    deu:DBW_2731 (1108 target-flexibility) (319 robustness)
    deu:DBW_2798 (231 target-flexibility) (158 robustness)
    deu:DBW_2799 (70 target-flexibility) (70 robustness)
    deu:DBW_2804 (67 target-flexibility) (67 robustness)
    deu:DBW_2805 (239 target-flexibility) (67 robustness)
    deu:DBW_2862 (91 target-flexibility) (91 robustness)
    deu:DBW_2871 (600 target-flexibility) (126 robustness)
    deu:DBW_3054 (1041 target-flexibility) (243 robustness)
    deu:DBW_3055 (1041 target-flexibility) (243 robustness)
    deu:DBW_3057 (350 target-flexibility) (84 robustness)
    deu:DBW_3101 (91 target-flexibility) (91 robustness)
    deu:DBW_3160 (262 target-flexibility) (86 robustness)
    deu:DBW_3162 (262 target-flexibility) (86 robustness)
    deu:DBW_3241 (138 target-flexibility) (138 robustness)
    deu:DBW_3264 (0 target-flexibility) (0 robustness)
    deu:DBW_3265 (0 target-flexibility) (0 robustness)
    deu:DBW_3285 (528 target-flexibility) (157 robustness)
    deu:DBW_3379 (0 target-flexibility) (0 robustness)
    deu:DBW_3516 (0 target-flexibility) (0 robustness)
    dfi:AXF13_00145 (212 target-flexibility) (73 robustness)
    dfi:AXF13_00200 (821 target-flexibility) (137 robustness)
    dfi:AXF13_00460 (434 target-flexibility) (67 robustness)
    dfi:AXF13_00525 (80 target-flexibility) (80 robustness)
    dfi:AXF13_00990 (222 target-flexibility) (83 robustness)
    dfi:AXF13_01640 (902 target-flexibility) (228 robustness)
    dfi:AXF13_01860 (357 target-flexibility) (102 robustness)
    dfi:AXF13_02225 (0 target-flexibility) (0 robustness)
    dfi:AXF13_02495 (0 target-flexibility) (0 robustness)
    dfi:AXF13_02595 (706 target-flexibility) (173 robustness)
    dfi:AXF13_02705 (0 target-flexibility) (0 robustness)
    dfi:AXF13_02840 (703 target-flexibility) (319 robustness)
    dfi:AXF13_03820 (0 target-flexibility) (0 robustness)
    dfi:AXF13_03855 (703 target-flexibility) (319 robustness)
    dfi:AXF13_03870 (1108 target-flexibility) (319 robustness)
    dfi:AXF13_04200 (357 target-flexibility) (115 robustness)
    dfi:AXF13_05010 (357 target-flexibility) (115 robustness)
    dfi:AXF13_05040 (686 target-flexibility) (192 robustness)
    dfi:AXF13_05160 (706 target-flexibility) (173 robustness)
    dfi:AXF13_05175 (706 target-flexibility) (173 robustness)
    dfi:AXF13_05725 (0 target-flexibility) (0 robustness)
    dfi:AXF13_05800 (1169 target-flexibility) (76 robustness)
    dfi:AXF13_05975 (0 target-flexibility) (0 robustness)
    dfi:AXF13_06295 (138 target-flexibility) (138 robustness)
    dfi:AXF13_06500 (706 target-flexibility) (173 robustness)
    dfi:AXF13_07230 (0 target-flexibility) (0 robustness)
    dfi:AXF13_09410 (821 target-flexibility) (137 robustness)
    dfi:AXF13_10380 (790 target-flexibility) (134 robustness)
    dfi:AXF13_10670 (686 target-flexibility) (192 robustness)
    dfi:AXF13_10905 (1041 target-flexibility) (243 robustness)
    dfi:AXF13_11195 (0 target-flexibility) (0 robustness)
    dfi:AXF13_11540 (468 target-flexibility) (75 robustness)
    dfi:AXF13_11695 (0 target-flexibility) (0 robustness)
    dfi:AXF13_12410 (357 target-flexibility) (102 robustness)
    dfi:AXF13_12555 (0 target-flexibility) (0 robustness)
    dfi:AXF13_12630 (1385 target-flexibility) (204 robustness)
    dfi:AXF13_12725 (138 target-flexibility) (138 robustness)
    dfi:AXF13_12855 (902 target-flexibility) (228 robustness)
    dfi:AXF13_13155 (289 target-flexibility) (73 robustness)
    dfi:AXF13_13325 (0 target-flexibility) (0 robustness)
    dfi:AXF13_13335 (1385 target-flexibility) (204 robustness)
    dfi:AXF13_13565 (301 target-flexibility) (154 robustness)
    dfi:AXF13_13900 (1108 target-flexibility) (319 robustness)
    dfi:AXF13_13965 (1041 target-flexibility) (243 robustness)
    dfi:AXF13_13970 (1041 target-flexibility) (243 robustness)
    dfi:AXF13_14405 (600 target-flexibility) (126 robustness)
    dfi:AXF13_14950 (600 target-flexibility) (126 robustness)
    dfi:AXF13_15030 (468 target-flexibility) (75 robustness)
    dfi:AXF13_15125 (301 target-flexibility) (154 robustness)
    dfi:AXF13_15545 (468 target-flexibility) (75 robustness)
    dgg:DGI_0026 (0 target-flexibility) (0 robustness)
    dgg:DGI_0069 (0 target-flexibility) (0 robustness)
    dgg:DGI_0194 (0 target-flexibility) (0 robustness)
    dgg:DGI_0259 (821 target-flexibility) (137 robustness)
    dgg:DGI_0581 (790 target-flexibility) (134 robustness)
    dgg:DGI_0644 (0 target-flexibility) (0 robustness)
    dgg:DGI_0677 (0 target-flexibility) (0 robustness)
    dgg:DGI_0738 (528 target-flexibility) (157 robustness)
    dgg:DGI_0864 (0 target-flexibility) (0 robustness)
    dgg:DGI_0873 (241 target-flexibility) (71 robustness)
    dgg:DGI_0878 (1385 target-flexibility) (204 robustness)
    dgg:DGI_0974 (138 target-flexibility) (138 robustness)
    dgg:DGI_1044 (0 target-flexibility) (0 robustness)
    dgg:DGI_1047 (0 target-flexibility) (0 robustness)
    dgg:DGI_1150 (357 target-flexibility) (115 robustness)
    dgg:DGI_1257 (357 target-flexibility) (115 robustness)
    dgg:DGI_1348 (1041 target-flexibility) (243 robustness)
    dgg:DGI_1422 (0 target-flexibility) (0 robustness)
    dgg:DGI_1438 (790 target-flexibility) (134 robustness)
    dgg:DGI_1581 (241 target-flexibility) (71 robustness)
    dgg:DGI_1613 (821 target-flexibility) (137 robustness)
    dgg:DGI_1648 (212 target-flexibility) (73 robustness)
    dgg:DGI_1654 (1385 target-flexibility) (204 robustness)
    dgg:DGI_1737 (790 target-flexibility) (134 robustness)
    dgg:DGI_1796 (879 target-flexibility) (71 robustness)
    dgg:DGI_1805 (700 target-flexibility) (77 robustness)
    dgg:DGI_1807 (350 target-flexibility) (189 robustness)
    dgg:DGI_1837 (357 target-flexibility) (102 robustness)
    dgg:DGI_1851 (289 target-flexibility) (73 robustness)
    dgg:DGI_1877 (350 target-flexibility) (189 robustness)
    dgg:DGI_1879 (700 target-flexibility) (77 robustness)
    dgg:DGI_1888 (879 target-flexibility) (71 robustness)
    dgg:DGI_1902 (0 target-flexibility) (0 robustness)
    dgg:DGI_2188 (600 target-flexibility) (126 robustness)
    dgg:DGI_2242 (0 target-flexibility) (0 robustness)
    dgg:DGI_2250 (706 target-flexibility) (173 robustness)
    dgg:DGI_2289 (0 target-flexibility) (0 robustness)
    dgg:DGI_2466 (0 target-flexibility) (0 robustness)
    dgg:DGI_2476 (0 target-flexibility) (0 robustness)
    dgg:DGI_2503 (841 target-flexibility) (126 robustness)
    dgg:DGI_2521 (138 target-flexibility) (138 robustness)
    dgg:DGI_2546 (600 target-flexibility) (126 robustness)
    dgg:DGI_2559 (0 target-flexibility) (0 robustness)
    dgg:DGI_2657 (0 target-flexibility) (0 robustness)
    dgg:DGI_2681 (358 target-flexibility) (104 robustness)
    dgg:DGI_2716 (0 target-flexibility) (0 robustness)
    dgg:DGI_2774 (222 target-flexibility) (83 robustness)
    dgg:DGI_2781 (138 target-flexibility) (138 robustness)
    dgg:DGI_2795 (1169 target-flexibility) (76 robustness)
    dgg:DGI_2876 (0 target-flexibility) (0 robustness)
    dgg:DGI_2938 (706 target-flexibility) (173 robustness)
    dgg:DGI_2942 (706 target-flexibility) (173 robustness)
    dgg:DGI_3014 (0 target-flexibility) (0 robustness)
    dgg:DGI_3030 (0 target-flexibility) (0 robustness)
    dgg:DGI_3042 (706 target-flexibility) (173 robustness)
    dgg:DGI_3046 (706 target-flexibility) (173 robustness)
    dgg:DGI_3110 (0 target-flexibility) (0 robustness)
    dgg:DGI_3140 (0 target-flexibility) (0 robustness)
    dgg:DGI_3260 (434 target-flexibility) (67 robustness)
    dgg:DGI_3263 (841 target-flexibility) (126 robustness)
    dgg:DGI_3398 (358 target-flexibility) (104 robustness)
    dgg:DGI_3482 (902 target-flexibility) (228 robustness)
    dgg:DGI_3493 (0 target-flexibility) (0 robustness)
    dgg:DGI_3507 (902 target-flexibility) (228 robustness)
    dgg:DGI_3520 (357 target-flexibility) (102 robustness)
    dgg:DGI_4014 (0 target-flexibility) (0 robustness)
    dgg:DGI_4019 (821 target-flexibility) (137 robustness)
    dhy:DESAM_10054 (71 target-flexibility) (71 robustness)
    dhy:DESAM_10059 (62 target-flexibility) (62 robustness)
    dhy:DESAM_10157 (358 target-flexibility) (104 robustness)
    dhy:DESAM_10178 (711 target-flexibility) (104 robustness)
    dhy:DESAM_10265 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20002 (239 target-flexibility) (99 robustness)
    dhy:DESAM_20071 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20072 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20147 (80 target-flexibility) (80 robustness)
    dhy:DESAM_20155 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20160 (1169 target-flexibility) (76 robustness)
    dhy:DESAM_20241 (1108 target-flexibility) (319 robustness)
    dhy:DESAM_20242 (659 target-flexibility) (240 robustness)
    dhy:DESAM_20244 (703 target-flexibility) (319 robustness)
    dhy:DESAM_20245 (1066 target-flexibility) (75 robustness)
    dhy:DESAM_20254 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20295 (821 target-flexibility) (137 robustness)
    dhy:DESAM_20338 (796 target-flexibility) (85 robustness)
    dhy:DESAM_20373 (358 target-flexibility) (104 robustness)
    dhy:DESAM_20409 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20444 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20447 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20480 (212 target-flexibility) (73 robustness)
    dhy:DESAM_20492 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20564 (790 target-flexibility) (134 robustness)
    dhy:DESAM_20574 (752 target-flexibility) (76 robustness)
    dhy:DESAM_20586 (528 target-flexibility) (157 robustness)
    dhy:DESAM_20633 (790 target-flexibility) (134 robustness)
    dhy:DESAM_20683 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20696 (821 target-flexibility) (137 robustness)
    dhy:DESAM_20710 (897 target-flexibility) (71 robustness)
    dhy:DESAM_20726 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20796 (1385 target-flexibility) (204 robustness)
    dhy:DESAM_20814 (600 target-flexibility) (126 robustness)
    dhy:DESAM_20816 (138 target-flexibility) (138 robustness)
    dhy:DESAM_20863 (790 target-flexibility) (134 robustness)
    dhy:DESAM_20884 (1041 target-flexibility) (243 robustness)
    dhy:DESAM_20902 (1108 target-flexibility) (319 robustness)
    dhy:DESAM_20916 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20933 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20948 (62 target-flexibility) (62 robustness)
    dhy:DESAM_20949 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20962 (821 target-flexibility) (137 robustness)
    dhy:DESAM_20985 (414 target-flexibility) (96 robustness)
    dhy:DESAM_21103 (1385 target-flexibility) (204 robustness)
    dhy:DESAM_21153 (703 target-flexibility) (319 robustness)
    dhy:DESAM_21156 (659 target-flexibility) (240 robustness)
    dhy:DESAM_21172 (1041 target-flexibility) (243 robustness)
    dhy:DESAM_21173 (1041 target-flexibility) (243 robustness)
    dhy:DESAM_21286 (0 target-flexibility) (0 robustness)
    dhy:DESAM_21414 (686 target-flexibility) (192 robustness)
    dhy:DESAM_21448 (706 target-flexibility) (173 robustness)
    dhy:DESAM_21558 (686 target-flexibility) (192 robustness)
    dhy:DESAM_21598 (0 target-flexibility) (0 robustness)
    dhy:DESAM_21612 (790 target-flexibility) (134 robustness)
    dhy:DESAM_21666 (0 target-flexibility) (0 robustness)
    dhy:DESAM_21680 (289 target-flexibility) (73 robustness)
    dhy:DESAM_21809 (206 target-flexibility) (68 robustness)
    dhy:DESAM_21837 (0 target-flexibility) (0 robustness)
    dhy:DESAM_21850 (706 target-flexibility) (173 robustness)
    dhy:DESAM_21922 (841 target-flexibility) (126 robustness)
    dhy:DESAM_21926 (434 target-flexibility) (67 robustness)
    dhy:DESAM_22043 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22057 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22128 (138 target-flexibility) (138 robustness)
    dhy:DESAM_22139 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22144 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22147 (659 target-flexibility) (240 robustness)
    dhy:DESAM_22210 (706 target-flexibility) (173 robustness)
    dhy:DESAM_22216 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22222 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22252 (222 target-flexibility) (83 robustness)
    dhy:DESAM_22258 (841 target-flexibility) (126 robustness)
    dhy:DESAM_22296 (239 target-flexibility) (99 robustness)
    dhy:DESAM_22317 (330 target-flexibility) (76 robustness)
    dhy:DESAM_22335 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22360 (600 target-flexibility) (126 robustness)
    dhy:DESAM_22412 (138 target-flexibility) (66 robustness)
    dhy:DESAM_22427 (902 target-flexibility) (228 robustness)
    dhy:DESAM_22453 (138 target-flexibility) (138 robustness)
    dhy:DESAM_22470 (732 target-flexibility) (78 robustness)
    dhy:DESAM_22526 (711 target-flexibility) (104 robustness)
    dhy:DESAM_22537 (902 target-flexibility) (228 robustness)
    dhy:DESAM_22538 (902 target-flexibility) (228 robustness)
    dhy:DESAM_22632 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22644 (1066 target-flexibility) (75 robustness)
    dhy:DESAM_22667 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22801 (902 target-flexibility) (228 robustness)
    dhy:DESAM_22936 (390 target-flexibility) (74 robustness)
    dhy:DESAM_22951 (414 target-flexibility) (96 robustness)
    dhy:DESAM_22954 (600 target-flexibility) (126 robustness)
    dhy:DESAM_22955 (390 target-flexibility) (74 robustness)
    dhy:DESAM_22957 (330 target-flexibility) (76 robustness)
    dhy:DESAM_22958 (1041 target-flexibility) (243 robustness)
    dhy:DESAM_23096 (0 target-flexibility) (0 robustness)
    dma:DMR_00110 (0 target-flexibility) (0 robustness)
    dma:DMR_00430 (0 target-flexibility) (0 robustness)
    dma:DMR_00560 (821 target-flexibility) (137 robustness)
    dma:DMR_01800 (0 target-flexibility) (0 robustness)
    dma:DMR_01890 (0 target-flexibility) (0 robustness)
    dma:DMR_02050 (212 target-flexibility) (73 robustness)
    dma:DMR_02170 (76 target-flexibility) (76 robustness)
    dma:DMR_02380 (0 target-flexibility) (0 robustness)
    dma:DMR_04400 (0 target-flexibility) (0 robustness)
    dma:DMR_04560 (0 target-flexibility) (0 robustness)
    dma:DMR_05110 (0 target-flexibility) (0 robustness)
    dma:DMR_05260 (686 target-flexibility) (192 robustness)
    dma:DMR_05730 (301 target-flexibility) (154 robustness)
    dma:DMR_05740 (301 target-flexibility) (154 robustness)
    dma:DMR_06660 (790 target-flexibility) (134 robustness)
    dma:DMR_07470 (0 target-flexibility) (0 robustness)
    dma:DMR_09030 (0 target-flexibility) (0 robustness)
    dma:DMR_10970 (0 target-flexibility) (0 robustness)
    dma:DMR_11010 (0 target-flexibility) (0 robustness)
    dma:DMR_11340 (0 target-flexibility) (0 robustness)
    dma:DMR_13630 (138 target-flexibility) (138 robustness)
    dma:DMR_14920 (1066 target-flexibility) (75 robustness)
    dma:DMR_15980 (841 target-flexibility) (126 robustness)
    dma:DMR_16010 (434 target-flexibility) (67 robustness)
    dma:DMR_16700 (0 target-flexibility) (0 robustness)
    dma:DMR_16990 (0 target-flexibility) (0 robustness)
    dma:DMR_17120 (528 target-flexibility) (157 robustness)
    dma:DMR_17130 (701 target-flexibility) (106 robustness)
    dma:DMR_17770 (790 target-flexibility) (134 robustness)
    dma:DMR_17800 (138 target-flexibility) (138 robustness)
    dma:DMR_17880 (841 target-flexibility) (126 robustness)
    dma:DMR_18200 (334 target-flexibility) (71 robustness)
    dma:DMR_19210 (600 target-flexibility) (126 robustness)
    dma:DMR_19340 (0 target-flexibility) (0 robustness)
    dma:DMR_19490 (686 target-flexibility) (192 robustness)
    dma:DMR_19670 (790 target-flexibility) (134 robustness)
    dma:DMR_20060 (0 target-flexibility) (0 robustness)
    dma:DMR_21220 (239 target-flexibility) (99 robustness)
    dma:DMR_21290 (239 target-flexibility) (99 robustness)
    dma:DMR_21660 (138 target-flexibility) (138 robustness)
    dma:DMR_21830 (902 target-flexibility) (228 robustness)
    dma:DMR_22170 (222 target-flexibility) (83 robustness)
    dma:DMR_22790 (659 target-flexibility) (240 robustness)
    dma:DMR_23160 (358 target-flexibility) (104 robustness)
    dma:DMR_25440 (0 target-flexibility) (0 robustness)
    dma:DMR_27000 (0 target-flexibility) (0 robustness)
    dma:DMR_28090 (706 target-flexibility) (173 robustness)
    dma:DMR_28220 (289 target-flexibility) (73 robustness)
    dma:DMR_28600 (0 target-flexibility) (0 robustness)
    dma:DMR_28790 (600 target-flexibility) (126 robustness)
    dma:DMR_30710 (358 target-flexibility) (104 robustness)
    dma:DMR_33250 (76 target-flexibility) (76 robustness)
    dma:DMR_34180 (902 target-flexibility) (228 robustness)
    dma:DMR_34300 (301 target-flexibility) (154 robustness)
    dma:DMR_34310 (301 target-flexibility) (154 robustness)
    dma:DMR_34740 (1385 target-flexibility) (204 robustness)
    dma:DMR_35020 (706 target-flexibility) (173 robustness)
    dma:DMR_37080 (701 target-flexibility) (106 robustness)
    dma:DMR_37110 (334 target-flexibility) (71 robustness)
    dma:DMR_37140 (528 target-flexibility) (157 robustness)
    dma:DMR_37150 (0 target-flexibility) (0 robustness)
    dma:DMR_37260 (706 target-flexibility) (173 robustness)
    dma:DMR_38720 (706 target-flexibility) (173 robustness)
    dma:DMR_39240 (0 target-flexibility) (0 robustness)
    dma:DMR_39860 (357 target-flexibility) (102 robustness)
    dma:DMR_39960 (659 target-flexibility) (240 robustness)
    dma:DMR_39990 (1066 target-flexibility) (75 robustness)
    dma:DMR_42440 (706 target-flexibility) (173 robustness)
    dma:DMR_42760 (821 target-flexibility) (137 robustness)
    dma:DMR_44510 (405 target-flexibility) (70 robustness)
    dma:DMR_45660 (0 target-flexibility) (0 robustness)
    dma:DMR_45930 (1385 target-flexibility) (204 robustness)
    dml:Dmul_00120 (600 target-flexibility) (126 robustness)
    dml:Dmul_00400 (0 target-flexibility) (0 robustness)
    dml:Dmul_00440 (855 target-flexibility) (138 robustness)
    dml:Dmul_00590 (558 target-flexibility) (68 robustness)
    dml:Dmul_01560 (0 target-flexibility) (0 robustness)
    dml:Dmul_01640 (0 target-flexibility) (0 robustness)
    dml:Dmul_01800 (0 target-flexibility) (0 robustness)
    dml:Dmul_03450 (64 target-flexibility) (64 robustness)
    dml:Dmul_03970 (91 target-flexibility) (91 robustness)
    dml:Dmul_05580 (405 target-flexibility) (169 robustness)
    dml:Dmul_05590 (732 target-flexibility) (78 robustness)
    dml:Dmul_06060 (138 target-flexibility) (138 robustness)
    dml:Dmul_07460 (0 target-flexibility) (0 robustness)
    dml:Dmul_07490 (0 target-flexibility) (0 robustness)
    dml:Dmul_07680 (752 target-flexibility) (105 robustness)
    dml:Dmul_07750 (138 target-flexibility) (138 robustness)
    dml:Dmul_08540 (0 target-flexibility) (0 robustness)
    dml:Dmul_08800 (657 target-flexibility) (95 robustness)
    dml:Dmul_08960 (289 target-flexibility) (73 robustness)
    dml:Dmul_09400 (752 target-flexibility) (105 robustness)
    dml:Dmul_09580 (0 target-flexibility) (0 robustness)
    dml:Dmul_10150 (752 target-flexibility) (76 robustness)
    dml:Dmul_11080 (0 target-flexibility) (0 robustness)
    dml:Dmul_11190 (855 target-flexibility) (138 robustness)
    dml:Dmul_12180 (1108 target-flexibility) (319 robustness)
    dml:Dmul_14330 (358 target-flexibility) (104 robustness)
    dml:Dmul_14360 (1183 target-flexibility) (114 robustness)
    dml:Dmul_14400 (691 target-flexibility) (528 robustness)
    dml:Dmul_15200 (732 target-flexibility) (78 robustness)
    dml:Dmul_15210 (405 target-flexibility) (169 robustness)
    dml:Dmul_15350 (138 target-flexibility) (138 robustness)
    dml:Dmul_15430 (686 target-flexibility) (192 robustness)
    dml:Dmul_15560 (558 target-flexibility) (68 robustness)
    dml:Dmul_15600 (691 target-flexibility) (528 robustness)
    dml:Dmul_16000 (0 target-flexibility) (0 robustness)
    dml:Dmul_16500 (634 target-flexibility) (72 robustness)
    dml:Dmul_16810 (0 target-flexibility) (0 robustness)
    dml:Dmul_18930 (71 target-flexibility) (71 robustness)
    dml:Dmul_19320 (790 target-flexibility) (134 robustness)
    dml:Dmul_19830 (1385 target-flexibility) (204 robustness)
    dml:Dmul_20530 (377 target-flexibility) (117 robustness)
    dml:Dmul_20590 (222 target-flexibility) (83 robustness)
    dml:Dmul_20930 (323 target-flexibility) (101 robustness)
    dml:Dmul_21160 (634 target-flexibility) (72 robustness)
    dml:Dmul_21170 (215 target-flexibility) (142 robustness)
    dml:Dmul_21250 (0 target-flexibility) (0 robustness)
    dml:Dmul_21290 (0 target-flexibility) (0 robustness)
    dml:Dmul_21510 (659 target-flexibility) (240 robustness)
    dml:Dmul_21830 (790 target-flexibility) (134 robustness)
    dml:Dmul_22280 (0 target-flexibility) (0 robustness)
    dml:Dmul_22400 (358 target-flexibility) (104 robustness)
    dml:Dmul_22810 (0 target-flexibility) (0 robustness)
    dml:Dmul_22820 (377 target-flexibility) (117 robustness)
    dml:Dmul_22850 (752 target-flexibility) (76 robustness)
    dml:Dmul_22990 (0 target-flexibility) (0 robustness)
    dml:Dmul_23060 (0 target-flexibility) (0 robustness)
    dml:Dmul_23280 (0 target-flexibility) (0 robustness)
    dml:Dmul_23530 (841 target-flexibility) (126 robustness)
    dml:Dmul_23540 (841 target-flexibility) (126 robustness)
    dml:Dmul_23620 (790 target-flexibility) (134 robustness)
    dml:Dmul_24040 (0 target-flexibility) (0 robustness)
    dml:Dmul_24260 (0 target-flexibility) (0 robustness)
    dml:Dmul_24630 (0 target-flexibility) (0 robustness)
    dml:Dmul_24950 (659 target-flexibility) (240 robustness)
    dml:Dmul_25270 (64 target-flexibility) (64 robustness)
    dml:Dmul_25380 (528 target-flexibility) (157 robustness)
    dml:Dmul_26870 (138 target-flexibility) (138 robustness)
    dml:Dmul_27020 (0 target-flexibility) (0 robustness)
    dml:Dmul_27550 (657 target-flexibility) (95 robustness)
    dml:Dmul_27750 (70 target-flexibility) (70 robustness)
    dml:Dmul_27780 (140 target-flexibility) (71 robustness)
    dml:Dmul_27800 (67 target-flexibility) (67 robustness)
    dml:Dmul_27810 (239 target-flexibility) (67 robustness)
    dml:Dmul_28060 (659 target-flexibility) (240 robustness)
    dml:Dmul_28240 (0 target-flexibility) (0 robustness)
    dml:Dmul_28270 (0 target-flexibility) (0 robustness)
    dml:Dmul_28300 (0 target-flexibility) (0 robustness)
    dml:Dmul_28400 (686 target-flexibility) (192 robustness)
    dml:Dmul_30910 (600 target-flexibility) (126 robustness)
    dml:Dmul_31150 (0 target-flexibility) (0 robustness)
    dml:Dmul_31220 (924 target-flexibility) (101 robustness)
    dml:Dmul_31480 (659 target-flexibility) (240 robustness)
    dml:Dmul_32700 (0 target-flexibility) (0 robustness)
    dml:Dmul_32710 (0 target-flexibility) (0 robustness)
    dml:Dmul_34340 (0 target-flexibility) (0 robustness)
    dml:Dmul_34350 (0 target-flexibility) (0 robustness)
    dml:Dmul_34490 (1183 target-flexibility) (114 robustness)
    dml:Dmul_34830 (323 target-flexibility) (101 robustness)
    dml:Dmul_34880 (1385 target-flexibility) (204 robustness)
    dml:Dmul_35200 (924 target-flexibility) (101 robustness)
    dml:Dmul_35620 (434 target-flexibility) (67 robustness)
    dml:Dmul_36330 (1108 target-flexibility) (319 robustness)
    dml:Dmul_36880 (0 target-flexibility) (0 robustness)
    dml:Dmul_38190 (91 target-flexibility) (91 robustness)
    dml:Dmul_38690 (215 target-flexibility) (142 robustness)
    dml:Dmul_38810 (212 target-flexibility) (73 robustness)
    dml:Dmul_38840 (0 target-flexibility) (0 robustness)
    doa:AXF15_00335 (732 target-flexibility) (78 robustness)
    doa:AXF15_00575 (821 target-flexibility) (137 robustness)
    doa:AXF15_00690 (0 target-flexibility) (0 robustness)
    doa:AXF15_01445 (700 target-flexibility) (77 robustness)
    doa:AXF15_01830 (701 target-flexibility) (106 robustness)
    doa:AXF15_02145 (138 target-flexibility) (66 robustness)
    doa:AXF15_02215 (0 target-flexibility) (0 robustness)
    doa:AXF15_02480 (1385 target-flexibility) (204 robustness)
    doa:AXF15_02605 (821 target-flexibility) (137 robustness)
    doa:AXF15_03010 (1385 target-flexibility) (204 robustness)
    doa:AXF15_03265 (790 target-flexibility) (134 robustness)
    doa:AXF15_03465 (0 target-flexibility) (0 robustness)
    doa:AXF15_03650 (80 target-flexibility) (80 robustness)
    doa:AXF15_03730 (600 target-flexibility) (126 robustness)
    doa:AXF15_04035 (659 target-flexibility) (240 robustness)
    doa:AXF15_04135 (357 target-flexibility) (102 robustness)
    doa:AXF15_04310 (0 target-flexibility) (0 robustness)
    doa:AXF15_04445 (0 target-flexibility) (0 robustness)
    doa:AXF15_04685 (700 target-flexibility) (77 robustness)
    doa:AXF15_04690 (335 target-flexibility) (69 robustness)
    doa:AXF15_04820 (796 target-flexibility) (85 robustness)
    doa:AXF15_04965 (0 target-flexibility) (0 robustness)
    doa:AXF15_04970 (0 target-flexibility) (0 robustness)
    doa:AXF15_05040 (897 target-flexibility) (71 robustness)
    doa:AXF15_05165 (600 target-flexibility) (126 robustness)
    doa:AXF15_05690 (841 target-flexibility) (126 robustness)
    doa:AXF15_05735 (0 target-flexibility) (0 robustness)
    doa:AXF15_05770 (706 target-flexibility) (173 robustness)
    doa:AXF15_05775 (706 target-flexibility) (173 robustness)
    doa:AXF15_06215 (821 target-flexibility) (137 robustness)
    doa:AXF15_06240 (703 target-flexibility) (319 robustness)
    doa:AXF15_06350 (659 target-flexibility) (240 robustness)
    doa:AXF15_06360 (703 target-flexibility) (319 robustness)
    doa:AXF15_06400 (0 target-flexibility) (0 robustness)
    doa:AXF15_07580 (706 target-flexibility) (173 robustness)
    doa:AXF15_07625 (528 target-flexibility) (157 robustness)
    doa:AXF15_07630 (701 target-flexibility) (106 robustness)
    doa:AXF15_08605 (222 target-flexibility) (83 robustness)
    doa:AXF15_08610 (0 target-flexibility) (0 robustness)
    doa:AXF15_08670 (289 target-flexibility) (73 robustness)
    doa:AXF15_08785 (703 target-flexibility) (319 robustness)
    doa:AXF15_09000 (0 target-flexibility) (0 robustness)
    doa:AXF15_09390 (790 target-flexibility) (134 robustness)
    doa:AXF15_09515 (358 target-flexibility) (104 robustness)
    doa:AXF15_09785 (790 target-flexibility) (134 robustness)
    doa:AXF15_10405 (0 target-flexibility) (0 robustness)
    doa:AXF15_10595 (0 target-flexibility) (0 robustness)
    doa:AXF15_11000 (357 target-flexibility) (102 robustness)
    doa:AXF15_11370 (357 target-flexibility) (102 robustness)
    doa:AXF15_11375 (0 target-flexibility) (0 robustness)
    doa:AXF15_11595 (212 target-flexibility) (73 robustness)
    doa:AXF15_11865 (434 target-flexibility) (67 robustness)
    doa:AXF15_11880 (841 target-flexibility) (126 robustness)
    doa:AXF15_11960 (0 target-flexibility) (0 robustness)
    doa:AXF15_12135 (335 target-flexibility) (69 robustness)
    dol:Dole_0026 (924 target-flexibility) (101 robustness)
    dol:Dole_0063 (0 target-flexibility) (0 robustness)
    dol:Dole_0121 (405 target-flexibility) (169 robustness)
    dol:Dole_0122 (732 target-flexibility) (78 robustness)
    dol:Dole_0128 (343 target-flexibility) (180 robustness)
    dol:Dole_0164 (0 target-flexibility) (0 robustness)
    dol:Dole_0187 (700 target-flexibility) (89 robustness)
    dol:Dole_0202 (0 target-flexibility) (0 robustness)
    dol:Dole_0222 (600 target-flexibility) (126 robustness)
    dol:Dole_0261 (691 target-flexibility) (528 robustness)
    dol:Dole_0314 (0 target-flexibility) (0 robustness)
    dol:Dole_0337 (0 target-flexibility) (0 robustness)
    dol:Dole_0367 (1041 target-flexibility) (243 robustness)
    dol:Dole_0514 (897 target-flexibility) (71 robustness)
    dol:Dole_0542 (691 target-flexibility) (528 robustness)
    dol:Dole_0559 (0 target-flexibility) (0 robustness)
    dol:Dole_0582 (0 target-flexibility) (0 robustness)
    dol:Dole_0670 (752 target-flexibility) (76 robustness)
    dol:Dole_0679 (0 target-flexibility) (0 robustness)
    dol:Dole_0683 (0 target-flexibility) (0 robustness)
    dol:Dole_0756 (358 target-flexibility) (124 robustness)
    dol:Dole_0783 (0 target-flexibility) (0 robustness)
    dol:Dole_0838 (0 target-flexibility) (0 robustness)
    dol:Dole_0966 (377 target-flexibility) (117 robustness)
    dol:Dole_0983 (343 target-flexibility) (180 robustness)
    dol:Dole_1002 (0 target-flexibility) (0 robustness)
    dol:Dole_1010 (0 target-flexibility) (0 robustness)
    dol:Dole_1012 (0 target-flexibility) (0 robustness)
    dol:Dole_1021 (497 target-flexibility) (186 robustness)
    dol:Dole_1068 (879 target-flexibility) (71 robustness)
    dol:Dole_1107 (821 target-flexibility) (137 robustness)
    dol:Dole_1130 (1041 target-flexibility) (243 robustness)
    dol:Dole_1132 (80 target-flexibility) (80 robustness)
    dol:Dole_1166 (358 target-flexibility) (104 robustness)
    dol:Dole_1191 (222 target-flexibility) (83 robustness)
    dol:Dole_1326 (902 target-flexibility) (228 robustness)
    dol:Dole_1355 (706 target-flexibility) (173 robustness)
    dol:Dole_1426 (231 target-flexibility) (158 robustness)
    dol:Dole_1564 (686 target-flexibility) (192 robustness)
    dol:Dole_1608 (659 target-flexibility) (240 robustness)
    dol:Dole_1729 (212 target-flexibility) (73 robustness)
    dol:Dole_1848 (0 target-flexibility) (0 robustness)
    dol:Dole_1881 (343 target-flexibility) (180 robustness)
    dol:Dole_1908 (289 target-flexibility) (73 robustness)
    dol:Dole_1973 (790 target-flexibility) (134 robustness)
    dol:Dole_2040 (841 target-flexibility) (126 robustness)
    dol:Dole_2786 (70 target-flexibility) (70 robustness)
    dol:Dole_2791 (67 target-flexibility) (67 robustness)
    dpb:BABL1_gene_13 (0 target-flexibility) (0 robustness)
    dpb:BABL1_gene_199 (212 target-flexibility) (73 robustness)
    dpb:BABL1_gene_330 (752 target-flexibility) (76 robustness)
    dpb:BABL1_gene_5 (1935 target-flexibility) (162 robustness)
    dpb:BABL1_gene_545 (138 target-flexibility) (138 robustness)
    dpb:BABL1_gene_6 (1935 target-flexibility) (162 robustness)
    dpb:BABL1_gene_705 (71 target-flexibility) (71 robustness)
    dpb:BABL1_gene_809 (138 target-flexibility) (138 robustness)
    dpb:BABL1_gene_827 (138 target-flexibility) (138 robustness)
    dpb:BABL1_gene_858 (222 target-flexibility) (83 robustness)
    dpb:BABL1_gene_980 (138 target-flexibility) (138 robustness)
    dpg:DESPIGER_0283 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_0323 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_0326 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_0351 (357 target-flexibility) (115 robustness)
    dpg:DESPIGER_0488 (357 target-flexibility) (115 robustness)
    dpg:DESPIGER_0493 (686 target-flexibility) (192 robustness)
    dpg:DESPIGER_0549 (706 target-flexibility) (173 robustness)
    dpg:DESPIGER_0552 (706 target-flexibility) (173 robustness)
    dpg:DESPIGER_0559 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_0649 (706 target-flexibility) (173 robustness)
    dpg:DESPIGER_0682 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_0694 (138 target-flexibility) (138 robustness)
    dpg:DESPIGER_0969 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1072 (703 target-flexibility) (319 robustness)
    dpg:DESPIGER_1079 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1110 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1191 (357 target-flexibility) (102 robustness)
    dpg:DESPIGER_1250 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1284 (222 target-flexibility) (83 robustness)
    dpg:DESPIGER_1297 (790 target-flexibility) (134 robustness)
    dpg:DESPIGER_1352 (686 target-flexibility) (192 robustness)
    dpg:DESPIGER_1482 (706 target-flexibility) (173 robustness)
    dpg:DESPIGER_1531 (80 target-flexibility) (80 robustness)
    dpg:DESPIGER_1545 (434 target-flexibility) (67 robustness)
    dpg:DESPIGER_1552 (103 target-flexibility) (103 robustness)
    dpg:DESPIGER_1638 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1704 (1385 target-flexibility) (204 robustness)
    dpg:DESPIGER_1719 (357 target-flexibility) (102 robustness)
    dpg:DESPIGER_1797 (289 target-flexibility) (73 robustness)
    dpg:DESPIGER_1814 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1815 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1830 (1385 target-flexibility) (204 robustness)
    dpg:DESPIGER_1832 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1840 (600 target-flexibility) (126 robustness)
    dpg:DESPIGER_1913 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1949 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_2055 (103 target-flexibility) (103 robustness)
    dpg:DESPIGER_2071 (600 target-flexibility) (126 robustness)
    dpg:DESPIGER_2129 (212 target-flexibility) (73 robustness)
    dpg:DESPIGER_2402 (703 target-flexibility) (319 robustness)
    dpg:DESPIGER_2419 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_2427 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_2441 (138 target-flexibility) (138 robustness)
    dpi:BN4_10025 (301 target-flexibility) (154 robustness)
    dpi:BN4_10026 (301 target-flexibility) (154 robustness)
    dpi:BN4_10112 (841 target-flexibility) (126 robustness)
    dpi:BN4_10115 (434 target-flexibility) (67 robustness)
    dpi:BN4_10127 (0 target-flexibility) (0 robustness)
    dpi:BN4_10161 (138 target-flexibility) (138 robustness)
    dpi:BN4_10196 (71 target-flexibility) (71 robustness)
    dpi:BN4_10242 (279 target-flexibility) (126 robustness)
    dpi:BN4_10265 (711 target-flexibility) (104 robustness)
    dpi:BN4_10278 (0 target-flexibility) (0 robustness)
    dpi:BN4_10320 (138 target-flexibility) (138 robustness)
    dpi:BN4_10344 (0 target-flexibility) (0 robustness)
    dpi:BN4_10368 (902 target-flexibility) (228 robustness)
    dpi:BN4_10369 (902 target-flexibility) (228 robustness)
    dpi:BN4_10393 (222 target-flexibility) (83 robustness)
    dpi:BN4_10396 (528 target-flexibility) (157 robustness)
    dpi:BN4_10404 (902 target-flexibility) (228 robustness)
    dpi:BN4_10420 (706 target-flexibility) (173 robustness)
    dpi:BN4_10458 (854 target-flexibility) (204 robustness)
    dpi:BN4_10478 (0 target-flexibility) (0 robustness)
    dpi:BN4_10485 (841 target-flexibility) (126 robustness)
    dpi:BN4_10583 (301 target-flexibility) (154 robustness)
    dpi:BN4_10584 (301 target-flexibility) (154 robustness)
    dpi:BN4_10697 (706 target-flexibility) (173 robustness)
    dpi:BN4_10725 (711 target-flexibility) (104 robustness)
    dpi:BN4_10871 (0 target-flexibility) (0 robustness)
    dpi:BN4_10876 (0 target-flexibility) (0 robustness)
    dpi:BN4_10961 (0 target-flexibility) (0 robustness)
    dpi:BN4_10996 (0 target-flexibility) (0 robustness)
    dpi:BN4_11008 (358 target-flexibility) (104 robustness)
    dpi:BN4_11060 (0 target-flexibility) (0 robustness)
    dpi:BN4_11230 (528 target-flexibility) (157 robustness)
    dpi:BN4_11318 (0 target-flexibility) (0 robustness)
    dpi:BN4_11354 (80 target-flexibility) (80 robustness)
    dpi:BN4_11368 (659 target-flexibility) (240 robustness)
    dpi:BN4_11381 (138 target-flexibility) (138 robustness)
    dpi:BN4_11407 (289 target-flexibility) (73 robustness)
    dpi:BN4_11611 (659 target-flexibility) (240 robustness)
    dpi:BN4_11683 (0 target-flexibility) (0 robustness)
    dpi:BN4_11717 (80 target-flexibility) (80 robustness)
    dpi:BN4_11826 (358 target-flexibility) (104 robustness)
    dpi:BN4_11854 (0 target-flexibility) (0 robustness)
    dpi:BN4_11857 (0 target-flexibility) (0 robustness)
    dpi:BN4_11868 (854 target-flexibility) (204 robustness)
    dpi:BN4_11936 (212 target-flexibility) (73 robustness)
    dpi:BN4_11977 (752 target-flexibility) (76 robustness)
    dpi:BN4_12054 (790 target-flexibility) (134 robustness)
    dpi:BN4_12061 (0 target-flexibility) (0 robustness)
    dpi:BN4_12067 (821 target-flexibility) (137 robustness)
    dpi:BN4_12189 (821 target-flexibility) (137 robustness)
    dpi:BN4_12214 (0 target-flexibility) (0 robustness)
    dpi:BN4_12231 (0 target-flexibility) (0 robustness)
    dpi:BN4_12300 (902 target-flexibility) (228 robustness)
    dpi:BN4_12384 (790 target-flexibility) (134 robustness)
    dpi:BN4_12469 (0 target-flexibility) (0 robustness)
    dpi:BN4_12531 (1385 target-flexibility) (204 robustness)
    dpi:BN4_12584 (790 target-flexibility) (134 robustness)
    dpi:BN4_12643 (0 target-flexibility) (0 robustness)
    dpi:BN4_12690 (821 target-flexibility) (137 robustness)
    dpi:BN4_12775 (1385 target-flexibility) (204 robustness)
    dpi:BN4_12812 (0 target-flexibility) (0 robustness)
    dpi:BN4_20024 (706 target-flexibility) (173 robustness)
    dpi:BN4_20088 (706 target-flexibility) (173 robustness)
    dpi:BN4_20265 (0 target-flexibility) (0 robustness)
    dpi:BN4_20324 (0 target-flexibility) (0 robustness)
    dpi:BN4_20344 (219 target-flexibility) (63 robustness)
    dpi:BN4_20389 (279 target-flexibility) (126 robustness)
    dpi:BN4_20419 (219 target-flexibility) (63 robustness)
    dpr:Despr_0075 (0 target-flexibility) (0 robustness)
    dpr:Despr_0082 (0 target-flexibility) (0 robustness)
    dpr:Despr_0279 (0 target-flexibility) (0 robustness)
    dpr:Despr_0281 (924 target-flexibility) (101 robustness)
    dpr:Despr_0314 (691 target-flexibility) (528 robustness)
    dpr:Despr_0363 (0 target-flexibility) (0 robustness)
    dpr:Despr_0386 (0 target-flexibility) (0 robustness)
    dpr:Despr_0441 (902 target-flexibility) (228 robustness)
    dpr:Despr_0517 (138 target-flexibility) (66 robustness)
    dpr:Despr_0555 (0 target-flexibility) (0 robustness)
    dpr:Despr_0559 (0 target-flexibility) (0 robustness)
    dpr:Despr_0574 (289 target-flexibility) (73 robustness)
    dpr:Despr_0744 (924 target-flexibility) (101 robustness)
    dpr:Despr_0827 (700 target-flexibility) (80 robustness)
    dpr:Despr_0862 (1385 target-flexibility) (204 robustness)
    dpr:Despr_0909 (434 target-flexibility) (67 robustness)
    dpr:Despr_0910 (657 target-flexibility) (95 robustness)
    dpr:Despr_0918 (71 target-flexibility) (71 robustness)
    dpr:Despr_0929 (405 target-flexibility) (169 robustness)
    dpr:Despr_1050 (1385 target-flexibility) (204 robustness)
    dpr:Despr_1373 (0 target-flexibility) (0 robustness)
    dpr:Despr_1394 (902 target-flexibility) (228 robustness)
    dpr:Despr_1502 (790 target-flexibility) (134 robustness)
    dpr:Despr_1504 (924 target-flexibility) (101 robustness)
    dpr:Despr_1528 (732 target-flexibility) (78 robustness)
    dpr:Despr_1538 (0 target-flexibility) (0 robustness)
    dpr:Despr_1637 (0 target-flexibility) (0 robustness)
    dpr:Despr_1640 (138 target-flexibility) (138 robustness)
    dpr:Despr_1674 (0 target-flexibility) (0 robustness)
    dpr:Despr_1776 (841 target-flexibility) (126 robustness)
    dpr:Despr_1832 (0 target-flexibility) (0 robustness)
    dpr:Despr_1881 (0 target-flexibility) (0 robustness)
    dpr:Despr_1896 (0 target-flexibility) (0 robustness)
    dpr:Despr_1916 (691 target-flexibility) (528 robustness)
    dpr:Despr_1928 (0 target-flexibility) (0 robustness)
    dpr:Despr_1962 (0 target-flexibility) (0 robustness)
    dpr:Despr_2003 (0 target-flexibility) (0 robustness)
    dpr:Despr_2009 (703 target-flexibility) (319 robustness)
    dpr:Despr_2011 (659 target-flexibility) (240 robustness)
    dpr:Despr_2042 (706 target-flexibility) (173 robustness)
    dpr:Despr_2089 (0 target-flexibility) (0 robustness)
    dpr:Despr_2092 (0 target-flexibility) (0 robustness)
    dpr:Despr_2093 (0 target-flexibility) (0 robustness)
    dpr:Despr_2189 (138 target-flexibility) (138 robustness)
    dpr:Despr_2283 (358 target-flexibility) (104 robustness)
    dpr:Despr_2289 (239 target-flexibility) (99 robustness)
    dpr:Despr_2311 (841 target-flexibility) (126 robustness)
    dpr:Despr_2324 (239 target-flexibility) (99 robustness)
    dpr:Despr_2346 (686 target-flexibility) (192 robustness)
    dpr:Despr_2376 (686 target-flexibility) (192 robustness)
    dpr:Despr_2394 (222 target-flexibility) (83 robustness)
    dpr:Despr_2467 (0 target-flexibility) (0 robustness)
    dpr:Despr_2483 (657 target-flexibility) (95 robustness)
    dpr:Despr_2500 (659 target-flexibility) (240 robustness)
    dpr:Despr_2534 (902 target-flexibility) (228 robustness)
    dpr:Despr_2589 (700 target-flexibility) (80 robustness)
    dpr:Despr_2665 (659 target-flexibility) (240 robustness)
    dpr:Despr_2670 (703 target-flexibility) (319 robustness)
    dpr:Despr_2672 (790 target-flexibility) (134 robustness)
    dpr:Despr_2721 (732 target-flexibility) (78 robustness)
    dpr:Despr_2776 (752 target-flexibility) (76 robustness)
    dpr:Despr_2813 (706 target-flexibility) (173 robustness)
    dpr:Despr_2865 (706 target-flexibility) (173 robustness)
    dpr:Despr_2867 (706 target-flexibility) (173 robustness)
    dpr:Despr_2873 (706 target-flexibility) (173 robustness)
    dpr:Despr_2908 (0 target-flexibility) (0 robustness)
    dpr:Despr_2956 (138 target-flexibility) (138 robustness)
    dpr:Despr_2958 (80 target-flexibility) (80 robustness)
    dpr:Despr_2977 (600 target-flexibility) (126 robustness)
    dpr:Despr_2980 (1784 target-flexibility) (162 robustness)
    dpr:Despr_2989 (528 target-flexibility) (157 robustness)
    dpr:Despr_3037 (212 target-flexibility) (73 robustness)
    dpr:Despr_3102 (0 target-flexibility) (0 robustness)
    dpr:Despr_3152 (600 target-flexibility) (126 robustness)
    dpr:Despr_3156 (897 target-flexibility) (71 robustness)
    dpr:Despr_3168 (0 target-flexibility) (0 robustness)
    dpr:Despr_3183 (358 target-flexibility) (104 robustness)
    dpr:Despr_3256 (1784 target-flexibility) (162 robustness)
    dpr:Despr_3296 (405 target-flexibility) (169 robustness)
    dpr:Despr_3306 (0 target-flexibility) (0 robustness)
    dpr:Despr_3332 (0 target-flexibility) (0 robustness)
    dps:DP0014 (0 target-flexibility) (0 robustness)
    dps:DP0022 (0 target-flexibility) (0 robustness)
    dps:DP0026 (0 target-flexibility) (0 robustness)
    dps:DP0044 (0 target-flexibility) (0 robustness)
    dps:DP0045 (0 target-flexibility) (0 robustness)
    dps:DP0059 (0 target-flexibility) (0 robustness)
    dps:DP0067 (0 target-flexibility) (0 robustness)
    dps:DP0103 (600 target-flexibility) (126 robustness)
    dps:DP0106 (897 target-flexibility) (71 robustness)
    dps:DP0394 (924 target-flexibility) (101 robustness)
    dps:DP0437 (138 target-flexibility) (66 robustness)
    dps:DP0475 (0 target-flexibility) (0 robustness)
    dps:DP0540 (879 target-flexibility) (71 robustness)
    dps:DP0544 (879 target-flexibility) (71 robustness)
    dps:DP0555 (0 target-flexibility) (0 robustness)
    dps:DP0660 (841 target-flexibility) (126 robustness)
    dps:DP0784 (691 target-flexibility) (528 robustness)
    dps:DP0812 (80 target-flexibility) (80 robustness)
    dps:DP0822 (600 target-flexibility) (126 robustness)
    dps:DP0825 (790 target-flexibility) (134 robustness)
    dps:DP0950 (0 target-flexibility) (0 robustness)
    dps:DP0951 (0 target-flexibility) (0 robustness)
    dps:DP0952 (0 target-flexibility) (0 robustness)
    dps:DP0955 (0 target-flexibility) (0 robustness)
    dps:DP1007 (0 target-flexibility) (0 robustness)
    dps:DP1022 (0 target-flexibility) (0 robustness)
    dps:DP1088 (924 target-flexibility) (101 robustness)
    dps:DP1165 (700 target-flexibility) (80 robustness)
    dps:DP1266 (0 target-flexibility) (0 robustness)
    dps:DP1272 (0 target-flexibility) (0 robustness)
    dps:DP1331 (206 target-flexibility) (68 robustness)
    dps:DP1333 (0 target-flexibility) (0 robustness)
    dps:DP1431 (691 target-flexibility) (528 robustness)
    dps:DP1472 (0 target-flexibility) (0 robustness)
    dps:DP1629 (71 target-flexibility) (71 robustness)
    dps:DP1631 (686 target-flexibility) (192 robustness)
    dps:DP1796 (212 target-flexibility) (73 robustness)
    dps:DP1847 (659 target-flexibility) (240 robustness)
    dps:DP1859 (703 target-flexibility) (319 robustness)
    dps:DP1905 (700 target-flexibility) (80 robustness)
    dps:DP2097 (790 target-flexibility) (134 robustness)
    dps:DP2110 (0 target-flexibility) (0 robustness)
    dps:DP2172 (700 target-flexibility) (89 robustness)
    dps:DP2220 (0 target-flexibility) (0 robustness)
    dps:DP2221 (0 target-flexibility) (0 robustness)
    dps:DP2376 (0 target-flexibility) (0 robustness)
    dps:DP2403 (703 target-flexibility) (319 robustness)
    dps:DP2407 (659 target-flexibility) (240 robustness)
    dps:DP2474 (0 target-flexibility) (0 robustness)
    dps:DP2475 (0 target-flexibility) (0 robustness)
    dps:DP2548 (0 target-flexibility) (0 robustness)
    dps:DP2552 (222 target-flexibility) (83 robustness)
    dps:DP2600 (0 target-flexibility) (0 robustness)
    dps:DP2716 (0 target-flexibility) (0 robustness)
    dps:DP2768 (841 target-flexibility) (126 robustness)
    dps:DP2788 (703 target-flexibility) (319 robustness)
    dps:DP2790 (659 target-flexibility) (240 robustness)
    dps:DP2949 (686 target-flexibility) (192 robustness)
    dps:DP2990 (0 target-flexibility) (0 robustness)
    dps:DP2991 (700 target-flexibility) (89 robustness)
    dps:DPPB37 (790 target-flexibility) (134 robustness)
    dps:DPPB64 (0 target-flexibility) (0 robustness)
    dps:DPPB68 (0 target-flexibility) (0 robustness)
    dps:DPPB70 (0 target-flexibility) (0 robustness)
    drt:Dret_0011 (0 target-flexibility) (0 robustness)
    drt:Dret_0014 (752 target-flexibility) (76 robustness)
    drt:Dret_0042 (0 target-flexibility) (0 robustness)
    drt:Dret_0079 (1385 target-flexibility) (204 robustness)
    drt:Dret_0124 (686 target-flexibility) (192 robustness)
    drt:Dret_0143 (796 target-flexibility) (85 robustness)
    drt:Dret_0199 (0 target-flexibility) (0 robustness)
    drt:Dret_0202 (0 target-flexibility) (0 robustness)
    drt:Dret_0251 (212 target-flexibility) (73 robustness)
    drt:Dret_0307 (0 target-flexibility) (0 robustness)
    drt:Dret_0321 (732 target-flexibility) (78 robustness)
    drt:Dret_0340 (600 target-flexibility) (126 robustness)
    drt:Dret_0439 (289 target-flexibility) (73 robustness)
    drt:Dret_0460 (0 target-flexibility) (0 robustness)
    drt:Dret_0505 (855 target-flexibility) (138 robustness)
    drt:Dret_0537 (358 target-flexibility) (104 robustness)
    drt:Dret_0542 (138 target-flexibility) (138 robustness)
    drt:Dret_0704 (706 target-flexibility) (173 robustness)
    drt:Dret_0730 (0 target-flexibility) (0 robustness)
    drt:Dret_0772 (138 target-flexibility) (138 robustness)
    drt:Dret_0798 (686 target-flexibility) (192 robustness)
    drt:Dret_0818 (790 target-flexibility) (134 robustness)
    drt:Dret_0830 (358 target-flexibility) (104 robustness)
    drt:Dret_1010 (706 target-flexibility) (173 robustness)
    drt:Dret_1046 (0 target-flexibility) (0 robustness)
    drt:Dret_1100 (434 target-flexibility) (67 robustness)
    drt:Dret_1107 (855 target-flexibility) (138 robustness)
    drt:Dret_1118 (222 target-flexibility) (83 robustness)
    drt:Dret_1139 (0 target-flexibility) (0 robustness)
    drt:Dret_1384 (405 target-flexibility) (70 robustness)
    drt:Dret_1385 (528 target-flexibility) (157 robustness)
    drt:Dret_1397 (600 target-flexibility) (126 robustness)
    drt:Dret_1409 (357 target-flexibility) (102 robustness)
    drt:Dret_1425 (0 target-flexibility) (0 robustness)
    drt:Dret_1459 (841 target-flexibility) (126 robustness)
    drt:Dret_1706 (841 target-flexibility) (126 robustness)
    drt:Dret_1756 (0 target-flexibility) (0 robustness)
    drt:Dret_1907 (138 target-flexibility) (138 robustness)
    drt:Dret_1968 (0 target-flexibility) (0 robustness)
    drt:Dret_2027 (1385 target-flexibility) (204 robustness)
    drt:Dret_2034 (0 target-flexibility) (0 robustness)
    drt:Dret_2102 (497 target-flexibility) (186 robustness)
    drt:Dret_2103 (0 target-flexibility) (0 robustness)
    drt:Dret_2110 (0 target-flexibility) (0 robustness)
    drt:Dret_2132 (790 target-flexibility) (134 robustness)
    drt:Dret_2234 (71 target-flexibility) (71 robustness)
    drt:Dret_2408 (0 target-flexibility) (0 robustness)
    drt:Dret_2421 (80 target-flexibility) (80 robustness)
    drt:Dret_2429 (497 target-flexibility) (186 robustness)
    drt:Dret_2432 (0 target-flexibility) (0 robustness)
    drt:Dret_2481 (790 target-flexibility) (134 robustness)
    drt:Dret_2499 (0 target-flexibility) (0 robustness)
    dsa:Desal_0017 (897 target-flexibility) (71 robustness)
    dsa:Desal_0041 (0 target-flexibility) (0 robustness)
    dsa:Desal_0092 (790 target-flexibility) (134 robustness)
    dsa:Desal_0136 (528 target-flexibility) (157 robustness)
    dsa:Desal_0143 (752 target-flexibility) (76 robustness)
    dsa:Desal_0152 (790 target-flexibility) (134 robustness)
    dsa:Desal_0178 (0 target-flexibility) (0 robustness)
    dsa:Desal_0250 (212 target-flexibility) (73 robustness)
    dsa:Desal_0284 (0 target-flexibility) (0 robustness)
    dsa:Desal_0289 (0 target-flexibility) (0 robustness)
    dsa:Desal_0368 (0 target-flexibility) (0 robustness)
    dsa:Desal_0408 (138 target-flexibility) (138 robustness)
    dsa:Desal_0523 (703 target-flexibility) (319 robustness)
    dsa:Desal_0538 (703 target-flexibility) (319 robustness)
    dsa:Desal_0541 (659 target-flexibility) (240 robustness)
    dsa:Desal_0558 (1041 target-flexibility) (243 robustness)
    dsa:Desal_0559 (1041 target-flexibility) (243 robustness)
    dsa:Desal_0574 (1041 target-flexibility) (243 robustness)
    dsa:Desal_0575 (1041 target-flexibility) (243 robustness)
    dsa:Desal_0576 (659 target-flexibility) (240 robustness)
    dsa:Desal_0616 (387 target-flexibility) (72 robustness)
    dsa:Desal_0650 (0 target-flexibility) (0 robustness)
    dsa:Desal_0657 (1066 target-flexibility) (75 robustness)
    dsa:Desal_0661 (1108 target-flexibility) (319 robustness)
    dsa:Desal_0743 (0 target-flexibility) (0 robustness)
    dsa:Desal_0753 (80 target-flexibility) (80 robustness)
    dsa:Desal_0836 (0 target-flexibility) (0 robustness)
    dsa:Desal_0990 (0 target-flexibility) (0 robustness)
    dsa:Desal_1082 (821 target-flexibility) (137 robustness)
    dsa:Desal_1093 (289 target-flexibility) (73 robustness)
    dsa:Desal_1102 (103 target-flexibility) (103 robustness)
    dsa:Desal_1363 (138 target-flexibility) (138 robustness)
    dsa:Desal_1479 (902 target-flexibility) (228 robustness)
    dsa:Desal_1582 (841 target-flexibility) (126 robustness)
    dsa:Desal_1628 (0 target-flexibility) (0 robustness)
    dsa:Desal_1645 (0 target-flexibility) (0 robustness)
    dsa:Desal_1745 (138 target-flexibility) (138 robustness)
    dsa:Desal_1769 (902 target-flexibility) (228 robustness)
    dsa:Desal_1818 (138 target-flexibility) (138 robustness)
    dsa:Desal_1910 (600 target-flexibility) (126 robustness)
    dsa:Desal_2027 (0 target-flexibility) (0 robustness)
    dsa:Desal_2033 (0 target-flexibility) (0 robustness)
    dsa:Desal_2037 (706 target-flexibility) (173 robustness)
    dsa:Desal_2170 (732 target-flexibility) (78 robustness)
    dsa:Desal_2198 (706 target-flexibility) (173 robustness)
    dsa:Desal_2302 (855 target-flexibility) (138 robustness)
    dsa:Desal_2682 (0 target-flexibility) (0 robustness)
    dsa:Desal_2806 (219 target-flexibility) (63 robustness)
    dsa:Desal_2862 (358 target-flexibility) (104 robustness)
    dsa:Desal_2872 (0 target-flexibility) (0 robustness)
    dsa:Desal_2997 (323 target-flexibility) (101 robustness)
    dsa:Desal_3010 (686 target-flexibility) (192 robustness)
    dsa:Desal_3303 (879 target-flexibility) (71 robustness)
    dsa:Desal_3407 (1385 target-flexibility) (204 robustness)
    dsf:UWK_00066 (405 target-flexibility) (169 robustness)
    dsf:UWK_00067 (405 target-flexibility) (169 robustness)
    dsf:UWK_00087 (0 target-flexibility) (0 robustness)
    dsf:UWK_00094 (0 target-flexibility) (0 robustness)
    dsf:UWK_00105 (528 target-flexibility) (157 robustness)
    dsf:UWK_00122 (703 target-flexibility) (319 robustness)
    dsf:UWK_00132 (659 target-flexibility) (240 robustness)
    dsf:UWK_00143 (703 target-flexibility) (319 robustness)
    dsf:UWK_00144 (703 target-flexibility) (319 robustness)
    dsf:UWK_00180 (212 target-flexibility) (73 robustness)
    dsf:UWK_00304 (1784 target-flexibility) (162 robustness)
    dsf:UWK_00316 (0 target-flexibility) (0 robustness)
    dsf:UWK_00318 (1784 target-flexibility) (162 robustness)
    dsf:UWK_00454 (607 target-flexibility) (75 robustness)
    dsf:UWK_00579 (924 target-flexibility) (101 robustness)
    dsf:UWK_00627 (706 target-flexibility) (173 robustness)
    dsf:UWK_00683 (138 target-flexibility) (66 robustness)
    dsf:UWK_00704 (1784 target-flexibility) (162 robustness)
    dsf:UWK_00709 (1784 target-flexibility) (162 robustness)
    dsf:UWK_00789 (600 target-flexibility) (126 robustness)
    dsf:UWK_00793 (897 target-flexibility) (71 robustness)
    dsf:UWK_00827 (91 target-flexibility) (91 robustness)
    dsf:UWK_00846 (0 target-flexibility) (0 robustness)
    dsf:UWK_00965 (0 target-flexibility) (0 robustness)
    dsf:UWK_00991 (0 target-flexibility) (0 robustness)
    dsf:UWK_01050 (0 target-flexibility) (0 robustness)
    dsf:UWK_01152 (752 target-flexibility) (76 robustness)
    dsf:UWK_01260 (732 target-flexibility) (78 robustness)
    dsf:UWK_01351 (821 target-flexibility) (137 robustness)
    dsf:UWK_01372 (0 target-flexibility) (0 robustness)
    dsf:UWK_01373 (0 target-flexibility) (0 robustness)
    dsf:UWK_01435 (0 target-flexibility) (0 robustness)
    dsf:UWK_01482 (150 target-flexibility) (76 robustness)
    dsf:UWK_01506 (262 target-flexibility) (86 robustness)
    dsf:UWK_01617 (691 target-flexibility) (528 robustness)
    dsf:UWK_01660 (138 target-flexibility) (138 robustness)
    dsf:UWK_01662 (80 target-flexibility) (80 robustness)
    dsf:UWK_01685 (150 target-flexibility) (76 robustness)
    dsf:UWK_01687 (600 target-flexibility) (126 robustness)
    dsf:UWK_01758 (0 target-flexibility) (0 robustness)
    dsf:UWK_01777 (821 target-flexibility) (137 robustness)
    dsf:UWK_01801 (821 target-flexibility) (137 robustness)
    dsf:UWK_01819 (358 target-flexibility) (104 robustness)
    dsf:UWK_01838 (691 target-flexibility) (528 robustness)
    dsf:UWK_01840 (0 target-flexibility) (0 robustness)
    dsf:UWK_01915 (700 target-flexibility) (80 robustness)
    dsf:UWK_01920 (902 target-flexibility) (228 robustness)
    dsf:UWK_01937 (924 target-flexibility) (101 robustness)
    dsf:UWK_02087 (700 target-flexibility) (80 robustness)
    dsf:UWK_02122 (0 target-flexibility) (0 robustness)
    dsf:UWK_02241 (358 target-flexibility) (104 robustness)
    dsf:UWK_02316 (700 target-flexibility) (77 robustness)
    dsf:UWK_02323 (659 target-flexibility) (240 robustness)
    dsf:UWK_02355 (706 target-flexibility) (173 robustness)
    dsf:UWK_02372 (70 target-flexibility) (70 robustness)
    dsf:UWK_02430 (902 target-flexibility) (228 robustness)
    dsf:UWK_02435 (70 target-flexibility) (70 robustness)
    dsf:UWK_02496 (657 target-flexibility) (95 robustness)
    dsf:UWK_02513 (0 target-flexibility) (0 robustness)
    dsf:UWK_02514 (1169 target-flexibility) (76 robustness)
    dsf:UWK_02522 (691 target-flexibility) (528 robustness)
    dsf:UWK_02569 (659 target-flexibility) (240 robustness)
    dsf:UWK_02571 (703 target-flexibility) (319 robustness)
    dsf:UWK_02594 (902 target-flexibility) (228 robustness)
    dsf:UWK_02595 (841 target-flexibility) (126 robustness)
    dsf:UWK_02650 (706 target-flexibility) (173 robustness)
    dsf:UWK_02667 (0 target-flexibility) (0 robustness)
    dsf:UWK_02742 (607 target-flexibility) (75 robustness)
    dsf:UWK_02745 (262 target-flexibility) (86 robustness)
    dsf:UWK_02784 (91 target-flexibility) (91 robustness)
    dsf:UWK_02797 (1041 target-flexibility) (243 robustness)
    dsf:UWK_02799 (0 target-flexibility) (0 robustness)
    dsf:UWK_02885 (841 target-flexibility) (126 robustness)
    dsf:UWK_02927 (700 target-flexibility) (77 robustness)
    dsf:UWK_02972 (138 target-flexibility) (138 robustness)
    dsf:UWK_02973 (703 target-flexibility) (319 robustness)
    dsf:UWK_02977 (659 target-flexibility) (240 robustness)
    dsf:UWK_03000 (72 target-flexibility) (72 robustness)
    dsf:UWK_03051 (405 target-flexibility) (169 robustness)
    dsf:UWK_03052 (405 target-flexibility) (169 robustness)
    dsf:UWK_03057 (0 target-flexibility) (0 robustness)
    dsf:UWK_03174 (70 target-flexibility) (70 robustness)
    dsf:UWK_03294 (0 target-flexibility) (0 robustness)
    dsf:UWK_03329 (686 target-flexibility) (192 robustness)
    dsf:UWK_03336 (691 target-flexibility) (528 robustness)
    dsf:UWK_03366 (686 target-flexibility) (192 robustness)
    dsf:UWK_03406 (0 target-flexibility) (0 robustness)
    dsf:UWK_03410 (222 target-flexibility) (83 robustness)
    dsf:UWK_03421 (0 target-flexibility) (0 robustness)
    dsf:UWK_03510 (796 target-flexibility) (85 robustness)
    dsf:UWK_03535 (71 target-flexibility) (71 robustness)
    dsf:UWK_03539 (657 target-flexibility) (95 robustness)
    dti:Desti_0036 (0 target-flexibility) (0 robustness)
    dti:Desti_0051 (902 target-flexibility) (228 robustness)
    dti:Desti_0057 (600 target-flexibility) (126 robustness)
    dti:Desti_0059 (528 target-flexibility) (157 robustness)
    dti:Desti_0062 (405 target-flexibility) (169 robustness)
    dti:Desti_0148 (1041 target-flexibility) (243 robustness)
    dti:Desti_0149 (1041 target-flexibility) (243 robustness)
    dti:Desti_0205 (175 target-flexibility) (96 robustness)
    dti:Desti_0219 (790 target-flexibility) (134 robustness)
    dti:Desti_0225 (0 target-flexibility) (0 robustness)
    dti:Desti_0234 (841 target-flexibility) (126 robustness)
    dti:Desti_0240 (323 target-flexibility) (101 robustness)
    dti:Desti_0353 (0 target-flexibility) (0 robustness)
    dti:Desti_0395 (706 target-flexibility) (173 robustness)
    dti:Desti_0426 (600 target-flexibility) (126 robustness)
    dti:Desti_0441 (350 target-flexibility) (84 robustness)
    dti:Desti_0473 (0 target-flexibility) (0 robustness)
    dti:Desti_0504 (0 target-flexibility) (0 robustness)
    dti:Desti_0569 (0 target-flexibility) (0 robustness)
    dti:Desti_0754 (219 target-flexibility) (63 robustness)
    dti:Desti_0755 (323 target-flexibility) (101 robustness)
    dti:Desti_0757 (91 target-flexibility) (91 robustness)
    dti:Desti_0759 (659 target-flexibility) (240 robustness)
    dti:Desti_0774 (0 target-flexibility) (0 robustness)
    dti:Desti_0802 (73 target-flexibility) (73 robustness)
    dti:Desti_0830 (706 target-flexibility) (173 robustness)
    dti:Desti_0874 (138 target-flexibility) (138 robustness)
    dti:Desti_0881 (0 target-flexibility) (0 robustness)
    dti:Desti_0896 (0 target-flexibility) (0 robustness)
    dti:Desti_0901 (0 target-flexibility) (0 robustness)
    dti:Desti_0925 (0 target-flexibility) (0 robustness)
    dti:Desti_0927 (821 target-flexibility) (137 robustness)
    dti:Desti_0942 (0 target-flexibility) (0 robustness)
    dti:Desti_0981 (350 target-flexibility) (84 robustness)
    dti:Desti_0988 (634 target-flexibility) (72 robustness)
    dti:Desti_1014 (175 target-flexibility) (96 robustness)
    dti:Desti_1036 (659 target-flexibility) (240 robustness)
    dti:Desti_1039 (486 target-flexibility) (89 robustness)
    dti:Desti_1152 (206 target-flexibility) (68 robustness)
    dti:Desti_1171 (706 target-flexibility) (173 robustness)
    dti:Desti_1190 (0 target-flexibility) (0 robustness)
    dti:Desti_1200 (0 target-flexibility) (0 robustness)
    dti:Desti_1201 (0 target-flexibility) (0 robustness)
    dti:Desti_1206 (841 target-flexibility) (126 robustness)
    dti:Desti_1259 (752 target-flexibility) (76 robustness)
    dti:Desti_1266 (686 target-flexibility) (192 robustness)
    dti:Desti_1340 (323 target-flexibility) (101 robustness)
    dti:Desti_1366 (0 target-flexibility) (0 robustness)
    dti:Desti_1457 (0 target-flexibility) (0 robustness)
    dti:Desti_1492 (1169 target-flexibility) (76 robustness)
    dti:Desti_1600 (821 target-flexibility) (137 robustness)
    dti:Desti_1662 (138 target-flexibility) (138 robustness)
    dti:Desti_1674 (0 target-flexibility) (0 robustness)
    dti:Desti_1695 (279 target-flexibility) (126 robustness)
    dti:Desti_1700 (387 target-flexibility) (72 robustness)
    dti:Desti_1808 (0 target-flexibility) (0 robustness)
    dti:Desti_1836 (0 target-flexibility) (0 robustness)
    dti:Desti_1892 (301 target-flexibility) (154 robustness)
    dti:Desti_2003 (0 target-flexibility) (0 robustness)
    dti:Desti_2096 (350 target-flexibility) (84 robustness)
    dti:Desti_2110 (486 target-flexibility) (89 robustness)
    dti:Desti_2111 (1041 target-flexibility) (243 robustness)
    dti:Desti_2134 (138 target-flexibility) (138 robustness)
    dti:Desti_2232 (0 target-flexibility) (0 robustness)
    dti:Desti_2278 (0 target-flexibility) (0 robustness)
    dti:Desti_2327 (528 target-flexibility) (157 robustness)
    dti:Desti_2341 (790 target-flexibility) (134 robustness)
    dti:Desti_2345 (790 target-flexibility) (134 robustness)
    dti:Desti_2348 (790 target-flexibility) (134 robustness)
    dti:Desti_2371 (0 target-flexibility) (0 robustness)
    dti:Desti_2479 (0 target-flexibility) (0 robustness)
    dti:Desti_2554 (158 target-flexibility) (72 robustness)
    dti:Desti_2576 (691 target-flexibility) (528 robustness)
    dti:Desti_2718 (343 target-flexibility) (180 robustness)
    dti:Desti_2739 (0 target-flexibility) (0 robustness)
    dti:Desti_2740 (0 target-flexibility) (0 robustness)
    dti:Desti_2768 (377 target-flexibility) (117 robustness)
    dti:Desti_2797 (0 target-flexibility) (0 robustness)
    dti:Desti_2811 (821 target-flexibility) (137 robustness)
    dti:Desti_2825 (659 target-flexibility) (240 robustness)
    dti:Desti_2856 (377 target-flexibility) (117 robustness)
    dti:Desti_2892 (0 target-flexibility) (0 robustness)
    dti:Desti_2957 (73 target-flexibility) (73 robustness)
    dti:Desti_2988 (358 target-flexibility) (124 robustness)
    dti:Desti_2998 (841 target-flexibility) (126 robustness)
    dti:Desti_3051 (1385 target-flexibility) (204 robustness)
    dti:Desti_3101 (659 target-flexibility) (240 robustness)
    dti:Desti_3108 (279 target-flexibility) (126 robustness)
    dti:Desti_3121 (71 target-flexibility) (71 robustness)
    dti:Desti_3139 (1041 target-flexibility) (243 robustness)
    dti:Desti_3164 (0 target-flexibility) (0 robustness)
    dti:Desti_3199 (405 target-flexibility) (169 robustness)
    dti:Desti_3300 (175 target-flexibility) (96 robustness)
    dti:Desti_3356 (0 target-flexibility) (0 robustness)
    dti:Desti_3578 (0 target-flexibility) (0 robustness)
    dti:Desti_3611 (821 target-flexibility) (137 robustness)
    dti:Desti_3628 (1385 target-flexibility) (204 robustness)
    dti:Desti_3650 (0 target-flexibility) (0 robustness)
    dti:Desti_3684 (212 target-flexibility) (73 robustness)
    dti:Desti_3693 (0 target-flexibility) (0 robustness)
    dti:Desti_3729 (0 target-flexibility) (0 robustness)
    dti:Desti_3747 (80 target-flexibility) (80 robustness)
    dti:Desti_3834 (0 target-flexibility) (0 robustness)
    dti:Desti_3894 (0 target-flexibility) (0 robustness)
    dti:Desti_4020 (528 target-flexibility) (157 robustness)
    dti:Desti_4083 (222 target-flexibility) (83 robustness)
    dti:Desti_4113 (634 target-flexibility) (72 robustness)
    dti:Desti_4116 (686 target-flexibility) (192 robustness)
    dti:Desti_4149 (219 target-flexibility) (63 robustness)
    dti:Desti_4150 (434 target-flexibility) (67 robustness)
    dti:Desti_4164 (790 target-flexibility) (134 robustness)
    dti:Desti_4182 (358 target-flexibility) (124 robustness)
    dti:Desti_4253 (289 target-flexibility) (73 robustness)
    dti:Desti_4337 (0 target-flexibility) (0 robustness)
    dti:Desti_4345 (0 target-flexibility) (0 robustness)
    dti:Desti_4384 (138 target-flexibility) (138 robustness)
    dti:Desti_4402 (91 target-flexibility) (91 robustness)
    dti:Desti_4450 (691 target-flexibility) (528 robustness)
    dti:Desti_4464 (158 target-flexibility) (72 robustness)
    dti:Desti_4547 (0 target-flexibility) (0 robustness)
    dti:Desti_4572 (0 target-flexibility) (0 robustness)
    dti:Desti_4587 (377 target-flexibility) (117 robustness)
    dti:Desti_4704 (239 target-flexibility) (67 robustness)
    dti:Desti_4705 (67 target-flexibility) (67 robustness)
    dti:Desti_4732 (358 target-flexibility) (124 robustness)
    dti:Desti_4769 (350 target-flexibility) (84 robustness)
    dti:Desti_4868 (691 target-flexibility) (528 robustness)
    dti:Desti_4903 (902 target-flexibility) (228 robustness)
    dti:Desti_4907 (0 target-flexibility) (0 robustness)
    dti:Desti_4911 (0 target-flexibility) (0 robustness)
    dti:Desti_4995 (0 target-flexibility) (0 robustness)
    dti:Desti_5141 (138 target-flexibility) (138 robustness)
    dti:Desti_5320 (343 target-flexibility) (180 robustness)
    dti:Desti_5358 (0 target-flexibility) (0 robustness)
    dti:Desti_5499 (350 target-flexibility) (84 robustness)
    dti:Desti_5539 (301 target-flexibility) (154 robustness)
    dti:Desti_5563 (91 target-flexibility) (91 robustness)
    dti:Desti_5667 (691 target-flexibility) (528 robustness)
    dto:TOL2_C00330 (706 target-flexibility) (173 robustness)
    dto:TOL2_C00560 (91 target-flexibility) (91 robustness)
    dto:TOL2_C02640 (528 target-flexibility) (157 robustness)
    dto:TOL2_C03020 (0 target-flexibility) (0 robustness)
    dto:TOL2_C03030 (0 target-flexibility) (0 robustness)
    dto:TOL2_C03360 (686 target-flexibility) (192 robustness)
    dto:TOL2_C03820 (659 target-flexibility) (240 robustness)
    dto:TOL2_C04170 (706 target-flexibility) (173 robustness)
    dto:TOL2_C04490 (659 target-flexibility) (240 robustness)
    dto:TOL2_C05070 (0 target-flexibility) (0 robustness)
    dto:TOL2_C05080 (0 target-flexibility) (0 robustness)
    dto:TOL2_C05120 (301 target-flexibility) (154 robustness)
    dto:TOL2_C05220 (790 target-flexibility) (134 robustness)
    dto:TOL2_C05370 (634 target-flexibility) (72 robustness)
    dto:TOL2_C07190 (841 target-flexibility) (126 robustness)
    dto:TOL2_C08210 (0 target-flexibility) (0 robustness)
    dto:TOL2_C08510 (0 target-flexibility) (0 robustness)
    dto:TOL2_C10040 (732 target-flexibility) (78 robustness)
    dto:TOL2_C10990 (358 target-flexibility) (104 robustness)
    dto:TOL2_C11340 (0 target-flexibility) (0 robustness)
    dto:TOL2_C11440 (752 target-flexibility) (76 robustness)
    dto:TOL2_C12360 (0 target-flexibility) (0 robustness)
    dto:TOL2_C13270 (691 target-flexibility) (528 robustness)
    dto:TOL2_C13310 (358 target-flexibility) (104 robustness)
    dto:TOL2_C13420 (691 target-flexibility) (528 robustness)
    dto:TOL2_C15720 (357 target-flexibility) (115 robustness)
    dto:TOL2_C15960 (706 target-flexibility) (173 robustness)
    dto:TOL2_C16510 (212 target-flexibility) (73 robustness)
    dto:TOL2_C16630 (841 target-flexibility) (126 robustness)
    dto:TOL2_C16640 (841 target-flexibility) (126 robustness)
    dto:TOL2_C17330 (924 target-flexibility) (101 robustness)
    dto:TOL2_C17500 (0 target-flexibility) (0 robustness)
    dto:TOL2_C18190 (80 target-flexibility) (80 robustness)
    dto:TOL2_C18400 (0 target-flexibility) (0 robustness)
    dto:TOL2_C18860 (80 target-flexibility) (80 robustness)
    dto:TOL2_C21050 (222 target-flexibility) (83 robustness)
    dto:TOL2_C21920 (897 target-flexibility) (71 robustness)
    dto:TOL2_C22060 (600 target-flexibility) (126 robustness)
    dto:TOL2_C22520 (634 target-flexibility) (72 robustness)
    dto:TOL2_C22640 (0 target-flexibility) (0 robustness)
    dto:TOL2_C22880 (0 target-flexibility) (0 robustness)
    dto:TOL2_C23200 (239 target-flexibility) (99 robustness)
    dto:TOL2_C23400 (0 target-flexibility) (0 robustness)
    dto:TOL2_C24560 (138 target-flexibility) (66 robustness)
    dto:TOL2_C24750 (0 target-flexibility) (0 robustness)
    dto:TOL2_C24800 (0 target-flexibility) (0 robustness)
    dto:TOL2_C26900 (0 target-flexibility) (0 robustness)
    dto:TOL2_C27090 (0 target-flexibility) (0 robustness)
    dto:TOL2_C27260 (0 target-flexibility) (0 robustness)
    dto:TOL2_C27460 (0 target-flexibility) (0 robustness)
    dto:TOL2_C27650 (0 target-flexibility) (0 robustness)
    dto:TOL2_C28080 (0 target-flexibility) (0 robustness)
    dto:TOL2_C28120 (0 target-flexibility) (0 robustness)
    dto:TOL2_C28470 (0 target-flexibility) (0 robustness)
    dto:TOL2_C28480 (0 target-flexibility) (0 robustness)
    dto:TOL2_C29790 (301 target-flexibility) (154 robustness)
    dto:TOL2_C31520 (790 target-flexibility) (134 robustness)
    dto:TOL2_C33600 (0 target-flexibility) (0 robustness)
    dto:TOL2_C35200 (0 target-flexibility) (0 robustness)
    dto:TOL2_C35290 (0 target-flexibility) (0 robustness)
    dto:TOL2_C35960 (239 target-flexibility) (99 robustness)
    dto:TOL2_C36220 (405 target-flexibility) (169 robustness)
    dto:TOL2_C37120 (0 target-flexibility) (0 robustness)
    dto:TOL2_C38340 (703 target-flexibility) (319 robustness)
    dto:TOL2_C38520 (0 target-flexibility) (0 robustness)
    dto:TOL2_C38530 (659 target-flexibility) (240 robustness)
    dto:TOL2_C38550 (703 target-flexibility) (319 robustness)
    dto:TOL2_C38950 (924 target-flexibility) (101 robustness)
    dto:TOL2_C39750 (91 target-flexibility) (91 robustness)
    dto:TOL2_C39790 (752 target-flexibility) (76 robustness)
    dto:TOL2_C39980 (600 target-flexibility) (126 robustness)
    dto:TOL2_C41270 (686 target-flexibility) (192 robustness)
    dto:TOL2_C41730 (0 target-flexibility) (0 robustness)
    dto:TOL2_C42790 (357 target-flexibility) (115 robustness)
    dto:TOL2_C42990 (732 target-flexibility) (78 robustness)
    dto:TOL2_C43000 (405 target-flexibility) (169 robustness)
    dto:TOL2_C43490 (0 target-flexibility) (0 robustness)
    dto:TOL2_C43570 (0 target-flexibility) (0 robustness)
    dvu:DVU0085 (686 target-flexibility) (192 robustness)
    dvu:DVU0152 (706 target-flexibility) (173 robustness)
    dvu:DVU0246 (706 target-flexibility) (173 robustness)
    dvu:DVU0283 (138 target-flexibility) (138 robustness)
    dvu:DVU0341 (70 target-flexibility) (70 robustness)
    dvu:DVU0360 (902 target-flexibility) (228 robustness)
    dvu:DVU0377 (138 target-flexibility) (138 robustness)
    dvu:DVU0470 (686 target-flexibility) (192 robustness)
    dvu:DVU0477 (289 target-flexibility) (73 robustness)
    dvu:DVU0489 (0 target-flexibility) (0 robustness)
    dvu:DVU0565 (600 target-flexibility) (126 robustness)
    dvu:DVU0626 (902 target-flexibility) (228 robustness)
    dvu:DVU0732 (212 target-flexibility) (73 robustness)
    dvu:DVU0748 (790 target-flexibility) (134 robustness)
    dvu:DVU0827 (0 target-flexibility) (0 robustness)
    dvu:DVU0841 (1385 target-flexibility) (204 robustness)
    dvu:DVU0951 (0 target-flexibility) (0 robustness)
    dvu:DVU1196 (0 target-flexibility) (0 robustness)
    dvu:DVU1204 (703 target-flexibility) (319 robustness)
    dvu:DVU1206 (659 target-flexibility) (240 robustness)
    dvu:DVU1350 (1169 target-flexibility) (76 robustness)
    dvu:DVU1360 (0 target-flexibility) (0 robustness)
    dvu:DVU1364 (0 target-flexibility) (0 robustness)
    dvu:DVU1376 (902 target-flexibility) (228 robustness)
    dvu:DVU1377 (902 target-flexibility) (228 robustness)
    dvu:DVU1453 (0 target-flexibility) (0 robustness)
    dvu:DVU1457 (138 target-flexibility) (138 robustness)
    dvu:DVU1615 (0 target-flexibility) (0 robustness)
    dvu:DVU1647 (239 target-flexibility) (99 robustness)
    dvu:DVU1693 (357 target-flexibility) (102 robustness)
    dvu:DVU1833 (706 target-flexibility) (173 robustness)
    dvu:DVU1838 (138 target-flexibility) (138 robustness)
    dvu:DVU1914 (841 target-flexibility) (126 robustness)
    dvu:DVU1927 (222 target-flexibility) (83 robustness)
    dvu:DVU1940 (497 target-flexibility) (186 robustness)
    dvu:DVU2091 (0 target-flexibility) (0 robustness)
    dvu:DVU2144 (600 target-flexibility) (126 robustness)
    dvu:DVU2250 (790 target-flexibility) (134 robustness)
    dvu:DVU2362 (0 target-flexibility) (0 robustness)
    dvu:DVU2396 (0 target-flexibility) (0 robustness)
    dvu:DVU2405 (0 target-flexibility) (0 robustness)
    dvu:DVU2530 (1041 target-flexibility) (243 robustness)
    dvu:DVU2552 (357 target-flexibility) (102 robustness)
    dvu:DVU2559 (0 target-flexibility) (0 robustness)
    dvu:DVU2563 (703 target-flexibility) (319 robustness)
    dvu:DVU2566 (239 target-flexibility) (99 robustness)
    dvu:DVU2673 (497 target-flexibility) (186 robustness)
    dvu:DVU2735 (0 target-flexibility) (0 robustness)
    dvu:DVU2739 (706 target-flexibility) (173 robustness)
    dvu:DVU2885 (0 target-flexibility) (0 robustness)
    dvu:DVU2905 (0 target-flexibility) (0 robustness)
    dvu:DVU2969 (790 target-flexibility) (134 robustness)
    dvu:DVU2981 (841 target-flexibility) (126 robustness)
    dvu:DVU2985 (434 target-flexibility) (67 robustness)
    dvu:DVU2990 (0 target-flexibility) (0 robustness)
    dvu:DVU2996 (0 target-flexibility) (0 robustness)
    dvu:DVU3014 (821 target-flexibility) (137 robustness)
    dvu:DVU3027 (0 target-flexibility) (0 robustness)
    dvu:DVU3114 (70 target-flexibility) (70 robustness)
    dvu:DVU3119 (0 target-flexibility) (0 robustness)
    dvu:DVU3132 (497 target-flexibility) (186 robustness)
    dvu:DVU3137 (659 target-flexibility) (240 robustness)
    dvu:DVU3168 (80 target-flexibility) (80 robustness)
    dvu:DVU3214 (706 target-flexibility) (173 robustness)
    dvu:DVU3223 (1385 target-flexibility) (204 robustness)
    dvu:DVU3237 (706 target-flexibility) (173 robustness)
    dvu:DVU3253 (0 target-flexibility) (0 robustness)
    dvu:DVU3293 (902 target-flexibility) (228 robustness)
    dvu:DVU3356 (0 target-flexibility) (0 robustness)
    dvu:DVUA0073 (821 target-flexibility) (137 robustness)
    gao:A2G06_01250 (1108 target-flexibility) (319 robustness)
    gao:A2G06_02140 (659 target-flexibility) (240 robustness)
    gao:A2G06_03585 (1169 target-flexibility) (76 robustness)
    gao:A2G06_05615 (686 target-flexibility) (192 robustness)
    gao:A2G06_05630 (686 target-flexibility) (192 robustness)
    gao:A2G06_05670 (0 target-flexibility) (0 robustness)
    gao:A2G06_05980 (71 target-flexibility) (71 robustness)
    gao:A2G06_06115 (0 target-flexibility) (0 robustness)
    gao:A2G06_06120 (0 target-flexibility) (0 robustness)
    gao:A2G06_06270 (0 target-flexibility) (0 robustness)
    gao:A2G06_06620 (0 target-flexibility) (0 robustness)
    gao:A2G06_06650 (212 target-flexibility) (73 robustness)
    gao:A2G06_07085 (0 target-flexibility) (0 robustness)
    gao:A2G06_07325 (841 target-flexibility) (126 robustness)
    gao:A2G06_07620 (0 target-flexibility) (0 robustness)
    gao:A2G06_07920 (841 target-flexibility) (126 robustness)
    gao:A2G06_08130 (1169 target-flexibility) (76 robustness)
    gao:A2G06_08260 (0 target-flexibility) (0 robustness)
    gao:A2G06_08985 (659 target-flexibility) (240 robustness)
    gao:A2G06_08995 (1108 target-flexibility) (319 robustness)
    gao:A2G06_09115 (0 target-flexibility) (0 robustness)
    gao:A2G06_09675 (752 target-flexibility) (76 robustness)
    gao:A2G06_10540 (897 target-flexibility) (71 robustness)
    gao:A2G06_10625 (1385 target-flexibility) (204 robustness)
    gao:A2G06_11490 (1385 target-flexibility) (204 robustness)
    gao:A2G06_12745 (0 target-flexibility) (0 robustness)
    gao:A2G06_13050 (0 target-flexibility) (0 robustness)
    gao:A2G06_13760 (1041 target-flexibility) (243 robustness)
    gao:A2G06_13765 (1041 target-flexibility) (243 robustness)
    gao:A2G06_14560 (0 target-flexibility) (0 robustness)
    gao:A2G06_14565 (0 target-flexibility) (0 robustness)
    gao:A2G06_14765 (222 target-flexibility) (83 robustness)
    gao:A2G06_15675 (138 target-flexibility) (66 robustness)
    gao:A2G06_16175 (1041 target-flexibility) (243 robustness)
    gbm:Gbem_0212 (691 target-flexibility) (528 robustness)
    gbm:Gbem_0259 (0 target-flexibility) (0 robustness)
    gbm:Gbem_0260 (0 target-flexibility) (0 robustness)
    gbm:Gbem_0279 (1041 target-flexibility) (243 robustness)
    gbm:Gbem_0280 (1041 target-flexibility) (243 robustness)
    gbm:Gbem_0486 (239 target-flexibility) (67 robustness)
    gbm:Gbem_0487 (67 target-flexibility) (67 robustness)
    gbm:Gbem_0493 (76 target-flexibility) (76 robustness)
    gbm:Gbem_0564 (0 target-flexibility) (0 robustness)
    gbm:Gbem_0567 (0 target-flexibility) (0 robustness)
    gbm:Gbem_0635 (350 target-flexibility) (189 robustness)
    gbm:Gbem_0751 (0 target-flexibility) (0 robustness)
    gbm:Gbem_0823 (150 target-flexibility) (76 robustness)
    gbm:Gbem_0836 (71 target-flexibility) (71 robustness)
    gbm:Gbem_0861 (0 target-flexibility) (0 robustness)
    gbm:Gbem_0909 (166 target-flexibility) (99 robustness)
    gbm:Gbem_0910 (166 target-flexibility) (99 robustness)
    gbm:Gbem_1081 (821 target-flexibility) (137 robustness)
    gbm:Gbem_1258 (1169 target-flexibility) (76 robustness)
    gbm:Gbem_1265 (841 target-flexibility) (126 robustness)
    gbm:Gbem_1341 (175 target-flexibility) (96 robustness)
    gbm:Gbem_1348 (70 target-flexibility) (70 robustness)
    gbm:Gbem_1349 (0 target-flexibility) (0 robustness)
    gbm:Gbem_1354 (700 target-flexibility) (89 robustness)
    gbm:Gbem_1379 (1041 target-flexibility) (243 robustness)
    gbm:Gbem_1436 (700 target-flexibility) (89 robustness)
    gbm:Gbem_1464 (0 target-flexibility) (0 robustness)
    gbm:Gbem_1465 (0 target-flexibility) (0 robustness)
    gbm:Gbem_1531 (212 target-flexibility) (73 robustness)
    gbm:Gbem_1554 (150 target-flexibility) (76 robustness)
    gbm:Gbem_1571 (0 target-flexibility) (0 robustness)
    gbm:Gbem_1615 (821 target-flexibility) (137 robustness)
    gbm:Gbem_1629 (0 target-flexibility) (0 robustness)
    gbm:Gbem_1630 (0 target-flexibility) (0 robustness)
    gbm:Gbem_1652 (924 target-flexibility) (101 robustness)
    gbm:Gbem_1725 (175 target-flexibility) (96 robustness)
    gbm:Gbem_1778 (821 target-flexibility) (137 robustness)
    gbm:Gbem_1896 (897 target-flexibility) (71 robustness)
    gbm:Gbem_1958 (686 target-flexibility) (192 robustness)
    gbm:Gbem_1983 (528 target-flexibility) (157 robustness)
    gbm:Gbem_2051 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2125 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2149 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2173 (262 target-flexibility) (86 robustness)
    gbm:Gbem_2184 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2192 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2216 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2235 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2258 (262 target-flexibility) (86 robustness)
    gbm:Gbem_2272 (700 target-flexibility) (89 robustness)
    gbm:Gbem_2273 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2274 (70 target-flexibility) (70 robustness)
    gbm:Gbem_2336 (600 target-flexibility) (126 robustness)
    gbm:Gbem_2352 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2353 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2446 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2561 (139 target-flexibility) (139 robustness)
    gbm:Gbem_2692 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2742 (841 target-flexibility) (126 robustness)
    gbm:Gbem_2797 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2828 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2859 (239 target-flexibility) (99 robustness)
    gbm:Gbem_2903 (752 target-flexibility) (76 robustness)
    gbm:Gbem_2906 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2980 (350 target-flexibility) (189 robustness)
    gbm:Gbem_3108 (1108 target-flexibility) (319 robustness)
    gbm:Gbem_3162 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3163 (528 target-flexibility) (157 robustness)
    gbm:Gbem_3180 (76 target-flexibility) (76 robustness)
    gbm:Gbem_3205 (691 target-flexibility) (528 robustness)
    gbm:Gbem_3222 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3223 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3321 (686 target-flexibility) (192 robustness)
    gbm:Gbem_3345 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3346 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3362 (1169 target-flexibility) (76 robustness)
    gbm:Gbem_3400 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3463 (91 target-flexibility) (91 robustness)
    gbm:Gbem_3530 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3637 (138 target-flexibility) (66 robustness)
    gbm:Gbem_3650 (222 target-flexibility) (83 robustness)
    gbm:Gbem_3700 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3701 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3783 (139 target-flexibility) (139 robustness)
    gbm:Gbem_3789 (600 target-flexibility) (126 robustness)
    gbm:Gbem_3809 (91 target-flexibility) (91 robustness)
    gbm:Gbem_3820 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3905 (924 target-flexibility) (101 robustness)
    gbm:Gbem_3927 (80 target-flexibility) (80 robustness)
    gbm:Gbem_3995 (1108 target-flexibility) (319 robustness)
    gbm:Gbem_4020 (0 target-flexibility) (0 robustness)
    gbm:Gbem_4055 (239 target-flexibility) (99 robustness)
    geb:GM18_0169 (691 target-flexibility) (528 robustness)
    geb:GM18_0287 (0 target-flexibility) (0 robustness)
    geb:GM18_0288 (0 target-flexibility) (0 robustness)
    geb:GM18_0316 (1041 target-flexibility) (243 robustness)
    geb:GM18_0317 (1041 target-flexibility) (243 robustness)
    geb:GM18_0559 (0 target-flexibility) (0 robustness)
    geb:GM18_0634 (91 target-flexibility) (91 robustness)
    geb:GM18_0699 (0 target-flexibility) (0 robustness)
    geb:GM18_0719 (150 target-flexibility) (76 robustness)
    geb:GM18_0730 (71 target-flexibility) (71 robustness)
    geb:GM18_0750 (0 target-flexibility) (0 robustness)
    geb:GM18_0779 (301 target-flexibility) (154 robustness)
    geb:GM18_0809 (166 target-flexibility) (99 robustness)
    geb:GM18_0810 (166 target-flexibility) (99 robustness)
    geb:GM18_0958 (790 target-flexibility) (134 robustness)
    geb:GM18_1054 (734 target-flexibility) (110 robustness)
    geb:GM18_1091 (0 target-flexibility) (0 robustness)
    geb:GM18_1116 (1169 target-flexibility) (76 robustness)
    geb:GM18_1123 (841 target-flexibility) (126 robustness)
    geb:GM18_1206 (0 target-flexibility) (0 robustness)
    geb:GM18_1211 (700 target-flexibility) (89 robustness)
    geb:GM18_1241 (1041 target-flexibility) (243 robustness)
    geb:GM18_1366 (212 target-flexibility) (73 robustness)
    geb:GM18_1389 (150 target-flexibility) (76 robustness)
    geb:GM18_1403 (358 target-flexibility) (124 robustness)
    geb:GM18_1436 (0 target-flexibility) (0 robustness)
    geb:GM18_1438 (821 target-flexibility) (137 robustness)
    geb:GM18_1442 (0 target-flexibility) (0 robustness)
    geb:GM18_1443 (0 target-flexibility) (0 robustness)
    geb:GM18_1454 (821 target-flexibility) (137 robustness)
    geb:GM18_1602 (0 target-flexibility) (0 robustness)
    geb:GM18_1672 (821 target-flexibility) (137 robustness)
    geb:GM18_1720 (897 target-flexibility) (71 robustness)
    geb:GM18_1836 (358 target-flexibility) (124 robustness)
    geb:GM18_1893 (600 target-flexibility) (126 robustness)
    geb:GM18_1956 (0 target-flexibility) (0 robustness)
    geb:GM18_1958 (700 target-flexibility) (89 robustness)
    geb:GM18_1971 (262 target-flexibility) (86 robustness)
    geb:GM18_1990 (0 target-flexibility) (0 robustness)
    geb:GM18_2013 (0 target-flexibility) (0 robustness)
    geb:GM18_2054 (0 target-flexibility) (0 robustness)
    geb:GM18_2062 (0 target-flexibility) (0 robustness)
    geb:GM18_2068 (262 target-flexibility) (86 robustness)
    geb:GM18_2111 (0 target-flexibility) (0 robustness)
    geb:GM18_2157 (0 target-flexibility) (0 robustness)
    geb:GM18_2226 (528 target-flexibility) (157 robustness)
    geb:GM18_2264 (686 target-flexibility) (192 robustness)
    geb:GM18_2304 (0 target-flexibility) (0 robustness)
    geb:GM18_2560 (0 target-flexibility) (0 robustness)
    geb:GM18_2608 (841 target-flexibility) (126 robustness)
    geb:GM18_2665 (0 target-flexibility) (0 robustness)
    geb:GM18_2719 (239 target-flexibility) (99 robustness)
    geb:GM18_2739 (0 target-flexibility) (0 robustness)
    geb:GM18_2759 (0 target-flexibility) (0 robustness)
    geb:GM18_2790 (752 target-flexibility) (76 robustness)
    geb:GM18_2793 (0 target-flexibility) (0 robustness)
    geb:GM18_3075 (703 target-flexibility) (319 robustness)
    geb:GM18_3077 (659 target-flexibility) (240 robustness)
    geb:GM18_3079 (1108 target-flexibility) (319 robustness)
    geb:GM18_3132 (528 target-flexibility) (157 robustness)
    geb:GM18_3185 (76 target-flexibility) (76 robustness)
    geb:GM18_3247 (691 target-flexibility) (528 robustness)
    geb:GM18_3257 (0 target-flexibility) (0 robustness)
    geb:GM18_3274 (0 target-flexibility) (0 robustness)
    geb:GM18_3275 (0 target-flexibility) (0 robustness)
    geb:GM18_3400 (686 target-flexibility) (192 robustness)
    geb:GM18_3424 (0 target-flexibility) (0 robustness)
    geb:GM18_3441 (1169 target-flexibility) (76 robustness)
    geb:GM18_3547 (734 target-flexibility) (110 robustness)
    geb:GM18_3598 (0 target-flexibility) (0 robustness)
    geb:GM18_3789 (0 target-flexibility) (0 robustness)
    geb:GM18_3792 (0 target-flexibility) (0 robustness)
    geb:GM18_3827 (301 target-flexibility) (154 robustness)
    geb:GM18_3885 (76 target-flexibility) (76 robustness)
    geb:GM18_3889 (140 target-flexibility) (71 robustness)
    geb:GM18_3891 (67 target-flexibility) (67 robustness)
    geb:GM18_3892 (239 target-flexibility) (67 robustness)
    geb:GM18_3980 (0 target-flexibility) (0 robustness)
    geb:GM18_4050 (703 target-flexibility) (319 robustness)
    geb:GM18_4055 (703 target-flexibility) (319 robustness)
    geb:GM18_4063 (0 target-flexibility) (0 robustness)
    geb:GM18_4066 (703 target-flexibility) (319 robustness)
    geb:GM18_4069 (659 target-flexibility) (240 robustness)
    geb:GM18_4095 (138 target-flexibility) (66 robustness)
    geb:GM18_4108 (222 target-flexibility) (83 robustness)
    geb:GM18_4149 (0 target-flexibility) (0 robustness)
    geb:GM18_4150 (0 target-flexibility) (0 robustness)
    geb:GM18_4151 (0 target-flexibility) (0 robustness)
    geb:GM18_4171 (0 target-flexibility) (0 robustness)
    geb:GM18_4219 (600 target-flexibility) (126 robustness)
    geb:GM18_4239 (91 target-flexibility) (91 robustness)
    geb:GM18_4250 (0 target-flexibility) (0 robustness)
    geb:GM18_4391 (80 target-flexibility) (80 robustness)
    geb:GM18_4453 (1108 target-flexibility) (319 robustness)
    geb:GM18_4463 (0 target-flexibility) (0 robustness)
    geb:GM18_4466 (0 target-flexibility) (0 robustness)
    geb:GM18_4516 (239 target-flexibility) (99 robustness)
    gem:GM21_0195 (691 target-flexibility) (528 robustness)
    gem:GM21_0244 (0 target-flexibility) (0 robustness)
    gem:GM21_0245 (0 target-flexibility) (0 robustness)
    gem:GM21_0264 (1041 target-flexibility) (243 robustness)
    gem:GM21_0265 (1041 target-flexibility) (243 robustness)
    gem:GM21_0503 (239 target-flexibility) (67 robustness)
    gem:GM21_0506 (140 target-flexibility) (71 robustness)
    gem:GM21_0510 (76 target-flexibility) (76 robustness)
    gem:GM21_0577 (0 target-flexibility) (0 robustness)
    gem:GM21_0580 (0 target-flexibility) (0 robustness)
    gem:GM21_0718 (323 target-flexibility) (101 robustness)
    gem:GM21_0766 (0 target-flexibility) (0 robustness)
    gem:GM21_0883 (1169 target-flexibility) (76 robustness)
    gem:GM21_0899 (0 target-flexibility) (0 robustness)
    gem:GM21_0900 (0 target-flexibility) (0 robustness)
    gem:GM21_0925 (686 target-flexibility) (192 robustness)
    gem:GM21_1040 (0 target-flexibility) (0 robustness)
    gem:GM21_1041 (0 target-flexibility) (0 robustness)
    gem:GM21_1080 (76 target-flexibility) (76 robustness)
    gem:GM21_1096 (528 target-flexibility) (157 robustness)
    gem:GM21_1097 (0 target-flexibility) (0 robustness)
    gem:GM21_1154 (1108 target-flexibility) (319 robustness)
    gem:GM21_1322 (752 target-flexibility) (76 robustness)
    gem:GM21_1355 (239 target-flexibility) (99 robustness)
    gem:GM21_1385 (0 target-flexibility) (0 robustness)
    gem:GM21_1413 (0 target-flexibility) (0 robustness)
    gem:GM21_1499 (841 target-flexibility) (126 robustness)
    gem:GM21_1667 (139 target-flexibility) (139 robustness)
    gem:GM21_1771 (0 target-flexibility) (0 robustness)
    gem:GM21_1884 (600 target-flexibility) (126 robustness)
    gem:GM21_1949 (70 target-flexibility) (70 robustness)
    gem:GM21_1950 (0 target-flexibility) (0 robustness)
    gem:GM21_1951 (700 target-flexibility) (89 robustness)
    gem:GM21_1966 (262 target-flexibility) (86 robustness)
    gem:GM21_1992 (0 target-flexibility) (0 robustness)
    gem:GM21_2011 (0 target-flexibility) (0 robustness)
    gem:GM21_2035 (0 target-flexibility) (0 robustness)
    gem:GM21_2043 (0 target-flexibility) (0 robustness)
    gem:GM21_2072 (0 target-flexibility) (0 robustness)
    gem:GM21_2166 (0 target-flexibility) (0 robustness)
    gem:GM21_2312 (897 target-flexibility) (71 robustness)
    gem:GM21_2457 (139 target-flexibility) (72 robustness)
    gem:GM21_2469 (821 target-flexibility) (137 robustness)
    gem:GM21_2561 (924 target-flexibility) (101 robustness)
    gem:GM21_2662 (150 target-flexibility) (76 robustness)
    gem:GM21_2685 (212 target-flexibility) (73 robustness)
    gem:GM21_2818 (700 target-flexibility) (89 robustness)
    gem:GM21_2903 (1041 target-flexibility) (243 robustness)
    gem:GM21_3025 (1169 target-flexibility) (76 robustness)
    gem:GM21_3529 (91 target-flexibility) (91 robustness)
    gem:GM21_3795 (0 target-flexibility) (0 robustness)
    geo:Geob_0099 (659 target-flexibility) (240 robustness)
    geo:Geob_0150 (0 target-flexibility) (0 robustness)
    geo:Geob_0247 (0 target-flexibility) (0 robustness)
    geo:Geob_0248 (0 target-flexibility) (0 robustness)
    geo:Geob_0284 (0 target-flexibility) (0 robustness)
    geo:Geob_0378 (691 target-flexibility) (528 robustness)
    geo:Geob_0392 (222 target-flexibility) (83 robustness)
    geo:Geob_0461 (80 target-flexibility) (80 robustness)
    geo:Geob_0514 (924 target-flexibility) (101 robustness)
    geo:Geob_0532 (0 target-flexibility) (0 robustness)
    geo:Geob_0543 (91 target-flexibility) (91 robustness)
    geo:Geob_0666 (1041 target-flexibility) (243 robustness)
    geo:Geob_0667 (1041 target-flexibility) (243 robustness)
    geo:Geob_0692 (0 target-flexibility) (0 robustness)
    geo:Geob_0693 (0 target-flexibility) (0 robustness)
    geo:Geob_0761 (0 target-flexibility) (0 robustness)
    geo:Geob_0762 (0 target-flexibility) (0 robustness)
    geo:Geob_0775 (239 target-flexibility) (67 robustness)
    geo:Geob_0776 (67 target-flexibility) (67 robustness)
    geo:Geob_0778 (140 target-flexibility) (71 robustness)
    geo:Geob_0781 (70 target-flexibility) (70 robustness)
    geo:Geob_0805 (0 target-flexibility) (0 robustness)
    geo:Geob_0952 (350 target-flexibility) (189 robustness)
    geo:Geob_1002 (1041 target-flexibility) (243 robustness)
    geo:Geob_1062 (0 target-flexibility) (0 robustness)
    geo:Geob_1088 (0 target-flexibility) (0 robustness)
    geo:Geob_1123 (138 target-flexibility) (66 robustness)
    geo:Geob_1129 (239 target-flexibility) (99 robustness)
    geo:Geob_1143 (239 target-flexibility) (99 robustness)
    geo:Geob_1167 (600 target-flexibility) (126 robustness)
    geo:Geob_1333 (0 target-flexibility) (0 robustness)
    geo:Geob_1367 (1041 target-flexibility) (243 robustness)
    geo:Geob_1368 (1041 target-flexibility) (243 robustness)
    geo:Geob_1403 (528 target-flexibility) (157 robustness)
    geo:Geob_1417 (91 target-flexibility) (91 robustness)
    geo:Geob_1420 (64 target-flexibility) (64 robustness)
    geo:Geob_1439 (0 target-flexibility) (0 robustness)
    geo:Geob_1458 (0 target-flexibility) (0 robustness)
    geo:Geob_1504 (841 target-flexibility) (126 robustness)
    geo:Geob_1550 (350 target-flexibility) (189 robustness)
    geo:Geob_1637 (0 target-flexibility) (0 robustness)
    geo:Geob_1647 (0 target-flexibility) (0 robustness)
    geo:Geob_1656 (175 target-flexibility) (96 robustness)
    geo:Geob_1753 (0 target-flexibility) (0 robustness)
    geo:Geob_1870 (0 target-flexibility) (0 robustness)
    geo:Geob_1910 (659 target-flexibility) (240 robustness)
    geo:Geob_1911 (703 target-flexibility) (319 robustness)
    geo:Geob_1980 (358 target-flexibility) (124 robustness)
    geo:Geob_2094 (71 target-flexibility) (71 robustness)
    geo:Geob_2134 (0 target-flexibility) (0 robustness)
    geo:Geob_2151 (691 target-flexibility) (528 robustness)
    geo:Geob_2171 (0 target-flexibility) (0 robustness)
    geo:Geob_2241 (175 target-flexibility) (96 robustness)
    geo:Geob_2295 (64 target-flexibility) (64 robustness)
    geo:Geob_2315 (64 target-flexibility) (64 robustness)
    geo:Geob_2459 (528 target-flexibility) (157 robustness)
    geo:Geob_2507 (358 target-flexibility) (124 robustness)
    geo:Geob_2508 (64 target-flexibility) (64 robustness)
    geo:Geob_2526 (358 target-flexibility) (124 robustness)
    geo:Geob_2530 (528 target-flexibility) (157 robustness)
    geo:Geob_2612 (1108 target-flexibility) (319 robustness)
    geo:Geob_2614 (659 target-flexibility) (240 robustness)
    geo:Geob_2616 (703 target-flexibility) (319 robustness)
    geo:Geob_2629 (1169 target-flexibility) (76 robustness)
    geo:Geob_2661 (752 target-flexibility) (76 robustness)
    geo:Geob_2796 (0 target-flexibility) (0 robustness)
    geo:Geob_2804 (0 target-flexibility) (0 robustness)
    geo:Geob_2897 (600 target-flexibility) (126 robustness)
    geo:Geob_2923 (0 target-flexibility) (0 robustness)
    geo:Geob_2938 (841 target-flexibility) (126 robustness)
    geo:Geob_3010 (0 target-flexibility) (0 robustness)
    geo:Geob_3049 (358 target-flexibility) (124 robustness)
    geo:Geob_3082 (212 target-flexibility) (73 robustness)
    geo:Geob_3264 (897 target-flexibility) (71 robustness)
    geo:Geob_3462 (0 target-flexibility) (0 robustness)
    geo:Geob_3549 (924 target-flexibility) (101 robustness)
    geo:Geob_3651 (166 target-flexibility) (99 robustness)
    geo:Geob_3652 (166 target-flexibility) (99 robustness)
    geo:Geob_3664 (1169 target-flexibility) (76 robustness)
    geo:Geob_3708 (1108 target-flexibility) (319 robustness)
    glo:Glov_0210 (0 target-flexibility) (0 robustness)
    glo:Glov_0365 (691 target-flexibility) (528 robustness)
    glo:Glov_0418 (1108 target-flexibility) (319 robustness)
    glo:Glov_0474 (0 target-flexibility) (0 robustness)
    glo:Glov_0479 (0 target-flexibility) (0 robustness)
    glo:Glov_0555 (0 target-flexibility) (0 robustness)
    glo:Glov_0584 (357 target-flexibility) (102 robustness)
    glo:Glov_0674 (67 target-flexibility) (67 robustness)
    glo:Glov_0675 (239 target-flexibility) (67 robustness)
    glo:Glov_0692 (0 target-flexibility) (0 robustness)
    glo:Glov_0757 (71 target-flexibility) (71 robustness)
    glo:Glov_0763 (339 target-flexibility) (98 robustness)
    glo:Glov_0786 (902 target-flexibility) (228 robustness)
    glo:Glov_0795 (1041 target-flexibility) (243 robustness)
    glo:Glov_0796 (1041 target-flexibility) (243 robustness)
    glo:Glov_0808 (796 target-flexibility) (85 robustness)
    glo:Glov_0823 (0 target-flexibility) (0 robustness)
    glo:Glov_0835 (358 target-flexibility) (124 robustness)
    glo:Glov_0892 (700 target-flexibility) (89 robustness)
    glo:Glov_0893 (0 target-flexibility) (0 robustness)
    glo:Glov_0909 (0 target-flexibility) (0 robustness)
    glo:Glov_0981 (222 target-flexibility) (83 robustness)
    glo:Glov_1018 (0 target-flexibility) (0 robustness)
    glo:Glov_1019 (0 target-flexibility) (0 robustness)
    glo:Glov_1024 (528 target-flexibility) (157 robustness)
    glo:Glov_1067 (0 target-flexibility) (0 robustness)
    glo:Glov_1099 (76 target-flexibility) (76 robustness)
    glo:Glov_1157 (0 target-flexibility) (0 robustness)
    glo:Glov_1159 (700 target-flexibility) (89 robustness)
    glo:Glov_1211 (686 target-flexibility) (192 robustness)
    glo:Glov_1213 (686 target-flexibility) (192 robustness)
    glo:Glov_1512 (796 target-flexibility) (85 robustness)
    glo:Glov_1531 (0 target-flexibility) (0 robustness)
    glo:Glov_1607 (358 target-flexibility) (124 robustness)
    glo:Glov_1616 (600 target-flexibility) (126 robustness)
    glo:Glov_1622 (752 target-flexibility) (76 robustness)
    glo:Glov_1658 (0 target-flexibility) (0 robustness)
    glo:Glov_1768 (1385 target-flexibility) (204 robustness)
    glo:Glov_1858 (0 target-flexibility) (0 robustness)
    glo:Glov_1910 (0 target-flexibility) (0 robustness)
    glo:Glov_1934 (703 target-flexibility) (319 robustness)
    glo:Glov_1936 (659 target-flexibility) (240 robustness)
    glo:Glov_1937 (339 target-flexibility) (98 robustness)
    glo:Glov_1939 (1108 target-flexibility) (319 robustness)
    glo:Glov_1947 (691 target-flexibility) (528 robustness)
    glo:Glov_2038 (841 target-flexibility) (126 robustness)
    glo:Glov_2085 (897 target-flexibility) (71 robustness)
    glo:Glov_2116 (0 target-flexibility) (0 robustness)
    glo:Glov_2128 (405 target-flexibility) (70 robustness)
    glo:Glov_2182 (1169 target-flexibility) (76 robustness)
    glo:Glov_2193 (703 target-flexibility) (319 robustness)
    glo:Glov_2194 (659 target-flexibility) (240 robustness)
    glo:Glov_2235 (1169 target-flexibility) (76 robustness)
    glo:Glov_2247 (0 target-flexibility) (0 robustness)
    glo:Glov_2405 (0 target-flexibility) (0 robustness)
    glo:Glov_2418 (1108 target-flexibility) (319 robustness)
    glo:Glov_2503 (902 target-flexibility) (228 robustness)
    glo:Glov_2508 (0 target-flexibility) (0 robustness)
    glo:Glov_2538 (212 target-flexibility) (73 robustness)
    glo:Glov_2562 (600 target-flexibility) (126 robustness)
    glo:Glov_2600 (1385 target-flexibility) (204 robustness)
    glo:Glov_2713 (76 target-flexibility) (76 robustness)
    glo:Glov_2764 (91 target-flexibility) (91 robustness)
    glo:Glov_2804 (1041 target-flexibility) (243 robustness)
    glo:Glov_2962 (0 target-flexibility) (0 robustness)
    glo:Glov_3068 (528 target-flexibility) (157 robustness)
    glo:Glov_3139 (80 target-flexibility) (80 robustness)
    glo:Glov_3149 (138 target-flexibility) (66 robustness)
    glo:Glov_3217 (350 target-flexibility) (189 robustness)
    glo:Glov_3322 (0 target-flexibility) (0 robustness)
    glo:Glov_3325 (841 target-flexibility) (126 robustness)
    glo:Glov_3365 (0 target-flexibility) (0 robustness)
    glo:Glov_3399 (0 target-flexibility) (0 robustness)
    glo:Glov_3457 (0 target-flexibility) (0 robustness)
    glo:Glov_3585 (0 target-flexibility) (0 robustness)
    glo:Glov_3634 (350 target-flexibility) (189 robustness)
    glo:Glov_3677 (91 target-flexibility) (91 robustness)
    glo:Glov_3718 (0 target-flexibility) (0 robustness)
    gme:Gmet_0065 (0 target-flexibility) (0 robustness)
    gme:Gmet_0104 (796 target-flexibility) (85 robustness)
    gme:Gmet_0178 (1041 target-flexibility) (243 robustness)
    gme:Gmet_0205 (138 target-flexibility) (66 robustness)
    gme:Gmet_0219 (239 target-flexibility) (99 robustness)
    gme:Gmet_0264 (528 target-flexibility) (157 robustness)
    gme:Gmet_0301 (700 target-flexibility) (89 robustness)
    gme:Gmet_0336 (0 target-flexibility) (0 robustness)
    gme:Gmet_0337 (700 target-flexibility) (89 robustness)
    gme:Gmet_0351 (222 target-flexibility) (83 robustness)
    gme:Gmet_0388 (0 target-flexibility) (0 robustness)
    gme:Gmet_0389 (0 target-flexibility) (0 robustness)
    gme:Gmet_0407 (239 target-flexibility) (67 robustness)
    gme:Gmet_0408 (67 target-flexibility) (67 robustness)
    gme:Gmet_0410 (140 target-flexibility) (71 robustness)
    gme:Gmet_0413 (70 target-flexibility) (70 robustness)
    gme:Gmet_0471 (91 target-flexibility) (91 robustness)
    gme:Gmet_0551 (1041 target-flexibility) (243 robustness)
    gme:Gmet_0552 (1041 target-flexibility) (243 robustness)
    gme:Gmet_0661 (405 target-flexibility) (169 robustness)
    gme:Gmet_0707 (0 target-flexibility) (0 robustness)
    gme:Gmet_0729 (0 target-flexibility) (0 robustness)
    gme:Gmet_0730 (0 target-flexibility) (0 robustness)
    gme:Gmet_0770 (706 target-flexibility) (173 robustness)
    gme:Gmet_0872 (358 target-flexibility) (124 robustness)
    gme:Gmet_0884 (350 target-flexibility) (189 robustness)
    gme:Gmet_0940 (0 target-flexibility) (0 robustness)
    gme:Gmet_0950 (0 target-flexibility) (0 robustness)
    gme:Gmet_0956 (212 target-flexibility) (73 robustness)
    gme:Gmet_0992 (358 target-flexibility) (124 robustness)
    gme:Gmet_1016 (262 target-flexibility) (86 robustness)
    gme:Gmet_1038 (0 target-flexibility) (0 robustness)
    gme:Gmet_1124 (924 target-flexibility) (101 robustness)
    gme:Gmet_1211 (600 target-flexibility) (126 robustness)
    gme:Gmet_1265 (841 target-flexibility) (126 robustness)
    gme:Gmet_1297 (734 target-flexibility) (110 robustness)
    gme:Gmet_1357 (752 target-flexibility) (76 robustness)
    gme:Gmet_1469 (0 target-flexibility) (0 robustness)
    gme:Gmet_1486 (0 target-flexibility) (0 robustness)
    gme:Gmet_1487 (796 target-flexibility) (85 robustness)
    gme:Gmet_1558 (528 target-flexibility) (157 robustness)
    gme:Gmet_1580 (0 target-flexibility) (0 robustness)
    gme:Gmet_1599 (1108 target-flexibility) (319 robustness)
    gme:Gmet_1601 (659 target-flexibility) (240 robustness)
    gme:Gmet_1603 (703 target-flexibility) (319 robustness)
    gme:Gmet_1604 (486 target-flexibility) (89 robustness)
    gme:Gmet_1613 (0 target-flexibility) (0 robustness)
    gme:Gmet_1694 (659 target-flexibility) (240 robustness)
    gme:Gmet_1695 (703 target-flexibility) (319 robustness)
    gme:Gmet_1769 (897 target-flexibility) (71 robustness)
    gme:Gmet_1774 (405 target-flexibility) (169 robustness)
    gme:Gmet_1804 (0 target-flexibility) (0 robustness)
    gme:Gmet_1818 (0 target-flexibility) (0 robustness)
    gme:Gmet_1825 (0 target-flexibility) (0 robustness)
    gme:Gmet_1879 (841 target-flexibility) (126 robustness)
    gme:Gmet_1896 (323 target-flexibility) (101 robustness)
    gme:Gmet_1910 (734 target-flexibility) (110 robustness)
    gme:Gmet_1934 (1169 target-flexibility) (76 robustness)
    gme:Gmet_1946 (600 target-flexibility) (126 robustness)
    gme:Gmet_1954 (854 target-flexibility) (204 robustness)
    gme:Gmet_2007 (0 target-flexibility) (0 robustness)
    gme:Gmet_2019 (239 target-flexibility) (99 robustness)
    gme:Gmet_2024 (821 target-flexibility) (137 robustness)
    gme:Gmet_2059 (659 target-flexibility) (240 robustness)
    gme:Gmet_2068 (0 target-flexibility) (0 robustness)
    gme:Gmet_2069 (0 target-flexibility) (0 robustness)
    gme:Gmet_2095 (700 target-flexibility) (89 robustness)
    gme:Gmet_2101 (706 target-flexibility) (173 robustness)
    gme:Gmet_2172 (821 target-flexibility) (137 robustness)
    gme:Gmet_2229 (0 target-flexibility) (0 robustness)
    gme:Gmet_2260 (0 target-flexibility) (0 robustness)
    gme:Gmet_2261 (0 target-flexibility) (0 robustness)
    gme:Gmet_2300 (0 target-flexibility) (0 robustness)
    gme:Gmet_2319 (691 target-flexibility) (528 robustness)
    gme:Gmet_2329 (0 target-flexibility) (0 robustness)
    gme:Gmet_2330 (0 target-flexibility) (0 robustness)
    gme:Gmet_2340 (790 target-flexibility) (134 robustness)
    gme:Gmet_2353 (139 target-flexibility) (66 robustness)
    gme:Gmet_2360 (71 target-flexibility) (71 robustness)
    gme:Gmet_2473 (0 target-flexibility) (0 robustness)
    gme:Gmet_2482 (686 target-flexibility) (192 robustness)
    gme:Gmet_2493 (686 target-flexibility) (192 robustness)
    gme:Gmet_2567 (139 target-flexibility) (66 robustness)
    gme:Gmet_2621 (486 target-flexibility) (89 robustness)
    gme:Gmet_2689 (924 target-flexibility) (101 robustness)
    gme:Gmet_2763 (262 target-flexibility) (86 robustness)
    gme:Gmet_2764 (323 target-flexibility) (101 robustness)
    gme:Gmet_2767 (0 target-flexibility) (0 robustness)
    gme:Gmet_2822 (1169 target-flexibility) (76 robustness)
    gme:Gmet_2910 (91 target-flexibility) (91 robustness)
    gme:Gmet_2911 (854 target-flexibility) (204 robustness)
    gme:Gmet_2988 (528 target-flexibility) (157 robustness)
    gme:Gmet_3078 (0 target-flexibility) (0 robustness)
    gme:Gmet_3159 (0 target-flexibility) (0 robustness)
    gme:Gmet_3175 (0 target-flexibility) (0 robustness)
    gme:Gmet_3272 (1108 target-flexibility) (319 robustness)
    gme:Gmet_3339 (350 target-flexibility) (189 robustness)
    gme:Gmet_3356 (80 target-flexibility) (80 robustness)
    gme:Gmet_3422 (691 target-flexibility) (528 robustness)
    gpi:GPICK_00285 (405 target-flexibility) (70 robustness)
    gpi:GPICK_00320 (0 target-flexibility) (0 robustness)
    gpi:GPICK_01105 (175 target-flexibility) (96 robustness)
    gpi:GPICK_01155 (358 target-flexibility) (124 robustness)
    gpi:GPICK_01260 (528 target-flexibility) (157 robustness)
    gpi:GPICK_01450 (138 target-flexibility) (66 robustness)
    gpi:GPICK_01855 (0 target-flexibility) (0 robustness)
    gpi:GPICK_02005 (528 target-flexibility) (157 robustness)
    gpi:GPICK_02075 (222 target-flexibility) (83 robustness)
    gpi:GPICK_02235 (0 target-flexibility) (0 robustness)
    gpi:GPICK_02240 (0 target-flexibility) (0 robustness)
    gpi:GPICK_02335 (239 target-flexibility) (67 robustness)
    gpi:GPICK_02340 (67 target-flexibility) (67 robustness)
    gpi:GPICK_02630 (91 target-flexibility) (91 robustness)
    gpi:GPICK_02895 (1041 target-flexibility) (243 robustness)
    gpi:GPICK_02900 (1041 target-flexibility) (243 robustness)
    gpi:GPICK_03195 (166 target-flexibility) (99 robustness)
    gpi:GPICK_03200 (166 target-flexibility) (99 robustness)
    gpi:GPICK_03805 (358 target-flexibility) (124 robustness)
    gpi:GPICK_03840 (64 target-flexibility) (64 robustness)
    gpi:GPICK_04075 (1169 target-flexibility) (76 robustness)
    gpi:GPICK_04525 (0 target-flexibility) (0 robustness)
    gpi:GPICK_04615 (924 target-flexibility) (101 robustness)
    gpi:GPICK_04625 (841 target-flexibility) (126 robustness)
    gpi:GPICK_05040 (734 target-flexibility) (110 robustness)
    gpi:GPICK_05075 (0 target-flexibility) (0 robustness)
    gpi:GPICK_05080 (0 target-flexibility) (0 robustness)
    gpi:GPICK_05085 (1385 target-flexibility) (204 robustness)
    gpi:GPICK_05200 (64 target-flexibility) (64 robustness)
    gpi:GPICK_05385 (0 target-flexibility) (0 robustness)
    gpi:GPICK_05460 (212 target-flexibility) (73 robustness)
    gpi:GPICK_06080 (841 target-flexibility) (126 robustness)
    gpi:GPICK_06205 (175 target-flexibility) (96 robustness)
    gpi:GPICK_06250 (734 target-flexibility) (110 robustness)
    gpi:GPICK_06360 (821 target-flexibility) (137 robustness)
    gpi:GPICK_06970 (357 target-flexibility) (102 robustness)
    gpi:GPICK_07085 (841 target-flexibility) (126 robustness)
    gpi:GPICK_07275 (1169 target-flexibility) (76 robustness)
    gpi:GPICK_07425 (600 target-flexibility) (126 robustness)
    gpi:GPICK_07440 (0 target-flexibility) (0 robustness)
    gpi:GPICK_07485 (0 target-flexibility) (0 robustness)
    gpi:GPICK_07640 (796 target-flexibility) (85 robustness)
    gpi:GPICK_07650 (0 target-flexibility) (0 robustness)
    gpi:GPICK_07790 (0 target-flexibility) (0 robustness)
    gpi:GPICK_07830 (0 target-flexibility) (0 robustness)
    gpi:GPICK_07925 (1108 target-flexibility) (319 robustness)
    gpi:GPICK_07935 (659 target-flexibility) (240 robustness)
    gpi:GPICK_07945 (703 target-flexibility) (319 robustness)
    gpi:GPICK_08135 (1041 target-flexibility) (243 robustness)
    gpi:GPICK_08200 (0 target-flexibility) (0 robustness)
    gpi:GPICK_08240 (0 target-flexibility) (0 robustness)
    gpi:GPICK_08380 (732 target-flexibility) (78 robustness)
    gpi:GPICK_08415 (600 target-flexibility) (126 robustness)
    gpi:GPICK_08745 (752 target-flexibility) (76 robustness)
    gpi:GPICK_09020 (821 target-flexibility) (137 robustness)
    gpi:GPICK_09250 (528 target-flexibility) (157 robustness)
    gpi:GPICK_09325 (659 target-flexibility) (240 robustness)
    gpi:GPICK_09350 (0 target-flexibility) (0 robustness)
    gpi:GPICK_09355 (0 target-flexibility) (0 robustness)
    gpi:GPICK_09465 (0 target-flexibility) (0 robustness)
    gpi:GPICK_09850 (897 target-flexibility) (71 robustness)
    gpi:GPICK_09910 (1385 target-flexibility) (204 robustness)
    gpi:GPICK_10090 (323 target-flexibility) (101 robustness)
    gpi:GPICK_10225 (0 target-flexibility) (0 robustness)
    gpi:GPICK_10320 (691 target-flexibility) (528 robustness)
    gpi:GPICK_10370 (0 target-flexibility) (0 robustness)
    gpi:GPICK_10380 (0 target-flexibility) (0 robustness)
    gpi:GPICK_10485 (139 target-flexibility) (66 robustness)
    gpi:GPICK_10520 (71 target-flexibility) (71 robustness)
    gpi:GPICK_10945 (358 target-flexibility) (124 robustness)
    gpi:GPICK_11140 (924 target-flexibility) (101 robustness)
    gpi:GPICK_11530 (323 target-flexibility) (101 robustness)
    gpi:GPICK_11735 (0 target-flexibility) (0 robustness)
    gpi:GPICK_11740 (0 target-flexibility) (0 robustness)
    gpi:GPICK_11785 (686 target-flexibility) (192 robustness)
    gpi:GPICK_11795 (686 target-flexibility) (192 robustness)
    gpi:GPICK_12055 (0 target-flexibility) (0 robustness)
    gpi:GPICK_12360 (139 target-flexibility) (66 robustness)
    gpi:GPICK_12620 (350 target-flexibility) (189 robustness)
    gpi:GPICK_13255 (0 target-flexibility) (0 robustness)
    gpi:GPICK_13390 (91 target-flexibility) (91 robustness)
    gpi:GPICK_13690 (528 target-flexibility) (157 robustness)
    gpi:GPICK_14070 (0 target-flexibility) (0 robustness)
    gpi:GPICK_14470 (0 target-flexibility) (0 robustness)
    gpi:GPICK_14550 (0 target-flexibility) (0 robustness)
    gpi:GPICK_14900 (0 target-flexibility) (0 robustness)
    gpi:GPICK_15035 (1108 target-flexibility) (319 robustness)
    gpi:GPICK_15235 (350 target-flexibility) (189 robustness)
    gpi:GPICK_15315 (80 target-flexibility) (80 robustness)
    gpi:GPICK_15365 (796 target-flexibility) (85 robustness)
    gpi:GPICK_15425 (659 target-flexibility) (240 robustness)
    gpi:GPICK_15430 (703 target-flexibility) (319 robustness)
    gpi:GPICK_15670 (691 target-flexibility) (528 robustness)
    gsb:GSUB_00160 (138 target-flexibility) (138 robustness)
    gsb:GSUB_00535 (528 target-flexibility) (157 robustness)
    gsb:GSUB_00615 (80 target-flexibility) (80 robustness)
    gsb:GSUB_01295 (691 target-flexibility) (528 robustness)
    gsb:GSUB_01445 (0 target-flexibility) (0 robustness)
    gsb:GSUB_01620 (0 target-flexibility) (0 robustness)
    gsb:GSUB_01730 (222 target-flexibility) (83 robustness)
    gsb:GSUB_01835 (0 target-flexibility) (0 robustness)
    gsb:GSUB_01970 (231 target-flexibility) (158 robustness)
    gsb:GSUB_02190 (796 target-flexibility) (85 robustness)
    gsb:GSUB_02445 (528 target-flexibility) (157 robustness)
    gsb:GSUB_02540 (0 target-flexibility) (0 robustness)
    gsb:GSUB_02545 (0 target-flexibility) (0 robustness)
    gsb:GSUB_02660 (138 target-flexibility) (138 robustness)
    gsb:GSUB_02810 (1041 target-flexibility) (243 robustness)
    gsb:GSUB_02815 (1041 target-flexibility) (243 robustness)
    gsb:GSUB_03040 (138 target-flexibility) (66 robustness)
    gsb:GSUB_03270 (0 target-flexibility) (0 robustness)
    gsb:GSUB_03680 (243 target-flexibility) (97 robustness)
    gsb:GSUB_03880 (405 target-flexibility) (169 robustness)
    gsb:GSUB_04800 (752 target-flexibility) (76 robustness)
    gsb:GSUB_05075 (243 target-flexibility) (97 robustness)
    gsb:GSUB_05255 (0 target-flexibility) (0 robustness)
    gsb:GSUB_06155 (1169 target-flexibility) (76 robustness)
    gsb:GSUB_07140 (700 target-flexibility) (80 robustness)
    gsb:GSUB_07510 (691 target-flexibility) (528 robustness)
    gsb:GSUB_07515 (526 target-flexibility) (95 robustness)
    gsb:GSUB_07600 (0 target-flexibility) (0 robustness)
    gsb:GSUB_07655 (1108 target-flexibility) (319 robustness)
    gsb:GSUB_08095 (0 target-flexibility) (0 robustness)
    gsb:GSUB_08160 (0 target-flexibility) (0 robustness)
    gsb:GSUB_08195 (0 target-flexibility) (0 robustness)
    gsb:GSUB_08785 (902 target-flexibility) (228 robustness)
    gsb:GSUB_08840 (0 target-flexibility) (0 robustness)
    gsb:GSUB_08845 (0 target-flexibility) (0 robustness)
    gsb:GSUB_08910 (0 target-flexibility) (0 robustness)
    gsb:GSUB_09020 (0 target-flexibility) (0 robustness)
    gsb:GSUB_09095 (0 target-flexibility) (0 robustness)
    gsb:GSUB_09105 (0 target-flexibility) (0 robustness)
    gsb:GSUB_09165 (405 target-flexibility) (169 robustness)
    gsb:GSUB_09180 (897 target-flexibility) (71 robustness)
    gsb:GSUB_09375 (732 target-flexibility) (78 robustness)
    gsb:GSUB_09400 (600 target-flexibility) (126 robustness)
    gsb:GSUB_09555 (0 target-flexibility) (0 robustness)
    gsb:GSUB_10305 (700 target-flexibility) (80 robustness)
    gsb:GSUB_10480 (71 target-flexibility) (71 robustness)
    gsb:GSUB_10525 (1108 target-flexibility) (319 robustness)
    gsb:GSUB_10905 (841 target-flexibility) (126 robustness)
    gsb:GSUB_10925 (902 target-flexibility) (228 robustness)
    gsb:GSUB_11175 (212 target-flexibility) (73 robustness)
    gsb:GSUB_11235 (600 target-flexibility) (126 robustness)
    gsb:GSUB_12340 (841 target-flexibility) (126 robustness)
    gsb:GSUB_12475 (686 target-flexibility) (192 robustness)
    gsb:GSUB_12485 (686 target-flexibility) (192 robustness)
    gsb:GSUB_12790 (902 target-flexibility) (228 robustness)
    gsb:GSUB_12980 (231 target-flexibility) (158 robustness)
    gsb:GSUB_12985 (70 target-flexibility) (70 robustness)
    gsb:GSUB_13010 (67 target-flexibility) (67 robustness)
    gsb:GSUB_13015 (239 target-flexibility) (67 robustness)
    gsb:GSUB_13265 (600 target-flexibility) (126 robustness)
    gsb:GSUB_13365 (0 target-flexibility) (0 robustness)
    gsb:GSUB_13565 (528 target-flexibility) (157 robustness)
    gsb:GSUB_13655 (0 target-flexibility) (0 robustness)
    gsb:GSUB_13975 (0 target-flexibility) (0 robustness)
    gsb:GSUB_14410 (1041 target-flexibility) (243 robustness)
    gsb:GSUB_15430 (0 target-flexibility) (0 robustness)
    gsb:GSUB_15700 (0 target-flexibility) (0 robustness)
    gsb:GSUB_17495 (526 target-flexibility) (95 robustness)
    gsu:GSU0067 (0 target-flexibility) (0 robustness)
    gsu:GSU0094 (691 target-flexibility) (528 robustness)
    gsu:GSU0152 (138 target-flexibility) (66 robustness)
    gsu:GSU0290 (1108 target-flexibility) (319 robustness)
    gsu:GSU0337 (80 target-flexibility) (80 robustness)
    gsu:GSU0371 (0 target-flexibility) (0 robustness)
    gsu:GSU0460 (703 target-flexibility) (319 robustness)
    gsu:GSU0461 (659 target-flexibility) (240 robustness)
    gsu:GSU0482 (0 target-flexibility) (0 robustness)
    gsu:GSU0535 (528 target-flexibility) (157 robustness)
    gsu:GSU0604 (91 target-flexibility) (91 robustness)
    gsu:GSU0686 (1169 target-flexibility) (76 robustness)
    gsu:GSU0846 (262 target-flexibility) (86 robustness)
    gsu:GSU0999 (139 target-flexibility) (66 robustness)
    gsu:GSU1023 (0 target-flexibility) (0 robustness)
    gsu:GSU1061 (1385 target-flexibility) (204 robustness)
    gsu:GSU1242 (1385 target-flexibility) (204 robustness)
    gsu:GSU1271 (897 target-flexibility) (71 robustness)
    gsu:GSU1463 (752 target-flexibility) (76 robustness)
    gsu:GSU1582 (0 target-flexibility) (0 robustness)
    gsu:GSU1601 (1108 target-flexibility) (319 robustness)
    gsu:GSU1603 (659 target-flexibility) (240 robustness)
    gsu:GSU1605 (703 target-flexibility) (319 robustness)
    gsu:GSU1623 (0 target-flexibility) (0 robustness)
    gsu:GSU1729 (0 target-flexibility) (0 robustness)
    gsu:GSU1737 (0 target-flexibility) (0 robustness)
    gsu:GSU1764 (1169 target-flexibility) (76 robustness)
    gsu:GSU1798 (841 target-flexibility) (126 robustness)
    gsu:GSU1906 (841 target-flexibility) (126 robustness)
    gsu:GSU2011 (358 target-flexibility) (124 robustness)
    gsu:GSU2045 (212 target-flexibility) (73 robustness)
    gsu:GSU2066 (0 target-flexibility) (0 robustness)
    gsu:GSU2209 (0 target-flexibility) (0 robustness)
    gsu:GSU2230 (691 target-flexibility) (528 robustness)
    gsu:GSU2241 (0 target-flexibility) (0 robustness)
    gsu:GSU2264 (139 target-flexibility) (66 robustness)
    gsu:GSU2271 (71 target-flexibility) (71 robustness)
    gsu:GSU2307 (0 target-flexibility) (0 robustness)
    gsu:GSU2366 (0 target-flexibility) (0 robustness)
    gsu:GSU2375 (686 target-flexibility) (192 robustness)
    gsu:GSU2379 (686 target-flexibility) (192 robustness)
    gsu:GSU2445 (262 target-flexibility) (86 robustness)
    gsu:GSU2446 (323 target-flexibility) (101 robustness)
    gsu:GSU2570 (358 target-flexibility) (124 robustness)
    gsu:GSU2588 (323 target-flexibility) (101 robustness)
    gsu:GSU2786 (358 target-flexibility) (124 robustness)
    gsu:GSU2918 (1041 target-flexibility) (243 robustness)
    gsu:GSU2919 (1041 target-flexibility) (243 robustness)
    gsu:GSU3005 (91 target-flexibility) (91 robustness)
    gsu:GSU3095 (0 target-flexibility) (0 robustness)
    gsu:GSU3096 (0 target-flexibility) (0 robustness)
    gsu:GSU3136 (222 target-flexibility) (83 robustness)
    gsu:GSU3158 (528 target-flexibility) (157 robustness)
    gsu:GSU3257 (0 target-flexibility) (0 robustness)
    gsu:GSU3296 (0 target-flexibility) (0 robustness)
    gsu:GSU3372 (0 target-flexibility) (0 robustness)
    gsu:GSU3423 (1041 target-flexibility) (243 robustness)
    gur:Gura_0074 (0 target-flexibility) (0 robustness)
    gur:Gura_0135 (1108 target-flexibility) (319 robustness)
    gur:Gura_0155 (0 target-flexibility) (0 robustness)
    gur:Gura_0156 (0 target-flexibility) (0 robustness)
    gur:Gura_0185 (734 target-flexibility) (110 robustness)
    gur:Gura_0191 (0 target-flexibility) (0 robustness)
    gur:Gura_0227 (138 target-flexibility) (66 robustness)
    gur:Gura_0462 (0 target-flexibility) (0 robustness)
    gur:Gura_0491 (1041 target-flexibility) (243 robustness)
    gur:Gura_0492 (1041 target-flexibility) (243 robustness)
    gur:Gura_0620 (902 target-flexibility) (228 robustness)
    gur:Gura_0648 (0 target-flexibility) (0 robustness)
    gur:Gura_0822 (528 target-flexibility) (157 robustness)
    gur:Gura_0841 (1041 target-flexibility) (243 robustness)
    gur:Gura_0937 (0 target-flexibility) (0 robustness)
    gur:Gura_0970 (1041 target-flexibility) (243 robustness)
    gur:Gura_1018 (1169 target-flexibility) (76 robustness)
    gur:Gura_1046 (166 target-flexibility) (99 robustness)
    gur:Gura_1047 (166 target-flexibility) (99 robustness)
    gur:Gura_1346 (821 target-flexibility) (137 robustness)
    gur:Gura_1351 (821 target-flexibility) (137 robustness)
    gur:Gura_1387 (64 target-flexibility) (64 robustness)
    gur:Gura_1493 (358 target-flexibility) (124 robustness)
    gur:Gura_1570 (600 target-flexibility) (126 robustness)
    gur:Gura_1685 (0 target-flexibility) (0 robustness)
    gur:Gura_1691 (0 target-flexibility) (0 robustness)
    gur:Gura_1692 (0 target-flexibility) (0 robustness)
    gur:Gura_1705 (0 target-flexibility) (0 robustness)
    gur:Gura_1735 (686 target-flexibility) (192 robustness)
    gur:Gura_1799 (212 target-flexibility) (73 robustness)
    gur:Gura_1833 (358 target-flexibility) (124 robustness)
    gur:Gura_1856 (897 target-flexibility) (71 robustness)
    gur:Gura_1875 (1108 target-flexibility) (319 robustness)
    gur:Gura_1877 (659 target-flexibility) (240 robustness)
    gur:Gura_1879 (703 target-flexibility) (319 robustness)
    gur:Gura_2025 (0 target-flexibility) (0 robustness)
    gur:Gura_2061 (600 target-flexibility) (126 robustness)
    gur:Gura_2124 (0 target-flexibility) (0 robustness)
    gur:Gura_2133 (0 target-flexibility) (0 robustness)
    gur:Gura_2175 (1169 target-flexibility) (76 robustness)
    gur:Gura_2196 (752 target-flexibility) (76 robustness)
    gur:Gura_2199 (0 target-flexibility) (0 robustness)
    gur:Gura_2244 (0 target-flexibility) (0 robustness)
    gur:Gura_2259 (734 target-flexibility) (110 robustness)
    gur:Gura_2317 (841 target-flexibility) (126 robustness)
    gur:Gura_2419 (700 target-flexibility) (89 robustness)
    gur:Gura_2420 (0 target-flexibility) (0 robustness)
    gur:Gura_2501 (1385 target-flexibility) (204 robustness)
    gur:Gura_2532 (686 target-flexibility) (192 robustness)
    gur:Gura_2566 (526 target-flexibility) (95 robustness)
    gur:Gura_2598 (0 target-flexibility) (0 robustness)
    gur:Gura_2643 (526 target-flexibility) (95 robustness)
    gur:Gura_2655 (1784 target-flexibility) (162 robustness)
    gur:Gura_2659 (600 target-flexibility) (126 robustness)
    gur:Gura_2661 (0 target-flexibility) (0 robustness)
    gur:Gura_2953 (64 target-flexibility) (64 robustness)
    gur:Gura_3134 (0 target-flexibility) (0 robustness)
    gur:Gura_3154 (691 target-flexibility) (528 robustness)
    gur:Gura_3171 (0 target-flexibility) (0 robustness)
    gur:Gura_3240 (71 target-flexibility) (71 robustness)
    gur:Gura_3273 (0 target-flexibility) (0 robustness)
    gur:Gura_3288 (686 target-flexibility) (192 robustness)
    gur:Gura_3354 (1385 target-flexibility) (204 robustness)
    gur:Gura_3393 (0 target-flexibility) (0 robustness)
    gur:Gura_3485 (0 target-flexibility) (0 robustness)
    gur:Gura_3486 (0 target-flexibility) (0 robustness)
    gur:Gura_3541 (0 target-flexibility) (0 robustness)
    gur:Gura_3571 (700 target-flexibility) (89 robustness)
    gur:Gura_3574 (0 target-flexibility) (0 robustness)
    gur:Gura_3606 (703 target-flexibility) (319 robustness)
    gur:Gura_3607 (659 target-flexibility) (240 robustness)
    gur:Gura_3622 (139 target-flexibility) (139 robustness)
    gur:Gura_3715 (841 target-flexibility) (126 robustness)
    gur:Gura_3720 (902 target-flexibility) (228 robustness)
    gur:Gura_3830 (0 target-flexibility) (0 robustness)
    gur:Gura_3852 (91 target-flexibility) (91 robustness)
    gur:Gura_3854 (0 target-flexibility) (0 robustness)
    gur:Gura_3859 (528 target-flexibility) (157 robustness)
    gur:Gura_3907 (528 target-flexibility) (157 robustness)
    gur:Gura_3934 (0 target-flexibility) (0 robustness)
    gur:Gura_3978 (67 target-flexibility) (67 robustness)
    gur:Gura_3979 (239 target-flexibility) (67 robustness)
    gur:Gura_3998 (0 target-flexibility) (0 robustness)
    gur:Gura_3999 (0 target-flexibility) (0 robustness)
    gur:Gura_4053 (0 target-flexibility) (0 robustness)
    gur:Gura_4054 (0 target-flexibility) (0 robustness)
    gur:Gura_4055 (0 target-flexibility) (0 robustness)
    gur:Gura_4137 (139 target-flexibility) (139 robustness)
    gur:Gura_4183 (91 target-flexibility) (91 robustness)
    gur:Gura_4193 (0 target-flexibility) (0 robustness)
    gur:Gura_4245 (80 target-flexibility) (80 robustness)
    gur:Gura_4250 (600 target-flexibility) (126 robustness)
    gur:Gura_4313 (222 target-flexibility) (83 robustness)
    gur:Gura_4327 (691 target-flexibility) (528 robustness)
    gur:Gura_4348 (0 target-flexibility) (0 robustness)
    gur:Gura_4349 (0 target-flexibility) (0 robustness)
    gur:Gura_4409 (1784 target-flexibility) (162 robustness)
    hmr:Hipma_0012 (1041 target-flexibility) (243 robustness)
    hmr:Hipma_0121 (138 target-flexibility) (66 robustness)
    hmr:Hipma_0146 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0215 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0301 (222 target-flexibility) (83 robustness)
    hmr:Hipma_0341 (71 target-flexibility) (71 robustness)
    hmr:Hipma_0369 (146 target-flexibility) (70 robustness)
    hmr:Hipma_0390 (146 target-flexibility) (70 robustness)
    hmr:Hipma_0412 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0431 (752 target-flexibility) (76 robustness)
    hmr:Hipma_0432 (686 target-flexibility) (192 robustness)
    hmr:Hipma_0501 (897 target-flexibility) (71 robustness)
    hmr:Hipma_0574 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0577 (790 target-flexibility) (134 robustness)
    hmr:Hipma_0790 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0845 (80 target-flexibility) (80 robustness)
    hmr:Hipma_0954 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0956 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0985 (1169 target-flexibility) (76 robustness)
    hmr:Hipma_1016 (212 target-flexibility) (73 robustness)
    hmr:Hipma_1025 (1385 target-flexibility) (204 robustness)
    hmr:Hipma_1045 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1167 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1193 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1212 (659 target-flexibility) (240 robustness)
    hmr:Hipma_1397 (1385 target-flexibility) (204 robustness)
    hmr:Hipma_1401 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1462 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1516 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1526 (790 target-flexibility) (134 robustness)
    hmr:Hipma_1565 (686 target-flexibility) (192 robustness)
    hmr:Hipma_1646 (659 target-flexibility) (240 robustness)
    hmr:Hipma_1703 (0 target-flexibility) (0 robustness)
    hoh:Hoch_0005 (1108 target-flexibility) (319 robustness)
    hoh:Hoch_0106 (0 target-flexibility) (0 robustness)
    hoh:Hoch_0124 (841 target-flexibility) (126 robustness)
    hoh:Hoch_0217 (528 target-flexibility) (157 robustness)
    hoh:Hoch_0232 (1108 target-flexibility) (319 robustness)
    hoh:Hoch_0240 (323 target-flexibility) (101 robustness)
    hoh:Hoch_0330 (657 target-flexibility) (95 robustness)
    hoh:Hoch_0343 (80 target-flexibility) (80 robustness)
    hoh:Hoch_0345 (73 target-flexibility) (73 robustness)
    hoh:Hoch_0360 (231 target-flexibility) (158 robustness)
    hoh:Hoch_0379 (0 target-flexibility) (0 robustness)
    hoh:Hoch_0394 (138 target-flexibility) (66 robustness)
    hoh:Hoch_0481 (659 target-flexibility) (240 robustness)
    hoh:Hoch_0610 (1022 target-flexibility) (80 robustness)
    hoh:Hoch_0637 (691 target-flexibility) (528 robustness)
    hoh:Hoch_0966 (691 target-flexibility) (528 robustness)
    hoh:Hoch_1085 (855 target-flexibility) (138 robustness)
    hoh:Hoch_1478 (796 target-flexibility) (85 robustness)
    hoh:Hoch_1786 (752 target-flexibility) (105 robustness)
    hoh:Hoch_1849 (0 target-flexibility) (0 robustness)
    hoh:Hoch_1891 (530 target-flexibility) (162 robustness)
    hoh:Hoch_2046 (0 target-flexibility) (0 robustness)
    hoh:Hoch_2104 (902 target-flexibility) (228 robustness)
    hoh:Hoch_2190 (358 target-flexibility) (124 robustness)
    hoh:Hoch_2547 (358 target-flexibility) (124 robustness)
    hoh:Hoch_2693 (0 target-flexibility) (0 robustness)
    hoh:Hoch_3033 (855 target-flexibility) (138 robustness)
    hoh:Hoch_3186 (752 target-flexibility) (76 robustness)
    hoh:Hoch_3189 (212 target-flexibility) (73 robustness)
    hoh:Hoch_3234 (323 target-flexibility) (101 robustness)
    hoh:Hoch_3248 (0 target-flexibility) (0 robustness)
    hoh:Hoch_3514 (0 target-flexibility) (0 robustness)
    hoh:Hoch_3572 (0 target-flexibility) (0 robustness)
    hoh:Hoch_3581 (634 target-flexibility) (72 robustness)
    hoh:Hoch_3705 (323 target-flexibility) (101 robustness)
    hoh:Hoch_4024 (357 target-flexibility) (115 robustness)
    hoh:Hoch_4075 (74 target-flexibility) (74 robustness)
    hoh:Hoch_4175 (528 target-flexibility) (157 robustness)
    hoh:Hoch_4179 (528 target-flexibility) (157 robustness)
    hoh:Hoch_4359 (166 target-flexibility) (99 robustness)
    hoh:Hoch_4360 (752 target-flexibility) (105 robustness)
    hoh:Hoch_4463 (796 target-flexibility) (85 robustness)
    hoh:Hoch_4475 (80 target-flexibility) (80 robustness)
    hoh:Hoch_4947 (752 target-flexibility) (105 robustness)
    hoh:Hoch_4968 (1385 target-flexibility) (204 robustness)
    hoh:Hoch_5001 (659 target-flexibility) (240 robustness)
    hoh:Hoch_5030 (659 target-flexibility) (240 robustness)
    hoh:Hoch_5197 (659 target-flexibility) (240 robustness)
    hoh:Hoch_5539 (790 target-flexibility) (134 robustness)
    hoh:Hoch_5889 (222 target-flexibility) (83 robustness)
    hoh:Hoch_6483 (691 target-flexibility) (528 robustness)
    lip:LI0152 (0 target-flexibility) (0 robustness)
    lip:LI0379 (0 target-flexibility) (0 robustness)
    lip:LI0466 (0 target-flexibility) (0 robustness)
    lip:LI0580 (0 target-flexibility) (0 robustness)
    lip:LI0648 (212 target-flexibility) (73 robustness)
    lip:LI0764 (600 target-flexibility) (126 robustness)
    lip:LI1051 (222 target-flexibility) (83 robustness)
    lip:LI1066 (0 target-flexibility) (0 robustness)
    lip:LI1119 (600 target-flexibility) (126 robustness)
    lip:LIC023 (0 target-flexibility) (0 robustness)
    llu:AKJ09_00297 (691 target-flexibility) (528 robustness)
    llu:AKJ09_00381 (0 target-flexibility) (0 robustness)
    llu:AKJ09_00430 (323 target-flexibility) (101 robustness)
    llu:AKJ09_00583 (0 target-flexibility) (0 robustness)
    llu:AKJ09_00609 (0 target-flexibility) (0 robustness)
    llu:AKJ09_00756 (686 target-flexibility) (192 robustness)
    llu:AKJ09_00929 (0 target-flexibility) (0 robustness)
    llu:AKJ09_00976 (0 target-flexibility) (0 robustness)
    llu:AKJ09_00988 (343 target-flexibility) (180 robustness)
    llu:AKJ09_01024 (0 target-flexibility) (0 robustness)
    llu:AKJ09_01101 (175 target-flexibility) (78 robustness)
    llu:AKJ09_01219 (659 target-flexibility) (240 robustness)
    llu:AKJ09_01359 (659 target-flexibility) (240 robustness)
    llu:AKJ09_01443 (659 target-flexibility) (240 robustness)
    llu:AKJ09_01492 (1041 target-flexibility) (243 robustness)
    llu:AKJ09_01495 (0 target-flexibility) (0 robustness)
    llu:AKJ09_01814 (0 target-flexibility) (0 robustness)
    llu:AKJ09_01841 (659 target-flexibility) (240 robustness)
    llu:AKJ09_01852 (0 target-flexibility) (0 robustness)
    llu:AKJ09_01880 (734 target-flexibility) (110 robustness)
    llu:AKJ09_01932 (659 target-flexibility) (240 robustness)
    llu:AKJ09_02037 (301 target-flexibility) (154 robustness)
    llu:AKJ09_02362 (659 target-flexibility) (240 robustness)
    llu:AKJ09_02446 (752 target-flexibility) (105 robustness)
    llu:AKJ09_02465 (503 target-flexibility) (78 robustness)
    llu:AKJ09_02467 (1108 target-flexibility) (319 robustness)
    llu:AKJ09_02491 (175 target-flexibility) (78 robustness)
    llu:AKJ09_02570 (706 target-flexibility) (173 robustness)
    llu:AKJ09_02591 (902 target-flexibility) (228 robustness)
    llu:AKJ09_02664 (0 target-flexibility) (0 robustness)
    llu:AKJ09_02687 (697 target-flexibility) (78 robustness)
    llu:AKJ09_02763 (357 target-flexibility) (102 robustness)
    llu:AKJ09_02792 (138 target-flexibility) (138 robustness)
    llu:AKJ09_02816 (357 target-flexibility) (102 robustness)
    llu:AKJ09_02824 (855 target-flexibility) (138 robustness)
    llu:AKJ09_02949 (189 target-flexibility) (94 robustness)
    llu:AKJ09_02979 (228 target-flexibility) (83 robustness)
    llu:AKJ09_02991 (0 target-flexibility) (0 robustness)
    llu:AKJ09_03084 (924 target-flexibility) (101 robustness)
    llu:AKJ09_03136 (841 target-flexibility) (126 robustness)
    llu:AKJ09_03141 (841 target-flexibility) (126 robustness)
    llu:AKJ09_03445 (691 target-flexibility) (528 robustness)
    llu:AKJ09_03567 (752 target-flexibility) (76 robustness)
    llu:AKJ09_03571 (357 target-flexibility) (115 robustness)
    llu:AKJ09_03976 (0 target-flexibility) (0 robustness)
    llu:AKJ09_04170 (0 target-flexibility) (0 robustness)
    llu:AKJ09_04246 (358 target-flexibility) (104 robustness)
    llu:AKJ09_04269 (796 target-flexibility) (85 robustness)
    llu:AKJ09_04272 (434 target-flexibility) (67 robustness)
    llu:AKJ09_04281 (1183 target-flexibility) (114 robustness)
    llu:AKJ09_04504 (269 target-flexibility) (64 robustness)
    llu:AKJ09_04506 (902 target-flexibility) (228 robustness)
    llu:AKJ09_04690 (239 target-flexibility) (67 robustness)
    llu:AKJ09_04691 (67 target-flexibility) (67 robustness)
    llu:AKJ09_04767 (71 target-flexibility) (71 robustness)
    llu:AKJ09_04777 (821 target-flexibility) (137 robustness)
    llu:AKJ09_04857 (231 target-flexibility) (158 robustness)
    llu:AKJ09_04918 (358 target-flexibility) (104 robustness)
    llu:AKJ09_04925 (659 target-flexibility) (240 robustness)
    llu:AKJ09_05088 (821 target-flexibility) (137 robustness)
    llu:AKJ09_05091 (821 target-flexibility) (137 robustness)
    llu:AKJ09_05171 (1108 target-flexibility) (319 robustness)
    llu:AKJ09_05284 (0 target-flexibility) (0 robustness)
    llu:AKJ09_05314 (0 target-flexibility) (0 robustness)
    llu:AKJ09_05385 (138 target-flexibility) (138 robustness)
    llu:AKJ09_05466 (0 target-flexibility) (0 robustness)
    llu:AKJ09_05499 (0 target-flexibility) (0 robustness)
    llu:AKJ09_05604 (855 target-flexibility) (138 robustness)
    llu:AKJ09_05672 (497 target-flexibility) (186 robustness)
    llu:AKJ09_05860 (405 target-flexibility) (169 robustness)
    llu:AKJ09_05861 (0 target-flexibility) (0 robustness)
    llu:AKJ09_05870 (358 target-flexibility) (124 robustness)
    llu:AKJ09_06116 (1108 target-flexibility) (319 robustness)
    llu:AKJ09_06135 (357 target-flexibility) (115 robustness)
    llu:AKJ09_06149 (790 target-flexibility) (134 robustness)
    llu:AKJ09_06301 (902 target-flexibility) (228 robustness)
    llu:AKJ09_06311 (497 target-flexibility) (186 robustness)
    llu:AKJ09_06892 (706 target-flexibility) (173 robustness)
    llu:AKJ09_06902 (269 target-flexibility) (64 robustness)
    llu:AKJ09_06932 (0 target-flexibility) (0 robustness)
    llu:AKJ09_07273 (1041 target-flexibility) (243 robustness)
    llu:AKJ09_07279 (138 target-flexibility) (138 robustness)
    llu:AKJ09_07318 (902 target-flexibility) (228 robustness)
    llu:AKJ09_07370 (790 target-flexibility) (134 robustness)
    llu:AKJ09_07537 (301 target-flexibility) (154 robustness)
    llu:AKJ09_07617 (323 target-flexibility) (101 robustness)
    llu:AKJ09_07685 (657 target-flexibility) (95 robustness)
    llu:AKJ09_07813 (0 target-flexibility) (0 robustness)
    llu:AKJ09_07814 (0 target-flexibility) (0 robustness)
    llu:AKJ09_07818 (659 target-flexibility) (240 robustness)
    llu:AKJ09_07825 (821 target-flexibility) (137 robustness)
    llu:AKJ09_07946 (497 target-flexibility) (186 robustness)
    llu:AKJ09_07972 (72 target-flexibility) (72 robustness)
    llu:AKJ09_08079 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08130 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08203 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08204 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08207 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08280 (1108 target-flexibility) (319 robustness)
    llu:AKJ09_08366 (657 target-flexibility) (95 robustness)
    llu:AKJ09_08401 (528 target-flexibility) (157 robustness)
    llu:AKJ09_08434 (703 target-flexibility) (319 robustness)
    llu:AKJ09_08436 (703 target-flexibility) (319 robustness)
    llu:AKJ09_08534 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08543 (358 target-flexibility) (124 robustness)
    llu:AKJ09_08550 (1041 target-flexibility) (243 robustness)
    llu:AKJ09_08589 (1108 target-flexibility) (319 robustness)
    llu:AKJ09_08666 (323 target-flexibility) (101 robustness)
    llu:AKJ09_08711 (343 target-flexibility) (180 robustness)
    llu:AKJ09_08721 (323 target-flexibility) (101 robustness)
    llu:AKJ09_08807 (231 target-flexibility) (158 robustness)
    llu:AKJ09_08845 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08892 (703 target-flexibility) (319 robustness)
    llu:AKJ09_08893 (703 target-flexibility) (319 robustness)
    llu:AKJ09_08899 (222 target-flexibility) (83 robustness)
    llu:AKJ09_09034 (497 target-flexibility) (186 robustness)
    llu:AKJ09_09066 (528 target-flexibility) (157 robustness)
    llu:AKJ09_09070 (528 target-flexibility) (157 robustness)
    llu:AKJ09_09395 (659 target-flexibility) (240 robustness)
    llu:AKJ09_09399 (0 target-flexibility) (0 robustness)
    llu:AKJ09_09446 (530 target-flexibility) (162 robustness)
    llu:AKJ09_09477 (734 target-flexibility) (110 robustness)
    llu:AKJ09_09492 (752 target-flexibility) (105 robustness)
    llu:AKJ09_09548 (686 target-flexibility) (192 robustness)
    llu:AKJ09_09565 (0 target-flexibility) (0 robustness)
    llu:AKJ09_09576 (0 target-flexibility) (0 robustness)
    llu:AKJ09_09652 (0 target-flexibility) (0 robustness)
    llu:AKJ09_09653 (924 target-flexibility) (101 robustness)
    llu:AKJ09_09654 (924 target-flexibility) (101 robustness)
    llu:AKJ09_09735 (0 target-flexibility) (0 robustness)
    llu:AKJ09_09838 (691 target-flexibility) (528 robustness)
    llu:AKJ09_09908 (1183 target-flexibility) (114 robustness)
    llu:AKJ09_09992 (189 target-flexibility) (94 robustness)
    llu:AKJ09_10077 (855 target-flexibility) (138 robustness)
    llu:AKJ09_10095 (691 target-flexibility) (528 robustness)
    llu:AKJ09_10129 (0 target-flexibility) (0 robustness)
    llu:AKJ09_10188 (0 target-flexibility) (0 robustness)
    llu:AKJ09_10310 (1108 target-flexibility) (319 robustness)
    llu:AKJ09_10313 (503 target-flexibility) (78 robustness)
    llu:AKJ09_10314 (659 target-flexibility) (240 robustness)
    llu:AKJ09_10316 (703 target-flexibility) (319 robustness)
    llu:AKJ09_10333 (732 target-flexibility) (78 robustness)
    llu:AKJ09_10337 (228 target-flexibility) (83 robustness)
    llu:AKJ09_10397 (289 target-flexibility) (73 robustness)
    llu:AKJ09_10666 (703 target-flexibility) (319 robustness)
    llu:AKJ09_10708 (323 target-flexibility) (101 robustness)
    llu:AKJ09_10720 (343 target-flexibility) (180 robustness)
    llu:AKJ09_10739 (0 target-flexibility) (0 robustness)
    llu:AKJ09_10878 (343 target-flexibility) (180 robustness)
    llu:AKJ09_10905 (212 target-flexibility) (73 robustness)
    llu:AKJ09_10940 (697 target-flexibility) (78 robustness)
    llu:AKJ09_11102 (72 target-flexibility) (72 robustness)
    llu:AKJ09_11129 (358 target-flexibility) (124 robustness)
    llu:AKJ09_11361 (855 target-flexibility) (138 robustness)
    llu:AKJ09_11379 (530 target-flexibility) (162 robustness)
    llu:AKJ09_11455 (405 target-flexibility) (169 robustness)
    llu:AKJ09_11473 (659 target-flexibility) (240 robustness)
    mbd:MEBOL_000129 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_000187 (855 target-flexibility) (138 robustness)
    mbd:MEBOL_000191 (358 target-flexibility) (124 robustness)
    mbd:MEBOL_000258 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_000259 (700 target-flexibility) (77 robustness)
    mbd:MEBOL_000279 (734 target-flexibility) (110 robustness)
    mbd:MEBOL_000359 (691 target-flexibility) (528 robustness)
    mbd:MEBOL_000546 (357 target-flexibility) (102 robustness)
    mbd:MEBOL_000633 (1022 target-flexibility) (80 robustness)
    mbd:MEBOL_000658 (1183 target-flexibility) (114 robustness)
    mbd:MEBOL_000709 (526 target-flexibility) (95 robustness)
    mbd:MEBOL_000749 (790 target-flexibility) (134 robustness)
    mbd:MEBOL_000779 (530 target-flexibility) (162 robustness)
    mbd:MEBOL_000837 (706 target-flexibility) (173 robustness)
    mbd:MEBOL_000907 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_000935 (528 target-flexibility) (157 robustness)
    mbd:MEBOL_000951 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_001212 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_001262 (231 target-flexibility) (158 robustness)
    mbd:MEBOL_001387 (231 target-flexibility) (158 robustness)
    mbd:MEBOL_001393 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_001459 (228 target-flexibility) (83 robustness)
    mbd:MEBOL_001626 (239 target-flexibility) (99 robustness)
    mbd:MEBOL_001640 (231 target-flexibility) (158 robustness)
    mbd:MEBOL_001826 (323 target-flexibility) (101 robustness)
    mbd:MEBOL_001876 (821 target-flexibility) (137 robustness)
    mbd:MEBOL_001936 (1784 target-flexibility) (162 robustness)
    mbd:MEBOL_002073 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_002076 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_002081 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_002086 (1183 target-flexibility) (114 robustness)
    mbd:MEBOL_002196 (222 target-flexibility) (83 robustness)
    mbd:MEBOL_002331 (1022 target-flexibility) (80 robustness)
    mbd:MEBOL_002332 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_002444 (231 target-flexibility) (158 robustness)
    mbd:MEBOL_002466 (700 target-flexibility) (77 robustness)
    mbd:MEBOL_002467 (423 target-flexibility) (81 robustness)
    mbd:MEBOL_002469 (1022 target-flexibility) (80 robustness)
    mbd:MEBOL_002586 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_002622 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_002704 (659 target-flexibility) (240 robustness)
    mbd:MEBOL_002843 (657 target-flexibility) (95 robustness)
    mbd:MEBOL_002893 (359 target-flexibility) (65 robustness)
    mbd:MEBOL_002972 (659 target-flexibility) (240 robustness)
    mbd:MEBOL_003044 (659 target-flexibility) (240 robustness)
    mbd:MEBOL_003120 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_003149 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_003186 (706 target-flexibility) (173 robustness)
    mbd:MEBOL_003195 (703 target-flexibility) (319 robustness)
    mbd:MEBOL_003207 (855 target-flexibility) (138 robustness)
    mbd:MEBOL_003365 (706 target-flexibility) (173 robustness)
    mbd:MEBOL_003524 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_003610 (659 target-flexibility) (240 robustness)
    mbd:MEBOL_003612 (1108 target-flexibility) (319 robustness)
    mbd:MEBOL_003654 (528 target-flexibility) (157 robustness)
    mbd:MEBOL_003759 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_003801 (222 target-flexibility) (83 robustness)
    mbd:MEBOL_003817 (73 target-flexibility) (73 robustness)
    mbd:MEBOL_003822 (80 target-flexibility) (80 robustness)
    mbd:MEBOL_004017 (1385 target-flexibility) (204 robustness)
    mbd:MEBOL_004287 (359 target-flexibility) (65 robustness)
    mbd:MEBOL_004288 (855 target-flexibility) (138 robustness)
    mbd:MEBOL_004362 (790 target-flexibility) (134 robustness)
    mbd:MEBOL_004403 (343 target-flexibility) (180 robustness)
    mbd:MEBOL_004464 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_004536 (73 target-flexibility) (73 robustness)
    mbd:MEBOL_004563 (732 target-flexibility) (78 robustness)
    mbd:MEBOL_004613 (74 target-flexibility) (74 robustness)
    mbd:MEBOL_004626 (231 target-flexibility) (158 robustness)
    mbd:MEBOL_004723 (659 target-flexibility) (240 robustness)
    mbd:MEBOL_004742 (357 target-flexibility) (102 robustness)
    mbd:MEBOL_004866 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_004893 (796 target-flexibility) (85 robustness)
    mbd:MEBOL_004899 (734 target-flexibility) (110 robustness)
    mbd:MEBOL_004988 (343 target-flexibility) (180 robustness)
    mbd:MEBOL_005080 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_005163 (526 target-flexibility) (95 robustness)
    mbd:MEBOL_005201 (691 target-flexibility) (528 robustness)
    mbd:MEBOL_005217 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_005248 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_005276 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_005346 (706 target-flexibility) (173 robustness)
    mbd:MEBOL_005347 (706 target-flexibility) (173 robustness)
    mbd:MEBOL_005452 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_005477 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_005679 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_005688 (657 target-flexibility) (95 robustness)
    mbd:MEBOL_005729 (358 target-flexibility) (124 robustness)
    mbd:MEBOL_005896 (752 target-flexibility) (105 robustness)
    mbd:MEBOL_005961 (530 target-flexibility) (162 robustness)
    mbd:MEBOL_005962 (1108 target-flexibility) (319 robustness)
    mbd:MEBOL_005963 (503 target-flexibility) (78 robustness)
    mbd:MEBOL_005964 (659 target-flexibility) (240 robustness)
    mbd:MEBOL_005966 (703 target-flexibility) (319 robustness)
    mbd:MEBOL_005988 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006001 (71 target-flexibility) (71 robustness)
    mbd:MEBOL_006201 (323 target-flexibility) (101 robustness)
    mbd:MEBOL_006208 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006356 (231 target-flexibility) (158 robustness)
    mbd:MEBOL_006515 (821 target-flexibility) (137 robustness)
    mbd:MEBOL_006600 (343 target-flexibility) (180 robustness)
    mbd:MEBOL_006606 (503 target-flexibility) (78 robustness)
    mbd:MEBOL_006623 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006635 (228 target-flexibility) (83 robustness)
    mbd:MEBOL_006697 (239 target-flexibility) (99 robustness)
    mbd:MEBOL_006725 (752 target-flexibility) (105 robustness)
    mbd:MEBOL_006810 (706 target-flexibility) (173 robustness)
    mbd:MEBOL_006836 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006837 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006840 (897 target-flexibility) (71 robustness)
    mbd:MEBOL_006847 (1784 target-flexibility) (162 robustness)
    mbd:MEBOL_006903 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006920 (74 target-flexibility) (74 robustness)
    mbd:MEBOL_006939 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006971 (706 target-flexibility) (173 robustness)
    mbd:MEBOL_007199 (423 target-flexibility) (81 robustness)
    mbd:MEBOL_007247 (423 target-flexibility) (81 robustness)
    mbd:MEBOL_007560 (343 target-flexibility) (180 robustness)
    mbd:MEBOL_007627 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_007650 (821 target-flexibility) (137 robustness)
    mbd:MEBOL_007696 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_007699 (301 target-flexibility) (74 robustness)
    mbd:MEBOL_007700 (138 target-flexibility) (66 robustness)
    mbd:MEBOL_007718 (1385 target-flexibility) (204 robustness)
    mbd:MEBOL_007719 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_007750 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_007805 (301 target-flexibility) (74 robustness)
    mbd:MEBOL_007806 (528 target-flexibility) (157 robustness)
    mbd:MEBOL_007830 (659 target-flexibility) (240 robustness)
    mbd:MEBOL_007910 (212 target-flexibility) (73 robustness)
    mbd:MEBOL_007979 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_008059 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_008079 (752 target-flexibility) (76 robustness)
    mfu:LILAB_00500 (0 target-flexibility) (0 robustness)
    mfu:LILAB_00760 (0 target-flexibility) (0 robustness)
    mfu:LILAB_00790 (215 target-flexibility) (142 robustness)
    mfu:LILAB_00885 (528 target-flexibility) (157 robustness)
    mfu:LILAB_01140 (0 target-flexibility) (0 robustness)
    mfu:LILAB_01545 (336 target-flexibility) (81 robustness)
    mfu:LILAB_01860 (796 target-flexibility) (85 robustness)
    mfu:LILAB_01980 (0 target-flexibility) (0 robustness)
    mfu:LILAB_02370 (357 target-flexibility) (102 robustness)
    mfu:LILAB_03115 (732 target-flexibility) (78 robustness)
    mfu:LILAB_03385 (0 target-flexibility) (0 robustness)
    mfu:LILAB_03490 (154 target-flexibility) (80 robustness)
    mfu:LILAB_03630 (361 target-flexibility) (101 robustness)
    mfu:LILAB_03750 (528 target-flexibility) (157 robustness)
    mfu:LILAB_04135 (659 target-flexibility) (240 robustness)
    mfu:LILAB_04155 (357 target-flexibility) (115 robustness)
    mfu:LILAB_04510 (1108 target-flexibility) (319 robustness)
    mfu:LILAB_06150 (0 target-flexibility) (0 robustness)
    mfu:LILAB_06190 (1385 target-flexibility) (204 robustness)
    mfu:LILAB_06660 (924 target-flexibility) (101 robustness)
    mfu:LILAB_06720 (80 target-flexibility) (80 robustness)
    mfu:LILAB_06880 (222 target-flexibility) (83 robustness)
    mfu:LILAB_07065 (0 target-flexibility) (0 robustness)
    mfu:LILAB_07165 (821 target-flexibility) (137 robustness)
    mfu:LILAB_07270 (323 target-flexibility) (101 robustness)
    mfu:LILAB_07620 (1108 target-flexibility) (319 robustness)
    mfu:LILAB_07680 (659 target-flexibility) (240 robustness)
    mfu:LILAB_07990 (343 target-flexibility) (180 robustness)
    mfu:LILAB_08110 (361 target-flexibility) (101 robustness)
    mfu:LILAB_08200 (0 target-flexibility) (0 robustness)
    mfu:LILAB_09240 (0 target-flexibility) (0 robustness)
    mfu:LILAB_10620 (657 target-flexibility) (95 robustness)
    mfu:LILAB_10705 (336 target-flexibility) (81 robustness)
    mfu:LILAB_11470 (0 target-flexibility) (0 robustness)
    mfu:LILAB_11935 (659 target-flexibility) (240 robustness)
    mfu:LILAB_12180 (0 target-flexibility) (0 robustness)
    mfu:LILAB_14035 (154 target-flexibility) (80 robustness)
    mfu:LILAB_14400 (0 target-flexibility) (0 robustness)
    mfu:LILAB_14860 (0 target-flexibility) (0 robustness)
    mfu:LILAB_14960 (1784 target-flexibility) (162 robustness)
    mfu:LILAB_15365 (222 target-flexibility) (83 robustness)
    mfu:LILAB_15700 (0 target-flexibility) (0 robustness)
    mfu:LILAB_15915 (215 target-flexibility) (142 robustness)
    mfu:LILAB_16115 (1022 target-flexibility) (80 robustness)
    mfu:LILAB_16510 (231 target-flexibility) (158 robustness)
    mfu:LILAB_16625 (239 target-flexibility) (99 robustness)
    mfu:LILAB_17495 (691 target-flexibility) (528 robustness)
    mfu:LILAB_17540 (0 target-flexibility) (0 robustness)
    mfu:LILAB_19465 (0 target-flexibility) (0 robustness)
    mfu:LILAB_19495 (239 target-flexibility) (99 robustness)
    mfu:LILAB_20360 (0 target-flexibility) (0 robustness)
    mfu:LILAB_20395 (530 target-flexibility) (162 robustness)
    mfu:LILAB_20770 (1022 target-flexibility) (80 robustness)
    mfu:LILAB_21070 (357 target-flexibility) (102 robustness)
    mfu:LILAB_21465 (821 target-flexibility) (137 robustness)
    mfu:LILAB_21705 (691 target-flexibility) (528 robustness)
    mfu:LILAB_22395 (734 target-flexibility) (110 robustness)
    mfu:LILAB_22525 (0 target-flexibility) (0 robustness)
    mfu:LILAB_22655 (358 target-flexibility) (124 robustness)
    mfu:LILAB_24435 (343 target-flexibility) (180 robustness)
    mfu:LILAB_24700 (0 target-flexibility) (0 robustness)
    mfu:LILAB_24705 (1385 target-flexibility) (204 robustness)
    mfu:LILAB_25075 (752 target-flexibility) (105 robustness)
    mfu:LILAB_25505 (0 target-flexibility) (0 robustness)
    mfu:LILAB_25510 (0 target-flexibility) (0 robustness)
    mfu:LILAB_25545 (1784 target-flexibility) (162 robustness)
    mfu:LILAB_25560 (0 target-flexibility) (0 robustness)
    mfu:LILAB_25565 (924 target-flexibility) (101 robustness)
    mfu:LILAB_25930 (0 target-flexibility) (0 robustness)
    mfu:LILAB_27945 (343 target-flexibility) (180 robustness)
    mfu:LILAB_28080 (0 target-flexibility) (0 robustness)
    mfu:LILAB_28260 (0 target-flexibility) (0 robustness)
    mfu:LILAB_28305 (0 target-flexibility) (0 robustness)
    mfu:LILAB_28665 (231 target-flexibility) (158 robustness)
    mfu:LILAB_29010 (528 target-flexibility) (157 robustness)
    mfu:LILAB_29200 (0 target-flexibility) (0 robustness)
    mfu:LILAB_29235 (323 target-flexibility) (101 robustness)
    mfu:LILAB_29280 (0 target-flexibility) (0 robustness)
    mfu:LILAB_29975 (659 target-flexibility) (240 robustness)
    mfu:LILAB_30430 (212 target-flexibility) (73 robustness)
    mfu:LILAB_31010 (0 target-flexibility) (0 robustness)
    mfu:LILAB_31365 (752 target-flexibility) (76 robustness)
    mfu:LILAB_31605 (71 target-flexibility) (71 robustness)
    mfu:LILAB_31675 (0 target-flexibility) (0 robustness)
    mfu:LILAB_31800 (659 target-flexibility) (240 robustness)
    mfu:LILAB_31810 (530 target-flexibility) (162 robustness)
    mfu:LILAB_32345 (752 target-flexibility) (105 robustness)
    mfu:LILAB_32910 (358 target-flexibility) (124 robustness)
    mfu:LILAB_33165 (734 target-flexibility) (110 robustness)
    mfu:LILAB_33330 (657 target-flexibility) (95 robustness)
    mfu:LILAB_34620 (0 target-flexibility) (0 robustness)
    mfu:LILAB_35365 (343 target-flexibility) (180 robustness)
    mfu:LILAB_35470 (231 target-flexibility) (158 robustness)
    mfu:LILAB_35480 (70 target-flexibility) (70 robustness)
    mfu:LILAB_35505 (67 target-flexibility) (67 robustness)
    mfu:LILAB_35630 (357 target-flexibility) (115 robustness)
    mfu:LILAB_36195 (231 target-flexibility) (158 robustness)
    mmas:MYMAC_000124 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_000161 (343 target-flexibility) (180 robustness)
    mmas:MYMAC_000220 (659 target-flexibility) (240 robustness)
    mmas:MYMAC_000232 (1108 target-flexibility) (319 robustness)
    mmas:MYMAC_000305 (323 target-flexibility) (101 robustness)
    mmas:MYMAC_000327 (821 target-flexibility) (137 robustness)
    mmas:MYMAC_000346 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_000385 (222 target-flexibility) (83 robustness)
    mmas:MYMAC_000432 (80 target-flexibility) (80 robustness)
    mmas:MYMAC_000444 (924 target-flexibility) (101 robustness)
    mmas:MYMAC_000545 (1385 target-flexibility) (204 robustness)
    mmas:MYMAC_000552 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_000869 (1108 target-flexibility) (319 robustness)
    mmas:MYMAC_000935 (357 target-flexibility) (115 robustness)
    mmas:MYMAC_000937 (659 target-flexibility) (240 robustness)
    mmas:MYMAC_001009 (528 target-flexibility) (157 robustness)
    mmas:MYMAC_001062 (154 target-flexibility) (80 robustness)
    mmas:MYMAC_001081 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_001135 (732 target-flexibility) (78 robustness)
    mmas:MYMAC_001273 (357 target-flexibility) (102 robustness)
    mmas:MYMAC_001355 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_001379 (796 target-flexibility) (85 robustness)
    mmas:MYMAC_001440 (336 target-flexibility) (81 robustness)
    mmas:MYMAC_001577 (691 target-flexibility) (528 robustness)
    mmas:MYMAC_001644 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_001692 (528 target-flexibility) (157 robustness)
    mmas:MYMAC_001711 (215 target-flexibility) (142 robustness)
    mmas:MYMAC_001717 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_001767 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_001939 (691 target-flexibility) (528 robustness)
    mmas:MYMAC_001988 (691 target-flexibility) (528 robustness)
    mmas:MYMAC_002002 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_002320 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_002326 (239 target-flexibility) (99 robustness)
    mmas:MYMAC_002498 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_002505 (530 target-flexibility) (162 robustness)
    mmas:MYMAC_002638 (357 target-flexibility) (102 robustness)
    mmas:MYMAC_002715 (821 target-flexibility) (137 robustness)
    mmas:MYMAC_002764 (691 target-flexibility) (528 robustness)
    mmas:MYMAC_002881 (734 target-flexibility) (110 robustness)
    mmas:MYMAC_002908 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_002933 (358 target-flexibility) (124 robustness)
    mmas:MYMAC_003287 (343 target-flexibility) (180 robustness)
    mmas:MYMAC_003337 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003338 (1385 target-flexibility) (204 robustness)
    mmas:MYMAC_003407 (752 target-flexibility) (105 robustness)
    mmas:MYMAC_003448 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003449 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003456 (1784 target-flexibility) (162 robustness)
    mmas:MYMAC_003459 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003460 (924 target-flexibility) (101 robustness)
    mmas:MYMAC_003532 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003879 (343 target-flexibility) (180 robustness)
    mmas:MYMAC_003905 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003937 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003947 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_004020 (231 target-flexibility) (158 robustness)
    mmas:MYMAC_004085 (528 target-flexibility) (157 robustness)
    mmas:MYMAC_004122 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_004129 (323 target-flexibility) (101 robustness)
    mmas:MYMAC_004138 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_004291 (659 target-flexibility) (240 robustness)
    mmas:MYMAC_004501 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_004575 (752 target-flexibility) (76 robustness)
    mmas:MYMAC_004629 (71 target-flexibility) (71 robustness)
    mmas:MYMAC_004643 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_004668 (659 target-flexibility) (240 robustness)
    mmas:MYMAC_004670 (530 target-flexibility) (162 robustness)
    mmas:MYMAC_004768 (752 target-flexibility) (105 robustness)
    mmas:MYMAC_004879 (358 target-flexibility) (124 robustness)
    mmas:MYMAC_004931 (734 target-flexibility) (110 robustness)
    mmas:MYMAC_004962 (657 target-flexibility) (95 robustness)
    mmas:MYMAC_005218 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_005375 (343 target-flexibility) (180 robustness)
    mmas:MYMAC_005396 (231 target-flexibility) (158 robustness)
    mmas:MYMAC_005398 (70 target-flexibility) (70 robustness)
    mmas:MYMAC_005403 (67 target-flexibility) (67 robustness)
    mmas:MYMAC_005404 (239 target-flexibility) (67 robustness)
    mmas:MYMAC_005425 (357 target-flexibility) (115 robustness)
    mmas:MYMAC_005532 (231 target-flexibility) (158 robustness)
    mmas:MYMAC_005716 (239 target-flexibility) (99 robustness)
    mmas:MYMAC_005739 (231 target-flexibility) (158 robustness)
    mmas:MYMAC_005856 (215 target-flexibility) (142 robustness)
    mmas:MYMAC_005899 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_005959 (222 target-flexibility) (83 robustness)
    mmas:MYMAC_006033 (1784 target-flexibility) (162 robustness)
    mmas:MYMAC_006053 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_006137 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_006204 (154 target-flexibility) (80 robustness)
    mmas:MYMAC_006554 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_006600 (659 target-flexibility) (240 robustness)
    mmas:MYMAC_006691 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_006837 (336 target-flexibility) (81 robustness)
    mmas:MYMAC_006854 (657 target-flexibility) (95 robustness)
    mmas:MYMAC_007137 (0 target-flexibility) (0 robustness)
    mrm:A7982_00131 (138 target-flexibility) (138 robustness)
    mrm:A7982_00170 (902 target-flexibility) (228 robustness)
    mrm:A7982_00288 (241 target-flexibility) (71 robustness)
    mrm:A7982_00296 (659 target-flexibility) (240 robustness)
    mrm:A7982_00309 (497 target-flexibility) (186 robustness)
    mrm:A7982_00315 (0 target-flexibility) (0 robustness)
    mrm:A7982_00371 (239 target-flexibility) (67 robustness)
    mrm:A7982_00419 (528 target-flexibility) (157 robustness)
    mrm:A7982_00443 (0 target-flexibility) (0 robustness)
    mrm:A7982_00857 (189 target-flexibility) (94 robustness)
    mrm:A7982_01128 (0 target-flexibility) (0 robustness)
    mrm:A7982_01149 (1385 target-flexibility) (204 robustness)
    mrm:A7982_01228 (659 target-flexibility) (240 robustness)
    mrm:A7982_01282 (902 target-flexibility) (228 robustness)
    mrm:A7982_01283 (1108 target-flexibility) (319 robustness)
    mrm:A7982_01358 (301 target-flexibility) (154 robustness)
    mrm:A7982_01390 (1108 target-flexibility) (319 robustness)
    mrm:A7982_01558 (189 target-flexibility) (94 robustness)
    mrm:A7982_01769 (0 target-flexibility) (0 robustness)
    mrm:A7982_01898 (821 target-flexibility) (137 robustness)
    mrm:A7982_02037 (0 target-flexibility) (0 robustness)
    mrm:A7982_02117 (0 target-flexibility) (0 robustness)
    mrm:A7982_02397 (0 target-flexibility) (0 robustness)
    mrm:A7982_02481 (0 target-flexibility) (0 robustness)
    mrm:A7982_02519 (790 target-flexibility) (134 robustness)
    mrm:A7982_02611 (222 target-flexibility) (83 robustness)
    mrm:A7982_02751 (423 target-flexibility) (81 robustness)
    mrm:A7982_02766 (0 target-flexibility) (0 robustness)
    mrm:A7982_02846 (146 target-flexibility) (75 robustness)
    mrm:A7982_02892 (228 target-flexibility) (83 robustness)
    mrm:A7982_02930 (0 target-flexibility) (0 robustness)
    mrm:A7982_02946 (703 target-flexibility) (319 robustness)
    mrm:A7982_02947 (703 target-flexibility) (319 robustness)
    mrm:A7982_02950 (659 target-flexibility) (240 robustness)
    mrm:A7982_02966 (1108 target-flexibility) (319 robustness)
    mrm:A7982_03001 (358 target-flexibility) (124 robustness)
    mrm:A7982_03017 (780 target-flexibility) (243 robustness)
    mrm:A7982_03046 (0 target-flexibility) (0 robustness)
    mrm:A7982_03051 (700 target-flexibility) (80 robustness)
    mrm:A7982_03222 (228 target-flexibility) (83 robustness)
    mrm:A7982_03225 (0 target-flexibility) (0 robustness)
    mrm:A7982_03238 (1041 target-flexibility) (243 robustness)
    mrm:A7982_03263 (1041 target-flexibility) (243 robustness)
    mrm:A7982_03371 (0 target-flexibility) (0 robustness)
    mrm:A7982_03403 (902 target-flexibility) (228 robustness)
    mrm:A7982_03732 (231 target-flexibility) (158 robustness)
    mrm:A7982_04070 (691 target-flexibility) (528 robustness)
    mrm:A7982_04111 (358 target-flexibility) (104 robustness)
    mrm:A7982_04172 (350 target-flexibility) (189 robustness)
    mrm:A7982_04312 (358 target-flexibility) (124 robustness)
    mrm:A7982_04316 (782 target-flexibility) (75 robustness)
    mrm:A7982_04557 (0 target-flexibility) (0 robustness)
    mrm:A7982_04801 (239 target-flexibility) (67 robustness)
    mrm:A7982_04886 (703 target-flexibility) (319 robustness)
    mrm:A7982_04896 (0 target-flexibility) (0 robustness)
    mrm:A7982_04984 (1108 target-flexibility) (319 robustness)
    mrm:A7982_04986 (902 target-flexibility) (228 robustness)
    mrm:A7982_05137 (1108 target-flexibility) (319 robustness)
    mrm:A7982_05182 (0 target-flexibility) (0 robustness)
    mrm:A7982_05215 (241 target-flexibility) (71 robustness)
    mrm:A7982_05274 (0 target-flexibility) (0 robustness)
    mrm:A7982_05339 (0 target-flexibility) (0 robustness)
    mrm:A7982_05341 (659 target-flexibility) (240 robustness)
    mrm:A7982_05342 (231 target-flexibility) (158 robustness)
    mrm:A7982_05402 (0 target-flexibility) (0 robustness)
    mrm:A7982_05441 (357 target-flexibility) (102 robustness)
    mrm:A7982_05825 (0 target-flexibility) (0 robustness)
    mrm:A7982_05891 (0 target-flexibility) (0 robustness)
    mrm:A7982_05940 (752 target-flexibility) (105 robustness)
    mrm:A7982_06222 (140 target-flexibility) (74 robustness)
    mrm:A7982_06344 (700 target-flexibility) (80 robustness)
    mrm:A7982_06544 (701 target-flexibility) (106 robustness)
    mrm:A7982_06545 (528 target-flexibility) (157 robustness)
    mrm:A7982_06576 (0 target-flexibility) (0 robustness)
    mrm:A7982_06712 (528 target-flexibility) (157 robustness)
    mrm:A7982_06716 (528 target-flexibility) (157 robustness)
    mrm:A7982_06797 (703 target-flexibility) (319 robustness)
    mrm:A7982_06799 (703 target-flexibility) (319 robustness)
    mrm:A7982_06887 (140 target-flexibility) (74 robustness)
    mrm:A7982_06955 (289 target-flexibility) (73 robustness)
    mrm:A7982_07040 (212 target-flexibility) (73 robustness)
    mrm:A7982_07107 (239 target-flexibility) (99 robustness)
    mrm:A7982_07443 (0 target-flexibility) (0 robustness)
    mrm:A7982_07487 (782 target-flexibility) (75 robustness)
    mrm:A7982_07497 (821 target-flexibility) (137 robustness)
    mrm:A7982_07501 (821 target-flexibility) (137 robustness)
    mrm:A7982_07540 (657 target-flexibility) (95 robustness)
    mrm:A7982_07690 (0 target-flexibility) (0 robustness)
    mrm:A7982_07760 (701 target-flexibility) (106 robustness)
    mrm:A7982_07817 (1108 target-flexibility) (319 robustness)
    mrm:A7982_07818 (902 target-flexibility) (228 robustness)
    mrm:A7982_07821 (855 target-flexibility) (138 robustness)
    mrm:A7982_08046 (239 target-flexibility) (99 robustness)
    mrm:A7982_08253 (780 target-flexibility) (243 robustness)
    mrm:A7982_08288 (497 target-flexibility) (186 robustness)
    mrm:A7982_08337 (790 target-flexibility) (134 robustness)
    mrm:A7982_08390 (734 target-flexibility) (110 robustness)
    mrm:A7982_08416 (1041 target-flexibility) (243 robustness)
    mrm:A7982_08417 (1041 target-flexibility) (243 robustness)
    mrm:A7982_08418 (80 target-flexibility) (80 robustness)
    mrm:A7982_08550 (528 target-flexibility) (157 robustness)
    mrm:A7982_08578 (138 target-flexibility) (138 robustness)
    mrm:A7982_08670 (323 target-flexibility) (101 robustness)
    mrm:A7982_08677 (497 target-flexibility) (186 robustness)
    mrm:A7982_08728 (358 target-flexibility) (104 robustness)
    mrm:A7982_08798 (1108 target-flexibility) (319 robustness)
    mrm:A7982_08818 (659 target-flexibility) (240 robustness)
    mrm:A7982_08822 (0 target-flexibility) (0 robustness)
    mrm:A7982_08954 (336 target-flexibility) (81 robustness)
    mrm:A7982_08974 (924 target-flexibility) (101 robustness)
    mrm:A7982_09042 (0 target-flexibility) (0 robustness)
    mrm:A7982_09160 (0 target-flexibility) (0 robustness)
    mrm:A7982_09221 (434 target-flexibility) (67 robustness)
    mrm:A7982_09248 (336 target-flexibility) (81 robustness)
    mrm:A7982_09318 (1108 target-flexibility) (319 robustness)
    mrm:A7982_09430 (0 target-flexibility) (0 robustness)
    mrm:A7982_09467 (350 target-flexibility) (189 robustness)
    mrm:A7982_09539 (790 target-flexibility) (134 robustness)
    mrm:A7982_09573 (659 target-flexibility) (240 robustness)
    mrm:A7982_09578 (497 target-flexibility) (186 robustness)
    mrm:A7982_09588 (691 target-flexibility) (528 robustness)
    mrm:A7982_09589 (691 target-flexibility) (528 robustness)
    mrm:A7982_09670 (902 target-flexibility) (228 robustness)
    mrm:A7982_09691 (231 target-flexibility) (158 robustness)
    mrm:A7982_09715 (80 target-flexibility) (80 robustness)
    mrm:A7982_09718 (301 target-flexibility) (154 robustness)
    mrm:A7982_09830 (703 target-flexibility) (319 robustness)
    mrm:A7982_09898 (423 target-flexibility) (81 robustness)
    mrm:A7982_09970 (1385 target-flexibility) (204 robustness)
    mrm:A7982_10056 (0 target-flexibility) (0 robustness)
    mrm:A7982_10241 (189 target-flexibility) (94 robustness)
    mrm:A7982_10601 (0 target-flexibility) (0 robustness)
    mrm:A7982_10667 (659 target-flexibility) (240 robustness)
    mrm:A7982_10763 (358 target-flexibility) (124 robustness)
    mrm:A7982_10858 (855 target-flexibility) (138 robustness)
    mrm:A7982_10892 (752 target-flexibility) (105 robustness)
    mrm:A7982_10954 (0 target-flexibility) (0 robustness)
    mrm:A7982_11144 (0 target-flexibility) (0 robustness)
    mrm:A7982_11237 (841 target-flexibility) (288 robustness)
    mrm:A7982_11353 (902 target-flexibility) (228 robustness)
    mrm:A7982_11365 (323 target-flexibility) (101 robustness)
    mrm:A7982_11385 (657 target-flexibility) (95 robustness)
    mrm:A7982_11740 (752 target-flexibility) (105 robustness)
    mrm:A7982_12232 (1108 target-flexibility) (319 robustness)
    mrm:A7982_12387 (0 target-flexibility) (0 robustness)
    mrm:A7982_12408 (703 target-flexibility) (319 robustness)
    mrm:A7982_12661 (841 target-flexibility) (288 robustness)
    mrm:A7982_12663 (231 target-flexibility) (158 robustness)
    mrm:A7982_12709 (924 target-flexibility) (101 robustness)
    mrm:A7982_12710 (924 target-flexibility) (101 robustness)
    mrm:A7982_12819 (0 target-flexibility) (0 robustness)
    mrm:A7982_12858 (0 target-flexibility) (0 robustness)
    mrm:A7982_12872 (0 target-flexibility) (0 robustness)
    mrm:A7982_12928 (734 target-flexibility) (110 robustness)
    mrm:A7982_12969 (146 target-flexibility) (75 robustness)
    mrm:A7982_13093 (357 target-flexibility) (102 robustness)
    mrm:A7982_13482 (659 target-flexibility) (240 robustness)
    mrm:A7982_13543 (239 target-flexibility) (99 robustness)
    mrm:A7982_13556 (0 target-flexibility) (0 robustness)
    mrm:A7982_13708 (0 target-flexibility) (0 robustness)
    msd:MYSTI_00087 (358 target-flexibility) (124 robustness)
    msd:MYSTI_00124 (343 target-flexibility) (180 robustness)
    msd:MYSTI_00211 (659 target-flexibility) (240 robustness)
    msd:MYSTI_00219 (1108 target-flexibility) (319 robustness)
    msd:MYSTI_00274 (323 target-flexibility) (101 robustness)
    msd:MYSTI_00373 (222 target-flexibility) (83 robustness)
    msd:MYSTI_00520 (1385 target-flexibility) (204 robustness)
    msd:MYSTI_00528 (0 target-flexibility) (0 robustness)
    msd:MYSTI_00925 (357 target-flexibility) (115 robustness)
    msd:MYSTI_00933 (659 target-flexibility) (240 robustness)
    msd:MYSTI_00991 (790 target-flexibility) (134 robustness)
    msd:MYSTI_01019 (528 target-flexibility) (157 robustness)
    msd:MYSTI_01045 (528 target-flexibility) (157 robustness)
    msd:MYSTI_01086 (154 target-flexibility) (80 robustness)
    msd:MYSTI_01146 (732 target-flexibility) (78 robustness)
    msd:MYSTI_01293 (357 target-flexibility) (102 robustness)
    msd:MYSTI_01365 (659 target-flexibility) (240 robustness)
    msd:MYSTI_01369 (1041 target-flexibility) (243 robustness)
    msd:MYSTI_01370 (1041 target-flexibility) (243 robustness)
    msd:MYSTI_01382 (0 target-flexibility) (0 robustness)
    msd:MYSTI_01404 (796 target-flexibility) (85 robustness)
    msd:MYSTI_01458 (336 target-flexibility) (81 robustness)
    msd:MYSTI_01589 (1108 target-flexibility) (319 robustness)
    msd:MYSTI_01655 (0 target-flexibility) (0 robustness)
    msd:MYSTI_01696 (528 target-flexibility) (157 robustness)
    msd:MYSTI_01723 (0 target-flexibility) (0 robustness)
    msd:MYSTI_01751 (0 target-flexibility) (0 robustness)
    msd:MYSTI_01815 (0 target-flexibility) (0 robustness)
    msd:MYSTI_01936 (267 target-flexibility) (74 robustness)
    msd:MYSTI_02222 (691 target-flexibility) (528 robustness)
    msd:MYSTI_02238 (0 target-flexibility) (0 robustness)
    msd:MYSTI_02246 (138 target-flexibility) (138 robustness)
    msd:MYSTI_02512 (703 target-flexibility) (319 robustness)
    msd:MYSTI_02683 (0 target-flexibility) (0 robustness)
    msd:MYSTI_02722 (0 target-flexibility) (0 robustness)
    msd:MYSTI_02727 (239 target-flexibility) (99 robustness)
    msd:MYSTI_02928 (530 target-flexibility) (162 robustness)
    msd:MYSTI_02961 (790 target-flexibility) (134 robustness)
    msd:MYSTI_03078 (357 target-flexibility) (102 robustness)
    msd:MYSTI_03222 (691 target-flexibility) (528 robustness)
    msd:MYSTI_03297 (703 target-flexibility) (319 robustness)
    msd:MYSTI_03298 (659 target-flexibility) (240 robustness)
    msd:MYSTI_03397 (734 target-flexibility) (110 robustness)
    msd:MYSTI_03416 (0 target-flexibility) (0 robustness)
    msd:MYSTI_03419 (0 target-flexibility) (0 robustness)
    msd:MYSTI_03443 (358 target-flexibility) (124 robustness)
    msd:MYSTI_03722 (0 target-flexibility) (0 robustness)
    msd:MYSTI_03731 (323 target-flexibility) (101 robustness)
    msd:MYSTI_03738 (0 target-flexibility) (0 robustness)
    msd:MYSTI_03778 (528 target-flexibility) (157 robustness)
    msd:MYSTI_03827 (231 target-flexibility) (158 robustness)
    msd:MYSTI_03888 (0 target-flexibility) (0 robustness)
    msd:MYSTI_03897 (0 target-flexibility) (0 robustness)
    msd:MYSTI_03928 (0 target-flexibility) (0 robustness)
    msd:MYSTI_03947 (343 target-flexibility) (180 robustness)
    msd:MYSTI_04013 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04068 (267 target-flexibility) (74 robustness)
    msd:MYSTI_04345 (67 target-flexibility) (67 robustness)
    msd:MYSTI_04360 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04456 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04459 (1784 target-flexibility) (162 robustness)
    msd:MYSTI_04466 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04467 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04482 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04507 (752 target-flexibility) (105 robustness)
    msd:MYSTI_04546 (1385 target-flexibility) (204 robustness)
    msd:MYSTI_04547 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04606 (343 target-flexibility) (180 robustness)
    msd:MYSTI_04683 (701 target-flexibility) (106 robustness)
    msd:MYSTI_04778 (503 target-flexibility) (78 robustness)
    msd:MYSTI_04815 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04872 (659 target-flexibility) (240 robustness)
    msd:MYSTI_04946 (212 target-flexibility) (73 robustness)
    msd:MYSTI_05067 (0 target-flexibility) (0 robustness)
    msd:MYSTI_05093 (1169 target-flexibility) (76 robustness)
    msd:MYSTI_05139 (752 target-flexibility) (76 robustness)
    msd:MYSTI_05188 (71 target-flexibility) (71 robustness)
    msd:MYSTI_05203 (0 target-flexibility) (0 robustness)
    msd:MYSTI_05226 (703 target-flexibility) (319 robustness)
    msd:MYSTI_05228 (659 target-flexibility) (240 robustness)
    msd:MYSTI_05229 (503 target-flexibility) (78 robustness)
    msd:MYSTI_05230 (530 target-flexibility) (162 robustness)
    msd:MYSTI_05360 (752 target-flexibility) (105 robustness)
    msd:MYSTI_05450 (703 target-flexibility) (319 robustness)
    msd:MYSTI_05492 (358 target-flexibility) (124 robustness)
    msd:MYSTI_05549 (734 target-flexibility) (110 robustness)
    msd:MYSTI_05561 (657 target-flexibility) (95 robustness)
    msd:MYSTI_05851 (1183 target-flexibility) (114 robustness)
    msd:MYSTI_05889 (1183 target-flexibility) (114 robustness)
    msd:MYSTI_05921 (0 target-flexibility) (0 robustness)
    msd:MYSTI_06076 (228 target-flexibility) (83 robustness)
    msd:MYSTI_06140 (1183 target-flexibility) (114 robustness)
    msd:MYSTI_06170 (343 target-flexibility) (180 robustness)
    msd:MYSTI_06191 (231 target-flexibility) (158 robustness)
    msd:MYSTI_06198 (67 target-flexibility) (67 robustness)
    msd:MYSTI_06221 (357 target-flexibility) (115 robustness)
    msd:MYSTI_06327 (231 target-flexibility) (158 robustness)
    msd:MYSTI_06393 (701 target-flexibility) (106 robustness)
    msd:MYSTI_06394 (228 target-flexibility) (83 robustness)
    msd:MYSTI_06468 (790 target-flexibility) (134 robustness)
    msd:MYSTI_06547 (239 target-flexibility) (99 robustness)
    msd:MYSTI_06570 (231 target-flexibility) (158 robustness)
    msd:MYSTI_06617 (659 target-flexibility) (240 robustness)
    msd:MYSTI_06805 (222 target-flexibility) (83 robustness)
    msd:MYSTI_06833 (1041 target-flexibility) (243 robustness)
    msd:MYSTI_06919 (1784 target-flexibility) (162 robustness)
    msd:MYSTI_06940 (0 target-flexibility) (0 robustness)
    msd:MYSTI_07032 (1183 target-flexibility) (114 robustness)
    msd:MYSTI_07106 (0 target-flexibility) (0 robustness)
    msd:MYSTI_07118 (154 target-flexibility) (80 robustness)
    msd:MYSTI_07249 (796 target-flexibility) (85 robustness)
    msd:MYSTI_07288 (138 target-flexibility) (138 robustness)
    msd:MYSTI_07451 (0 target-flexibility) (0 robustness)
    msd:MYSTI_07506 (659 target-flexibility) (240 robustness)
    msd:MYSTI_07724 (336 target-flexibility) (81 robustness)
    msd:MYSTI_07749 (657 target-flexibility) (95 robustness)
    msd:MYSTI_07831 (659 target-flexibility) (240 robustness)
    msd:MYSTI_08015 (1041 target-flexibility) (243 robustness)
    msd:MYSTI_08065 (0 target-flexibility) (0 robustness)
    msd:MYSTI_08093 (0 target-flexibility) (0 robustness)
    mxa:MXAN_0110 (0 target-flexibility) (0 robustness)
    mxa:MXAN_0147 (343 target-flexibility) (180 robustness)
    mxa:MXAN_0211 (659 target-flexibility) (240 robustness)
    mxa:MXAN_0215 (1108 target-flexibility) (319 robustness)
    mxa:MXAN_0278 (323 target-flexibility) (101 robustness)
    mxa:MXAN_0318 (0 target-flexibility) (0 robustness)
    mxa:MXAN_0358 (222 target-flexibility) (83 robustness)
    mxa:MXAN_0395 (80 target-flexibility) (80 robustness)
    mxa:MXAN_0407 (924 target-flexibility) (101 robustness)
    mxa:MXAN_0501 (796 target-flexibility) (85 robustness)
    mxa:MXAN_0531 (1385 target-flexibility) (204 robustness)
    mxa:MXAN_0537 (0 target-flexibility) (0 robustness)
    mxa:MXAN_0853 (1108 target-flexibility) (319 robustness)
    mxa:MXAN_0912 (357 target-flexibility) (115 robustness)
    mxa:MXAN_0915 (659 target-flexibility) (240 robustness)
    mxa:MXAN_0949 (790 target-flexibility) (134 robustness)
    mxa:MXAN_0992 (528 target-flexibility) (157 robustness)
    mxa:MXAN_1039 (154 target-flexibility) (80 robustness)
    mxa:MXAN_1103 (732 target-flexibility) (78 robustness)
    mxa:MXAN_1271 (357 target-flexibility) (102 robustness)
    mxa:MXAN_1283 (434 target-flexibility) (67 robustness)
    mxa:MXAN_1362 (0 target-flexibility) (0 robustness)
    mxa:MXAN_1386 (796 target-flexibility) (85 robustness)
    mxa:MXAN_1438 (336 target-flexibility) (81 robustness)
    mxa:MXAN_1528 (0 target-flexibility) (0 robustness)
    mxa:MXAN_1571 (528 target-flexibility) (157 robustness)
    mxa:MXAN_1595 (0 target-flexibility) (0 robustness)
    mxa:MXAN_1933 (691 target-flexibility) (528 robustness)
    mxa:MXAN_1947 (0 target-flexibility) (0 robustness)
    mxa:MXAN_2352 (0 target-flexibility) (0 robustness)
    mxa:MXAN_2358 (239 target-flexibility) (99 robustness)
    mxa:MXAN_2536 (0 target-flexibility) (0 robustness)
    mxa:MXAN_2543 (530 target-flexibility) (162 robustness)
    mxa:MXAN_2570 (790 target-flexibility) (134 robustness)
    mxa:MXAN_2675 (357 target-flexibility) (102 robustness)
    mxa:MXAN_2800 (691 target-flexibility) (528 robustness)
    mxa:MXAN_2925 (734 target-flexibility) (110 robustness)
    mxa:MXAN_2959 (0 target-flexibility) (0 robustness)
    mxa:MXAN_2983 (358 target-flexibility) (124 robustness)
    mxa:MXAN_3330 (343 target-flexibility) (180 robustness)
    mxa:MXAN_3385 (0 target-flexibility) (0 robustness)
    mxa:MXAN_3386 (1385 target-flexibility) (204 robustness)
    mxa:MXAN_3466 (752 target-flexibility) (105 robustness)
    mxa:MXAN_3506 (0 target-flexibility) (0 robustness)
    mxa:MXAN_3507 (0 target-flexibility) (0 robustness)
    mxa:MXAN_3514 (1784 target-flexibility) (162 robustness)
    mxa:MXAN_3518 (0 target-flexibility) (0 robustness)
    mxa:MXAN_3519 (924 target-flexibility) (101 robustness)
    mxa:MXAN_3537 (289 target-flexibility) (73 robustness)
    mxa:MXAN_3591 (0 target-flexibility) (0 robustness)
    mxa:MXAN_3969 (343 target-flexibility) (180 robustness)
    mxa:MXAN_3987 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4027 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4038 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4051 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4097 (231 target-flexibility) (158 robustness)
    mxa:MXAN_4171 (528 target-flexibility) (157 robustness)
    mxa:MXAN_4212 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4219 (323 target-flexibility) (101 robustness)
    mxa:MXAN_4228 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4370 (659 target-flexibility) (240 robustness)
    mxa:MXAN_4460 (212 target-flexibility) (73 robustness)
    mxa:MXAN_4613 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4684 (752 target-flexibility) (76 robustness)
    mxa:MXAN_4725 (339 target-flexibility) (98 robustness)
    mxa:MXAN_4731 (71 target-flexibility) (71 robustness)
    mxa:MXAN_4745 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4768 (703 target-flexibility) (319 robustness)
    mxa:MXAN_4770 (659 target-flexibility) (240 robustness)
    mxa:MXAN_4772 (530 target-flexibility) (162 robustness)
    mxa:MXAN_4877 (752 target-flexibility) (105 robustness)
    mxa:MXAN_5001 (358 target-flexibility) (124 robustness)
    mxa:MXAN_5057 (734 target-flexibility) (110 robustness)
    mxa:MXAN_5075 (657 target-flexibility) (95 robustness)
    mxa:MXAN_5358 (0 target-flexibility) (0 robustness)
    mxa:MXAN_5578 (343 target-flexibility) (180 robustness)
    mxa:MXAN_5601 (231 target-flexibility) (158 robustness)
    mxa:MXAN_5608 (67 target-flexibility) (67 robustness)
    mxa:MXAN_5609 (239 target-flexibility) (67 robustness)
    mxa:MXAN_5630 (357 target-flexibility) (115 robustness)
    mxa:MXAN_5741 (231 target-flexibility) (158 robustness)
    mxa:MXAN_5856 (790 target-flexibility) (134 robustness)
    mxa:MXAN_5928 (697 target-flexibility) (78 robustness)
    mxa:MXAN_5929 (239 target-flexibility) (99 robustness)
    mxa:MXAN_5951 (231 target-flexibility) (158 robustness)
    mxa:MXAN_6112 (0 target-flexibility) (0 robustness)
    mxa:MXAN_6220 (222 target-flexibility) (83 robustness)
    mxa:MXAN_6299 (1784 target-flexibility) (162 robustness)
    mxa:MXAN_6319 (0 target-flexibility) (0 robustness)
    mxa:MXAN_6393 (339 target-flexibility) (98 robustness)
    mxa:MXAN_6395 (703 target-flexibility) (319 robustness)
    mxa:MXAN_6398 (659 target-flexibility) (240 robustness)
    mxa:MXAN_6399 (659 target-flexibility) (240 robustness)
    mxa:MXAN_6400 (703 target-flexibility) (319 robustness)
    mxa:MXAN_6431 (0 target-flexibility) (0 robustness)
    mxa:MXAN_6497 (154 target-flexibility) (80 robustness)
    mxa:MXAN_6731 (697 target-flexibility) (78 robustness)
    mxa:MXAN_6859 (0 target-flexibility) (0 robustness)
    mxa:MXAN_6909 (659 target-flexibility) (240 robustness)
    mxa:MXAN_7138 (336 target-flexibility) (81 robustness)
    mxa:MXAN_7156 (657 target-flexibility) (95 robustness)
    mxa:MXAN_7413 (0 target-flexibility) (0 robustness)
    mym:A176_000033 (706 target-flexibility) (173 robustness)
    mym:A176_000388 (154 target-flexibility) (80 robustness)
    mym:A176_000459 (0 target-flexibility) (0 robustness)
    mym:A176_000489 (703 target-flexibility) (319 robustness)
    mym:A176_000490 (659 target-flexibility) (240 robustness)
    mym:A176_000491 (659 target-flexibility) (240 robustness)
    mym:A176_000494 (703 target-flexibility) (319 robustness)
    mym:A176_000496 (339 target-flexibility) (98 robustness)
    mym:A176_000578 (0 target-flexibility) (0 robustness)
    mym:A176_000601 (1784 target-flexibility) (162 robustness)
    mym:A176_000635 (0 target-flexibility) (0 robustness)
    mym:A176_000682 (222 target-flexibility) (83 robustness)
    mym:A176_000945 (231 target-flexibility) (158 robustness)
    mym:A176_000967 (239 target-flexibility) (99 robustness)
    mym:A176_001048 (790 target-flexibility) (134 robustness)
    mym:A176_001167 (231 target-flexibility) (158 robustness)
    mym:A176_001288 (357 target-flexibility) (115 robustness)
    mym:A176_001320 (231 target-flexibility) (158 robustness)
    mym:A176_001362 (343 target-flexibility) (180 robustness)
    mym:A176_001499 (0 target-flexibility) (0 robustness)
    mym:A176_001554 (0 target-flexibility) (0 robustness)
    mym:A176_001811 (657 target-flexibility) (95 robustness)
    mym:A176_001826 (734 target-flexibility) (110 robustness)
    mym:A176_001887 (358 target-flexibility) (124 robustness)
    mym:A176_001932 (703 target-flexibility) (319 robustness)
    mym:A176_002007 (752 target-flexibility) (105 robustness)
    mym:A176_002120 (530 target-flexibility) (162 robustness)
    mym:A176_002122 (659 target-flexibility) (240 robustness)
    mym:A176_002124 (703 target-flexibility) (319 robustness)
    mym:A176_002147 (0 target-flexibility) (0 robustness)
    mym:A176_002161 (71 target-flexibility) (71 robustness)
    mym:A176_002167 (339 target-flexibility) (98 robustness)
    mym:A176_002210 (752 target-flexibility) (76 robustness)
    mym:A176_002255 (1169 target-flexibility) (76 robustness)
    mym:A176_002284 (0 target-flexibility) (0 robustness)
    mym:A176_002437 (212 target-flexibility) (73 robustness)
    mym:A176_002532 (659 target-flexibility) (240 robustness)
    mym:A176_002672 (0 target-flexibility) (0 robustness)
    mym:A176_002681 (323 target-flexibility) (101 robustness)
    mym:A176_002689 (0 target-flexibility) (0 robustness)
    mym:A176_002734 (528 target-flexibility) (157 robustness)
    mym:A176_002773 (706 target-flexibility) (173 robustness)
    mym:A176_002800 (231 target-flexibility) (158 robustness)
    mym:A176_002870 (0 target-flexibility) (0 robustness)
    mym:A176_002879 (0 target-flexibility) (0 robustness)
    mym:A176_002926 (0 target-flexibility) (0 robustness)
    mym:A176_002955 (343 target-flexibility) (180 robustness)
    mym:A176_002984 (0 target-flexibility) (0 robustness)
    mym:A176_003317 (0 target-flexibility) (0 robustness)
    mym:A176_003393 (0 target-flexibility) (0 robustness)
    mym:A176_003399 (1784 target-flexibility) (162 robustness)
    mym:A176_003407 (0 target-flexibility) (0 robustness)
    mym:A176_003408 (0 target-flexibility) (0 robustness)
    mym:A176_003458 (752 target-flexibility) (105 robustness)
    mym:A176_003560 (1385 target-flexibility) (204 robustness)
    mym:A176_003561 (0 target-flexibility) (0 robustness)
    mym:A176_003617 (343 target-flexibility) (180 robustness)
    mym:A176_003849 (0 target-flexibility) (0 robustness)
    mym:A176_003863 (1041 target-flexibility) (243 robustness)
    mym:A176_004027 (358 target-flexibility) (124 robustness)
    mym:A176_004054 (0 target-flexibility) (0 robustness)
    mym:A176_004057 (0 target-flexibility) (0 robustness)
    mym:A176_004084 (734 target-flexibility) (110 robustness)
    mym:A176_004217 (691 target-flexibility) (528 robustness)
    mym:A176_004236 (703 target-flexibility) (319 robustness)
    mym:A176_004355 (357 target-flexibility) (102 robustness)
    mym:A176_004468 (790 target-flexibility) (134 robustness)
    mym:A176_004497 (530 target-flexibility) (162 robustness)
    mym:A176_004505 (0 target-flexibility) (0 robustness)
    mym:A176_004685 (239 target-flexibility) (99 robustness)
    mym:A176_004693 (0 target-flexibility) (0 robustness)
    mym:A176_004884 (358 target-flexibility) (124 robustness)
    mym:A176_005044 (0 target-flexibility) (0 robustness)
    mym:A176_005054 (691 target-flexibility) (528 robustness)
    mym:A176_005227 (0 target-flexibility) (0 robustness)
    mym:A176_005386 (0 target-flexibility) (0 robustness)
    mym:A176_005409 (528 target-flexibility) (157 robustness)
    mym:A176_005454 (0 target-flexibility) (0 robustness)
    mym:A176_005543 (336 target-flexibility) (81 robustness)
    mym:A176_005616 (796 target-flexibility) (85 robustness)
    mym:A176_005642 (0 target-flexibility) (0 robustness)
    mym:A176_005718 (357 target-flexibility) (102 robustness)
    mym:A176_005864 (732 target-flexibility) (78 robustness)
    mym:A176_005929 (154 target-flexibility) (80 robustness)
    mym:A176_005981 (528 target-flexibility) (157 robustness)
    mym:A176_006029 (790 target-flexibility) (134 robustness)
    mym:A176_006064 (659 target-flexibility) (240 robustness)
    mym:A176_006068 (357 target-flexibility) (115 robustness)
    mym:A176_006490 (0 target-flexibility) (0 robustness)
    mym:A176_006496 (1385 target-flexibility) (204 robustness)
    mym:A176_006642 (222 target-flexibility) (83 robustness)
    mym:A176_006715 (323 target-flexibility) (101 robustness)
    mym:A176_006784 (659 target-flexibility) (240 robustness)
    mym:A176_006864 (343 target-flexibility) (180 robustness)
    mym:A176_006908 (0 target-flexibility) (0 robustness)
    mym:A176_007109 (0 target-flexibility) (0 robustness)
    mym:A176_007168 (1041 target-flexibility) (243 robustness)
    mym:A176_007377 (657 target-flexibility) (95 robustness)
    mym:A176_007396 (336 target-flexibility) (81 robustness)
    mym:A176_007563 (0 target-flexibility) (0 robustness)
    mym:A176_007648 (659 target-flexibility) (240 robustness)
    pace:A6070_00050 (73 target-flexibility) (73 robustness)
    pace:A6070_00320 (358 target-flexibility) (124 robustness)
    pace:A6070_00575 (1041 target-flexibility) (243 robustness)
    pace:A6070_00600 (138 target-flexibility) (138 robustness)
    pace:A6070_01225 (1108 target-flexibility) (319 robustness)
    pace:A6070_01315 (528 target-flexibility) (157 robustness)
    pace:A6070_01515 (138 target-flexibility) (138 robustness)
    pace:A6070_01580 (691 target-flexibility) (528 robustness)
    pace:A6070_01735 (91 target-flexibility) (91 robustness)
    pace:A6070_01780 (323 target-flexibility) (101 robustness)
    pace:A6070_01880 (796 target-flexibility) (85 robustness)
    pace:A6070_02565 (613 target-flexibility) (72 robustness)
    pace:A6070_02940 (222 target-flexibility) (83 robustness)
    pace:A6070_03160 (528 target-flexibility) (157 robustness)
    pace:A6070_03240 (138 target-flexibility) (66 robustness)
    pace:A6070_03835 (212 target-flexibility) (73 robustness)
    pace:A6070_04095 (686 target-flexibility) (192 robustness)
    pace:A6070_04115 (91 target-flexibility) (91 robustness)
    pace:A6070_04145 (0 target-flexibility) (0 robustness)
    pace:A6070_04260 (239 target-flexibility) (67 robustness)
    pace:A6070_04265 (67 target-flexibility) (67 robustness)
    pace:A6070_04300 (231 target-flexibility) (158 robustness)
    pace:A6070_04750 (0 target-flexibility) (0 robustness)
    pace:A6070_04955 (686 target-flexibility) (192 robustness)
    pace:A6070_04975 (71 target-flexibility) (71 robustness)
    pace:A6070_05010 (139 target-flexibility) (66 robustness)
    pace:A6070_05320 (0 target-flexibility) (0 robustness)
    pace:A6070_05385 (732 target-flexibility) (78 robustness)
    pace:A6070_05405 (600 target-flexibility) (126 robustness)
    pace:A6070_05790 (0 target-flexibility) (0 robustness)
    pace:A6070_05920 (1108 target-flexibility) (319 robustness)
    pace:A6070_06035 (0 target-flexibility) (0 robustness)
    pace:A6070_06075 (0 target-flexibility) (0 robustness)
    pace:A6070_06120 (0 target-flexibility) (0 robustness)
    pace:A6070_06385 (323 target-flexibility) (101 robustness)
    pace:A6070_06445 (231 target-flexibility) (158 robustness)
    pace:A6070_06450 (231 target-flexibility) (158 robustness)
    pace:A6070_06665 (691 target-flexibility) (528 robustness)
    pace:A6070_06815 (1169 target-flexibility) (76 robustness)
    pace:A6070_06835 (139 target-flexibility) (66 robustness)
    pace:A6070_07185 (897 target-flexibility) (71 robustness)
    pace:A6070_07200 (405 target-flexibility) (169 robustness)
    pace:A6070_07305 (0 target-flexibility) (0 robustness)
    pace:A6070_07325 (0 target-flexibility) (0 robustness)
    pace:A6070_07525 (821 target-flexibility) (137 robustness)
    pace:A6070_07975 (613 target-flexibility) (72 robustness)
    pace:A6070_08045 (358 target-flexibility) (124 robustness)
    pace:A6070_08275 (841 target-flexibility) (126 robustness)
    pace:A6070_08290 (902 target-flexibility) (228 robustness)
    pace:A6070_09000 (0 target-flexibility) (0 robustness)
    pace:A6070_10090 (752 target-flexibility) (76 robustness)
    pace:A6070_10120 (0 target-flexibility) (0 robustness)
    pace:A6070_10395 (841 target-flexibility) (126 robustness)
    pace:A6070_10675 (0 target-flexibility) (0 robustness)
    pace:A6070_10805 (0 target-flexibility) (0 robustness)
    pace:A6070_11125 (600 target-flexibility) (126 robustness)
    pace:A6070_12850 (0 target-flexibility) (0 robustness)
    pace:A6070_13030 (821 target-flexibility) (137 robustness)
    pace:A6070_13195 (0 target-flexibility) (0 robustness)
    pace:A6070_13200 (0 target-flexibility) (0 robustness)
    pace:A6070_13365 (1041 target-flexibility) (243 robustness)
    pace:A6070_13370 (1041 target-flexibility) (243 robustness)
    pace:A6070_13415 (600 target-flexibility) (126 robustness)
    pace:A6070_13790 (405 target-flexibility) (169 robustness)
    pace:A6070_13980 (0 target-flexibility) (0 robustness)
    pace:A6070_13985 (0 target-flexibility) (0 robustness)
    pace:A6070_14230 (902 target-flexibility) (228 robustness)
    pace:A6070_14605 (0 target-flexibility) (0 robustness)
    pace:A6070_14615 (0 target-flexibility) (0 robustness)
    pace:A6070_14665 (80 target-flexibility) (80 robustness)
    pace:A6070_14775 (73 target-flexibility) (73 robustness)
    pca:Pcar_0050 (358 target-flexibility) (124 robustness)
    pca:Pcar_0092 (334 target-flexibility) (71 robustness)
    pca:Pcar_0114 (138 target-flexibility) (138 robustness)
    pca:Pcar_0189 (902 target-flexibility) (228 robustness)
    pca:Pcar_0251 (0 target-flexibility) (0 robustness)
    pca:Pcar_0255 (0 target-flexibility) (0 robustness)
    pca:Pcar_0266 (80 target-flexibility) (80 robustness)
    pca:Pcar_0337 (91 target-flexibility) (91 robustness)
    pca:Pcar_0342 (0 target-flexibility) (0 robustness)
    pca:Pcar_0347 (323 target-flexibility) (101 robustness)
    pca:Pcar_0374 (691 target-flexibility) (528 robustness)
    pca:Pcar_0482 (0 target-flexibility) (0 robustness)
    pca:Pcar_0607 (0 target-flexibility) (0 robustness)
    pca:Pcar_0824 (279 target-flexibility) (126 robustness)
    pca:Pcar_1007 (841 target-flexibility) (126 robustness)
    pca:Pcar_1033 (0 target-flexibility) (0 robustness)
    pca:Pcar_1040 (752 target-flexibility) (76 robustness)
    pca:Pcar_1121 (902 target-flexibility) (228 robustness)
    pca:Pcar_1129 (0 target-flexibility) (0 robustness)
    pca:Pcar_1244 (686 target-flexibility) (192 robustness)
    pca:Pcar_1248 (71 target-flexibility) (71 robustness)
    pca:Pcar_1255 (139 target-flexibility) (66 robustness)
    pca:Pcar_1320 (0 target-flexibility) (0 robustness)
    pca:Pcar_1326 (732 target-flexibility) (78 robustness)
    pca:Pcar_1331 (600 target-flexibility) (126 robustness)
    pca:Pcar_1413 (0 target-flexibility) (0 robustness)
    pca:Pcar_1436 (1108 target-flexibility) (319 robustness)
    pca:Pcar_1438 (659 target-flexibility) (240 robustness)
    pca:Pcar_1440 (703 target-flexibility) (319 robustness)
    pca:Pcar_1460 (0 target-flexibility) (0 robustness)
    pca:Pcar_1466 (0 target-flexibility) (0 robustness)
    pca:Pcar_1467 (0 target-flexibility) (0 robustness)
    pca:Pcar_1486 (323 target-flexibility) (101 robustness)
    pca:Pcar_1495 (139 target-flexibility) (66 robustness)
    pca:Pcar_1514 (279 target-flexibility) (126 robustness)
    pca:Pcar_1534 (528 target-flexibility) (157 robustness)
    pca:Pcar_1569 (0 target-flexibility) (0 robustness)
    pca:Pcar_1594 (0 target-flexibility) (0 robustness)
    pca:Pcar_1607 (0 target-flexibility) (0 robustness)
    pca:Pcar_1615 (897 target-flexibility) (71 robustness)
    pca:Pcar_1632 (0 target-flexibility) (0 robustness)
    pca:Pcar_1667 (1169 target-flexibility) (76 robustness)
    pca:Pcar_1692 (691 target-flexibility) (528 robustness)
    pca:Pcar_1718 (528 target-flexibility) (157 robustness)
    pca:Pcar_1722 (0 target-flexibility) (0 robustness)
    pca:Pcar_1727 (334 target-flexibility) (71 robustness)
    pca:Pcar_1776 (243 target-flexibility) (97 robustness)
    pca:Pcar_1804 (0 target-flexibility) (0 robustness)
    pca:Pcar_1805 (796 target-flexibility) (85 robustness)
    pca:Pcar_1806 (0 target-flexibility) (0 robustness)
    pca:Pcar_1807 (0 target-flexibility) (0 robustness)
    pca:Pcar_1841 (358 target-flexibility) (124 robustness)
    pca:Pcar_1860 (358 target-flexibility) (124 robustness)
    pca:Pcar_1907 (841 target-flexibility) (126 robustness)
    pca:Pcar_1910 (902 target-flexibility) (228 robustness)
    pca:Pcar_1916 (76 target-flexibility) (76 robustness)
    pca:Pcar_2115 (0 target-flexibility) (0 robustness)
    pca:Pcar_2150 (241 target-flexibility) (71 robustness)
    pca:Pcar_2174 (243 target-flexibility) (97 robustness)
    pca:Pcar_2192 (241 target-flexibility) (71 robustness)
    pca:Pcar_2206 (67 target-flexibility) (67 robustness)
    pca:Pcar_2207 (239 target-flexibility) (67 robustness)
    pca:Pcar_2230 (0 target-flexibility) (0 robustness)
    pca:Pcar_2236 (91 target-flexibility) (91 robustness)
    pca:Pcar_2240 (686 target-flexibility) (192 robustness)
    pca:Pcar_2254 (600 target-flexibility) (126 robustness)
    pca:Pcar_2315 (212 target-flexibility) (73 robustness)
    pca:Pcar_2415 (138 target-flexibility) (66 robustness)
    pca:Pcar_2430 (528 target-flexibility) (157 robustness)
    pca:Pcar_2435 (706 target-flexibility) (173 robustness)
    pca:Pcar_2455 (222 target-flexibility) (83 robustness)
    pca:Pcar_2506 (0 target-flexibility) (0 robustness)
    pca:Pcar_2593 (0 target-flexibility) (0 robustness)
    pca:Pcar_2596 (0 target-flexibility) (0 robustness)
    pca:Pcar_2624 (600 target-flexibility) (126 robustness)
    pca:Pcar_2664 (703 target-flexibility) (319 robustness)
    pca:Pcar_2667 (659 target-flexibility) (240 robustness)
    pca:Pcar_2684 (0 target-flexibility) (0 robustness)
    pca:Pcar_2685 (0 target-flexibility) (0 robustness)
    pca:Pcar_2719 (1041 target-flexibility) (243 robustness)
    pca:Pcar_2720 (1041 target-flexibility) (243 robustness)
    pca:Pcar_2778 (76 target-flexibility) (76 robustness)
    pca:Pcar_2847 (0 target-flexibility) (0 robustness)
    pca:Pcar_2933 (796 target-flexibility) (85 robustness)
    pca:Pcar_2943 (138 target-flexibility) (138 robustness)
    pca:Pcar_2987 (1108 target-flexibility) (319 robustness)
    pca:Pcar_3005 (528 target-flexibility) (157 robustness)
    pca:Pcar_3011 (706 target-flexibility) (173 robustness)
    pca:Pcar_3106 (0 target-flexibility) (0 robustness)
    pca:Pcar_3125 (1041 target-flexibility) (243 robustness)
    pef:A7E78_00020 (0 target-flexibility) (0 robustness)
    pef:A7E78_00045 (350 target-flexibility) (84 robustness)
    pef:A7E78_00095 (290 target-flexibility) (63 robustness)
    pef:A7E78_00335 (0 target-flexibility) (0 robustness)
    pef:A7E78_00350 (0 target-flexibility) (0 robustness)
    pef:A7E78_00355 (0 target-flexibility) (0 robustness)
    pef:A7E78_00360 (0 target-flexibility) (0 robustness)
    pef:A7E78_01045 (0 target-flexibility) (0 robustness)
    pef:A7E78_01225 (290 target-flexibility) (63 robustness)
    pef:A7E78_01330 (71 target-flexibility) (71 robustness)
    pef:A7E78_01430 (0 target-flexibility) (0 robustness)
    pef:A7E78_01440 (0 target-flexibility) (0 robustness)
    pef:A7E78_01445 (0 target-flexibility) (0 robustness)
    pef:A7E78_01785 (613 target-flexibility) (72 robustness)
    pef:A7E78_01825 (1108 target-flexibility) (319 robustness)
    pef:A7E78_02235 (0 target-flexibility) (0 robustness)
    pef:A7E78_02275 (691 target-flexibility) (528 robustness)
    pef:A7E78_02355 (691 target-flexibility) (528 robustness)
    pef:A7E78_02400 (0 target-flexibility) (0 robustness)
    pef:A7E78_02580 (600 target-flexibility) (126 robustness)
    pef:A7E78_02600 (732 target-flexibility) (78 robustness)
    pef:A7E78_02750 (1169 target-flexibility) (76 robustness)
    pef:A7E78_02810 (231 target-flexibility) (158 robustness)
    pef:A7E78_02815 (231 target-flexibility) (158 robustness)
    pef:A7E78_02985 (897 target-flexibility) (71 robustness)
    pef:A7E78_03040 (0 target-flexibility) (0 robustness)
    pef:A7E78_03600 (528 target-flexibility) (157 robustness)
    pef:A7E78_03620 (0 target-flexibility) (0 robustness)
    pef:A7E78_03875 (0 target-flexibility) (0 robustness)
    pef:A7E78_04140 (358 target-flexibility) (124 robustness)
    pef:A7E78_04420 (528 target-flexibility) (157 robustness)
    pef:A7E78_04585 (358 target-flexibility) (124 robustness)
    pef:A7E78_04590 (358 target-flexibility) (124 robustness)
    pef:A7E78_04875 (434 target-flexibility) (67 robustness)
    pef:A7E78_04890 (841 target-flexibility) (126 robustness)
    pef:A7E78_05185 (691 target-flexibility) (528 robustness)
    pef:A7E78_05540 (350 target-flexibility) (189 robustness)
    pef:A7E78_05805 (497 target-flexibility) (186 robustness)
    pef:A7E78_05895 (752 target-flexibility) (76 robustness)
    pef:A7E78_05905 (289 target-flexibility) (73 robustness)
    pef:A7E78_06000 (841 target-flexibility) (126 robustness)
    pef:A7E78_06095 (0 target-flexibility) (0 robustness)
    pef:A7E78_06150 (0 target-flexibility) (0 robustness)
    pef:A7E78_06630 (212 target-flexibility) (73 robustness)
    pef:A7E78_07325 (686 target-flexibility) (192 robustness)
    pef:A7E78_07335 (686 target-flexibility) (192 robustness)
    pef:A7E78_07855 (600 target-flexibility) (126 robustness)
    pef:A7E78_08220 (0 target-flexibility) (0 robustness)
    pef:A7E78_08225 (0 target-flexibility) (0 robustness)
    pef:A7E78_08565 (691 target-flexibility) (528 robustness)
    pef:A7E78_08985 (528 target-flexibility) (157 robustness)
    pef:A7E78_09055 (1108 target-flexibility) (319 robustness)
    pef:A7E78_10095 (334 target-flexibility) (71 robustness)
    pef:A7E78_10390 (1041 target-flexibility) (243 robustness)
    pef:A7E78_10450 (138 target-flexibility) (138 robustness)
    pef:A7E78_10690 (358 target-flexibility) (124 robustness)
    pef:A7E78_10820 (0 target-flexibility) (0 robustness)
    pef:A7E78_10830 (0 target-flexibility) (0 robustness)
    pef:A7E78_10835 (0 target-flexibility) (0 robustness)
    pef:A7E78_10875 (350 target-flexibility) (189 robustness)
    pef:A7E78_11135 (350 target-flexibility) (84 robustness)
    pef:A7E78_11145 (1041 target-flexibility) (243 robustness)
    pef:A7E78_11150 (1041 target-flexibility) (243 robustness)
    pef:A7E78_11340 (600 target-flexibility) (126 robustness)
    pef:A7E78_11715 (796 target-flexibility) (85 robustness)
    pef:A7E78_11740 (0 target-flexibility) (0 robustness)
    pef:A7E78_11875 (0 target-flexibility) (0 robustness)
    pef:A7E78_12325 (138 target-flexibility) (138 robustness)
    pef:A7E78_12430 (497 target-flexibility) (186 robustness)
    pef:A7E78_12505 (600 target-flexibility) (126 robustness)
    pef:A7E78_12525 (334 target-flexibility) (71 robustness)
    pef:A7E78_13175 (613 target-flexibility) (72 robustness)
    pef:A7E78_13520 (222 target-flexibility) (83 robustness)
    pef:A7E78_13750 (528 target-flexibility) (157 robustness)
    pef:A7E78_13795 (138 target-flexibility) (66 robustness)
    pef:A7E78_14195 (231 target-flexibility) (158 robustness)
    ppd:Ppro_0016 (1108 target-flexibility) (319 robustness)
    ppd:Ppro_0050 (821 target-flexibility) (137 robustness)
    ppd:Ppro_0301 (691 target-flexibility) (528 robustness)
    ppd:Ppro_0342 (339 target-flexibility) (98 robustness)
    ppd:Ppro_0343 (600 target-flexibility) (126 robustness)
    ppd:Ppro_0387 (0 target-flexibility) (0 robustness)
    ppd:Ppro_0415 (0 target-flexibility) (0 robustness)
    ppd:Ppro_0454 (0 target-flexibility) (0 robustness)
    ppd:Ppro_0579 (267 target-flexibility) (74 robustness)
    ppd:Ppro_0905 (659 target-flexibility) (240 robustness)
    ppd:Ppro_0907 (703 target-flexibility) (319 robustness)
    ppd:Ppro_1029 (219 target-flexibility) (63 robustness)
    ppd:Ppro_1034 (91 target-flexibility) (91 robustness)
    ppd:Ppro_1046 (1385 target-flexibility) (204 robustness)
    ppd:Ppro_1177 (0 target-flexibility) (0 robustness)
    ppd:Ppro_1191 (1169 target-flexibility) (76 robustness)
    ppd:Ppro_1291 (686 target-flexibility) (192 robustness)
    ppd:Ppro_1453 (0 target-flexibility) (0 robustness)
    ppd:Ppro_1518 (659 target-flexibility) (240 robustness)
    ppd:Ppro_1520 (0 target-flexibility) (0 robustness)
    ppd:Ppro_1580 (212 target-flexibility) (73 robustness)
    ppd:Ppro_1669 (0 target-flexibility) (0 robustness)
    ppd:Ppro_1725 (405 target-flexibility) (70 robustness)
    ppd:Ppro_1731 (0 target-flexibility) (0 robustness)
    ppd:Ppro_1832 (528 target-flexibility) (157 robustness)
    ppd:Ppro_2098 (0 target-flexibility) (0 robustness)
    ppd:Ppro_2118 (0 target-flexibility) (0 robustness)
    ppd:Ppro_2240 (0 target-flexibility) (0 robustness)
    ppd:Ppro_2329 (752 target-flexibility) (76 robustness)
    ppd:Ppro_2466 (821 target-flexibility) (137 robustness)
    ppd:Ppro_2529 (897 target-flexibility) (71 robustness)
    ppd:Ppro_2540 (0 target-flexibility) (0 robustness)
    ppd:Ppro_2556 (902 target-flexibility) (228 robustness)
    ppd:Ppro_2596 (91 target-flexibility) (91 robustness)
    ppd:Ppro_3055 (0 target-flexibility) (0 robustness)
    ppd:Ppro_3288 (70 target-flexibility) (70 robustness)
    ppd:Ppro_3293 (67 target-flexibility) (67 robustness)
    pprf:DPRO_0148 (841 target-flexibility) (126 robustness)
    pprf:DPRO_0151 (434 target-flexibility) (67 robustness)
    pprf:DPRO_0163 (0 target-flexibility) (0 robustness)
    pprf:DPRO_0184 (138 target-flexibility) (138 robustness)
    pprf:DPRO_0282 (279 target-flexibility) (126 robustness)
    pprf:DPRO_0296 (711 target-flexibility) (104 robustness)
    pprf:DPRO_0434 (330 target-flexibility) (76 robustness)
    pprf:DPRO_0650 (706 target-flexibility) (173 robustness)
    pprf:DPRO_0665 (902 target-flexibility) (228 robustness)
    pprf:DPRO_0799 (528 target-flexibility) (157 robustness)
    pprf:DPRO_0802 (222 target-flexibility) (83 robustness)
    pprf:DPRO_0842 (841 target-flexibility) (126 robustness)
    pprf:DPRO_0843 (600 target-flexibility) (126 robustness)
    pprf:DPRO_0869 (902 target-flexibility) (228 robustness)
    pprf:DPRO_0870 (902 target-flexibility) (228 robustness)
    pprf:DPRO_0895 (0 target-flexibility) (0 robustness)
    pprf:DPRO_0920 (138 target-flexibility) (138 robustness)
    pprf:DPRO_1057 (711 target-flexibility) (104 robustness)
    pprf:DPRO_1084 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1221 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1333 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1336 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1432 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1450 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1502 (790 target-flexibility) (134 robustness)
    pprf:DPRO_1557 (1385 target-flexibility) (204 robustness)
    pprf:DPRO_1577 (414 target-flexibility) (96 robustness)
    pprf:DPRO_1580 (600 target-flexibility) (126 robustness)
    pprf:DPRO_1581 (390 target-flexibility) (74 robustness)
    pprf:DPRO_1583 (1784 target-flexibility) (162 robustness)
    pprf:DPRO_1584 (330 target-flexibility) (76 robustness)
    pprf:DPRO_1586 (1041 target-flexibility) (243 robustness)
    pprf:DPRO_1657 (80 target-flexibility) (80 robustness)
    pprf:DPRO_1802 (790 target-flexibility) (134 robustness)
    pprf:DPRO_1845 (138 target-flexibility) (138 robustness)
    pprf:DPRO_1856 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1945 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1966 (902 target-flexibility) (228 robustness)
    pprf:DPRO_2030 (0 target-flexibility) (0 robustness)
    pprf:DPRO_2174 (790 target-flexibility) (134 robustness)
    pprf:DPRO_2239 (879 target-flexibility) (71 robustness)
    pprf:DPRO_2275 (0 target-flexibility) (0 robustness)
    pprf:DPRO_2329 (414 target-flexibility) (96 robustness)
    pprf:DPRO_2330 (1041 target-flexibility) (243 robustness)
    pprf:DPRO_2444 (358 target-flexibility) (104 robustness)
    pprf:DPRO_2470 (212 target-flexibility) (73 robustness)
    pprf:DPRO_2555 (0 target-flexibility) (0 robustness)
    pprf:DPRO_2602 (0 target-flexibility) (0 robustness)
    pprf:DPRO_2629 (1385 target-flexibility) (204 robustness)
    pprf:DPRO_2638 (0 target-flexibility) (0 robustness)
    pprf:DPRO_2643 (0 target-flexibility) (0 robustness)
    pprf:DPRO_2705 (1784 target-flexibility) (162 robustness)
    pprf:DPRO_2839 (686 target-flexibility) (192 robustness)
    pprf:DPRO_2879 (289 target-flexibility) (73 robustness)
    pprf:DPRO_2881 (686 target-flexibility) (192 robustness)
    pprf:DPRO_2976 (358 target-flexibility) (104 robustness)
    pprf:DPRO_3025 (0 target-flexibility) (0 robustness)
    pprf:DPRO_3102 (0 target-flexibility) (0 robustness)
    pprf:DPRO_3319 (706 target-flexibility) (173 robustness)
    pprf:DPRO_3321 (879 target-flexibility) (71 robustness)
    pprf:DPRO_3425 (706 target-flexibility) (173 robustness)
    pprf:DPRO_3768 (0 target-flexibility) (0 robustness)
    pprf:DPRO_3829 (0 target-flexibility) (0 robustness)
    pprf:DPRO_3892 (279 target-flexibility) (126 robustness)
    pprf:DPRO_4008 (390 target-flexibility) (74 robustness)
    samy:DB32_000011 (241 target-flexibility) (71 robustness)
    samy:DB32_000113 (231 target-flexibility) (158 robustness)
    samy:DB32_000220 (659 target-flexibility) (240 robustness)
    samy:DB32_000279 (703 target-flexibility) (319 robustness)
    samy:DB32_000329 (175 target-flexibility) (96 robustness)
    samy:DB32_000330 (686 target-flexibility) (192 robustness)
    samy:DB32_000455 (138 target-flexibility) (138 robustness)
    samy:DB32_000467 (497 target-flexibility) (186 robustness)
    samy:DB32_000470 (357 target-flexibility) (102 robustness)
    samy:DB32_000588 (657 target-flexibility) (95 robustness)
    samy:DB32_000657 (703 target-flexibility) (319 robustness)
    samy:DB32_000680 (0 target-flexibility) (0 robustness)
    samy:DB32_000949 (659 target-flexibility) (240 robustness)
    samy:DB32_000965 (0 target-flexibility) (0 robustness)
    samy:DB32_000992 (0 target-flexibility) (0 robustness)
    samy:DB32_001023 (752 target-flexibility) (76 robustness)
    samy:DB32_001141 (1108 target-flexibility) (319 robustness)
    samy:DB32_001261 (140 target-flexibility) (65 robustness)
    samy:DB32_001353 (0 target-flexibility) (0 robustness)
    samy:DB32_001409 (703 target-flexibility) (319 robustness)
    samy:DB32_001412 (659 target-flexibility) (240 robustness)
    samy:DB32_001415 (503 target-flexibility) (78 robustness)
    samy:DB32_001613 (323 target-flexibility) (101 robustness)
    samy:DB32_001636 (323 target-flexibility) (101 robustness)
    samy:DB32_001667 (350 target-flexibility) (189 robustness)
    samy:DB32_001708 (434 target-flexibility) (67 robustness)
    samy:DB32_001770 (924 target-flexibility) (101 robustness)
    samy:DB32_001845 (821 target-flexibility) (137 robustness)
    samy:DB32_001908 (357 target-flexibility) (102 robustness)
    samy:DB32_001928 (659 target-flexibility) (240 robustness)
    samy:DB32_002077 (1385 target-flexibility) (204 robustness)
    samy:DB32_002225 (902 target-flexibility) (228 robustness)
    samy:DB32_002239 (659 target-flexibility) (240 robustness)
    samy:DB32_002265 (0 target-flexibility) (0 robustness)
    samy:DB32_002497 (691 target-flexibility) (528 robustness)
    samy:DB32_002655 (1183 target-flexibility) (114 robustness)
    samy:DB32_002852 (0 target-flexibility) (0 robustness)
    samy:DB32_002924 (503 target-flexibility) (78 robustness)
    samy:DB32_002947 (350 target-flexibility) (189 robustness)
    samy:DB32_002954 (0 target-flexibility) (0 robustness)
    samy:DB32_003077 (528 target-flexibility) (157 robustness)
    samy:DB32_003101 (902 target-flexibility) (228 robustness)
    samy:DB32_003115 (902 target-flexibility) (228 robustness)
    samy:DB32_003116 (1108 target-flexibility) (319 robustness)
    samy:DB32_003149 (0 target-flexibility) (0 robustness)
    samy:DB32_003166 (497 target-flexibility) (186 robustness)
    samy:DB32_003170 (0 target-flexibility) (0 robustness)
    samy:DB32_003477 (0 target-flexibility) (0 robustness)
    samy:DB32_003480 (0 target-flexibility) (0 robustness)
    samy:DB32_003518 (0 target-flexibility) (0 robustness)
    samy:DB32_003546 (0 target-flexibility) (0 robustness)
    samy:DB32_003553 (212 target-flexibility) (73 robustness)
    samy:DB32_003583 (752 target-flexibility) (105 robustness)
    samy:DB32_003678 (289 target-flexibility) (73 robustness)
    samy:DB32_003711 (0 target-flexibility) (0 robustness)
    samy:DB32_003728 (222 target-flexibility) (83 robustness)
    samy:DB32_003841 (0 target-flexibility) (0 robustness)
    samy:DB32_003842 (0 target-flexibility) (0 robustness)
    samy:DB32_003877 (691 target-flexibility) (528 robustness)
    samy:DB32_003887 (659 target-flexibility) (240 robustness)
    samy:DB32_003889 (703 target-flexibility) (319 robustness)
    samy:DB32_003941 (175 target-flexibility) (78 robustness)
    samy:DB32_003961 (528 target-flexibility) (157 robustness)
    samy:DB32_003964 (528 target-flexibility) (157 robustness)
    samy:DB32_003973 (231 target-flexibility) (158 robustness)
    samy:DB32_004039 (855 target-flexibility) (138 robustness)
    samy:DB32_004060 (752 target-flexibility) (105 robustness)
    samy:DB32_004093 (358 target-flexibility) (124 robustness)
    samy:DB32_004135 (0 target-flexibility) (0 robustness)
    samy:DB32_004155 (821 target-flexibility) (137 robustness)
    samy:DB32_004284 (497 target-flexibility) (186 robustness)
    samy:DB32_004319 (0 target-flexibility) (0 robustness)
    samy:DB32_004322 (0 target-flexibility) (0 robustness)
    samy:DB32_004394 (706 target-flexibility) (173 robustness)
    samy:DB32_004421 (0 target-flexibility) (0 robustness)
    samy:DB32_004445 (239 target-flexibility) (67 robustness)
    samy:DB32_004448 (140 target-flexibility) (71 robustness)
    samy:DB32_004546 (855 target-flexibility) (138 robustness)
    samy:DB32_004597 (1183 target-flexibility) (114 robustness)
    samy:DB32_004608 (0 target-flexibility) (0 robustness)
    samy:DB32_004662 (703 target-flexibility) (319 robustness)
    samy:DB32_004711 (358 target-flexibility) (124 robustness)
    samy:DB32_004856 (657 target-flexibility) (95 robustness)
    samy:DB32_004998 (323 target-flexibility) (101 robustness)
    samy:DB32_005052 (1041 target-flexibility) (243 robustness)
    samy:DB32_005101 (528 target-flexibility) (157 robustness)
    samy:DB32_005105 (358 target-flexibility) (104 robustness)
    samy:DB32_005118 (1385 target-flexibility) (204 robustness)
    samy:DB32_005205 (434 target-flexibility) (67 robustness)
    samy:DB32_005206 (841 target-flexibility) (126 robustness)
    samy:DB32_005209 (841 target-flexibility) (126 robustness)
    samy:DB32_005212 (902 target-flexibility) (228 robustness)
    samy:DB32_005289 (657 target-flexibility) (95 robustness)
    samy:DB32_005406 (71 target-flexibility) (71 robustness)
    samy:DB32_005686 (0 target-flexibility) (0 robustness)
    samy:DB32_005700 (497 target-flexibility) (186 robustness)
    samy:DB32_005704 (686 target-flexibility) (192 robustness)
    samy:DB32_005734 (0 target-flexibility) (0 robustness)
    samy:DB32_005885 (323 target-flexibility) (101 robustness)
    samy:DB32_005931 (1041 target-flexibility) (243 robustness)
    samy:DB32_005996 (691 target-flexibility) (528 robustness)
    samy:DB32_006298 (528 target-flexibility) (157 robustness)
    samy:DB32_006304 (231 target-flexibility) (158 robustness)
    samy:DB32_006309 (924 target-flexibility) (101 robustness)
    samy:DB32_006310 (924 target-flexibility) (101 robustness)
    samy:DB32_006326 (175 target-flexibility) (78 robustness)
    samy:DB32_006421 (0 target-flexibility) (0 robustness)
    samy:DB32_006503 (138 target-flexibility) (138 robustness)
    samy:DB32_006581 (0 target-flexibility) (0 robustness)
    samy:DB32_006761 (841 target-flexibility) (126 robustness)
    samy:DB32_006869 (706 target-flexibility) (173 robustness)
    samy:DB32_006894 (0 target-flexibility) (0 robustness)
    samy:DB32_007120 (0 target-flexibility) (0 robustness)
    samy:DB32_007124 (358 target-flexibility) (104 robustness)
    samy:DB32_007188 (1108 target-flexibility) (319 robustness)
    samy:DB32_007196 (0 target-flexibility) (0 robustness)
    samy:DB32_007268 (790 target-flexibility) (134 robustness)
    samy:DB32_007373 (175 target-flexibility) (96 robustness)
    samy:DB32_007469 (0 target-flexibility) (0 robustness)
    samy:DB32_007585 (734 target-flexibility) (110 robustness)
    samy:DB32_007648 (0 target-flexibility) (0 robustness)
    samy:DB32_007837 (1385 target-flexibility) (204 robustness)
    samy:DB32_007931 (1108 target-flexibility) (319 robustness)
    samy:DB32_008364 (0 target-flexibility) (0 robustness)
    samy:DB32_008367 (1108 target-flexibility) (319 robustness)
    samy:DB32_008421 (734 target-flexibility) (110 robustness)
    samy:DB32_008496 (0 target-flexibility) (0 robustness)
    samy:DB32_008540 (241 target-flexibility) (71 robustness)
    samy:DB32_008570 (691 target-flexibility) (528 robustness)
    samy:DB32_008592 (140 target-flexibility) (65 robustness)
    samy:DB32_008649 (231 target-flexibility) (158 robustness)
    samy:DB32_008650 (231 target-flexibility) (158 robustness)
    samy:DB32_008655 (1385 target-flexibility) (204 robustness)
    samy:DB32_008737 (0 target-flexibility) (0 robustness)
    samy:DB32_008959 (241 target-flexibility) (71 robustness)
    sat:SYN_00001 (0 target-flexibility) (0 robustness)
    sat:SYN_00075 (358 target-flexibility) (104 robustness)
    sat:SYN_00090 (841 target-flexibility) (126 robustness)
    sat:SYN_00163 (691 target-flexibility) (528 robustness)
    sat:SYN_00211 (0 target-flexibility) (0 robustness)
    sat:SYN_00231 (0 target-flexibility) (0 robustness)
    sat:SYN_00266 (0 target-flexibility) (0 robustness)
    sat:SYN_00267 (0 target-flexibility) (0 robustness)
    sat:SYN_00272 (0 target-flexibility) (0 robustness)
    sat:SYN_00298 (0 target-flexibility) (0 robustness)
    sat:SYN_00302 (0 target-flexibility) (0 robustness)
    sat:SYN_00381 (700 target-flexibility) (89 robustness)
    sat:SYN_00412 (231 target-flexibility) (158 robustness)
    sat:SYN_00424 (854 target-flexibility) (204 robustness)
    sat:SYN_00442 (0 target-flexibility) (0 robustness)
    sat:SYN_00446 (528 target-flexibility) (157 robustness)
    sat:SYN_00583 (80 target-flexibility) (80 robustness)
    sat:SYN_00621 (279 target-flexibility) (126 robustness)
    sat:SYN_00729 (854 target-flexibility) (204 robustness)
    sat:SYN_00761 (0 target-flexibility) (0 robustness)
    sat:SYN_00891 (279 target-flexibility) (126 robustness)
    sat:SYN_00904 (700 target-flexibility) (80 robustness)
    sat:SYN_00907 (732 target-flexibility) (78 robustness)
    sat:SYN_00908 (1385 target-flexibility) (204 robustness)
    sat:SYN_01112 (0 target-flexibility) (0 robustness)
    sat:SYN_01125 (0 target-flexibility) (0 robustness)
    sat:SYN_01130 (0 target-flexibility) (0 robustness)
    sat:SYN_01149 (1108 target-flexibility) (319 robustness)
    sat:SYN_01150 (1108 target-flexibility) (319 robustness)
    sat:SYN_01164 (0 target-flexibility) (0 robustness)
    sat:SYN_01184 (146 target-flexibility) (70 robustness)
    sat:SYN_01209 (734 target-flexibility) (110 robustness)
    sat:SYN_01223 (790 target-flexibility) (134 robustness)
    sat:SYN_01226 (734 target-flexibility) (110 robustness)
    sat:SYN_01231 (512 target-flexibility) (74 robustness)
    sat:SYN_01251 (358 target-flexibility) (124 robustness)
    sat:SYN_01253 (528 target-flexibility) (157 robustness)
    sat:SYN_01258 (334 target-flexibility) (71 robustness)
    sat:SYN_01331 (0 target-flexibility) (0 robustness)
    sat:SYN_01365 (146 target-flexibility) (70 robustness)
    sat:SYN_01451 (0 target-flexibility) (0 robustness)
    sat:SYN_01454 (222 target-flexibility) (83 robustness)
    sat:SYN_01483 (231 target-flexibility) (158 robustness)
    sat:SYN_01517 (0 target-flexibility) (0 robustness)
    sat:SYN_01532 (897 target-flexibility) (71 robustness)
    sat:SYN_01577 (146 target-flexibility) (70 robustness)
    sat:SYN_01624 (732 target-flexibility) (78 robustness)
    sat:SYN_01625 (405 target-flexibility) (169 robustness)
    sat:SYN_01680 (659 target-flexibility) (240 robustness)
    sat:SYN_01684 (0 target-flexibility) (0 robustness)
    sat:SYN_01696 (659 target-flexibility) (240 robustness)
    sat:SYN_01710 (902 target-flexibility) (228 robustness)
    sat:SYN_01711 (902 target-flexibility) (228 robustness)
    sat:SYN_01712 (902 target-flexibility) (228 robustness)
    sat:SYN_01713 (902 target-flexibility) (228 robustness)
    sat:SYN_01740 (239 target-flexibility) (67 robustness)
    sat:SYN_01742 (67 target-flexibility) (67 robustness)
    sat:SYN_01747 (70 target-flexibility) (70 robustness)
    sat:SYN_01901 (700 target-flexibility) (80 robustness)
    sat:SYN_01942 (686 target-flexibility) (192 robustness)
    sat:SYN_01943 (226 target-flexibility) (85 robustness)
    sat:SYN_01944 (346 target-flexibility) (67 robustness)
    sat:SYN_01945 (634 target-flexibility) (72 robustness)
    sat:SYN_01960 (700 target-flexibility) (89 robustness)
    sat:SYN_01965 (902 target-flexibility) (228 robustness)
    sat:SYN_01988 (686 target-flexibility) (192 robustness)
    sat:SYN_02126 (358 target-flexibility) (124 robustness)
    sat:SYN_02127 (659 target-flexibility) (240 robustness)
    sat:SYN_02148 (0 target-flexibility) (0 robustness)
    sat:SYN_02156 (138 target-flexibility) (66 robustness)
    sat:SYN_02188 (607 target-flexibility) (75 robustness)
    sat:SYN_02194 (841 target-flexibility) (126 robustness)
    sat:SYN_02365 (703 target-flexibility) (319 robustness)
    sat:SYN_02374 (0 target-flexibility) (0 robustness)
    sat:SYN_02496 (512 target-flexibility) (74 robustness)
    sat:SYN_02501 (0 target-flexibility) (0 robustness)
    sat:SYN_02502 (0 target-flexibility) (0 robustness)
    sat:SYN_02535 (752 target-flexibility) (76 robustness)
    sat:SYN_02538 (607 target-flexibility) (75 robustness)
    sat:SYN_02563 (0 target-flexibility) (0 robustness)
    sat:SYN_02566 (703 target-flexibility) (319 robustness)
    sat:SYN_02578 (0 target-flexibility) (0 robustness)
    sat:SYN_02589 (405 target-flexibility) (169 robustness)
    sat:SYN_02590 (634 target-flexibility) (72 robustness)
    sat:SYN_02591 (346 target-flexibility) (67 robustness)
    sat:SYN_02592 (226 target-flexibility) (85 robustness)
    sat:SYN_02600 (0 target-flexibility) (0 robustness)
    sat:SYN_02602 (752 target-flexibility) (76 robustness)
    sat:SYN_02635 (790 target-flexibility) (134 robustness)
    sat:SYN_02640 (0 target-flexibility) (0 robustness)
    sat:SYN_02641 (279 target-flexibility) (126 robustness)
    sat:SYN_02643 (0 target-flexibility) (0 robustness)
    sat:SYN_02661 (0 target-flexibility) (0 robustness)
    sat:SYN_02666 (821 target-flexibility) (137 robustness)
    sat:SYN_02678 (821 target-flexibility) (137 robustness)
    sat:SYN_02758 (334 target-flexibility) (71 robustness)
    sat:SYN_02761 (0 target-flexibility) (0 robustness)
    sat:SYN_02778 (0 target-flexibility) (0 robustness)
    sat:SYN_02866 (0 target-flexibility) (0 robustness)
    sat:SYN_02880 (0 target-flexibility) (0 robustness)
    sat:SYN_02884 (0 target-flexibility) (0 robustness)
    sat:SYN_02886 (212 target-flexibility) (73 robustness)
    sat:SYN_02937 (1385 target-flexibility) (204 robustness)
    sat:SYN_02985 (691 target-flexibility) (528 robustness)
    sat:SYN_03026 (358 target-flexibility) (104 robustness)
    sat:SYN_03128 (0 target-flexibility) (0 robustness)
    sat:SYN_03227 (0 target-flexibility) (0 robustness)
    scl:sce0088 (423 target-flexibility) (81 robustness)
    scl:sce0127 (175 target-flexibility) (78 robustness)
    scl:sce0176 (855 target-flexibility) (138 robustness)
    scl:sce0253 (855 target-flexibility) (138 robustness)
    scl:sce0379 (734 target-flexibility) (110 robustness)
    scl:sce0564 (231 target-flexibility) (158 robustness)
    scl:sce0616 (358 target-flexibility) (104 robustness)
    scl:sce0693 (0 target-flexibility) (0 robustness)
    scl:sce0752 (0 target-flexibility) (0 robustness)
    scl:sce0903 (0 target-flexibility) (0 robustness)
    scl:sce1032 (423 target-flexibility) (81 robustness)
    scl:sce1044 (279 target-flexibility) (126 robustness)
    scl:sce1063 (0 target-flexibility) (0 robustness)
    scl:sce1175 (497 target-flexibility) (186 robustness)
    scl:sce1213 (1108 target-flexibility) (319 robustness)
    scl:sce1214 (902 target-flexibility) (228 robustness)
    scl:sce1639 (241 target-flexibility) (71 robustness)
    scl:sce1646 (659 target-flexibility) (240 robustness)
    scl:sce1736 (924 target-flexibility) (101 robustness)
    scl:sce1738 (924 target-flexibility) (101 robustness)
    scl:sce2226 (241 target-flexibility) (71 robustness)
    scl:sce2402 (0 target-flexibility) (0 robustness)
    scl:sce2526 (703 target-flexibility) (319 robustness)
    scl:sce2535 (752 target-flexibility) (105 robustness)
    scl:sce2553 (140 target-flexibility) (74 robustness)
    scl:sce2600 (1108 target-flexibility) (319 robustness)
    scl:sce2813 (0 target-flexibility) (0 robustness)
    scl:sce3018 (343 target-flexibility) (180 robustness)
    scl:sce3035 (248 target-flexibility) (73 robustness)
    scl:sce3161 (0 target-flexibility) (0 robustness)
    scl:sce3187 (821 target-flexibility) (137 robustness)
    scl:sce3273 (659 target-flexibility) (240 robustness)
    scl:sce3351 (703 target-flexibility) (319 robustness)
    scl:sce3354 (659 target-flexibility) (240 robustness)
    scl:sce3432 (343 target-flexibility) (180 robustness)
    scl:sce3447 (0 target-flexibility) (0 robustness)
    scl:sce3526 (701 target-flexibility) (106 robustness)
    scl:sce3703 (358 target-flexibility) (124 robustness)
    scl:sce3730 (902 target-flexibility) (228 robustness)
    scl:sce3733 (841 target-flexibility) (126 robustness)
    scl:sce3734 (841 target-flexibility) (126 robustness)
    scl:sce3735 (434 target-flexibility) (67 robustness)
    scl:sce3760 (0 target-flexibility) (0 robustness)
    scl:sce3813 (703 target-flexibility) (319 robustness)
    scl:sce3815 (659 target-flexibility) (240 robustness)
    scl:sce3817 (1108 target-flexibility) (319 robustness)
    scl:sce3826 (821 target-flexibility) (137 robustness)
    scl:sce3875 (734 target-flexibility) (110 robustness)
    scl:sce3953 (357 target-flexibility) (115 robustness)
    scl:sce3987 (1041 target-flexibility) (243 robustness)
    scl:sce4177 (706 target-flexibility) (173 robustness)
    scl:sce4215 (0 target-flexibility) (0 robustness)
    scl:sce4236 (222 target-flexibility) (83 robustness)
    scl:sce4259 (0 target-flexibility) (0 robustness)
    scl:sce4283 (0 target-flexibility) (0 robustness)
    scl:sce4320 (732 target-flexibility) (78 robustness)
    scl:sce4359 (343 target-flexibility) (180 robustness)
    scl:sce4502 (279 target-flexibility) (126 robustness)
    scl:sce4540 (1784 target-flexibility) (162 robustness)
    scl:sce4570 (706 target-flexibility) (173 robustness)
    scl:sce4640 (701 target-flexibility) (106 robustness)
    scl:sce4641 (528 target-flexibility) (157 robustness)
    scl:sce4786 (528 target-flexibility) (157 robustness)
    scl:sce4883 (841 target-flexibility) (126 robustness)
    scl:sce4939 (821 target-flexibility) (137 robustness)
    scl:sce5053 (1108 target-flexibility) (319 robustness)
    scl:sce5078 (0 target-flexibility) (0 robustness)
    scl:sce5134 (212 target-flexibility) (73 robustness)
    scl:sce5197 (1784 target-flexibility) (162 robustness)
    scl:sce5271 (0 target-flexibility) (0 robustness)
    scl:sce5302 (659 target-flexibility) (240 robustness)
    scl:sce5320 (358 target-flexibility) (104 robustness)
    scl:sce5556 (239 target-flexibility) (99 robustness)
    scl:sce5753 (528 target-flexibility) (157 robustness)
    scl:sce5757 (528 target-flexibility) (157 robustness)
    scl:sce5871 (350 target-flexibility) (84 robustness)
    scl:sce5886 (0 target-flexibility) (0 robustness)
    scl:sce5922 (703 target-flexibility) (319 robustness)
    scl:sce6193 (140 target-flexibility) (74 robustness)
    scl:sce6246 (752 target-flexibility) (105 robustness)
    scl:sce6540 (657 target-flexibility) (95 robustness)
    scl:sce6856 (231 target-flexibility) (158 robustness)
    scl:sce6876 (248 target-flexibility) (73 robustness)
    scl:sce6934 (657 target-flexibility) (95 robustness)
    scl:sce7038 (239 target-flexibility) (99 robustness)
    scl:sce7210 (357 target-flexibility) (115 robustness)
    scl:sce7329 (358 target-flexibility) (124 robustness)
    scl:sce7375 (528 target-flexibility) (157 robustness)
    scl:sce7407 (796 target-flexibility) (85 robustness)
    scl:sce7417 (0 target-flexibility) (0 robustness)
    scl:sce7733 (350 target-flexibility) (84 robustness)
    scl:sce7844 (0 target-flexibility) (0 robustness)
    scl:sce7847 (706 target-flexibility) (173 robustness)
    scl:sce7883 (175 target-flexibility) (78 robustness)
    scl:sce7927 (790 target-flexibility) (134 robustness)
    scl:sce8012 (0 target-flexibility) (0 robustness)
    scl:sce8081 (175 target-flexibility) (78 robustness)
    scl:sce8127 (902 target-flexibility) (228 robustness)
    scl:sce8151 (434 target-flexibility) (67 robustness)
    scl:sce8174 (841 target-flexibility) (126 robustness)
    scl:sce8230 (175 target-flexibility) (78 robustness)
    scl:sce8281 (924 target-flexibility) (101 robustness)
    scl:sce8467 (1041 target-flexibility) (243 robustness)
    scl:sce8601 (0 target-flexibility) (0 robustness)
    scl:sce8671 (691 target-flexibility) (528 robustness)
    scl:sce8676 (691 target-flexibility) (528 robustness)
    scl:sce8683 (497 target-flexibility) (186 robustness)
    scl:sce8696 (0 target-flexibility) (0 robustness)
    scl:sce8755 (902 target-flexibility) (228 robustness)
    scl:sce8804 (821 target-flexibility) (137 robustness)
    scl:sce8855 (0 target-flexibility) (0 robustness)
    scl:sce8915 (0 target-flexibility) (0 robustness)
    scl:sce8917 (0 target-flexibility) (0 robustness)
    scl:sce9115 (301 target-flexibility) (154 robustness)
    scl:sce9130 (301 target-flexibility) (154 robustness)
    scl:sce9167 (80 target-flexibility) (80 robustness)
    scl:sce9261 (752 target-flexibility) (105 robustness)
    scl:sce9309 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0007 (732 target-flexibility) (78 robustness)
    sfu:Sfum_0008 (405 target-flexibility) (169 robustness)
    sfu:Sfum_0062 (138 target-flexibility) (66 robustness)
    sfu:Sfum_0108 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0112 (659 target-flexibility) (240 robustness)
    sfu:Sfum_0113 (1108 target-flexibility) (319 robustness)
    sfu:Sfum_0122 (222 target-flexibility) (83 robustness)
    sfu:Sfum_0156 (691 target-flexibility) (528 robustness)
    sfu:Sfum_0179 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0192 (212 target-flexibility) (73 robustness)
    sfu:Sfum_0296 (902 target-flexibility) (228 robustness)
    sfu:Sfum_0379 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0382 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0392 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0478 (358 target-flexibility) (104 robustness)
    sfu:Sfum_0483 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0605 (854 target-flexibility) (204 robustness)
    sfu:Sfum_0615 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0630 (706 target-flexibility) (173 robustness)
    sfu:Sfum_0634 (706 target-flexibility) (173 robustness)
    sfu:Sfum_0649 (706 target-flexibility) (173 robustness)
    sfu:Sfum_0698 (138 target-flexibility) (138 robustness)
    sfu:Sfum_0745 (790 target-flexibility) (134 robustness)
    sfu:Sfum_0769 (634 target-flexibility) (72 robustness)
    sfu:Sfum_0841 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0871 (343 target-flexibility) (180 robustness)
    sfu:Sfum_0934 (486 target-flexibility) (89 robustness)
    sfu:Sfum_0937 (343 target-flexibility) (180 robustness)
    sfu:Sfum_0983 (700 target-flexibility) (80 robustness)
    sfu:Sfum_1039 (0 target-flexibility) (0 robustness)
    sfu:Sfum_1171 (1385 target-flexibility) (204 robustness)
    sfu:Sfum_1208 (657 target-flexibility) (95 robustness)
    sfu:Sfum_1215 (0 target-flexibility) (0 robustness)
    sfu:Sfum_1302 (1041 target-flexibility) (243 robustness)
    sfu:Sfum_1375 (703 target-flexibility) (319 robustness)
    sfu:Sfum_1468 (600 target-flexibility) (126 robustness)
    sfu:Sfum_1470 (0 target-flexibility) (0 robustness)
    sfu:Sfum_1475 (1784 target-flexibility) (162 robustness)
    sfu:Sfum_1533 (924 target-flexibility) (101 robustness)
    sfu:Sfum_1538 (0 target-flexibility) (0 robustness)
    sfu:Sfum_1608 (80 target-flexibility) (80 robustness)
    sfu:Sfum_1676 (0 target-flexibility) (0 robustness)
    sfu:Sfum_1700 (0 target-flexibility) (0 robustness)
    sfu:Sfum_1771 (686 target-flexibility) (192 robustness)
    sfu:Sfum_1824 (0 target-flexibility) (0 robustness)
    sfu:Sfum_1913 (154 target-flexibility) (80 robustness)
    sfu:Sfum_2015 (0 target-flexibility) (0 robustness)
    sfu:Sfum_2061 (600 target-flexibility) (126 robustness)
    sfu:Sfum_2123 (377 target-flexibility) (117 robustness)
    sfu:Sfum_2263 (0 target-flexibility) (0 robustness)
    sfu:Sfum_2610 (0 target-flexibility) (0 robustness)
    sfu:Sfum_2645 (323 target-flexibility) (101 robustness)
    sfu:Sfum_2980 (902 target-flexibility) (228 robustness)
    sfu:Sfum_2981 (902 target-flexibility) (228 robustness)
    sfu:Sfum_2982 (902 target-flexibility) (228 robustness)
    sfu:Sfum_2983 (902 target-flexibility) (228 robustness)
    sfu:Sfum_2984 (359 target-flexibility) (65 robustness)
    sfu:Sfum_2985 (103 target-flexibility) (103 robustness)
    sfu:Sfum_2986 (638 target-flexibility) (94 robustness)
    sfu:Sfum_2989 (434 target-flexibility) (67 robustness)
    sfu:Sfum_2990 (166 target-flexibility) (99 robustness)
    sfu:Sfum_2992 (0 target-flexibility) (0 robustness)
    sfu:Sfum_3010 (558 target-flexibility) (68 robustness)
    sfu:Sfum_3022 (902 target-flexibility) (228 robustness)
    sfu:Sfum_3023 (902 target-flexibility) (228 robustness)
    sfu:Sfum_3031 (434 target-flexibility) (67 robustness)
    sfu:Sfum_3302 (752 target-flexibility) (76 robustness)
    sfu:Sfum_3365 (752 target-flexibility) (76 robustness)
    sur:STAUR_0056 (1041 target-flexibility) (243 robustness)
    sur:STAUR_0276 (659 target-flexibility) (240 robustness)
    sur:STAUR_0279 (1108 target-flexibility) (319 robustness)
    sur:STAUR_0299 (0 target-flexibility) (0 robustness)
    sur:STAUR_0404 (154 target-flexibility) (80 robustness)
    sur:STAUR_0531 (212 target-flexibility) (73 robustness)
    sur:STAUR_0636 (336 target-flexibility) (81 robustness)
    sur:STAUR_0672 (526 target-flexibility) (95 robustness)
    sur:STAUR_0782 (215 target-flexibility) (142 robustness)
    sur:STAUR_0784 (0 target-flexibility) (0 robustness)
    sur:STAUR_0785 (855 target-flexibility) (138 robustness)
    sur:STAUR_1091 (686 target-flexibility) (192 robustness)
    sur:STAUR_1573 (503 target-flexibility) (78 robustness)
    sur:STAUR_1653 (73 target-flexibility) (73 robustness)
    sur:STAUR_1671 (732 target-flexibility) (78 robustness)
    sur:STAUR_1904 (357 target-flexibility) (102 robustness)
    sur:STAUR_2087 (659 target-flexibility) (240 robustness)
    sur:STAUR_2116 (0 target-flexibility) (0 robustness)
    sur:STAUR_2146 (796 target-flexibility) (85 robustness)
    sur:STAUR_2240 (336 target-flexibility) (81 robustness)
    sur:STAUR_2244 (343 target-flexibility) (180 robustness)
    sur:STAUR_2302 (0 target-flexibility) (0 robustness)
    sur:STAUR_2346 (528 target-flexibility) (157 robustness)
    sur:STAUR_2543 (691 target-flexibility) (528 robustness)
    sur:STAUR_2647 (691 target-flexibility) (528 robustness)
    sur:STAUR_2699 (691 target-flexibility) (528 robustness)
    sur:STAUR_2714 (0 target-flexibility) (0 robustness)
    sur:STAUR_2729 (659 target-flexibility) (240 robustness)
    sur:STAUR_3111 (697 target-flexibility) (78 robustness)
    sur:STAUR_3279 (0 target-flexibility) (0 robustness)
    sur:STAUR_3296 (790 target-flexibility) (134 robustness)
    sur:STAUR_3316 (526 target-flexibility) (95 robustness)
    sur:STAUR_3348 (1022 target-flexibility) (80 robustness)
    sur:STAUR_3412 (357 target-flexibility) (102 robustness)
    sur:STAUR_3549 (0 target-flexibility) (0 robustness)
    sur:STAUR_3605 (434 target-flexibility) (67 robustness)
    sur:STAUR_3608 (841 target-flexibility) (126 robustness)
    sur:STAUR_3769 (343 target-flexibility) (180 robustness)
    sur:STAUR_3779 (231 target-flexibility) (158 robustness)
    sur:STAUR_3846 (357 target-flexibility) (115 robustness)
    sur:STAUR_3888 (228 target-flexibility) (83 robustness)
    sur:STAUR_3898 (821 target-flexibility) (137 robustness)
    sur:STAUR_3946 (0 target-flexibility) (0 robustness)
    sur:STAUR_3991 (752 target-flexibility) (105 robustness)
    sur:STAUR_4027 (0 target-flexibility) (0 robustness)
    sur:STAUR_4028 (0 target-flexibility) (0 robustness)
    sur:STAUR_4035 (1784 target-flexibility) (162 robustness)
    sur:STAUR_4038 (0 target-flexibility) (0 robustness)
    sur:STAUR_4039 (924 target-flexibility) (101 robustness)
    sur:STAUR_4050 (289 target-flexibility) (73 robustness)
    sur:STAUR_4128 (0 target-flexibility) (0 robustness)
    sur:STAUR_4273 (821 target-flexibility) (137 robustness)
    sur:STAUR_4439 (343 target-flexibility) (180 robustness)
    sur:STAUR_4493 (0 target-flexibility) (0 robustness)
    sur:STAUR_4567 (231 target-flexibility) (158 robustness)
    sur:STAUR_4663 (0 target-flexibility) (0 robustness)
    sur:STAUR_4684 (0 target-flexibility) (0 robustness)
    sur:STAUR_4743 (659 target-flexibility) (240 robustness)
    sur:STAUR_4815 (212 target-flexibility) (73 robustness)
    sur:STAUR_4852 (528 target-flexibility) (157 robustness)
    sur:STAUR_4853 (301 target-flexibility) (74 robustness)
    sur:STAUR_4869 (0 target-flexibility) (0 robustness)
    sur:STAUR_4873 (841 target-flexibility) (126 robustness)
    sur:STAUR_4874 (434 target-flexibility) (67 robustness)
    sur:STAUR_5122 (855 target-flexibility) (138 robustness)
    sur:STAUR_5127 (358 target-flexibility) (124 robustness)
    sur:STAUR_5152 (0 target-flexibility) (0 robustness)
    sur:STAUR_5155 (0 target-flexibility) (0 robustness)
    sur:STAUR_5175 (734 target-flexibility) (110 robustness)
    sur:STAUR_5197 (657 target-flexibility) (95 robustness)
    sur:STAUR_5252 (691 target-flexibility) (528 robustness)
    sur:STAUR_5285 (528 target-flexibility) (157 robustness)
    sur:STAUR_5309 (796 target-flexibility) (85 robustness)
    sur:STAUR_5339 (703 target-flexibility) (319 robustness)
    sur:STAUR_5347 (902 target-flexibility) (228 robustness)
    sur:STAUR_5425 (1169 target-flexibility) (76 robustness)
    sur:STAUR_5482 (821 target-flexibility) (137 robustness)
    sur:STAUR_5486 (752 target-flexibility) (76 robustness)
    sur:STAUR_5581 (71 target-flexibility) (71 robustness)
    sur:STAUR_5595 (0 target-flexibility) (0 robustness)
    sur:STAUR_5618 (703 target-flexibility) (319 robustness)
    sur:STAUR_5620 (659 target-flexibility) (240 robustness)
    sur:STAUR_5621 (503 target-flexibility) (78 robustness)
    sur:STAUR_5622 (1108 target-flexibility) (319 robustness)
    sur:STAUR_5666 (752 target-flexibility) (105 robustness)
    sur:STAUR_5774 (222 target-flexibility) (83 robustness)
    sur:STAUR_5813 (358 target-flexibility) (124 robustness)
    sur:STAUR_5839 (734 target-flexibility) (110 robustness)
    sur:STAUR_5845 (657 target-flexibility) (95 robustness)
    sur:STAUR_5870 (0 target-flexibility) (0 robustness)
    sur:STAUR_5872 (301 target-flexibility) (74 robustness)
    sur:STAUR_5875 (0 target-flexibility) (0 robustness)
    sur:STAUR_6060 (0 target-flexibility) (0 robustness)
    sur:STAUR_6096 (0 target-flexibility) (0 robustness)
    sur:STAUR_6098 (0 target-flexibility) (0 robustness)
    sur:STAUR_6259 (231 target-flexibility) (158 robustness)
    sur:STAUR_6266 (67 target-flexibility) (67 robustness)
    sur:STAUR_6267 (239 target-flexibility) (67 robustness)
    sur:STAUR_6310 (357 target-flexibility) (115 robustness)
    sur:STAUR_6406 (231 target-flexibility) (158 robustness)
    sur:STAUR_6468 (228 target-flexibility) (83 robustness)
    sur:STAUR_6597 (697 target-flexibility) (78 robustness)
    sur:STAUR_6616 (231 target-flexibility) (158 robustness)
    sur:STAUR_6684 (0 target-flexibility) (0 robustness)
    sur:STAUR_6701 (924 target-flexibility) (101 robustness)
    sur:STAUR_6761 (686 target-flexibility) (192 robustness)
    sur:STAUR_6764 (215 target-flexibility) (142 robustness)
    sur:STAUR_6803 (902 target-flexibility) (228 robustness)
    sur:STAUR_6805 (855 target-flexibility) (138 robustness)
    sur:STAUR_6830 (357 target-flexibility) (115 robustness)
    sur:STAUR_6858 (1784 target-flexibility) (162 robustness)
    sur:STAUR_6979 (343 target-flexibility) (180 robustness)
    sur:STAUR_7012 (528 target-flexibility) (157 robustness)
    sur:STAUR_7055 (790 target-flexibility) (134 robustness)
    sur:STAUR_7164 (0 target-flexibility) (0 robustness)
    sur:STAUR_7165 (0 target-flexibility) (0 robustness)
    sur:STAUR_7168 (0 target-flexibility) (0 robustness)
    sur:STAUR_7259 (154 target-flexibility) (80 robustness)
    sur:STAUR_7849 (659 target-flexibility) (240 robustness)
    sur:STAUR_7912 (0 target-flexibility) (0 robustness)
    sur:STAUR_7939 (1022 target-flexibility) (80 robustness)
    sur:STAUR_8101 (80 target-flexibility) (80 robustness)
    sur:STAUR_8110 (73 target-flexibility) (73 robustness)
    sur:STAUR_8129 (222 target-flexibility) (83 robustness)
    sur:STAUR_8226 (0 target-flexibility) (0 robustness)
    vin:AKJ08_0033 (140 target-flexibility) (140 robustness)
    vin:AKJ08_0035 (140 target-flexibility) (140 robustness)
    vin:AKJ08_0051 (732 target-flexibility) (78 robustness)
    vin:AKJ08_0067 (0 target-flexibility) (0 robustness)
    vin:AKJ08_0163 (138 target-flexibility) (66 robustness)
    vin:AKJ08_0182 (343 target-flexibility) (180 robustness)
    vin:AKJ08_0229 (821 target-flexibility) (137 robustness)
    vin:AKJ08_0242 (821 target-flexibility) (137 robustness)
    vin:AKJ08_0304 (0 target-flexibility) (0 robustness)
    vin:AKJ08_0448 (262 target-flexibility) (86 robustness)
    vin:AKJ08_0452 (262 target-flexibility) (86 robustness)
    vin:AKJ08_0498 (530 target-flexibility) (162 robustness)
    vin:AKJ08_0507 (231 target-flexibility) (158 robustness)
    vin:AKJ08_0517 (262 target-flexibility) (86 robustness)
    vin:AKJ08_0647 (323 target-flexibility) (101 robustness)
    vin:AKJ08_0731 (1041 target-flexibility) (243 robustness)
    vin:AKJ08_0779 (0 target-flexibility) (0 robustness)
    vin:AKJ08_0879 (405 target-flexibility) (169 robustness)
    vin:AKJ08_0977 (0 target-flexibility) (0 robustness)
    vin:AKJ08_1030 (358 target-flexibility) (124 robustness)
    vin:AKJ08_1046 (796 target-flexibility) (85 robustness)
    vin:AKJ08_1190 (222 target-flexibility) (83 robustness)
    vin:AKJ08_1262 (1169 target-flexibility) (76 robustness)
    vin:AKJ08_1405 (289 target-flexibility) (73 robustness)
    vin:AKJ08_1409 (405 target-flexibility) (169 robustness)
    vin:AKJ08_1410 (149 target-flexibility) (77 robustness)
    vin:AKJ08_1411 (897 target-flexibility) (71 robustness)
    vin:AKJ08_1417 (0 target-flexibility) (0 robustness)
    vin:AKJ08_1488 (231 target-flexibility) (158 robustness)
    vin:AKJ08_1509 (357 target-flexibility) (102 robustness)
    vin:AKJ08_1631 (659 target-flexibility) (240 robustness)
    vin:AKJ08_1633 (530 target-flexibility) (162 robustness)
    vin:AKJ08_1829 (262 target-flexibility) (86 robustness)
    vin:AKJ08_1847 (405 target-flexibility) (169 robustness)
    vin:AKJ08_1848 (405 target-flexibility) (169 robustness)
    vin:AKJ08_1882 (434 target-flexibility) (67 robustness)
    vin:AKJ08_1884 (262 target-flexibility) (86 robustness)
    vin:AKJ08_1908 (0 target-flexibility) (0 robustness)
    vin:AKJ08_2065 (212 target-flexibility) (73 robustness)
    vin:AKJ08_2124 (323 target-flexibility) (101 robustness)
    vin:AKJ08_2231 (343 target-flexibility) (180 robustness)
    vin:AKJ08_2247 (231 target-flexibility) (158 robustness)
    vin:AKJ08_2249 (70 target-flexibility) (70 robustness)
    vin:AKJ08_2252 (140 target-flexibility) (71 robustness)
    vin:AKJ08_2254 (67 target-flexibility) (67 robustness)
    vin:AKJ08_2255 (239 target-flexibility) (67 robustness)
    vin:AKJ08_2274 (357 target-flexibility) (115 robustness)
    vin:AKJ08_2290 (358 target-flexibility) (124 robustness)
    vin:AKJ08_2325 (0 target-flexibility) (0 robustness)
    vin:AKJ08_2336 (659 target-flexibility) (240 robustness)
    vin:AKJ08_2528 (796 target-flexibility) (85 robustness)
    vin:AKJ08_2585 (659 target-flexibility) (240 robustness)
    vin:AKJ08_2627 (0 target-flexibility) (0 robustness)
    vin:AKJ08_2747 (74 target-flexibility) (74 robustness)
    vin:AKJ08_2748 (175 target-flexibility) (96 robustness)
    vin:AKJ08_2749 (175 target-flexibility) (96 robustness)
    vin:AKJ08_2890 (74 target-flexibility) (74 robustness)
    vin:AKJ08_3025 (175 target-flexibility) (96 robustness)
    vin:AKJ08_3161 (357 target-flexibility) (102 robustness)
    vin:AKJ08_3214 (222 target-flexibility) (83 robustness)
    vin:AKJ08_3459 (357 target-flexibility) (115 robustness)
    vin:AKJ08_3614 (0 target-flexibility) (0 robustness)
    vin:AKJ08_3662 (149 target-flexibility) (77 robustness)
    
    Target-flexibility contribution: 96.20466159790601%
    Robustness contribution: 86.81914495824505%


Conclusion
----------
27% of all enzymes are gene-duplicated, which seems like a sane value.

A bit more surprisingly, there are only 5868 gene-duplicated enzymes for a total of 5561 pairs of homologous enzymes, while it could have been double the number of pairs, i.e. 11122. 
But this would mean that each pair of enzymes contains unique enzymes. Obivously, however, there are many enzymes which occur in more than one pair. This means the enzymes actually form groups of homologous enzymes.

On the other hand, around 90% of all redundant enzymes have a gene-duplicated enzyme on one of their redundant paths. This seems like a lot, but such a high value is actually to be expected.
This is because, assuming the probability of hitting a gene-duplicated enzyme were to be equally distributed (which it is not, due to the scale-free architecture of the network), the probability of hitting at least one gene-duplicated enzyme on a redundant path of length 1 is 27%.
However, the probability of hitting at least one gene-duplicated enzyme on a redundant path of length 2 is already 54%.
Additionally, one node often has more than one alternative paths to another node. Also, one enzyme can have multiple edges, futher increasing the odds of hitting at least one gene-duplicated enzyme on any of its alternative paths.
Finally, in this case, we use an enzyme graph derived from enzymes which have EC numbers which occur in the core metabolism of the organism group.
Because of this, there almost certainly have to be multiple enzymes connecting each pair of nodes, because otherwise, they would not have been part of the enzymes involved in the core metabolism.

This does not answer the question whether an enzyme would not be robust/flexible if the gene-duplicated enzymes did not exist!

Due to the definition of flexibility and robustness, flexibility must always be higher than robustness, which it is here. Also, due to the definition of target-flexibility, it must always be even higher than flexibility.
Still, target-flexibility is close to 100%, which is probably due to the above mentioned likelihood of one enzyme (edge key), having multiple edges, having multiple alternative paths, of which only one must contain a gene-duplicated enzyme.
"""

from FEV_KEGG.KEGG.File import cache
from FEV_KEGG.Evolution.Clade import Clade
from FEV_KEGG.Statistics import Percent
from FEV_KEGG.Robustness.Topology.Redundancy import Redundancy, RedundancyContribution, RedundancyType

@cache(folder_path='experiments', file_name='deltaproteobacteria_clade')
def getCladeA():
    clade = Clade('Deltaproteobacteria')
    # pre-fetch collective metabolism into memory
    clade.collectiveMetabolism(excludeMultifunctionalEnzymes=True)
    # pre-fetch collective enzyme metabolism into memory
    clade.collectiveMetabolismEnzymes(excludeMultifunctionalEnzymes=True)
    return clade

if __name__ == '__main__':

    output = []
    
    #- get Deltaproteobacteria
    cladeA = getCladeA()
    majorityPercentageCoreMetabolism = 80
    output.append( 'core metabolism majority: ' + str(majorityPercentageCoreMetabolism) + '%' )
    output.append('')
    output.append(', '.join(cladeA.ncbiNames) + ':')
    output.append('')
    cladeAEnzymeGraph = cladeA.coreMetabolismEnzymes(majorityPercentageCoreMetabolism)
    cladeAenzymeCount = len(cladeAEnzymeGraph.getEnzymes())
    output.append( 'core metabolism enzymes: ' + str(cladeAenzymeCount) )
    output.append('')
    
    
    
    
    #- get and print gene-duplicated enzyme pairs
    cladeAGeneDuplicatedEnzymePairs = cladeA.geneDuplicatedEnzymePairs(majorityPercentageCoreMetabolism)
    
    cladeAGeneDuplicatedEnzymePairsSorted = list(cladeAGeneDuplicatedEnzymePairs)
    cladeAGeneDuplicatedEnzymePairsSorted.sort()
    
    output.append( 'gene-duplicated enzyme pairs: ' + str(len(cladeAGeneDuplicatedEnzymePairsSorted)) )
    
    for pair in cladeAGeneDuplicatedEnzymePairsSorted:
        output.append( pair )
    output.append('')
    
    
    
    
    
    cladeAGeneDuplicatedEnzymesSet = cladeA.geneDuplicatedEnzymes(majorityPercentageCoreMetabolism).getEnzymes()
    
    #- calculate redundancy
    cladeARedundancy = Redundancy(cladeAEnzymeGraph)
    cladeARedundancyContribution = RedundancyContribution(cladeARedundancy, cladeAGeneDuplicatedEnzymesSet)
    cladeARobustEnzymesForGeneDuplicatedEnzyme = cladeARedundancyContribution.getContributedKeysForSpecial(RedundancyType.ROBUSTNESS)
    cladeAFlexibleEnzymesForGeneDuplicatedEnzyme = cladeARedundancyContribution.getContributedKeysForSpecial(RedundancyType.TARGET_FLEXIBILITY)

    cladeAGeneDuplicatedEnzymesSetSorted = list(cladeAGeneDuplicatedEnzymesSet)
    cladeAGeneDuplicatedEnzymesSetSorted.sort()
      
    output.append( 'gene-duplicated enzymes: ' + str(len(cladeAGeneDuplicatedEnzymesSetSorted)) + ' (' + str(Percent.getPercentStringShort(len(cladeAGeneDuplicatedEnzymesSetSorted), cladeAenzymeCount, 0)) + '%)' )
    
    #- REPEAT for each gene-duplicated enzyme
    for enzyme in cladeAGeneDuplicatedEnzymesSetSorted:
        #-     print number of enzymes the gene-duplicated enzyme provides redundancy for (robustness and flexibility)
        output.append( str(enzyme) + ' (' + str(len(cladeAFlexibleEnzymesForGeneDuplicatedEnzyme.get(enzyme, []))) + ' target-flexibility) (' + str(len(cladeARobustEnzymesForGeneDuplicatedEnzyme.get(enzyme, []))) + ' robustness)')
    output.append('')
    
    
    output.append( 'Target-flexibility contribution: ' + str(cladeARedundancyContribution.getKeyContributionRatio(RedundancyType.TARGET_FLEXIBILITY) * 100) + '%' )
    output.append( 'Robustness contribution: ' + str(cladeARedundancyContribution.getKeyContributionRatio(RedundancyType.ROBUSTNESS) * 100) + '%' )
     
    
    
    
    
    for line in output:
        print( line )
