"""
Question
--------
Which neofunctionalised enzymes exist in Deltaproteobacteria?
Does their existence increase redundancy? If yes, how much?

Method
------
- get Deltaproteobacteria
- get neofunctionalised enzymes
- calculate redundancy
- REPEAT for each neofunctionalised enzyme
-     print number of enzymes the neofunctionalised enzyme provides redundancy for (robustness and flexibility)

Result
------

::
    core metabolism majority: 80%
    
    Deltaproteobacteria:
    
    core metabolism enzymes: 21519
    
    neofunctionalised enzymes: 1400 ( 7%)
    ade:Adeh_0012 (222 target-flexibility) (83 robustness)
    ade:Adeh_0069 (0 target-flexibility) (0 robustness)
    ade:Adeh_0221 (0 target-flexibility) (0 robustness)
    ade:Adeh_1078 (71 target-flexibility) (71 robustness)
    ade:Adeh_1165 (0 target-flexibility) (0 robustness)
    ade:Adeh_1618 (897 target-flexibility) (71 robustness)
    ade:Adeh_1954 (0 target-flexibility) (0 robustness)
    ade:Adeh_1955 (0 target-flexibility) (0 robustness)
    ade:Adeh_2390 (212 target-flexibility) (73 robustness)
    ade:Adeh_2533 (752 target-flexibility) (76 robustness)
    ade:Adeh_2619 (790 target-flexibility) (134 robustness)
    ade:Adeh_2691 (138 target-flexibility) (66 robustness)
    ade:Adeh_2727 (0 target-flexibility) (0 robustness)
    ade:Adeh_2728 (206 target-flexibility) (68 robustness)
    ade:Adeh_3766 (239 target-flexibility) (67 robustness)
    ade:Adeh_3767 (67 target-flexibility) (67 robustness)
    ade:Adeh_3769 (140 target-flexibility) (71 robustness)
    ade:Adeh_3772 (70 target-flexibility) (70 robustness)
    ade:Adeh_3959 (796 target-flexibility) (85 robustness)
    ade:Adeh_4206 (732 target-flexibility) (78 robustness)
    ade:Adeh_4288 (0 target-flexibility) (0 robustness)
    ade:Adeh_4344 (80 target-flexibility) (80 robustness)
    afw:Anae109_0013 (222 target-flexibility) (83 robustness)
    afw:Anae109_0070 (0 target-flexibility) (0 robustness)
    afw:Anae109_0462 (796 target-flexibility) (85 robustness)
    afw:Anae109_1117 (71 target-flexibility) (71 robustness)
    afw:Anae109_1136 (1169 target-flexibility) (76 robustness)
    afw:Anae109_1212 (0 target-flexibility) (0 robustness)
    afw:Anae109_1329 (752 target-flexibility) (76 robustness)
    afw:Anae109_1477 (212 target-flexibility) (73 robustness)
    afw:Anae109_1900 (0 target-flexibility) (0 robustness)
    afw:Anae109_1901 (0 target-flexibility) (0 robustness)
    afw:Anae109_2193 (897 target-flexibility) (71 robustness)
    afw:Anae109_2586 (790 target-flexibility) (134 robustness)
    afw:Anae109_2685 (138 target-flexibility) (66 robustness)
    afw:Anae109_2719 (0 target-flexibility) (0 robustness)
    afw:Anae109_3170 (790 target-flexibility) (134 robustness)
    afw:Anae109_3317 (1041 target-flexibility) (243 robustness)
    afw:Anae109_3879 (239 target-flexibility) (67 robustness)
    afw:Anae109_3880 (67 target-flexibility) (67 robustness)
    afw:Anae109_3882 (140 target-flexibility) (71 robustness)
    afw:Anae109_3885 (70 target-flexibility) (70 robustness)
    afw:Anae109_4196 (0 target-flexibility) (0 robustness)
    afw:Anae109_4354 (732 target-flexibility) (78 robustness)
    afw:Anae109_4443 (0 target-flexibility) (0 robustness)
    afw:Anae109_4491 (80 target-flexibility) (80 robustness)
    age:AA314_01105 (0 target-flexibility) (0 robustness)
    age:AA314_01165 (222 target-flexibility) (83 robustness)
    age:AA314_01193 (80 target-flexibility) (80 robustness)
    age:AA314_01912 (790 target-flexibility) (134 robustness)
    age:AA314_02310 (732 target-flexibility) (78 robustness)
    age:AA314_02714 (796 target-flexibility) (85 robustness)
    age:AA314_02872 (0 target-flexibility) (0 robustness)
    age:AA314_03054 (0 target-flexibility) (0 robustness)
    age:AA314_04189 (0 target-flexibility) (0 robustness)
    age:AA314_04205 (71 target-flexibility) (71 robustness)
    age:AA314_04258 (752 target-flexibility) (76 robustness)
    age:AA314_04350 (0 target-flexibility) (0 robustness)
    age:AA314_04447 (212 target-flexibility) (73 robustness)
    age:AA314_04970 (0 target-flexibility) (0 robustness)
    age:AA314_05002 (0 target-flexibility) (0 robustness)
    age:AA314_05003 (0 target-flexibility) (0 robustness)
    age:AA314_05007 (897 target-flexibility) (71 robustness)
    age:AA314_05182 (212 target-flexibility) (73 robustness)
    age:AA314_05840 (0 target-flexibility) (0 robustness)
    age:AA314_05880 (138 target-flexibility) (66 robustness)
    age:AA314_08007 (70 target-flexibility) (70 robustness)
    age:AA314_08012 (67 target-flexibility) (67 robustness)
    ank:AnaeK_0012 (222 target-flexibility) (83 robustness)
    ank:AnaeK_0075 (0 target-flexibility) (0 robustness)
    ank:AnaeK_0232 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1137 (71 target-flexibility) (71 robustness)
    ank:AnaeK_1224 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1316 (752 target-flexibility) (76 robustness)
    ank:AnaeK_1474 (212 target-flexibility) (73 robustness)
    ank:AnaeK_1924 (0 target-flexibility) (0 robustness)
    ank:AnaeK_1925 (0 target-flexibility) (0 robustness)
    ank:AnaeK_2242 (897 target-flexibility) (71 robustness)
    ank:AnaeK_2705 (790 target-flexibility) (134 robustness)
    ank:AnaeK_2784 (138 target-flexibility) (66 robustness)
    ank:AnaeK_2819 (0 target-flexibility) (0 robustness)
    ank:AnaeK_3822 (239 target-flexibility) (67 robustness)
    ank:AnaeK_3823 (67 target-flexibility) (67 robustness)
    ank:AnaeK_3825 (140 target-flexibility) (71 robustness)
    ank:AnaeK_3828 (70 target-flexibility) (70 robustness)
    ank:AnaeK_4069 (796 target-flexibility) (85 robustness)
    ank:AnaeK_4338 (732 target-flexibility) (78 robustness)
    ank:AnaeK_4425 (0 target-flexibility) (0 robustness)
    ank:AnaeK_4480 (80 target-flexibility) (80 robustness)
    ccro:CMC5_000130 (212 target-flexibility) (73 robustness)
    ccro:CMC5_011930 (80 target-flexibility) (80 robustness)
    ccro:CMC5_012020 (0 target-flexibility) (0 robustness)
    ccro:CMC5_012520 (0 target-flexibility) (0 robustness)
    ccro:CMC5_019230 (0 target-flexibility) (0 robustness)
    ccro:CMC5_044530 (222 target-flexibility) (83 robustness)
    ccro:CMC5_049960 (0 target-flexibility) (0 robustness)
    ccro:CMC5_065360 (70 target-flexibility) (70 robustness)
    ccro:CMC5_065390 (140 target-flexibility) (71 robustness)
    ccro:CMC5_084110 (0 target-flexibility) (0 robustness)
    ccx:COCOR_00905 (790 target-flexibility) (134 robustness)
    ccx:COCOR_01049 (732 target-flexibility) (78 robustness)
    ccx:COCOR_01272 (796 target-flexibility) (85 robustness)
    ccx:COCOR_01538 (0 target-flexibility) (0 robustness)
    ccx:COCOR_02172 (0 target-flexibility) (0 robustness)
    ccx:COCOR_02650 (0 target-flexibility) (0 robustness)
    ccx:COCOR_02664 (71 target-flexibility) (71 robustness)
    ccx:COCOR_02713 (752 target-flexibility) (76 robustness)
    ccx:COCOR_03319 (212 target-flexibility) (73 robustness)
    ccx:COCOR_03939 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04535 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04536 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04815 (0 target-flexibility) (0 robustness)
    ccx:COCOR_04847 (1169 target-flexibility) (76 robustness)
    ccx:COCOR_05520 (790 target-flexibility) (134 robustness)
    ccx:COCOR_06667 (222 target-flexibility) (83 robustness)
    ccx:COCOR_06741 (1041 target-flexibility) (243 robustness)
    ccx:COCOR_07636 (222 target-flexibility) (83 robustness)
    cfus:CYFUS_000638 (222 target-flexibility) (83 robustness)
    cfus:CYFUS_001210 (790 target-flexibility) (134 robustness)
    cfus:CYFUS_001311 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_001459 (732 target-flexibility) (78 robustness)
    cfus:CYFUS_002029 (796 target-flexibility) (85 robustness)
    cfus:CYFUS_002221 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_002381 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_002855 (790 target-flexibility) (134 robustness)
    cfus:CYFUS_003276 (222 target-flexibility) (83 robustness)
    cfus:CYFUS_003510 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_003523 (71 target-flexibility) (71 robustness)
    cfus:CYFUS_004387 (212 target-flexibility) (73 robustness)
    cfus:CYFUS_004499 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_004500 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_004504 (897 target-flexibility) (71 robustness)
    cfus:CYFUS_004967 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_005495 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_005533 (138 target-flexibility) (66 robustness)
    cfus:CYFUS_006014 (0 target-flexibility) (0 robustness)
    cfus:CYFUS_006116 (752 target-flexibility) (76 robustness)
    cfus:CYFUS_007834 (67 target-flexibility) (67 robustness)
    cfus:CYFUS_007835 (239 target-flexibility) (67 robustness)
    cfus:CYFUS_007908 (0 target-flexibility) (0 robustness)
    daf:Desaf_0090 (1041 target-flexibility) (243 robustness)
    daf:Desaf_0111 (732 target-flexibility) (78 robustness)
    daf:Desaf_0304 (1041 target-flexibility) (243 robustness)
    daf:Desaf_0322 (790 target-flexibility) (134 robustness)
    daf:Desaf_0930 (0 target-flexibility) (0 robustness)
    daf:Desaf_1013 (0 target-flexibility) (0 robustness)
    daf:Desaf_1251 (790 target-flexibility) (134 robustness)
    daf:Desaf_1274 (528 target-flexibility) (157 robustness)
    daf:Desaf_1333 (0 target-flexibility) (0 robustness)
    daf:Desaf_1391 (790 target-flexibility) (134 robustness)
    daf:Desaf_1457 (212 target-flexibility) (73 robustness)
    daf:Desaf_1564 (796 target-flexibility) (85 robustness)
    daf:Desaf_1776 (80 target-flexibility) (80 robustness)
    daf:Desaf_2132 (0 target-flexibility) (0 robustness)
    daf:Desaf_2261 (358 target-flexibility) (104 robustness)
    daf:Desaf_2305 (0 target-flexibility) (0 robustness)
    daf:Desaf_2339 (0 target-flexibility) (0 robustness)
    daf:Desaf_2415 (0 target-flexibility) (0 robustness)
    daf:Desaf_2509 (289 target-flexibility) (73 robustness)
    daf:Desaf_2909 (0 target-flexibility) (0 robustness)
    daf:Desaf_2926 (222 target-flexibility) (83 robustness)
    daf:Desaf_2970 (1169 target-flexibility) (76 robustness)
    daf:Desaf_3260 (434 target-flexibility) (67 robustness)
    dak:DaAHT2_0472 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1051 (212 target-flexibility) (73 robustness)
    dak:DaAHT2_1178 (222 target-flexibility) (83 robustness)
    dak:DaAHT2_1480 (70 target-flexibility) (70 robustness)
    dak:DaAHT2_1482 (140 target-flexibility) (71 robustness)
    dak:DaAHT2_1636 (732 target-flexibility) (78 robustness)
    dak:DaAHT2_1791 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1792 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1794 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_1831 (0 target-flexibility) (0 robustness)
    dak:DaAHT2_2211 (138 target-flexibility) (66 robustness)
    dak:DaAHT2_2315 (897 target-flexibility) (71 robustness)
    dak:DaAHT2_2371 (796 target-flexibility) (85 robustness)
    dak:DaAHT2_2537 (80 target-flexibility) (80 robustness)
    dak:DaAHT2_2561 (0 target-flexibility) (0 robustness)
    dal:Dalk_0475 (0 target-flexibility) (0 robustness)
    dal:Dalk_0497 (212 target-flexibility) (73 robustness)
    dal:Dalk_0836 (1169 target-flexibility) (76 robustness)
    dal:Dalk_0853 (0 target-flexibility) (0 robustness)
    dal:Dalk_0935 (0 target-flexibility) (0 robustness)
    dal:Dalk_1064 (1041 target-flexibility) (243 robustness)
    dal:Dalk_1193 (0 target-flexibility) (0 robustness)
    dal:Dalk_1240 (434 target-flexibility) (67 robustness)
    dal:Dalk_1587 (0 target-flexibility) (0 robustness)
    dal:Dalk_1693 (0 target-flexibility) (0 robustness)
    dal:Dalk_1699 (0 target-flexibility) (0 robustness)
    dal:Dalk_1770 (222 target-flexibility) (83 robustness)
    dal:Dalk_1784 (71 target-flexibility) (71 robustness)
    dal:Dalk_1934 (289 target-flexibility) (73 robustness)
    dal:Dalk_2329 (790 target-flexibility) (134 robustness)
    dal:Dalk_2651 (528 target-flexibility) (157 robustness)
    dal:Dalk_2756 (752 target-flexibility) (76 robustness)
    dal:Dalk_3130 (70 target-flexibility) (70 robustness)
    dal:Dalk_3133 (140 target-flexibility) (71 robustness)
    dal:Dalk_3135 (67 target-flexibility) (67 robustness)
    dal:Dalk_3136 (239 target-flexibility) (67 robustness)
    dal:Dalk_3333 (0 target-flexibility) (0 robustness)
    dal:Dalk_3370 (1385 target-flexibility) (204 robustness)
    dal:Dalk_3820 (358 target-flexibility) (104 robustness)
    dal:Dalk_4104 (0 target-flexibility) (0 robustness)
    dal:Dalk_4640 (0 target-flexibility) (0 robustness)
    dao:Desac_0009 (897 target-flexibility) (71 robustness)
    dao:Desac_0239 (0 target-flexibility) (0 robustness)
    dao:Desac_0519 (732 target-flexibility) (78 robustness)
    dao:Desac_0596 (70 target-flexibility) (70 robustness)
    dao:Desac_0599 (140 target-flexibility) (71 robustness)
    dao:Desac_0601 (67 target-flexibility) (67 robustness)
    dao:Desac_0602 (239 target-flexibility) (67 robustness)
    dao:Desac_0972 (206 target-flexibility) (68 robustness)
    dao:Desac_1300 (289 target-flexibility) (73 robustness)
    dao:Desac_1415 (212 target-flexibility) (73 robustness)
    dao:Desac_1501 (0 target-flexibility) (0 robustness)
    dao:Desac_1741 (0 target-flexibility) (0 robustness)
    dao:Desac_2262 (0 target-flexibility) (0 robustness)
    dao:Desac_2462 (796 target-flexibility) (85 robustness)
    dao:Desac_2478 (138 target-flexibility) (66 robustness)
    dao:Desac_2517 (0 target-flexibility) (0 robustness)
    dao:Desac_2541 (0 target-flexibility) (0 robustness)
    dao:Desac_2544 (0 target-flexibility) (0 robustness)
    dao:Desac_2593 (80 target-flexibility) (80 robustness)
    dao:Desac_2722 (71 target-flexibility) (71 robustness)
    dao:Desac_2908 (222 target-flexibility) (83 robustness)
    dao:Desac_2922 (434 target-flexibility) (67 robustness)
    das:Daes_0077 (1041 target-flexibility) (243 robustness)
    das:Daes_0202 (790 target-flexibility) (134 robustness)
    das:Daes_0235 (752 target-flexibility) (76 robustness)
    das:Daes_0542 (790 target-flexibility) (134 robustness)
    das:Daes_0665 (790 target-flexibility) (134 robustness)
    das:Daes_0687 (1385 target-flexibility) (204 robustness)
    das:Daes_0744 (212 target-flexibility) (73 robustness)
    das:Daes_0753 (80 target-flexibility) (80 robustness)
    das:Daes_0911 (1169 target-flexibility) (76 robustness)
    das:Daes_0961 (0 target-flexibility) (0 robustness)
    das:Daes_1318 (0 target-flexibility) (0 robustness)
    das:Daes_1396 (71 target-flexibility) (71 robustness)
    das:Daes_1706 (528 target-flexibility) (157 robustness)
    das:Daes_1709 (222 target-flexibility) (83 robustness)
    das:Daes_1850 (206 target-flexibility) (68 robustness)
    das:Daes_1909 (434 target-flexibility) (67 robustness)
    das:Daes_1972 (1041 target-flexibility) (243 robustness)
    das:Daes_2350 (358 target-flexibility) (104 robustness)
    das:Daes_2678 (289 target-flexibility) (73 robustness)
    das:Daes_2821 (0 target-flexibility) (0 robustness)
    das:Daes_2857 (0 target-flexibility) (0 robustness)
    das:Daes_2972 (0 target-flexibility) (0 robustness)
    das:Daes_3345 (0 target-flexibility) (0 robustness)
    dat:HRM2_04430 (434 target-flexibility) (67 robustness)
    dat:HRM2_06910 (528 target-flexibility) (157 robustness)
    dat:HRM2_08850 (790 target-flexibility) (134 robustness)
    dat:HRM2_11950 (790 target-flexibility) (134 robustness)
    dat:HRM2_12660 (239 target-flexibility) (67 robustness)
    dat:HRM2_12670 (67 target-flexibility) (67 robustness)
    dat:HRM2_13680 (0 target-flexibility) (0 robustness)
    dat:HRM2_20130 (358 target-flexibility) (104 robustness)
    dat:HRM2_20900 (212 target-flexibility) (73 robustness)
    dat:HRM2_23040 (0 target-flexibility) (0 robustness)
    dat:HRM2_24890 (222 target-flexibility) (83 robustness)
    dat:HRM2_26740 (358 target-flexibility) (104 robustness)
    dat:HRM2_27190 (0 target-flexibility) (0 robustness)
    dat:HRM2_27560 (138 target-flexibility) (66 robustness)
    dat:HRM2_27780 (897 target-flexibility) (71 robustness)
    dat:HRM2_28720 (790 target-flexibility) (134 robustness)
    dat:HRM2_29750 (0 target-flexibility) (0 robustness)
    dat:HRM2_41030 (289 target-flexibility) (73 robustness)
    dat:HRM2_47210 (790 target-flexibility) (134 robustness)
    dat:HRM2_47820 (0 target-flexibility) (0 robustness)
    dat:HRM2_47830 (0 target-flexibility) (0 robustness)
    dav:DESACE_00060 (1041 target-flexibility) (243 robustness)
    dav:DESACE_01185 (212 target-flexibility) (73 robustness)
    dav:DESACE_02320 (222 target-flexibility) (83 robustness)
    dav:DESACE_03005 (67 target-flexibility) (67 robustness)
    dav:DESACE_03010 (239 target-flexibility) (67 robustness)
    dav:DESACE_03180 (1169 target-flexibility) (76 robustness)
    dav:DESACE_03245 (70 target-flexibility) (70 robustness)
    dav:DESACE_03540 (0 target-flexibility) (0 robustness)
    dav:DESACE_05935 (80 target-flexibility) (80 robustness)
    dav:DESACE_08825 (0 target-flexibility) (0 robustness)
    dba:Dbac_0057 (0 target-flexibility) (0 robustness)
    dba:Dbac_0109 (790 target-flexibility) (134 robustness)
    dba:Dbac_0488 (222 target-flexibility) (83 robustness)
    dba:Dbac_1036 (358 target-flexibility) (104 robustness)
    dba:Dbac_1478 (790 target-flexibility) (134 robustness)
    dba:Dbac_1611 (0 target-flexibility) (0 robustness)
    dba:Dbac_1638 (528 target-flexibility) (157 robustness)
    dba:Dbac_1740 (434 target-flexibility) (67 robustness)
    dba:Dbac_1985 (289 target-flexibility) (73 robustness)
    dba:Dbac_2450 (212 target-flexibility) (73 robustness)
    dba:Dbac_2718 (0 target-flexibility) (0 robustness)
    dba:Dbac_2833 (796 target-flexibility) (85 robustness)
    dba:Dbac_2884 (0 target-flexibility) (0 robustness)
    dba:Dbac_3003 (80 target-flexibility) (80 robustness)
    dba:Dbac_3039 (0 target-flexibility) (0 robustness)
    dba:Dbac_3166 (790 target-flexibility) (134 robustness)
    dba:Dbac_3212 (732 target-flexibility) (78 robustness)
    dbr:Deba_0146 (0 target-flexibility) (0 robustness)
    dbr:Deba_0292 (796 target-flexibility) (85 robustness)
    dbr:Deba_0342 (434 target-flexibility) (67 robustness)
    dbr:Deba_0413 (222 target-flexibility) (83 robustness)
    dbr:Deba_0419 (0 target-flexibility) (0 robustness)
    dbr:Deba_0577 (80 target-flexibility) (80 robustness)
    dbr:Deba_0581 (0 target-flexibility) (0 robustness)
    dbr:Deba_0585 (790 target-flexibility) (134 robustness)
    dbr:Deba_0606 (0 target-flexibility) (0 robustness)
    dbr:Deba_0994 (0 target-flexibility) (0 robustness)
    dbr:Deba_1178 (528 target-flexibility) (157 robustness)
    dbr:Deba_1275 (289 target-flexibility) (73 robustness)
    dbr:Deba_1412 (0 target-flexibility) (0 robustness)
    dbr:Deba_1780 (0 target-flexibility) (0 robustness)
    dbr:Deba_1882 (138 target-flexibility) (66 robustness)
    dbr:Deba_2001 (212 target-flexibility) (73 robustness)
    dbr:Deba_2122 (790 target-flexibility) (134 robustness)
    dbr:Deba_2140 (0 target-flexibility) (0 robustness)
    dbr:Deba_2288 (0 target-flexibility) (0 robustness)
    dbr:Deba_2503 (790 target-flexibility) (134 robustness)
    dbr:Deba_2654 (897 target-flexibility) (71 robustness)
    dbr:Deba_2748 (0 target-flexibility) (0 robustness)
    dbr:Deba_2773 (0 target-flexibility) (0 robustness)
    dbr:Deba_2788 (239 target-flexibility) (67 robustness)
    dbr:Deba_2789 (67 target-flexibility) (67 robustness)
    dbr:Deba_2791 (140 target-flexibility) (71 robustness)
    dbr:Deba_2794 (70 target-flexibility) (70 robustness)
    dbr:Deba_3125 (732 target-flexibility) (78 robustness)
    dbr:Deba_3187 (790 target-flexibility) (134 robustness)
    dbr:Deba_3263 (358 target-flexibility) (104 robustness)
    dde:Dde_0033 (0 target-flexibility) (0 robustness)
    dde:Dde_0626 (405 target-flexibility) (70 robustness)
    dde:Dde_1725 (0 target-flexibility) (0 robustness)
    dde:Dde_2142 (222 target-flexibility) (83 robustness)
    dde:Dde_2182 (0 target-flexibility) (0 robustness)
    dde:Dde_2187 (0 target-flexibility) (0 robustness)
    dde:Dde_2317 (790 target-flexibility) (134 robustness)
    dde:Dde_2439 (0 target-flexibility) (0 robustness)
    dde:Dde_2648 (357 target-flexibility) (102 robustness)
    dde:Dde_2656 (0 target-flexibility) (0 robustness)
    dde:Dde_2823 (790 target-flexibility) (134 robustness)
    dde:Dde_2839 (212 target-flexibility) (73 robustness)
    dde:Dde_3180 (80 target-flexibility) (80 robustness)
    dde:Dde_3207 (790 target-flexibility) (134 robustness)
    dde:Dde_3222 (434 target-flexibility) (67 robustness)
    dde:Dde_3476 (289 target-flexibility) (73 robustness)
    dde:Dde_3691 (0 target-flexibility) (0 robustness)
    dds:Ddes_0025 (0 target-flexibility) (0 robustness)
    dds:Ddes_0101 (289 target-flexibility) (73 robustness)
    dds:Ddes_0385 (222 target-flexibility) (83 robustness)
    dds:Ddes_0509 (434 target-flexibility) (67 robustness)
    dds:Ddes_1253 (0 target-flexibility) (0 robustness)
    dds:Ddes_1300 (0 target-flexibility) (0 robustness)
    dds:Ddes_1623 (0 target-flexibility) (0 robustness)
    dds:Ddes_1748 (790 target-flexibility) (134 robustness)
    dds:Ddes_1950 (0 target-flexibility) (0 robustness)
    dds:Ddes_2017 (80 target-flexibility) (80 robustness)
    dds:Ddes_2073 (212 target-flexibility) (73 robustness)
    def:CNY67_00560 (289 target-flexibility) (73 robustness)
    def:CNY67_01730 (212 target-flexibility) (73 robustness)
    def:CNY67_03710 (790 target-flexibility) (134 robustness)
    def:CNY67_04820 (0 target-flexibility) (0 robustness)
    def:CNY67_08360 (0 target-flexibility) (0 robustness)
    def:CNY67_08465 (405 target-flexibility) (70 robustness)
    def:CNY67_11835 (434 target-flexibility) (67 robustness)
    def:CNY67_12850 (222 target-flexibility) (83 robustness)
    def:CNY67_14075 (357 target-flexibility) (102 robustness)
    dej:AWY79_00595 (790 target-flexibility) (134 robustness)
    dej:AWY79_00980 (790 target-flexibility) (134 robustness)
    dej:AWY79_01195 (790 target-flexibility) (134 robustness)
    dej:AWY79_02820 (0 target-flexibility) (0 robustness)
    dej:AWY79_03870 (752 target-flexibility) (76 robustness)
    dej:AWY79_04800 (212 target-flexibility) (73 robustness)
    dej:AWY79_05625 (0 target-flexibility) (0 robustness)
    dej:AWY79_10785 (434 target-flexibility) (67 robustness)
    dej:AWY79_10850 (0 target-flexibility) (0 robustness)
    dej:AWY79_12435 (528 target-flexibility) (157 robustness)
    dej:AWY79_12450 (222 target-flexibility) (83 robustness)
    dej:AWY79_13255 (206 target-flexibility) (68 robustness)
    dej:AWY79_15280 (358 target-flexibility) (104 robustness)
    dej:AWY79_15450 (289 target-flexibility) (73 robustness)
    dej:AWY79_17820 (0 target-flexibility) (0 robustness)
    des:DSOUD_0047 (796 target-flexibility) (85 robustness)
    des:DSOUD_0247 (80 target-flexibility) (80 robustness)
    des:DSOUD_0484 (222 target-flexibility) (83 robustness)
    des:DSOUD_0657 (1041 target-flexibility) (243 robustness)
    des:DSOUD_0923 (138 target-flexibility) (66 robustness)
    des:DSOUD_1127 (212 target-flexibility) (73 robustness)
    des:DSOUD_1475 (752 target-flexibility) (76 robustness)
    des:DSOUD_1660 (71 target-flexibility) (71 robustness)
    des:DSOUD_1686 (0 target-flexibility) (0 robustness)
    des:DSOUD_1782 (732 target-flexibility) (78 robustness)
    des:DSOUD_1879 (897 target-flexibility) (71 robustness)
    des:DSOUD_1909 (0 target-flexibility) (0 robustness)
    des:DSOUD_1920 (0 target-flexibility) (0 robustness)
    des:DSOUD_2288 (0 target-flexibility) (0 robustness)
    des:DSOUD_2394 (1169 target-flexibility) (76 robustness)
    des:DSOUD_2923 (70 target-flexibility) (70 robustness)
    des:DSOUD_2928 (67 target-flexibility) (67 robustness)
    des:DSOUD_2929 (239 target-flexibility) (67 robustness)
    des:DSOUD_3191 (0 target-flexibility) (0 robustness)
    des:DSOUD_3192 (0 target-flexibility) (0 robustness)
    deu:DBW_0440 (80 target-flexibility) (80 robustness)
    deu:DBW_0616 (796 target-flexibility) (85 robustness)
    deu:DBW_0759 (222 target-flexibility) (83 robustness)
    deu:DBW_0911 (138 target-flexibility) (66 robustness)
    deu:DBW_1650 (0 target-flexibility) (0 robustness)
    deu:DBW_1746 (732 target-flexibility) (78 robustness)
    deu:DBW_1916 (0 target-flexibility) (0 robustness)
    deu:DBW_1942 (897 target-flexibility) (71 robustness)
    deu:DBW_2132 (0 target-flexibility) (0 robustness)
    deu:DBW_2313 (0 target-flexibility) (0 robustness)
    deu:DBW_2425 (1169 target-flexibility) (76 robustness)
    deu:DBW_2639 (212 target-flexibility) (73 robustness)
    deu:DBW_2799 (70 target-flexibility) (70 robustness)
    deu:DBW_2804 (67 target-flexibility) (67 robustness)
    deu:DBW_2805 (239 target-flexibility) (67 robustness)
    deu:DBW_3054 (1041 target-flexibility) (243 robustness)
    deu:DBW_3264 (0 target-flexibility) (0 robustness)
    deu:DBW_3265 (0 target-flexibility) (0 robustness)
    dfi:AXF13_00145 (212 target-flexibility) (73 robustness)
    dfi:AXF13_00460 (434 target-flexibility) (67 robustness)
    dfi:AXF13_00525 (80 target-flexibility) (80 robustness)
    dfi:AXF13_00990 (222 target-flexibility) (83 robustness)
    dfi:AXF13_03820 (0 target-flexibility) (0 robustness)
    dfi:AXF13_05800 (1169 target-flexibility) (76 robustness)
    dfi:AXF13_05975 (0 target-flexibility) (0 robustness)
    dfi:AXF13_07230 (0 target-flexibility) (0 robustness)
    dfi:AXF13_10380 (790 target-flexibility) (134 robustness)
    dfi:AXF13_13155 (289 target-flexibility) (73 robustness)
    dfi:AXF13_13965 (1041 target-flexibility) (243 robustness)
    dgg:DGI_0026 (0 target-flexibility) (0 robustness)
    dgg:DGI_0069 (0 target-flexibility) (0 robustness)
    dgg:DGI_0581 (790 target-flexibility) (134 robustness)
    dgg:DGI_0738 (528 target-flexibility) (157 robustness)
    dgg:DGI_0864 (0 target-flexibility) (0 robustness)
    dgg:DGI_1348 (1041 target-flexibility) (243 robustness)
    dgg:DGI_1438 (790 target-flexibility) (134 robustness)
    dgg:DGI_1648 (212 target-flexibility) (73 robustness)
    dgg:DGI_1737 (790 target-flexibility) (134 robustness)
    dgg:DGI_1851 (289 target-flexibility) (73 robustness)
    dgg:DGI_1902 (0 target-flexibility) (0 robustness)
    dgg:DGI_2476 (0 target-flexibility) (0 robustness)
    dgg:DGI_2681 (358 target-flexibility) (104 robustness)
    dgg:DGI_2774 (222 target-flexibility) (83 robustness)
    dgg:DGI_2795 (1169 target-flexibility) (76 robustness)
    dgg:DGI_3014 (0 target-flexibility) (0 robustness)
    dgg:DGI_3260 (434 target-flexibility) (67 robustness)
    dgg:DGI_4014 (0 target-flexibility) (0 robustness)
    dhy:DESAM_10054 (71 target-flexibility) (71 robustness)
    dhy:DESAM_10157 (358 target-flexibility) (104 robustness)
    dhy:DESAM_20147 (80 target-flexibility) (80 robustness)
    dhy:DESAM_20155 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20160 (1169 target-flexibility) (76 robustness)
    dhy:DESAM_20254 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20338 (796 target-flexibility) (85 robustness)
    dhy:DESAM_20480 (212 target-flexibility) (73 robustness)
    dhy:DESAM_20564 (790 target-flexibility) (134 robustness)
    dhy:DESAM_20574 (752 target-flexibility) (76 robustness)
    dhy:DESAM_20586 (528 target-flexibility) (157 robustness)
    dhy:DESAM_20633 (790 target-flexibility) (134 robustness)
    dhy:DESAM_20710 (897 target-flexibility) (71 robustness)
    dhy:DESAM_20726 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20863 (790 target-flexibility) (134 robustness)
    dhy:DESAM_20916 (0 target-flexibility) (0 robustness)
    dhy:DESAM_20933 (0 target-flexibility) (0 robustness)
    dhy:DESAM_21173 (1041 target-flexibility) (243 robustness)
    dhy:DESAM_21598 (0 target-flexibility) (0 robustness)
    dhy:DESAM_21612 (790 target-flexibility) (134 robustness)
    dhy:DESAM_21680 (289 target-flexibility) (73 robustness)
    dhy:DESAM_21809 (206 target-flexibility) (68 robustness)
    dhy:DESAM_21837 (0 target-flexibility) (0 robustness)
    dhy:DESAM_21926 (434 target-flexibility) (67 robustness)
    dhy:DESAM_22057 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22216 (0 target-flexibility) (0 robustness)
    dhy:DESAM_22252 (222 target-flexibility) (83 robustness)
    dhy:DESAM_22412 (138 target-flexibility) (66 robustness)
    dhy:DESAM_22470 (732 target-flexibility) (78 robustness)
    dma:DMR_00110 (0 target-flexibility) (0 robustness)
    dma:DMR_02050 (212 target-flexibility) (73 robustness)
    dma:DMR_04560 (0 target-flexibility) (0 robustness)
    dma:DMR_16010 (434 target-flexibility) (67 robustness)
    dma:DMR_17120 (528 target-flexibility) (157 robustness)
    dma:DMR_22170 (222 target-flexibility) (83 robustness)
    dma:DMR_28220 (289 target-flexibility) (73 robustness)
    dma:DMR_28600 (0 target-flexibility) (0 robustness)
    dma:DMR_30710 (358 target-flexibility) (104 robustness)
    dma:DMR_37140 (528 target-flexibility) (157 robustness)
    dma:DMR_39860 (357 target-flexibility) (102 robustness)
    dma:DMR_44510 (405 target-flexibility) (70 robustness)
    dml:Dmul_07490 (0 target-flexibility) (0 robustness)
    dml:Dmul_08540 (0 target-flexibility) (0 robustness)
    dml:Dmul_08960 (289 target-flexibility) (73 robustness)
    dml:Dmul_09580 (0 target-flexibility) (0 robustness)
    dml:Dmul_14330 (358 target-flexibility) (104 robustness)
    dml:Dmul_18930 (71 target-flexibility) (71 robustness)
    dml:Dmul_19320 (790 target-flexibility) (134 robustness)
    dml:Dmul_20590 (222 target-flexibility) (83 robustness)
    dml:Dmul_21250 (0 target-flexibility) (0 robustness)
    dml:Dmul_21830 (790 target-flexibility) (134 robustness)
    dml:Dmul_22810 (0 target-flexibility) (0 robustness)
    dml:Dmul_22850 (752 target-flexibility) (76 robustness)
    dml:Dmul_23280 (0 target-flexibility) (0 robustness)
    dml:Dmul_23620 (790 target-flexibility) (134 robustness)
    dml:Dmul_24040 (0 target-flexibility) (0 robustness)
    dml:Dmul_24260 (0 target-flexibility) (0 robustness)
    dml:Dmul_24630 (0 target-flexibility) (0 robustness)
    dml:Dmul_25380 (528 target-flexibility) (157 robustness)
    dml:Dmul_27750 (70 target-flexibility) (70 robustness)
    dml:Dmul_27780 (140 target-flexibility) (71 robustness)
    dml:Dmul_27800 (67 target-flexibility) (67 robustness)
    dml:Dmul_27810 (239 target-flexibility) (67 robustness)
    dml:Dmul_28300 (0 target-flexibility) (0 robustness)
    dml:Dmul_35620 (434 target-flexibility) (67 robustness)
    dml:Dmul_36880 (0 target-flexibility) (0 robustness)
    dml:Dmul_38810 (212 target-flexibility) (73 robustness)
    doa:AXF15_00335 (732 target-flexibility) (78 robustness)
    doa:AXF15_02145 (138 target-flexibility) (66 robustness)
    doa:AXF15_02215 (0 target-flexibility) (0 robustness)
    doa:AXF15_03265 (790 target-flexibility) (134 robustness)
    doa:AXF15_03465 (0 target-flexibility) (0 robustness)
    doa:AXF15_03650 (80 target-flexibility) (80 robustness)
    doa:AXF15_04445 (0 target-flexibility) (0 robustness)
    doa:AXF15_04820 (796 target-flexibility) (85 robustness)
    doa:AXF15_05040 (897 target-flexibility) (71 robustness)
    doa:AXF15_06400 (0 target-flexibility) (0 robustness)
    doa:AXF15_07625 (528 target-flexibility) (157 robustness)
    doa:AXF15_08605 (222 target-flexibility) (83 robustness)
    doa:AXF15_08610 (0 target-flexibility) (0 robustness)
    doa:AXF15_08670 (289 target-flexibility) (73 robustness)
    doa:AXF15_09390 (790 target-flexibility) (134 robustness)
    doa:AXF15_09515 (358 target-flexibility) (104 robustness)
    doa:AXF15_09785 (790 target-flexibility) (134 robustness)
    doa:AXF15_11375 (0 target-flexibility) (0 robustness)
    doa:AXF15_11595 (212 target-flexibility) (73 robustness)
    doa:AXF15_11865 (434 target-flexibility) (67 robustness)
    dol:Dole_0337 (0 target-flexibility) (0 robustness)
    dol:Dole_0514 (897 target-flexibility) (71 robustness)
    dol:Dole_0670 (752 target-flexibility) (76 robustness)
    dol:Dole_0679 (0 target-flexibility) (0 robustness)
    dol:Dole_1010 (0 target-flexibility) (0 robustness)
    dol:Dole_1130 (1041 target-flexibility) (243 robustness)
    dol:Dole_1191 (222 target-flexibility) (83 robustness)
    dol:Dole_1545 (80 target-flexibility) (80 robustness)
    dol:Dole_1662 (1169 target-flexibility) (76 robustness)
    dol:Dole_1729 (212 target-flexibility) (73 robustness)
    dol:Dole_1848 (0 target-flexibility) (0 robustness)
    dol:Dole_1908 (289 target-flexibility) (73 robustness)
    dol:Dole_1973 (790 target-flexibility) (134 robustness)
    dol:Dole_1975 (790 target-flexibility) (134 robustness)
    dol:Dole_2219 (434 target-flexibility) (67 robustness)
    dol:Dole_2324 (0 target-flexibility) (0 robustness)
    dol:Dole_2438 (0 target-flexibility) (0 robustness)
    dol:Dole_2492 (138 target-flexibility) (66 robustness)
    dol:Dole_2786 (70 target-flexibility) (70 robustness)
    dol:Dole_2791 (67 target-flexibility) (67 robustness)
    dol:Dole_2792 (239 target-flexibility) (67 robustness)
    dol:Dole_2847 (71 target-flexibility) (71 robustness)
    dpb:BABL1_gene_13 (0 target-flexibility) (0 robustness)
    dpb:BABL1_gene_199 (212 target-flexibility) (73 robustness)
    dpb:BABL1_gene_330 (752 target-flexibility) (76 robustness)
    dpb:BABL1_gene_705 (71 target-flexibility) (71 robustness)
    dpb:BABL1_gene_858 (222 target-flexibility) (83 robustness)
    dpg:DESPIGER_0283 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_0323 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_0969 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1079 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1250 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1284 (222 target-flexibility) (83 robustness)
    dpg:DESPIGER_1297 (790 target-flexibility) (134 robustness)
    dpg:DESPIGER_1531 (80 target-flexibility) (80 robustness)
    dpg:DESPIGER_1545 (434 target-flexibility) (67 robustness)
    dpg:DESPIGER_1797 (289 target-flexibility) (73 robustness)
    dpg:DESPIGER_1913 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_1949 (0 target-flexibility) (0 robustness)
    dpg:DESPIGER_2129 (212 target-flexibility) (73 robustness)
    dpi:BN4_10115 (434 target-flexibility) (67 robustness)
    dpi:BN4_10127 (0 target-flexibility) (0 robustness)
    dpi:BN4_10196 (71 target-flexibility) (71 robustness)
    dpi:BN4_10393 (222 target-flexibility) (83 robustness)
    dpi:BN4_10396 (528 target-flexibility) (157 robustness)
    dpi:BN4_11008 (358 target-flexibility) (104 robustness)
    dpi:BN4_11230 (528 target-flexibility) (157 robustness)
    dpi:BN4_11407 (289 target-flexibility) (73 robustness)
    dpi:BN4_11936 (212 target-flexibility) (73 robustness)
    dpi:BN4_11977 (752 target-flexibility) (76 robustness)
    dpi:BN4_12054 (790 target-flexibility) (134 robustness)
    dpi:BN4_12214 (0 target-flexibility) (0 robustness)
    dpi:BN4_12384 (790 target-flexibility) (134 robustness)
    dpi:BN4_12584 (790 target-flexibility) (134 robustness)
    dpi:BN4_12643 (0 target-flexibility) (0 robustness)
    dpi:BN4_12812 (0 target-flexibility) (0 robustness)
    dpr:Despr_0279 (0 target-flexibility) (0 robustness)
    dpr:Despr_0517 (138 target-flexibility) (66 robustness)
    dpr:Despr_0555 (0 target-flexibility) (0 robustness)
    dpr:Despr_0574 (289 target-flexibility) (73 robustness)
    dpr:Despr_0909 (434 target-flexibility) (67 robustness)
    dpr:Despr_0918 (71 target-flexibility) (71 robustness)
    dpr:Despr_1050 (1385 target-flexibility) (204 robustness)
    dpr:Despr_1832 (0 target-flexibility) (0 robustness)
    dpr:Despr_2394 (222 target-flexibility) (83 robustness)
    dpr:Despr_2467 (0 target-flexibility) (0 robustness)
    dpr:Despr_2776 (752 target-flexibility) (76 robustness)
    dpr:Despr_2958 (80 target-flexibility) (80 robustness)
    dpr:Despr_2989 (528 target-flexibility) (157 robustness)
    dpr:Despr_3037 (212 target-flexibility) (73 robustness)
    dpr:Despr_3156 (897 target-flexibility) (71 robustness)
    dpr:Despr_3168 (0 target-flexibility) (0 robustness)
    dpr:Despr_3183 (358 target-flexibility) (104 robustness)
    dps:DP0045 (0 target-flexibility) (0 robustness)
    dps:DP0106 (897 target-flexibility) (71 robustness)
    dps:DP0437 (138 target-flexibility) (66 robustness)
    dps:DP0555 (0 target-flexibility) (0 robustness)
    dps:DP0812 (80 target-flexibility) (80 robustness)
    dps:DP1331 (206 target-flexibility) (68 robustness)
    dps:DP1629 (71 target-flexibility) (71 robustness)
    dps:DP1796 (212 target-flexibility) (73 robustness)
    dps:DP2097 (790 target-flexibility) (134 robustness)
    dps:DP2220 (0 target-flexibility) (0 robustness)
    dps:DP2548 (0 target-flexibility) (0 robustness)
    dps:DP2552 (222 target-flexibility) (83 robustness)
    dps:DP2600 (0 target-flexibility) (0 robustness)
    dps:DP2716 (0 target-flexibility) (0 robustness)
    dps:DPPB37 (790 target-flexibility) (134 robustness)
    drt:Dret_0014 (752 target-flexibility) (76 robustness)
    drt:Dret_0143 (796 target-flexibility) (85 robustness)
    drt:Dret_0251 (212 target-flexibility) (73 robustness)
    drt:Dret_0307 (0 target-flexibility) (0 robustness)
    drt:Dret_0321 (732 target-flexibility) (78 robustness)
    drt:Dret_0439 (289 target-flexibility) (73 robustness)
    drt:Dret_0818 (790 target-flexibility) (134 robustness)
    drt:Dret_0830 (358 target-flexibility) (104 robustness)
    drt:Dret_1046 (0 target-flexibility) (0 robustness)
    drt:Dret_1100 (434 target-flexibility) (67 robustness)
    drt:Dret_1118 (222 target-flexibility) (83 robustness)
    drt:Dret_1384 (405 target-flexibility) (70 robustness)
    drt:Dret_1385 (528 target-flexibility) (157 robustness)
    drt:Dret_1409 (357 target-flexibility) (102 robustness)
    drt:Dret_1425 (0 target-flexibility) (0 robustness)
    drt:Dret_1756 (0 target-flexibility) (0 robustness)
    drt:Dret_2132 (790 target-flexibility) (134 robustness)
    drt:Dret_2234 (71 target-flexibility) (71 robustness)
    drt:Dret_2421 (80 target-flexibility) (80 robustness)
    drt:Dret_2481 (790 target-flexibility) (134 robustness)
    drt:Dret_2499 (0 target-flexibility) (0 robustness)
    dsa:Desal_0017 (897 target-flexibility) (71 robustness)
    dsa:Desal_0092 (790 target-flexibility) (134 robustness)
    dsa:Desal_0136 (528 target-flexibility) (157 robustness)
    dsa:Desal_0143 (752 target-flexibility) (76 robustness)
    dsa:Desal_0152 (790 target-flexibility) (134 robustness)
    dsa:Desal_0178 (0 target-flexibility) (0 robustness)
    dsa:Desal_0250 (212 target-flexibility) (73 robustness)
    dsa:Desal_0558 (1041 target-flexibility) (243 robustness)
    dsa:Desal_0574 (1041 target-flexibility) (243 robustness)
    dsa:Desal_0650 (0 target-flexibility) (0 robustness)
    dsa:Desal_0740 (1169 target-flexibility) (76 robustness)
    dsa:Desal_0743 (0 target-flexibility) (0 robustness)
    dsa:Desal_0753 (80 target-flexibility) (80 robustness)
    dsa:Desal_1093 (289 target-flexibility) (73 robustness)
    dsa:Desal_1585 (434 target-flexibility) (67 robustness)
    dsa:Desal_1645 (0 target-flexibility) (0 robustness)
    dsa:Desal_1784 (138 target-flexibility) (66 robustness)
    dsa:Desal_2004 (222 target-flexibility) (83 robustness)
    dsa:Desal_2033 (0 target-flexibility) (0 robustness)
    dsa:Desal_2170 (732 target-flexibility) (78 robustness)
    dsa:Desal_2527 (71 target-flexibility) (71 robustness)
    dsa:Desal_2682 (0 target-flexibility) (0 robustness)
    dsa:Desal_2829 (790 target-flexibility) (134 robustness)
    dsa:Desal_2862 (358 target-flexibility) (104 robustness)
    dsa:Desal_2978 (0 target-flexibility) (0 robustness)
    dsa:Desal_3407 (1385 target-flexibility) (204 robustness)
    dsa:Desal_3566 (796 target-flexibility) (85 robustness)
    dsa:Desal_3834 (0 target-flexibility) (0 robustness)
    dsf:UWK_00105 (528 target-flexibility) (157 robustness)
    dsf:UWK_00180 (212 target-flexibility) (73 robustness)
    dsf:UWK_00683 (138 target-flexibility) (66 robustness)
    dsf:UWK_00793 (897 target-flexibility) (71 robustness)
    dsf:UWK_01152 (752 target-flexibility) (76 robustness)
    dsf:UWK_01260 (732 target-flexibility) (78 robustness)
    dsf:UWK_01662 (80 target-flexibility) (80 robustness)
    dsf:UWK_01819 (358 target-flexibility) (104 robustness)
    dsf:UWK_02513 (0 target-flexibility) (0 robustness)
    dsf:UWK_02514 (1169 target-flexibility) (76 robustness)
    dsf:UWK_02797 (1041 target-flexibility) (243 robustness)
    dsf:UWK_02799 (0 target-flexibility) (0 robustness)
    dsf:UWK_03000 (72 target-flexibility) (72 robustness)
    dsf:UWK_03057 (0 target-flexibility) (0 robustness)
    dsf:UWK_03406 (0 target-flexibility) (0 robustness)
    dsf:UWK_03410 (222 target-flexibility) (83 robustness)
    dsf:UWK_03421 (0 target-flexibility) (0 robustness)
    dsf:UWK_03510 (796 target-flexibility) (85 robustness)
    dsf:UWK_03535 (71 target-flexibility) (71 robustness)
    dti:Desti_0148 (1041 target-flexibility) (243 robustness)
    dti:Desti_0219 (790 target-flexibility) (134 robustness)
    dti:Desti_0225 (0 target-flexibility) (0 robustness)
    dti:Desti_0353 (0 target-flexibility) (0 robustness)
    dti:Desti_0473 (0 target-flexibility) (0 robustness)
    dti:Desti_0901 (0 target-flexibility) (0 robustness)
    dti:Desti_1152 (206 target-flexibility) (68 robustness)
    dti:Desti_1259 (752 target-flexibility) (76 robustness)
    dti:Desti_1366 (0 target-flexibility) (0 robustness)
    dti:Desti_1457 (0 target-flexibility) (0 robustness)
    dti:Desti_1492 (1169 target-flexibility) (76 robustness)
    dti:Desti_1700 (387 target-flexibility) (72 robustness)
    dti:Desti_1808 (0 target-flexibility) (0 robustness)
    dti:Desti_2003 (0 target-flexibility) (0 robustness)
    dti:Desti_2341 (790 target-flexibility) (134 robustness)
    dti:Desti_2345 (790 target-flexibility) (134 robustness)
    dti:Desti_2348 (790 target-flexibility) (134 robustness)
    dti:Desti_2479 (0 target-flexibility) (0 robustness)
    dti:Desti_2739 (0 target-flexibility) (0 robustness)
    dti:Desti_2740 (0 target-flexibility) (0 robustness)
    dti:Desti_2797 (0 target-flexibility) (0 robustness)
    dti:Desti_3121 (71 target-flexibility) (71 robustness)
    dti:Desti_3164 (0 target-flexibility) (0 robustness)
    dti:Desti_3650 (0 target-flexibility) (0 robustness)
    dti:Desti_3684 (212 target-flexibility) (73 robustness)
    dti:Desti_3693 (0 target-flexibility) (0 robustness)
    dti:Desti_3747 (80 target-flexibility) (80 robustness)
    dti:Desti_3834 (0 target-flexibility) (0 robustness)
    dti:Desti_4083 (222 target-flexibility) (83 robustness)
    dti:Desti_4150 (434 target-flexibility) (67 robustness)
    dti:Desti_4164 (790 target-flexibility) (134 robustness)
    dti:Desti_4253 (289 target-flexibility) (73 robustness)
    dti:Desti_4337 (0 target-flexibility) (0 robustness)
    dti:Desti_4704 (239 target-flexibility) (67 robustness)
    dti:Desti_4705 (67 target-flexibility) (67 robustness)
    dti:Desti_4907 (0 target-flexibility) (0 robustness)
    dto:TOL2_C02640 (528 target-flexibility) (157 robustness)
    dto:TOL2_C05220 (790 target-flexibility) (134 robustness)
    dto:TOL2_C08210 (0 target-flexibility) (0 robustness)
    dto:TOL2_C12360 (0 target-flexibility) (0 robustness)
    dto:TOL2_C13310 (358 target-flexibility) (104 robustness)
    dto:TOL2_C16510 (212 target-flexibility) (73 robustness)
    dto:TOL2_C21050 (222 target-flexibility) (83 robustness)
    dto:TOL2_C21920 (897 target-flexibility) (71 robustness)
    dto:TOL2_C22640 (0 target-flexibility) (0 robustness)
    dto:TOL2_C23400 (0 target-flexibility) (0 robustness)
    dto:TOL2_C24560 (138 target-flexibility) (66 robustness)
    dto:TOL2_C26900 (0 target-flexibility) (0 robustness)
    dto:TOL2_C27090 (0 target-flexibility) (0 robustness)
    dto:TOL2_C27260 (0 target-flexibility) (0 robustness)
    dto:TOL2_C27460 (0 target-flexibility) (0 robustness)
    dto:TOL2_C27650 (0 target-flexibility) (0 robustness)
    dto:TOL2_C31520 (790 target-flexibility) (134 robustness)
    dto:TOL2_C35200 (0 target-flexibility) (0 robustness)
    dto:TOL2_C35290 (0 target-flexibility) (0 robustness)
    dto:TOL2_C37120 (0 target-flexibility) (0 robustness)
    dvu:DVU0477 (289 target-flexibility) (73 robustness)
    dvu:DVU0732 (212 target-flexibility) (73 robustness)
    dvu:DVU0748 (790 target-flexibility) (134 robustness)
    dvu:DVU1196 (0 target-flexibility) (0 robustness)
    dvu:DVU1350 (1169 target-flexibility) (76 robustness)
    dvu:DVU1360 (0 target-flexibility) (0 robustness)
    dvu:DVU1364 (0 target-flexibility) (0 robustness)
    dvu:DVU1453 (0 target-flexibility) (0 robustness)
    dvu:DVU1927 (222 target-flexibility) (83 robustness)
    dvu:DVU2250 (790 target-flexibility) (134 robustness)
    dvu:DVU2530 (1041 target-flexibility) (243 robustness)
    dvu:DVU2559 (0 target-flexibility) (0 robustness)
    dvu:DVU2969 (790 target-flexibility) (134 robustness)
    dvu:DVU2985 (434 target-flexibility) (67 robustness)
    dvu:DVU3119 (0 target-flexibility) (0 robustness)
    dvu:DVU3168 (80 target-flexibility) (80 robustness)
    dvu:DVU3356 (0 target-flexibility) (0 robustness)
    gao:A2G06_03585 (1169 target-flexibility) (76 robustness)
    gao:A2G06_05670 (0 target-flexibility) (0 robustness)
    gao:A2G06_05980 (71 target-flexibility) (71 robustness)
    gao:A2G06_06115 (0 target-flexibility) (0 robustness)
    gao:A2G06_06270 (0 target-flexibility) (0 robustness)
    gao:A2G06_06650 (212 target-flexibility) (73 robustness)
    gao:A2G06_08130 (1169 target-flexibility) (76 robustness)
    gao:A2G06_09675 (752 target-flexibility) (76 robustness)
    gao:A2G06_10540 (897 target-flexibility) (71 robustness)
    gao:A2G06_12745 (0 target-flexibility) (0 robustness)
    gao:A2G06_13760 (1041 target-flexibility) (243 robustness)
    gao:A2G06_14560 (0 target-flexibility) (0 robustness)
    gao:A2G06_14565 (0 target-flexibility) (0 robustness)
    gao:A2G06_14765 (222 target-flexibility) (83 robustness)
    gao:A2G06_15675 (138 target-flexibility) (66 robustness)
    gbm:Gbem_0280 (1041 target-flexibility) (243 robustness)
    gbm:Gbem_0486 (239 target-flexibility) (67 robustness)
    gbm:Gbem_0487 (67 target-flexibility) (67 robustness)
    gbm:Gbem_0751 (0 target-flexibility) (0 robustness)
    gbm:Gbem_0836 (71 target-flexibility) (71 robustness)
    gbm:Gbem_0861 (0 target-flexibility) (0 robustness)
    gbm:Gbem_1258 (1169 target-flexibility) (76 robustness)
    gbm:Gbem_1531 (212 target-flexibility) (73 robustness)
    gbm:Gbem_1896 (897 target-flexibility) (71 robustness)
    gbm:Gbem_2051 (0 target-flexibility) (0 robustness)
    gbm:Gbem_2903 (752 target-flexibility) (76 robustness)
    gbm:Gbem_3346 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3362 (1169 target-flexibility) (76 robustness)
    gbm:Gbem_3637 (138 target-flexibility) (66 robustness)
    gbm:Gbem_3650 (222 target-flexibility) (83 robustness)
    gbm:Gbem_3700 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3701 (0 target-flexibility) (0 robustness)
    gbm:Gbem_3927 (80 target-flexibility) (80 robustness)
    geb:GM18_0317 (1041 target-flexibility) (243 robustness)
    geb:GM18_0730 (71 target-flexibility) (71 robustness)
    geb:GM18_0750 (0 target-flexibility) (0 robustness)
    geb:GM18_0958 (790 target-flexibility) (134 robustness)
    geb:GM18_1116 (1169 target-flexibility) (76 robustness)
    geb:GM18_1366 (212 target-flexibility) (73 robustness)
    geb:GM18_1602 (0 target-flexibility) (0 robustness)
    geb:GM18_1720 (897 target-flexibility) (71 robustness)
    geb:GM18_2157 (0 target-flexibility) (0 robustness)
    geb:GM18_2790 (752 target-flexibility) (76 robustness)
    geb:GM18_3257 (0 target-flexibility) (0 robustness)
    geb:GM18_3424 (0 target-flexibility) (0 robustness)
    geb:GM18_3441 (1169 target-flexibility) (76 robustness)
    geb:GM18_3598 (0 target-flexibility) (0 robustness)
    geb:GM18_3889 (140 target-flexibility) (71 robustness)
    geb:GM18_3891 (67 target-flexibility) (67 robustness)
    geb:GM18_3892 (239 target-flexibility) (67 robustness)
    geb:GM18_4095 (138 target-flexibility) (66 robustness)
    geb:GM18_4108 (222 target-flexibility) (83 robustness)
    geb:GM18_4149 (0 target-flexibility) (0 robustness)
    geb:GM18_4150 (0 target-flexibility) (0 robustness)
    geb:GM18_4171 (0 target-flexibility) (0 robustness)
    geb:GM18_4391 (80 target-flexibility) (80 robustness)
    gem:GM21_0265 (1041 target-flexibility) (243 robustness)
    gem:GM21_0503 (239 target-flexibility) (67 robustness)
    gem:GM21_0504 (67 target-flexibility) (67 robustness)
    gem:GM21_0506 (140 target-flexibility) (71 robustness)
    gem:GM21_0509 (70 target-flexibility) (70 robustness)
    gem:GM21_0766 (0 target-flexibility) (0 robustness)
    gem:GM21_0883 (1169 target-flexibility) (76 robustness)
    gem:GM21_0899 (0 target-flexibility) (0 robustness)
    gem:GM21_1322 (752 target-flexibility) (76 robustness)
    gem:GM21_2166 (0 target-flexibility) (0 robustness)
    gem:GM21_2312 (897 target-flexibility) (71 robustness)
    gem:GM21_2685 (212 target-flexibility) (73 robustness)
    gem:GM21_3025 (1169 target-flexibility) (76 robustness)
    gem:GM21_3397 (1041 target-flexibility) (243 robustness)
    gem:GM21_3403 (0 target-flexibility) (0 robustness)
    gem:GM21_3424 (71 target-flexibility) (71 robustness)
    gem:GM21_3742 (138 target-flexibility) (66 robustness)
    gem:GM21_3757 (222 target-flexibility) (83 robustness)
    gem:GM21_3795 (0 target-flexibility) (0 robustness)
    gem:GM21_3796 (0 target-flexibility) (0 robustness)
    gem:GM21_4011 (80 target-flexibility) (80 robustness)
    geo:Geob_0284 (0 target-flexibility) (0 robustness)
    geo:Geob_0392 (222 target-flexibility) (83 robustness)
    geo:Geob_0461 (80 target-flexibility) (80 robustness)
    geo:Geob_0666 (1041 target-flexibility) (243 robustness)
    geo:Geob_0692 (0 target-flexibility) (0 robustness)
    geo:Geob_0693 (0 target-flexibility) (0 robustness)
    geo:Geob_0775 (239 target-flexibility) (67 robustness)
    geo:Geob_0776 (67 target-flexibility) (67 robustness)
    geo:Geob_0778 (140 target-flexibility) (71 robustness)
    geo:Geob_0781 (70 target-flexibility) (70 robustness)
    geo:Geob_1002 (1041 target-flexibility) (243 robustness)
    geo:Geob_1123 (138 target-flexibility) (66 robustness)
    geo:Geob_1368 (1041 target-flexibility) (243 robustness)
    geo:Geob_1870 (0 target-flexibility) (0 robustness)
    geo:Geob_2094 (71 target-flexibility) (71 robustness)
    geo:Geob_2171 (0 target-flexibility) (0 robustness)
    geo:Geob_2629 (1169 target-flexibility) (76 robustness)
    geo:Geob_2661 (752 target-flexibility) (76 robustness)
    geo:Geob_2923 (0 target-flexibility) (0 robustness)
    geo:Geob_3010 (0 target-flexibility) (0 robustness)
    geo:Geob_3082 (212 target-flexibility) (73 robustness)
    geo:Geob_3264 (897 target-flexibility) (71 robustness)
    geo:Geob_3664 (1169 target-flexibility) (76 robustness)
    glo:Glov_0479 (0 target-flexibility) (0 robustness)
    glo:Glov_0584 (357 target-flexibility) (102 robustness)
    glo:Glov_0674 (67 target-flexibility) (67 robustness)
    glo:Glov_0675 (239 target-flexibility) (67 robustness)
    glo:Glov_0757 (71 target-flexibility) (71 robustness)
    glo:Glov_0796 (1041 target-flexibility) (243 robustness)
    glo:Glov_0981 (222 target-flexibility) (83 robustness)
    glo:Glov_1018 (0 target-flexibility) (0 robustness)
    glo:Glov_1019 (0 target-flexibility) (0 robustness)
    glo:Glov_1622 (752 target-flexibility) (76 robustness)
    glo:Glov_1658 (0 target-flexibility) (0 robustness)
    glo:Glov_2085 (897 target-flexibility) (71 robustness)
    glo:Glov_2116 (0 target-flexibility) (0 robustness)
    glo:Glov_2128 (405 target-flexibility) (70 robustness)
    glo:Glov_2182 (1169 target-flexibility) (76 robustness)
    glo:Glov_2235 (1169 target-flexibility) (76 robustness)
    glo:Glov_2247 (0 target-flexibility) (0 robustness)
    glo:Glov_2538 (212 target-flexibility) (73 robustness)
    glo:Glov_3139 (80 target-flexibility) (80 robustness)
    glo:Glov_3149 (138 target-flexibility) (66 robustness)
    glo:Glov_3365 (0 target-flexibility) (0 robustness)
    gme:Gmet_0205 (138 target-flexibility) (66 robustness)
    gme:Gmet_0351 (222 target-flexibility) (83 robustness)
    gme:Gmet_0388 (0 target-flexibility) (0 robustness)
    gme:Gmet_0389 (0 target-flexibility) (0 robustness)
    gme:Gmet_0407 (239 target-flexibility) (67 robustness)
    gme:Gmet_0408 (67 target-flexibility) (67 robustness)
    gme:Gmet_0410 (140 target-flexibility) (71 robustness)
    gme:Gmet_0413 (70 target-flexibility) (70 robustness)
    gme:Gmet_0552 (1041 target-flexibility) (243 robustness)
    gme:Gmet_0956 (212 target-flexibility) (73 robustness)
    gme:Gmet_1357 (752 target-flexibility) (76 robustness)
    gme:Gmet_1580 (0 target-flexibility) (0 robustness)
    gme:Gmet_1613 (0 target-flexibility) (0 robustness)
    gme:Gmet_1769 (897 target-flexibility) (71 robustness)
    gme:Gmet_1934 (1169 target-flexibility) (76 robustness)
    gme:Gmet_2229 (0 target-flexibility) (0 robustness)
    gme:Gmet_2300 (0 target-flexibility) (0 robustness)
    gme:Gmet_2329 (0 target-flexibility) (0 robustness)
    gme:Gmet_2330 (0 target-flexibility) (0 robustness)
    gme:Gmet_2340 (790 target-flexibility) (134 robustness)
    gme:Gmet_2360 (71 target-flexibility) (71 robustness)
    gme:Gmet_2473 (0 target-flexibility) (0 robustness)
    gme:Gmet_2822 (1169 target-flexibility) (76 robustness)
    gme:Gmet_3356 (80 target-flexibility) (80 robustness)
    gpi:GPICK_00285 (405 target-flexibility) (70 robustness)
    gpi:GPICK_01450 (138 target-flexibility) (66 robustness)
    gpi:GPICK_02075 (222 target-flexibility) (83 robustness)
    gpi:GPICK_02235 (0 target-flexibility) (0 robustness)
    gpi:GPICK_02240 (0 target-flexibility) (0 robustness)
    gpi:GPICK_02335 (239 target-flexibility) (67 robustness)
    gpi:GPICK_02340 (67 target-flexibility) (67 robustness)
    gpi:GPICK_02900 (1041 target-flexibility) (243 robustness)
    gpi:GPICK_04075 (1169 target-flexibility) (76 robustness)
    gpi:GPICK_05460 (212 target-flexibility) (73 robustness)
    gpi:GPICK_06970 (357 target-flexibility) (102 robustness)
    gpi:GPICK_07275 (1169 target-flexibility) (76 robustness)
    gpi:GPICK_07650 (0 target-flexibility) (0 robustness)
    gpi:GPICK_07830 (0 target-flexibility) (0 robustness)
    gpi:GPICK_08380 (732 target-flexibility) (78 robustness)
    gpi:GPICK_08745 (752 target-flexibility) (76 robustness)
    gpi:GPICK_09850 (897 target-flexibility) (71 robustness)
    gpi:GPICK_10225 (0 target-flexibility) (0 robustness)
    gpi:GPICK_10370 (0 target-flexibility) (0 robustness)
    gpi:GPICK_10380 (0 target-flexibility) (0 robustness)
    gpi:GPICK_10520 (71 target-flexibility) (71 robustness)
    gpi:GPICK_11740 (0 target-flexibility) (0 robustness)
    gpi:GPICK_15315 (80 target-flexibility) (80 robustness)
    gpi:GPICK_15365 (796 target-flexibility) (85 robustness)
    gsb:GSUB_00615 (80 target-flexibility) (80 robustness)
    gsb:GSUB_01730 (222 target-flexibility) (83 robustness)
    gsb:GSUB_02190 (796 target-flexibility) (85 robustness)
    gsb:GSUB_02540 (0 target-flexibility) (0 robustness)
    gsb:GSUB_02545 (0 target-flexibility) (0 robustness)
    gsb:GSUB_02815 (1041 target-flexibility) (243 robustness)
    gsb:GSUB_03040 (138 target-flexibility) (66 robustness)
    gsb:GSUB_04800 (752 target-flexibility) (76 robustness)
    gsb:GSUB_06155 (1169 target-flexibility) (76 robustness)
    gsb:GSUB_07600 (0 target-flexibility) (0 robustness)
    gsb:GSUB_08195 (0 target-flexibility) (0 robustness)
    gsb:GSUB_08845 (0 target-flexibility) (0 robustness)
    gsb:GSUB_09020 (0 target-flexibility) (0 robustness)
    gsb:GSUB_09180 (897 target-flexibility) (71 robustness)
    gsb:GSUB_09375 (732 target-flexibility) (78 robustness)
    gsb:GSUB_10480 (71 target-flexibility) (71 robustness)
    gsb:GSUB_11175 (212 target-flexibility) (73 robustness)
    gsb:GSUB_12985 (70 target-flexibility) (70 robustness)
    gsb:GSUB_13010 (67 target-flexibility) (67 robustness)
    gsb:GSUB_13015 (239 target-flexibility) (67 robustness)
    gsb:GSUB_15430 (0 target-flexibility) (0 robustness)
    gsu:GSU0152 (138 target-flexibility) (66 robustness)
    gsu:GSU0337 (80 target-flexibility) (80 robustness)
    gsu:GSU0686 (1169 target-flexibility) (76 robustness)
    gsu:GSU1271 (897 target-flexibility) (71 robustness)
    gsu:GSU1463 (752 target-flexibility) (76 robustness)
    gsu:GSU1582 (0 target-flexibility) (0 robustness)
    gsu:GSU1764 (1169 target-flexibility) (76 robustness)
    gsu:GSU2045 (212 target-flexibility) (73 robustness)
    gsu:GSU2209 (0 target-flexibility) (0 robustness)
    gsu:GSU2241 (0 target-flexibility) (0 robustness)
    gsu:GSU2271 (71 target-flexibility) (71 robustness)
    gsu:GSU2366 (0 target-flexibility) (0 robustness)
    gsu:GSU2918 (1041 target-flexibility) (243 robustness)
    gsu:GSU3095 (0 target-flexibility) (0 robustness)
    gsu:GSU3096 (0 target-flexibility) (0 robustness)
    gsu:GSU3136 (222 target-flexibility) (83 robustness)
    gur:Gura_0227 (138 target-flexibility) (66 robustness)
    gur:Gura_0492 (1041 target-flexibility) (243 robustness)
    gur:Gura_1018 (1169 target-flexibility) (76 robustness)
    gur:Gura_1685 (0 target-flexibility) (0 robustness)
    gur:Gura_1799 (212 target-flexibility) (73 robustness)
    gur:Gura_1856 (897 target-flexibility) (71 robustness)
    gur:Gura_2175 (1169 target-flexibility) (76 robustness)
    gur:Gura_2196 (752 target-flexibility) (76 robustness)
    gur:Gura_2244 (0 target-flexibility) (0 robustness)
    gur:Gura_2598 (0 target-flexibility) (0 robustness)
    gur:Gura_3134 (0 target-flexibility) (0 robustness)
    gur:Gura_3240 (71 target-flexibility) (71 robustness)
    gur:Gura_3273 (0 target-flexibility) (0 robustness)
    gur:Gura_3978 (67 target-flexibility) (67 robustness)
    gur:Gura_3979 (239 target-flexibility) (67 robustness)
    gur:Gura_4053 (0 target-flexibility) (0 robustness)
    gur:Gura_4054 (0 target-flexibility) (0 robustness)
    gur:Gura_4245 (80 target-flexibility) (80 robustness)
    gur:Gura_4313 (222 target-flexibility) (83 robustness)
    hmr:Hipma_0012 (1041 target-flexibility) (243 robustness)
    hmr:Hipma_0121 (138 target-flexibility) (66 robustness)
    hmr:Hipma_0215 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0301 (222 target-flexibility) (83 robustness)
    hmr:Hipma_0341 (71 target-flexibility) (71 robustness)
    hmr:Hipma_0412 (0 target-flexibility) (0 robustness)
    hmr:Hipma_0431 (752 target-flexibility) (76 robustness)
    hmr:Hipma_0501 (897 target-flexibility) (71 robustness)
    hmr:Hipma_0845 (80 target-flexibility) (80 robustness)
    hmr:Hipma_0985 (1169 target-flexibility) (76 robustness)
    hmr:Hipma_1016 (212 target-flexibility) (73 robustness)
    hmr:Hipma_1025 (1385 target-flexibility) (204 robustness)
    hmr:Hipma_1045 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1167 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1401 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1516 (0 target-flexibility) (0 robustness)
    hmr:Hipma_1703 (0 target-flexibility) (0 robustness)
    hoh:Hoch_0379 (0 target-flexibility) (0 robustness)
    hoh:Hoch_0394 (138 target-flexibility) (66 robustness)
    hoh:Hoch_1849 (0 target-flexibility) (0 robustness)
    hoh:Hoch_2693 (0 target-flexibility) (0 robustness)
    hoh:Hoch_3186 (752 target-flexibility) (76 robustness)
    hoh:Hoch_3189 (212 target-flexibility) (73 robustness)
    hoh:Hoch_3975 (71 target-flexibility) (71 robustness)
    hoh:Hoch_4463 (796 target-flexibility) (85 robustness)
    hoh:Hoch_4475 (80 target-flexibility) (80 robustness)
    hoh:Hoch_5324 (897 target-flexibility) (71 robustness)
    hoh:Hoch_5556 (732 target-flexibility) (78 robustness)
    hoh:Hoch_5889 (222 target-flexibility) (83 robustness)
    hoh:Hoch_6383 (0 target-flexibility) (0 robustness)
    hoh:Hoch_6458 (0 target-flexibility) (0 robustness)
    hoh:Hoch_6609 (0 target-flexibility) (0 robustness)
    hoh:Hoch_6893 (0 target-flexibility) (0 robustness)
    lip:LI0152 (0 target-flexibility) (0 robustness)
    lip:LI0379 (0 target-flexibility) (0 robustness)
    lip:LI0466 (0 target-flexibility) (0 robustness)
    lip:LI0580 (0 target-flexibility) (0 robustness)
    lip:LI0648 (212 target-flexibility) (73 robustness)
    lip:LI1051 (222 target-flexibility) (83 robustness)
    lip:LI1066 (0 target-flexibility) (0 robustness)
    lip:LIC023 (0 target-flexibility) (0 robustness)
    llu:AKJ09_00381 (0 target-flexibility) (0 robustness)
    llu:AKJ09_00976 (0 target-flexibility) (0 robustness)
    llu:AKJ09_01495 (0 target-flexibility) (0 robustness)
    llu:AKJ09_02991 (0 target-flexibility) (0 robustness)
    llu:AKJ09_03567 (752 target-flexibility) (76 robustness)
    llu:AKJ09_04269 (796 target-flexibility) (85 robustness)
    llu:AKJ09_04272 (434 target-flexibility) (67 robustness)
    llu:AKJ09_04690 (239 target-flexibility) (67 robustness)
    llu:AKJ09_04691 (67 target-flexibility) (67 robustness)
    llu:AKJ09_04767 (71 target-flexibility) (71 robustness)
    llu:AKJ09_05314 (0 target-flexibility) (0 robustness)
    llu:AKJ09_05466 (0 target-flexibility) (0 robustness)
    llu:AKJ09_06149 (790 target-flexibility) (134 robustness)
    llu:AKJ09_07370 (790 target-flexibility) (134 robustness)
    llu:AKJ09_08130 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08203 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08534 (0 target-flexibility) (0 robustness)
    llu:AKJ09_08899 (222 target-flexibility) (83 robustness)
    llu:AKJ09_09399 (0 target-flexibility) (0 robustness)
    llu:AKJ09_10333 (732 target-flexibility) (78 robustness)
    llu:AKJ09_10397 (289 target-flexibility) (73 robustness)
    llu:AKJ09_10905 (212 target-flexibility) (73 robustness)
    mbd:MEBOL_000129 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_000749 (790 target-flexibility) (134 robustness)
    mbd:MEBOL_002196 (222 target-flexibility) (83 robustness)
    mbd:MEBOL_003759 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_003801 (222 target-flexibility) (83 robustness)
    mbd:MEBOL_003822 (80 target-flexibility) (80 robustness)
    mbd:MEBOL_004362 (790 target-flexibility) (134 robustness)
    mbd:MEBOL_004563 (732 target-flexibility) (78 robustness)
    mbd:MEBOL_004893 (796 target-flexibility) (85 robustness)
    mbd:MEBOL_005080 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_005988 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006001 (71 target-flexibility) (71 robustness)
    mbd:MEBOL_006836 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006837 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_006840 (897 target-flexibility) (71 robustness)
    mbd:MEBOL_007627 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_007700 (138 target-flexibility) (66 robustness)
    mbd:MEBOL_007910 (212 target-flexibility) (73 robustness)
    mbd:MEBOL_007979 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_008059 (0 target-flexibility) (0 robustness)
    mbd:MEBOL_008079 (752 target-flexibility) (76 robustness)
    mfu:LILAB_01860 (796 target-flexibility) (85 robustness)
    mfu:LILAB_03115 (732 target-flexibility) (78 robustness)
    mfu:LILAB_06720 (80 target-flexibility) (80 robustness)
    mfu:LILAB_06880 (222 target-flexibility) (83 robustness)
    mfu:LILAB_07065 (0 target-flexibility) (0 robustness)
    mfu:LILAB_15365 (222 target-flexibility) (83 robustness)
    mfu:LILAB_24705 (1385 target-flexibility) (204 robustness)
    mfu:LILAB_25505 (0 target-flexibility) (0 robustness)
    mfu:LILAB_25510 (0 target-flexibility) (0 robustness)
    mfu:LILAB_28080 (0 target-flexibility) (0 robustness)
    mfu:LILAB_28305 (0 target-flexibility) (0 robustness)
    mfu:LILAB_30430 (212 target-flexibility) (73 robustness)
    mfu:LILAB_31010 (0 target-flexibility) (0 robustness)
    mfu:LILAB_31365 (752 target-flexibility) (76 robustness)
    mfu:LILAB_31605 (71 target-flexibility) (71 robustness)
    mfu:LILAB_31675 (0 target-flexibility) (0 robustness)
    mfu:LILAB_35480 (70 target-flexibility) (70 robustness)
    mfu:LILAB_35505 (67 target-flexibility) (67 robustness)
    mmas:MYMAC_000346 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_000385 (222 target-flexibility) (83 robustness)
    mmas:MYMAC_000432 (80 target-flexibility) (80 robustness)
    mmas:MYMAC_001135 (732 target-flexibility) (78 robustness)
    mmas:MYMAC_001379 (796 target-flexibility) (85 robustness)
    mmas:MYMAC_003338 (1385 target-flexibility) (204 robustness)
    mmas:MYMAC_003448 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003449 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003905 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_003947 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_004501 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_004575 (752 target-flexibility) (76 robustness)
    mmas:MYMAC_004629 (71 target-flexibility) (71 robustness)
    mmas:MYMAC_004643 (0 target-flexibility) (0 robustness)
    mmas:MYMAC_005398 (70 target-flexibility) (70 robustness)
    mmas:MYMAC_005403 (67 target-flexibility) (67 robustness)
    mmas:MYMAC_005404 (239 target-flexibility) (67 robustness)
    mmas:MYMAC_005959 (222 target-flexibility) (83 robustness)
    mrm:A7982_02481 (0 target-flexibility) (0 robustness)
    mrm:A7982_02519 (790 target-flexibility) (134 robustness)
    mrm:A7982_02611 (222 target-flexibility) (83 robustness)
    mrm:A7982_02766 (0 target-flexibility) (0 robustness)
    mrm:A7982_05402 (0 target-flexibility) (0 robustness)
    mrm:A7982_06955 (289 target-flexibility) (73 robustness)
    mrm:A7982_07040 (212 target-flexibility) (73 robustness)
    mrm:A7982_07443 (0 target-flexibility) (0 robustness)
    mrm:A7982_08337 (790 target-flexibility) (134 robustness)
    mrm:A7982_09042 (0 target-flexibility) (0 robustness)
    mrm:A7982_09160 (0 target-flexibility) (0 robustness)
    mrm:A7982_09221 (434 target-flexibility) (67 robustness)
    mrm:A7982_09539 (790 target-flexibility) (134 robustness)
    mrm:A7982_09715 (80 target-flexibility) (80 robustness)
    mrm:A7982_10056 (0 target-flexibility) (0 robustness)
    mrm:A7982_10954 (0 target-flexibility) (0 robustness)
    msd:MYSTI_00373 (222 target-flexibility) (83 robustness)
    msd:MYSTI_00991 (790 target-flexibility) (134 robustness)
    msd:MYSTI_01146 (732 target-flexibility) (78 robustness)
    msd:MYSTI_01404 (796 target-flexibility) (85 robustness)
    msd:MYSTI_01655 (0 target-flexibility) (0 robustness)
    msd:MYSTI_01751 (0 target-flexibility) (0 robustness)
    msd:MYSTI_02961 (790 target-flexibility) (134 robustness)
    msd:MYSTI_03928 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04466 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04467 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04815 (0 target-flexibility) (0 robustness)
    msd:MYSTI_04946 (212 target-flexibility) (73 robustness)
    msd:MYSTI_05067 (0 target-flexibility) (0 robustness)
    msd:MYSTI_05093 (1169 target-flexibility) (76 robustness)
    msd:MYSTI_05139 (752 target-flexibility) (76 robustness)
    msd:MYSTI_05188 (71 target-flexibility) (71 robustness)
    msd:MYSTI_05203 (0 target-flexibility) (0 robustness)
    msd:MYSTI_06468 (790 target-flexibility) (134 robustness)
    msd:MYSTI_06805 (222 target-flexibility) (83 robustness)
    msd:MYSTI_06833 (1041 target-flexibility) (243 robustness)
    mxa:MXAN_0318 (0 target-flexibility) (0 robustness)
    mxa:MXAN_0358 (222 target-flexibility) (83 robustness)
    mxa:MXAN_0395 (80 target-flexibility) (80 robustness)
    mxa:MXAN_0501 (796 target-flexibility) (85 robustness)
    mxa:MXAN_0949 (790 target-flexibility) (134 robustness)
    mxa:MXAN_1103 (732 target-flexibility) (78 robustness)
    mxa:MXAN_1283 (434 target-flexibility) (67 robustness)
    mxa:MXAN_1386 (796 target-flexibility) (85 robustness)
    mxa:MXAN_1528 (0 target-flexibility) (0 robustness)
    mxa:MXAN_3506 (0 target-flexibility) (0 robustness)
    mxa:MXAN_3507 (0 target-flexibility) (0 robustness)
    mxa:MXAN_3537 (289 target-flexibility) (73 robustness)
    mxa:MXAN_3987 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4051 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4460 (212 target-flexibility) (73 robustness)
    mxa:MXAN_4613 (0 target-flexibility) (0 robustness)
    mxa:MXAN_4684 (752 target-flexibility) (76 robustness)
    mxa:MXAN_4731 (71 target-flexibility) (71 robustness)
    mxa:MXAN_4745 (0 target-flexibility) (0 robustness)
    mxa:MXAN_5608 (67 target-flexibility) (67 robustness)
    mxa:MXAN_5609 (239 target-flexibility) (67 robustness)
    mxa:MXAN_6220 (222 target-flexibility) (83 robustness)
    mym:A176_000682 (222 target-flexibility) (83 robustness)
    mym:A176_001499 (0 target-flexibility) (0 robustness)
    mym:A176_002147 (0 target-flexibility) (0 robustness)
    mym:A176_002161 (71 target-flexibility) (71 robustness)
    mym:A176_002210 (752 target-flexibility) (76 robustness)
    mym:A176_002255 (1169 target-flexibility) (76 robustness)
    mym:A176_002284 (0 target-flexibility) (0 robustness)
    mym:A176_002437 (212 target-flexibility) (73 robustness)
    mym:A176_002926 (0 target-flexibility) (0 robustness)
    mym:A176_003407 (0 target-flexibility) (0 robustness)
    mym:A176_003408 (0 target-flexibility) (0 robustness)
    mym:A176_003863 (1041 target-flexibility) (243 robustness)
    mym:A176_005454 (0 target-flexibility) (0 robustness)
    mym:A176_005616 (796 target-flexibility) (85 robustness)
    mym:A176_005864 (732 target-flexibility) (78 robustness)
    mym:A176_006029 (790 target-flexibility) (134 robustness)
    mym:A176_006642 (222 target-flexibility) (83 robustness)
    mym:A176_007563 (0 target-flexibility) (0 robustness)
    pace:A6070_01880 (796 target-flexibility) (85 robustness)
    pace:A6070_02940 (222 target-flexibility) (83 robustness)
    pace:A6070_03240 (138 target-flexibility) (66 robustness)
    pace:A6070_03835 (212 target-flexibility) (73 robustness)
    pace:A6070_04260 (239 target-flexibility) (67 robustness)
    pace:A6070_04265 (67 target-flexibility) (67 robustness)
    pace:A6070_04975 (71 target-flexibility) (71 robustness)
    pace:A6070_05385 (732 target-flexibility) (78 robustness)
    pace:A6070_05790 (0 target-flexibility) (0 robustness)
    pace:A6070_06035 (0 target-flexibility) (0 robustness)
    pace:A6070_06075 (0 target-flexibility) (0 robustness)
    pace:A6070_06120 (0 target-flexibility) (0 robustness)
    pace:A6070_06815 (1169 target-flexibility) (76 robustness)
    pace:A6070_07185 (897 target-flexibility) (71 robustness)
    pace:A6070_10090 (752 target-flexibility) (76 robustness)
    pace:A6070_12850 (0 target-flexibility) (0 robustness)
    pace:A6070_13195 (0 target-flexibility) (0 robustness)
    pace:A6070_13200 (0 target-flexibility) (0 robustness)
    pace:A6070_13365 (1041 target-flexibility) (243 robustness)
    pace:A6070_14665 (80 target-flexibility) (80 robustness)
    pca:Pcar_0266 (80 target-flexibility) (80 robustness)
    pca:Pcar_1040 (752 target-flexibility) (76 robustness)
    pca:Pcar_1248 (71 target-flexibility) (71 robustness)
    pca:Pcar_1326 (732 target-flexibility) (78 robustness)
    pca:Pcar_1413 (0 target-flexibility) (0 robustness)
    pca:Pcar_1460 (0 target-flexibility) (0 robustness)
    pca:Pcar_1467 (0 target-flexibility) (0 robustness)
    pca:Pcar_1615 (897 target-flexibility) (71 robustness)
    pca:Pcar_1667 (1169 target-flexibility) (76 robustness)
    pca:Pcar_1804 (0 target-flexibility) (0 robustness)
    pca:Pcar_1805 (796 target-flexibility) (85 robustness)
    pca:Pcar_1807 (0 target-flexibility) (0 robustness)
    pca:Pcar_2206 (67 target-flexibility) (67 robustness)
    pca:Pcar_2207 (239 target-flexibility) (67 robustness)
    pca:Pcar_2315 (212 target-flexibility) (73 robustness)
    pca:Pcar_2415 (138 target-flexibility) (66 robustness)
    pca:Pcar_2455 (222 target-flexibility) (83 robustness)
    pca:Pcar_2593 (0 target-flexibility) (0 robustness)
    pca:Pcar_2684 (0 target-flexibility) (0 robustness)
    pca:Pcar_2685 (0 target-flexibility) (0 robustness)
    pca:Pcar_2719 (1041 target-flexibility) (243 robustness)
    pca:Pcar_2933 (796 target-flexibility) (85 robustness)
    pef:A7E78_00350 (0 target-flexibility) (0 robustness)
    pef:A7E78_01045 (0 target-flexibility) (0 robustness)
    pef:A7E78_01330 (71 target-flexibility) (71 robustness)
    pef:A7E78_01430 (0 target-flexibility) (0 robustness)
    pef:A7E78_02400 (0 target-flexibility) (0 robustness)
    pef:A7E78_02600 (732 target-flexibility) (78 robustness)
    pef:A7E78_02750 (1169 target-flexibility) (76 robustness)
    pef:A7E78_02985 (897 target-flexibility) (71 robustness)
    pef:A7E78_03875 (0 target-flexibility) (0 robustness)
    pef:A7E78_04875 (434 target-flexibility) (67 robustness)
    pef:A7E78_05895 (752 target-flexibility) (76 robustness)
    pef:A7E78_05905 (289 target-flexibility) (73 robustness)
    pef:A7E78_06630 (212 target-flexibility) (73 robustness)
    pef:A7E78_08220 (0 target-flexibility) (0 robustness)
    pef:A7E78_08225 (0 target-flexibility) (0 robustness)
    pef:A7E78_11150 (1041 target-flexibility) (243 robustness)
    pef:A7E78_11715 (796 target-flexibility) (85 robustness)
    pef:A7E78_13520 (222 target-flexibility) (83 robustness)
    pef:A7E78_13795 (138 target-flexibility) (66 robustness)
    ppd:Ppro_1177 (0 target-flexibility) (0 robustness)
    ppd:Ppro_1580 (212 target-flexibility) (73 robustness)
    ppd:Ppro_1725 (405 target-flexibility) (70 robustness)
    ppd:Ppro_1731 (0 target-flexibility) (0 robustness)
    ppd:Ppro_2098 (0 target-flexibility) (0 robustness)
    ppd:Ppro_2329 (752 target-flexibility) (76 robustness)
    ppd:Ppro_2529 (897 target-flexibility) (71 robustness)
    ppd:Ppro_2666 (80 target-flexibility) (80 robustness)
    ppd:Ppro_2973 (0 target-flexibility) (0 robustness)
    ppd:Ppro_3014 (71 target-flexibility) (71 robustness)
    ppd:Ppro_3055 (0 target-flexibility) (0 robustness)
    ppd:Ppro_3056 (0 target-flexibility) (0 robustness)
    ppd:Ppro_3172 (138 target-flexibility) (66 robustness)
    ppd:Ppro_3288 (70 target-flexibility) (70 robustness)
    ppd:Ppro_3293 (67 target-flexibility) (67 robustness)
    ppd:Ppro_3294 (239 target-flexibility) (67 robustness)
    ppd:Ppro_3406 (0 target-flexibility) (0 robustness)
    ppd:Ppro_3484 (357 target-flexibility) (102 robustness)
    ppd:Ppro_3596 (222 target-flexibility) (83 robustness)
    pprf:DPRO_0151 (434 target-flexibility) (67 robustness)
    pprf:DPRO_0163 (0 target-flexibility) (0 robustness)
    pprf:DPRO_0799 (528 target-flexibility) (157 robustness)
    pprf:DPRO_0802 (222 target-flexibility) (83 robustness)
    pprf:DPRO_1333 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1336 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1432 (0 target-flexibility) (0 robustness)
    pprf:DPRO_1502 (790 target-flexibility) (134 robustness)
    pprf:DPRO_1657 (80 target-flexibility) (80 robustness)
    pprf:DPRO_1802 (790 target-flexibility) (134 robustness)
    pprf:DPRO_1945 (0 target-flexibility) (0 robustness)
    pprf:DPRO_2174 (790 target-flexibility) (134 robustness)
    pprf:DPRO_2470 (212 target-flexibility) (73 robustness)
    pprf:DPRO_2602 (0 target-flexibility) (0 robustness)
    pprf:DPRO_2879 (289 target-flexibility) (73 robustness)
    pprf:DPRO_2976 (358 target-flexibility) (104 robustness)
    samy:DB32_001023 (752 target-flexibility) (76 robustness)
    samy:DB32_001708 (434 target-flexibility) (67 robustness)
    samy:DB32_002852 (0 target-flexibility) (0 robustness)
    samy:DB32_003553 (212 target-flexibility) (73 robustness)
    samy:DB32_003678 (289 target-flexibility) (73 robustness)
    samy:DB32_003711 (0 target-flexibility) (0 robustness)
    samy:DB32_003728 (222 target-flexibility) (83 robustness)
    samy:DB32_003841 (0 target-flexibility) (0 robustness)
    samy:DB32_003842 (0 target-flexibility) (0 robustness)
    samy:DB32_004135 (0 target-flexibility) (0 robustness)
    samy:DB32_004322 (0 target-flexibility) (0 robustness)
    samy:DB32_004445 (239 target-flexibility) (67 robustness)
    samy:DB32_004448 (140 target-flexibility) (71 robustness)
    samy:DB32_005205 (434 target-flexibility) (67 robustness)
    samy:DB32_005406 (71 target-flexibility) (71 robustness)
    samy:DB32_006581 (0 target-flexibility) (0 robustness)
    samy:DB32_007268 (790 target-flexibility) (134 robustness)
    sat:SYN_00075 (358 target-flexibility) (104 robustness)
    sat:SYN_00446 (528 target-flexibility) (157 robustness)
    sat:SYN_00583 (80 target-flexibility) (80 robustness)
    sat:SYN_00761 (0 target-flexibility) (0 robustness)
    sat:SYN_01112 (0 target-flexibility) (0 robustness)
    sat:SYN_01125 (0 target-flexibility) (0 robustness)
    sat:SYN_01130 (0 target-flexibility) (0 robustness)
    sat:SYN_01223 (790 target-flexibility) (134 robustness)
    sat:SYN_01253 (528 target-flexibility) (157 robustness)
    sat:SYN_01451 (0 target-flexibility) (0 robustness)
    sat:SYN_01454 (222 target-flexibility) (83 robustness)
    sat:SYN_01532 (897 target-flexibility) (71 robustness)
    sat:SYN_01740 (239 target-flexibility) (67 robustness)
    sat:SYN_01742 (67 target-flexibility) (67 robustness)
    sat:SYN_01747 (70 target-flexibility) (70 robustness)
    sat:SYN_02156 (138 target-flexibility) (66 robustness)
    sat:SYN_02374 (0 target-flexibility) (0 robustness)
    sat:SYN_02563 (0 target-flexibility) (0 robustness)
    sat:SYN_02635 (790 target-flexibility) (134 robustness)
    sat:SYN_02640 (0 target-flexibility) (0 robustness)
    sat:SYN_02643 (0 target-flexibility) (0 robustness)
    sat:SYN_02661 (0 target-flexibility) (0 robustness)
    sat:SYN_02866 (0 target-flexibility) (0 robustness)
    sat:SYN_02886 (212 target-flexibility) (73 robustness)
    sat:SYN_03128 (0 target-flexibility) (0 robustness)
    scl:sce0693 (0 target-flexibility) (0 robustness)
    scl:sce2813 (0 target-flexibility) (0 robustness)
    scl:sce4236 (222 target-flexibility) (83 robustness)
    scl:sce4320 (732 target-flexibility) (78 robustness)
    scl:sce5134 (212 target-flexibility) (73 robustness)
    scl:sce5886 (0 target-flexibility) (0 robustness)
    scl:sce7407 (796 target-flexibility) (85 robustness)
    scl:sce7417 (0 target-flexibility) (0 robustness)
    scl:sce7927 (790 target-flexibility) (134 robustness)
    scl:sce8012 (0 target-flexibility) (0 robustness)
    scl:sce9167 (80 target-flexibility) (80 robustness)
    sfu:Sfum_0007 (732 target-flexibility) (78 robustness)
    sfu:Sfum_0062 (138 target-flexibility) (66 robustness)
    sfu:Sfum_0108 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0122 (222 target-flexibility) (83 robustness)
    sfu:Sfum_0179 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0192 (212 target-flexibility) (73 robustness)
    sfu:Sfum_0478 (358 target-flexibility) (104 robustness)
    sfu:Sfum_0483 (0 target-flexibility) (0 robustness)
    sfu:Sfum_0745 (790 target-flexibility) (134 robustness)
    sfu:Sfum_1215 (0 target-flexibility) (0 robustness)
    sfu:Sfum_1302 (1041 target-flexibility) (243 robustness)
    sfu:Sfum_1418 (1169 target-flexibility) (76 robustness)
    sfu:Sfum_1608 (80 target-flexibility) (80 robustness)
    sfu:Sfum_2084 (0 target-flexibility) (0 robustness)
    sfu:Sfum_2090 (897 target-flexibility) (71 robustness)
    sfu:Sfum_2264 (0 target-flexibility) (0 robustness)
    sfu:Sfum_2580 (796 target-flexibility) (85 robustness)
    sfu:Sfum_2681 (528 target-flexibility) (157 robustness)
    sfu:Sfum_2989 (434 target-flexibility) (67 robustness)
    sfu:Sfum_3031 (434 target-flexibility) (67 robustness)
    sfu:Sfum_3365 (752 target-flexibility) (76 robustness)
    sfu:Sfum_3454 (790 target-flexibility) (134 robustness)
    sfu:Sfum_3692 (0 target-flexibility) (0 robustness)
    sfu:Sfum_3719 (0 target-flexibility) (0 robustness)
    sfu:Sfum_3742 (71 target-flexibility) (71 robustness)
    sfu:Sfum_3896 (289 target-flexibility) (73 robustness)
    sur:STAUR_0056 (1041 target-flexibility) (243 robustness)
    sur:STAUR_0531 (212 target-flexibility) (73 robustness)
    sur:STAUR_1671 (732 target-flexibility) (78 robustness)
    sur:STAUR_2146 (796 target-flexibility) (85 robustness)
    sur:STAUR_2302 (0 target-flexibility) (0 robustness)
    sur:STAUR_3279 (0 target-flexibility) (0 robustness)
    sur:STAUR_3296 (790 target-flexibility) (134 robustness)
    sur:STAUR_3549 (0 target-flexibility) (0 robustness)
    sur:STAUR_4027 (0 target-flexibility) (0 robustness)
    sur:STAUR_4028 (0 target-flexibility) (0 robustness)
    sur:STAUR_4050 (289 target-flexibility) (73 robustness)
    sur:STAUR_4815 (212 target-flexibility) (73 robustness)
    sur:STAUR_4874 (434 target-flexibility) (67 robustness)
    sur:STAUR_5425 (1169 target-flexibility) (76 robustness)
    sur:STAUR_5486 (752 target-flexibility) (76 robustness)
    sur:STAUR_5581 (71 target-flexibility) (71 robustness)
    sur:STAUR_5595 (0 target-flexibility) (0 robustness)
    sur:STAUR_5774 (222 target-flexibility) (83 robustness)
    sur:STAUR_6266 (67 target-flexibility) (67 robustness)
    sur:STAUR_6267 (239 target-flexibility) (67 robustness)
    sur:STAUR_7055 (790 target-flexibility) (134 robustness)
    sur:STAUR_8101 (80 target-flexibility) (80 robustness)
    sur:STAUR_8129 (222 target-flexibility) (83 robustness)
    sur:STAUR_8226 (0 target-flexibility) (0 robustness)
    vin:AKJ08_0051 (732 target-flexibility) (78 robustness)
    vin:AKJ08_0163 (138 target-flexibility) (66 robustness)
    vin:AKJ08_0731 (1041 target-flexibility) (243 robustness)
    vin:AKJ08_0977 (0 target-flexibility) (0 robustness)
    vin:AKJ08_1190 (222 target-flexibility) (83 robustness)
    vin:AKJ08_1262 (1169 target-flexibility) (76 robustness)
    vin:AKJ08_1405 (289 target-flexibility) (73 robustness)
    vin:AKJ08_1411 (897 target-flexibility) (71 robustness)
    vin:AKJ08_1417 (0 target-flexibility) (0 robustness)
    vin:AKJ08_1882 (434 target-flexibility) (67 robustness)
    vin:AKJ08_2065 (212 target-flexibility) (73 robustness)
    vin:AKJ08_2249 (70 target-flexibility) (70 robustness)
    vin:AKJ08_2252 (140 target-flexibility) (71 robustness)
    vin:AKJ08_2254 (67 target-flexibility) (67 robustness)
    vin:AKJ08_2255 (239 target-flexibility) (67 robustness)
    vin:AKJ08_2528 (796 target-flexibility) (85 robustness)
    vin:AKJ08_2627 (0 target-flexibility) (0 robustness)
    vin:AKJ08_3214 (222 target-flexibility) (83 robustness)
    
    Target-flexibility contribution: 39.14994391125514%
    Robustness contribution: 15.106568615231211%
    

Conclusion
----------
15% of robust enzymes have at least one neofunctionales enzyme on one of their alternative paths.
39% of target-flexible enzymes have at least one neofunctionales enzyme on one of their alternative paths. Due to the definition of flexible, this means that they have an edge leading away from at least one of their products, which belongs to a neofunctionalised enzyme.

This does not answer the question whether an enzyme would not be robust/flexible if the neofunctionalised enzymes did not exist!
"""

from FEV_KEGG.KEGG.File import cache
from FEV_KEGG.Evolution.Clade import Clade
from FEV_KEGG.Statistics import Percent
from FEV_KEGG.Robustness.Topology.Redundancy import Redundancy, RedundancyContribution, RedundancyType

@cache(folder_path='experiments', file_name='deltaproteobacteria_clade')
def getCladeA():
    clade = Clade('Deltaproteobacteria')
    # pre-fetch collective metabolism into memory
    clade.collectiveMetabolism(excludeMultifunctionalEnzymes=True)
    # pre-fetch collective enzyme metabolism into memory
    clade.collectiveMetabolismEnzymes(excludeMultifunctionalEnzymes=True)
    return clade

if __name__ == '__main__':

    output = []
    
    #- get Deltaproteobacteria
    cladeA = getCladeA()
    majorityPercentageCoreMetabolism = 80
    output.append( 'core metabolism majority: ' + str(majorityPercentageCoreMetabolism) + '%' )
    output.append('')
    output.append(', '.join(cladeA.ncbiNames) + ':')
    output.append('')
    cladeAEnzymeGraph = cladeA.coreMetabolismEnzymes(majorityPercentageCoreMetabolism)
    cladeAenzymeCount = len(cladeAEnzymeGraph.getEnzymes())
    output.append( 'core metabolism enzymes: ' + str(cladeAenzymeCount) )
    output.append('')
    
    #- get neofunctionalised enzymes
    cladeANeofunctionalisedEnzymesSet = cladeA.neofunctionalisedEnzymes(majorityPercentageCoreMetabolism).getEnzymes()
       
    cladeASortedList = list(cladeANeofunctionalisedEnzymesSet)
    cladeASortedList.sort()
    
    #- calculate redundancy
    cladeARedundancy = Redundancy(cladeAEnzymeGraph)
    cladeARedundancyContribution = RedundancyContribution(cladeARedundancy, cladeANeofunctionalisedEnzymesSet)
    cladeARobustEnzymesForGeneDuplicatedEnzyme = cladeARedundancyContribution.getContributedKeysForSpecial(RedundancyType.ROBUSTNESS)
    cladeAFlexibleEnzymesForGeneDuplicatedEnzyme = cladeARedundancyContribution.getContributedKeysForSpecial(RedundancyType.TARGET_FLEXIBILITY)
    
    #- REPEAT for each neofunctionalised enzyme
    output.append( 'neofunctionalised enzymes: ' + str(len(cladeASortedList)) + ' (' + str(Percent.getPercentStringShort(len(cladeASortedList), cladeAenzymeCount, 0)) + '%)' )
    for enzyme in cladeASortedList:
        #-     print number of enzymes the neofunctionalised enzyme provides redundancy for (robustness and flexibility)
        output.append( str(enzyme)  + ' (' + str(len(cladeAFlexibleEnzymesForGeneDuplicatedEnzyme.get(enzyme, []))) + ' target-flexibility) (' + str(len(cladeARobustEnzymesForGeneDuplicatedEnzyme.get(enzyme, []))) + ' robustness)')
    
    output.append('')
    output.append( 'Target-flexibility contribution: ' + str(cladeARedundancyContribution.getKeyContributionRatio(RedundancyType.TARGET_FLEXIBILITY) * 100) + '%' )
    output.append( 'Robustness contribution: ' + str(cladeARedundancyContribution.getKeyContributionRatio(RedundancyType.ROBUSTNESS) * 100) + '%' )
    
    
    
    
    
    
    for line in output:
        print( line )
